# 宿易管(StayEase) - 景区民宿发展管理系统

宿易管(StayEase)是一个专为景区民宿设计的综合管理系统，旨在提供全方位的民宿运营管理解决方案。系统包含房源管理、预订管理、会员管理、财务管理等多个功能模块，帮助民宿经营者提高管理效率，优化客户体验。

## 系统要求

- PHP 7.1+
- MySQL 8.0+
- Web服务器 (Apache/Nginx)
- 现代浏览器 (Chrome, Firefox, Safari, Edge)

## 安装说明

### 1. 环境准备

确保您的服务器已安装PHP 7.1+和MySQL 8.0+。

### 2. 下载代码

将系统代码下载到您的Web服务器目录中。

### 3. 配置数据库

1. 创建一个新的MySQL数据库
2. 执行`install.php`文件安装数据库
3. 修改`config/config.php`文件中的数据库连接信息

```php
// 数据库配置
define('DB_HOST', 'localhost'); // 数据库主机
define('DB_USER', 'root');      // 数据库用户名
define('DB_PASS', '');          // 数据库密码
define('DB_NAME', 'stayease');  // 数据库名称
```

### 4. 配置Web服务器

确保您的Web服务器指向系统的根目录，并且PHP有足够的权限访问系统文件。

### 5. 访问系统

通过浏览器访问系统地址，使用默认管理员账号登录：

- 用户名: admin
- 密码: admin

首次登录后，请立即修改默认密码以确保系统安全。

## 系统架构

```
StayEase/
├── assets/                  # 静态资源文件
│   ├── css/                 # CSS样式文件
│   ├── js/                  # JavaScript文件
│   └── images/              # 图片资源
├── config/                  # 配置文件
│   └── config.php           # 系统配置
├── includes/                # 公共包含文件
│   └── functions.php        # 通用函数
├── modules/                 # 功能模块
│   ├── room_management/     # 房源与房态管理
│   ├── booking_management/  # 预订与订单管理
│   ├── member_management/   # 会员与客户管理
│   ├── finance_management/  # 财务管理
│   ├── supply_management/   # 供应链与库存管理
│   ├── property_management/ # 物业与设备管理
│   ├── reception_management/# 智能前台管理
│   ├── marketing/           # 营销与推广
│   ├── tourism_service/     # 旅游服务与增值业务
│   ├── data_analysis/       # 数据分析与报表
│   └── system_management/   # 系统管理
├── index.php                # 入口文件
├── login.php                # 登录页面
├── logout.php               # 退出登录
├── home.php                 # 主页
├── StayEase.sql             # 数据库文件
├── install.php              # 安装文件
├── set.php               # 安装成功后的提示文件
└── README.md                # 说明文档
```

## 功能模块

系统包含以下主要功能模块：

1. **房源与房态管理**
   - 房源登记与管理
   - 房间状态管理
   - 房型管理
   - 智能定价
   - 房态一览表

2. **预订与订单管理**
   - 在线预订
   - 多渠道订单整合
   - 订单管理
   - 预订日历
   - 团队/长租订单
   - 自动确认与提醒

3. **会员与客户管理**
   - 会员注册/登录
   - 客户档案管理
   - 会员等级制度
   - 积分系统
   - 客户评价与反馈

4. **财务管理**
   - 房费与押金管理
   - 账单管理
   - 收入与支出统计
   - 退款管理
   - OTA平台结算对接

5. **供应链与库存管理**
   - 客房用品库存
   - 餐饮库存
   - 清洁用品库存
   - 库存预警
   - 供应商管理

6. **物业与设备管理**
   - 客房保洁安排
   - 设备报修
   - 能耗管理
   - 安全巡查记录

7. **智能前台管理**
   - 自助入住/退房
   - 电子门锁管理
   - 人脸识别
   - 入住登记上传公安系统
   - 电子发票

8. **营销与推广**
   - 促销活动
   - 推荐返利
   - 积分兑换
   - 社交媒体分享
   - 短信/微信营销

9. **旅游服务与增值业务**
   - 景区门票预订
   - 租车服务
   - 本地导游
   - 特色活动

10. **数据分析与报表**
    - 房间入住率分析
    - 客户来源分析
    - 营收趋势分析
    - 客户偏好分析
    - 运营成本分析

11. **系统管理**
    - 管理员管理
    - 日志管理
    - 系统备份与恢复

## 使用指南

### 登录系统

1. 访问系统登录页面
2. 输入用户名和密码
3. 点击"登录"按钮

### 主页导航

登录成功后，您将进入系统主页，可以看到所有功能模块的入口。点击相应的模块卡片进入对应的功能页面。

### 模块操作

每个功能模块都有统一的界面布局：
- 左侧为导航菜单，显示当前模块的各项功能
- 右侧为功能区，显示当前选中功能的内容
- 点击导航菜单中的功能项，右侧功能区将显示相应的内容

### 退出系统

点击页面右上角的"退出登录"按钮，安全退出系统。

## 安全建议

1. 定期修改管理员密码
2. 及时更新系统
3. 定期备份数据库
4. 控制用户权限，遵循最小权限原则
5. 使用HTTPS加密传输数据

## 技术支持

如有任何问题或需要技术支持，请联系系统管理员。

## 版权信息

© 2023 宿易管(StayEase) - 版权所有 