-- StayEase 景区民宿发展管理系统数据库
-- -- 创建数据库
-- CREATE DATABASE IF NOT EXISTS stayease DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

-- -- 使用数据库
-- USE stayease;

-- 用户表
CREATE TABLE IF NOT EXISTS users (
    id INT AUTO_INCREMENT PRIMARY KEY,
    username VARCHAR(50) NOT NULL UNIQUE,
    password VARCHAR(255) NOT NULL,
    name VARCHAR(100) NOT NULL,
    role ENUM('admin', 'manager', 'staff', 'receptionist') NOT NULL,
    email VARCHAR(100),
    phone VARCHAR(20),
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    last_login DATETIME,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 房型表
CREATE TABLE IF NOT EXISTS room_types (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    description TEXT,
    capacity INT NOT NULL,
    base_price DECIMAL(10, 2) NOT NULL,
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 房间表
CREATE TABLE IF NOT EXISTS rooms (
    id INT AUTO_INCREMENT PRIMARY KEY,
    room_number VARCHAR(20) NOT NULL UNIQUE,
    room_type_id INT NOT NULL,
    floor VARCHAR(10) NOT NULL,
    area DECIMAL(8, 2),
    bed_type VARCHAR(50),
    has_window BOOLEAN DEFAULT TRUE,
    has_bathroom BOOLEAN DEFAULT TRUE,
    amenities TEXT,
    description TEXT,
    price_adjustment DECIMAL(10, 2) DEFAULT 0.00,
    status ENUM('available', 'booked', 'occupied', 'maintenance') NOT NULL DEFAULT 'available',
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (room_type_id) REFERENCES room_types(id) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 房间图片表
CREATE TABLE IF NOT EXISTS room_images (
    id INT AUTO_INCREMENT PRIMARY KEY,
    room_id INT NOT NULL,
    image_path VARCHAR(255) NOT NULL,
    is_primary BOOLEAN DEFAULT FALSE,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (room_id) REFERENCES rooms(id) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 价格策略表
CREATE TABLE IF NOT EXISTS price_strategies (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    description TEXT,
    start_date DATE NOT NULL,
    end_date DATE NOT NULL,
    adjustment_type ENUM('percentage', 'fixed') NOT NULL,
    adjustment_value DECIMAL(10, 2) NOT NULL,
    room_type_id INT,
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (room_type_id) REFERENCES room_types(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 会员表
CREATE TABLE IF NOT EXISTS members (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    phone VARCHAR(20) NOT NULL UNIQUE,
    email VARCHAR(100),
    id_type ENUM(
        'id_card',
        'passport',
        'driving_license',
        'other'
    ) NOT NULL,
    id_number VARCHAR(50) NOT NULL,
    gender ENUM('male', 'female', 'other') NOT NULL,
    birthday DATE,
    address TEXT,
    level ENUM('regular', 'silver', 'gold', 'platinum') NOT NULL DEFAULT 'regular',
    points INT NOT NULL DEFAULT 0,
    registration_date DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    last_stay_date DATE,
    total_stays INT NOT NULL DEFAULT 0,
    total_spent DECIMAL(12, 2) NOT NULL DEFAULT 0.00,
    notes TEXT,
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 积分历史表
CREATE TABLE IF NOT EXISTS point_history (
    id INT AUTO_INCREMENT PRIMARY KEY,
    member_id INT NOT NULL,
    points_change INT NOT NULL,
    change_type ENUM('add', 'deduct') NOT NULL,
    reason VARCHAR(255) NOT NULL,
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (member_id) REFERENCES members(id) ON DELETE CASCADE,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 预订表
CREATE TABLE IF NOT EXISTS bookings (
    id INT AUTO_INCREMENT PRIMARY KEY,
    booking_number VARCHAR(20) NOT NULL UNIQUE,
    member_id INT,
    guest_name VARCHAR(100) NOT NULL,
    guest_phone VARCHAR(20) NOT NULL,
    guest_email VARCHAR(100),
    guest_id_type ENUM(
        'id_card',
        'passport',
        'driving_license',
        'other'
    ) NOT NULL,
    guest_id_number VARCHAR(50) NOT NULL,
    check_in_date DATE NOT NULL,
    check_out_date DATE NOT NULL,
    adults INT NOT NULL DEFAULT 1,
    children INT NOT NULL DEFAULT 0,
    special_requests TEXT,
    booking_source ENUM(
        'direct',
        'website',
        'phone',
        'email',
        'ota',
        'walk_in'
    ) NOT NULL,
    ota_name VARCHAR(50),
    ota_booking_id VARCHAR(50),
    status ENUM(
        'pending',
        'confirmed',
        'checked_in',
        'checked_out',
        'cancelled',
        'no_show'
    ) NOT NULL DEFAULT 'pending',
    total_amount DECIMAL(12, 2) NOT NULL,
    deposit_amount DECIMAL(12, 2) DEFAULT 0.00,
    payment_status ENUM('unpaid', 'partially_paid', 'paid') NOT NULL DEFAULT 'unpaid',
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (member_id) REFERENCES members(id) ON DELETE
    SET
        NULL,
        FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 预订房间关联表
CREATE TABLE IF NOT EXISTS booking_rooms (
    id INT AUTO_INCREMENT PRIMARY KEY,
    booking_id INT NOT NULL,
    room_id INT NOT NULL,
    room_rate DECIMAL(10, 2) NOT NULL,
    date_from DATE NOT NULL,
    date_to DATE NOT NULL,
    status ENUM(
        'booked',
        'checked_in',
        'checked_out',
        'cancelled'
    ) NOT NULL DEFAULT 'booked',
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (booking_id) REFERENCES bookings(id) ON DELETE CASCADE,
    FOREIGN KEY (room_id) REFERENCES rooms(id) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 支付记录表
CREATE TABLE IF NOT EXISTS payments (
    id INT AUTO_INCREMENT PRIMARY KEY,
    booking_id INT NOT NULL,
    amount DECIMAL(12, 2) NOT NULL,
    payment_method ENUM(
        'cash',
        'credit_card',
        'debit_card',
        'bank_transfer',
        'alipay',
        'wechat_pay',
        'other'
    ) NOT NULL,
    transaction_id VARCHAR(100),
    payment_date DATETIME NOT NULL,
    notes TEXT,
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (booking_id) REFERENCES bookings(id) ON DELETE CASCADE,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 发票表
CREATE TABLE IF NOT EXISTS invoices (
    id INT AUTO_INCREMENT PRIMARY KEY,
    booking_id INT NOT NULL,
    invoice_number VARCHAR(50) NOT NULL UNIQUE,
    invoice_type ENUM('personal', 'company') NOT NULL,
    invoice_title VARCHAR(100) NOT NULL,
    tax_number VARCHAR(50),
    amount DECIMAL(12, 2) NOT NULL,
    issue_date DATETIME NOT NULL,
    status ENUM('pending', 'issued', 'cancelled') NOT NULL DEFAULT 'pending',
    notes TEXT,
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (booking_id) REFERENCES bookings(id) ON DELETE CASCADE,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 库存分类表
CREATE TABLE IF NOT EXISTS inventory_categories (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    description TEXT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 库存物品表
CREATE TABLE IF NOT EXISTS inventory_items (
    id INT AUTO_INCREMENT PRIMARY KEY,
    category_id INT NOT NULL,
    name VARCHAR(100) NOT NULL,
    description TEXT,
    unit VARCHAR(20) NOT NULL,
    current_quantity INT NOT NULL DEFAULT 0,
    minimum_quantity INT NOT NULL DEFAULT 0,
    cost_per_unit DECIMAL(10, 2) NOT NULL,
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (category_id) REFERENCES inventory_categories(id) ON DELETE RESTRICT
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 库存交易记录表
CREATE TABLE IF NOT EXISTS inventory_transactions (
    id INT AUTO_INCREMENT PRIMARY KEY,
    item_id INT NOT NULL,
    transaction_type ENUM(
        'purchase',
        'consumption',
        'adjustment',
        'return'
    ) NOT NULL,
    quantity INT NOT NULL,
    unit_price DECIMAL(10, 2),
    total_price DECIMAL(12, 2),
    transaction_date DATETIME NOT NULL,
    notes TEXT,
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (item_id) REFERENCES inventory_items(id) ON DELETE RESTRICT,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 供应商表
CREATE TABLE IF NOT EXISTS suppliers (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    contact_person VARCHAR(100),
    phone VARCHAR(20) NOT NULL,
    email VARCHAR(100),
    address TEXT,
    product_categories TEXT,
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    notes TEXT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 设备表
CREATE TABLE IF NOT EXISTS equipments (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    category VARCHAR(50) NOT NULL,
    location VARCHAR(100) NOT NULL,
    purchase_date DATE,
    purchase_price DECIMAL(12, 2),
    warranty_end_date DATE,
    maintenance_cycle INT,
    -- 以天为单位
    last_maintenance_date DATE,
    next_maintenance_date DATE,
    status ENUM(
        'operational',
        'maintenance',
        'broken',
        'retired'
    ) NOT NULL DEFAULT 'operational',
    notes TEXT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 维修记录表
CREATE TABLE IF NOT EXISTS maintenance_records (
    id INT AUTO_INCREMENT PRIMARY KEY,
    equipment_id INT,
    room_id INT,
    issue_description TEXT NOT NULL,
    reported_by INT,
    reported_date DATETIME NOT NULL,
    assigned_to INT,
    priority ENUM('low', 'medium', 'high', 'urgent') NOT NULL DEFAULT 'medium',
    status ENUM(
        'reported',
        'assigned',
        'in_progress',
        'completed',
        'cancelled'
    ) NOT NULL DEFAULT 'reported',
    start_date DATETIME,
    completion_date DATETIME,
    solution TEXT,
    cost DECIMAL(10, 2),
    notes TEXT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (equipment_id) REFERENCES equipments(id) ON DELETE
    SET
        NULL,
        FOREIGN KEY (room_id) REFERENCES rooms(id) ON DELETE
    SET
        NULL,
        FOREIGN KEY (reported_by) REFERENCES users(id) ON DELETE
    SET
        NULL,
        FOREIGN KEY (assigned_to) REFERENCES users(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 清洁任务表
CREATE TABLE IF NOT EXISTS cleaning_tasks (
    id INT AUTO_INCREMENT PRIMARY KEY,
    room_id INT NOT NULL,
    scheduled_date DATE NOT NULL,
    scheduled_time TIME,
    assigned_to INT,
    status ENUM(
        'pending',
        'in_progress',
        'completed',
        'verified',
        'cancelled'
    ) NOT NULL DEFAULT 'pending',
    priority ENUM('normal', 'high', 'urgent') NOT NULL DEFAULT 'normal',
    notes TEXT,
    start_time DATETIME,
    end_time DATETIME,
    verified_by INT,
    verification_time DATETIME,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (room_id) REFERENCES rooms(id) ON DELETE CASCADE,
    FOREIGN KEY (assigned_to) REFERENCES users(id) ON DELETE
    SET
        NULL,
        FOREIGN KEY (verified_by) REFERENCES users(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 能耗记录表
CREATE TABLE IF NOT EXISTS utility_usage (
    id INT AUTO_INCREMENT PRIMARY KEY,
    utility_type ENUM('electricity', 'water', 'gas', 'other') NOT NULL,
    reading_date DATE NOT NULL,
    meter_reading DECIMAL(12, 2) NOT NULL,
    consumption DECIMAL(12, 2),
    cost DECIMAL(12, 2),
    notes TEXT,
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 促销活动表
CREATE TABLE IF NOT EXISTS promotions (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    description TEXT,
    promotion_type ENUM('discount', 'package', 'gift', 'points', 'other') NOT NULL,
    discount_type ENUM('percentage', 'fixed_amount') DEFAULT NULL,
    discount_value DECIMAL(10, 2) DEFAULT NULL,
    start_date DATE NOT NULL,
    end_date DATE NOT NULL,
    applicable_room_types TEXT,
    -- 存储适用房型ID，用逗号分隔
    min_stay_nights INT DEFAULT NULL,
    min_booking_amount DECIMAL(12, 2) DEFAULT NULL,
    usage_limit INT DEFAULT NULL,
    used_count INT NOT NULL DEFAULT 0,
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 旅游服务表
CREATE TABLE IF NOT EXISTS tourism_services (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    category ENUM(
        'ticket',
        'transport',
        'guide',
        'activity',
        'other'
    ) NOT NULL,
    description TEXT,
    price DECIMAL(10, 2) NOT NULL,
    commission_rate DECIMAL(5, 2) DEFAULT 0.00,
    provider VARCHAR(100),
    contact_info TEXT,
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 旅游服务预订表
CREATE TABLE IF NOT EXISTS tourism_bookings (
    id INT AUTO_INCREMENT PRIMARY KEY,
    service_id INT NOT NULL,
    booking_id INT,
    member_id INT,
    guest_name VARCHAR(100) NOT NULL,
    guest_phone VARCHAR(20) NOT NULL,
    service_date DATE NOT NULL,
    service_time TIME,
    quantity INT NOT NULL DEFAULT 1,
    total_price DECIMAL(12, 2) NOT NULL,
    payment_status ENUM('unpaid', 'paid', 'refunded') NOT NULL DEFAULT 'unpaid',
    status ENUM('pending', 'confirmed', 'completed', 'cancelled') NOT NULL DEFAULT 'pending',
    notes TEXT,
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (service_id) REFERENCES tourism_services(id) ON DELETE RESTRICT,
    FOREIGN KEY (booking_id) REFERENCES bookings(id) ON DELETE
    SET
        NULL,
        FOREIGN KEY (member_id) REFERENCES members(id) ON DELETE
    SET
        NULL,
        FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 系统日志表
CREATE TABLE IF NOT EXISTS system_logs (
    id INT AUTO_INCREMENT PRIMARY KEY,
    user_id INT,
    action VARCHAR(100) NOT NULL,
    description TEXT,
    ip_address VARCHAR(45),
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE
    SET
        NULL
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 插入初始管理员用户
-- 密码: admin (已使用password_hash加密)
INSERT INTO
    users (
        username,
        password,
        name,
        role,
        email,
        phone,
        status
    )
VALUES
    (
        'admin',
        '$2y$10$7DOsBGGPYLrOYejhj07BbOmC4pq1gFp0qImybWTD4iX3pVnaACUMa',
        '系统管理员',
        'admin',
        'admin@stayease.com',
        '13800138000',
        'active'
    );

-- 插入初始房型数据
INSERT INTO
    room_types (name, description, capacity, base_price, status)
VALUES
    ('单人间', '舒适的单人房间，配备单人床', 1, 188.00, 'active'),
    ('标准双人间', '标准双人房间，配备两张单人床', 2, 268.00, 'active'),
    ('豪华双人间', '豪华双人房间，配备一张大床', 2, 328.00, 'active'),
    (
        '家庭房',
        '宽敞的家庭房，配备一张大床和两张单人床',
        4,
        468.00,
        'active'
    ),
    ('主题房', '特色主题装修房间，提供独特的住宿体验', 2, 398.00, 'active'),
    (
        '露营帐篷',
        '户外露营体验，配备舒适床垫和露营设备',
        2,
        158.00,
        'active'
    );

-- 插入初始库存分类
INSERT INTO
    inventory_categories (name, description)
VALUES
    ('客房用品', '床单、被套、枕头等客房必备用品'),
    ('洗漱用品', '洗发水、沐浴露、牙刷等洗漱用品'),
    ('清洁用品', '清洁剂、洗涤剂、垃圾袋等清洁用品'),
    ('餐饮用品', '早餐食材、饮料、零食等餐饮用品'),
    ('办公用品', '纸张、笔、文件夹等办公用品');

-- 插入初始促销活动
INSERT INTO
    promotions (
        name,
        description,
        promotion_type,
        discount_type,
        discount_value,
        start_date,
        end_date,
        applicable_room_types,
        min_stay_nights,
        status,
        created_by
    )
VALUES
    (
        '开业特惠',
        '民宿开业特惠活动，所有房型享受8折优惠',
        'discount',
        'percentage',
        20.00,
        CURDATE(),
        DATE_ADD(CURDATE(), INTERVAL 30 DAY),
        '1,2,3,4,5,6',
        1,
        'active',
        1
    ),
    (
        '长住优惠',
        '连续入住3晚及以上享受85折优惠',
        'discount',
        'percentage',
        15.00,
        CURDATE(),
        DATE_ADD(CURDATE(), INTERVAL 90 DAY),
        '1,2,3,4',
        3,
        'active',
        1
    );

-- 插入初始旅游服务
INSERT INTO
    tourism_services (
        name,
        category,
        description,
        price,
        commission_rate,
        provider,
        status
    )
VALUES
    (
        '景区A门票',
        'ticket',
        '著名景区A的门票，含景区内交通',
        120.00,
        10.00,
        '本地旅游局',
        'active'
    ),
    (
        '景区B门票',
        'ticket',
        '著名景区B的门票',
        80.00,
        10.00,
        '本地旅游局',
        'active'
    ),
    (
        '电动车租赁',
        'transport',
        '电动车租赁服务，方便游客出行',
        50.00,
        20.00,
        '本地租车公司',
        'active'
    ),
    (
        '徒步向导',
        'guide',
        '专业向导带领游客徒步探索自然风光',
        200.00,
        15.00,
        '本地导游协会',
        'active'
    ),
    (
        '篝火晚会',
        'activity',
        '民宿组织的篝火晚会活动，含烧烤',
        100.00,
        0.00,
        '自营',
        'active'
    );