<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前年月
$year = isset($_GET['year']) ? (int)$_GET['year'] : (int)date('Y');
$month = isset($_GET['month']) ? (int)$_GET['month'] : (int)date('m');

// 获取房型列表
$roomTypesSql = "SELECT * FROM room_types ORDER BY name";
$roomTypesResult = $conn->query($roomTypesSql);
$roomTypes = [];
if ($roomTypesResult && $roomTypesResult->num_rows > 0) {
    while ($row = $roomTypesResult->fetch_assoc()) {
        $roomTypes[] = $row;
    }
}

// 获取所有房间
$roomsSql = "SELECT r.*, rt.name as room_type 
             FROM rooms r 
             JOIN room_types rt ON r.room_type_id = rt.id 
             ORDER BY r.floor, r.room_number";
$roomsResult = $conn->query($roomsSql);
$rooms = [];
if ($roomsResult && $roomsResult->num_rows > 0) {
    while ($row = $roomsResult->fetch_assoc()) {
        $rooms[] = $row;
    }
}

// 获取当月预订信息
$startDate = date('Y-m-01', strtotime("$year-$month-01"));
$endDate = date('Y-m-t', strtotime("$year-$month-01"));
$bookingsSql = "SELECT b.*, br.room_id, r.room_number, r.floor, rt.name as room_type 
                FROM bookings b 
                JOIN booking_rooms br ON b.id = br.booking_id 
                JOIN rooms r ON br.room_id = r.id 
                JOIN room_types rt ON r.room_type_id = rt.id 
                WHERE (b.check_in_date BETWEEN ? AND ? 
                OR b.check_out_date BETWEEN ? AND ?)
                AND b.status NOT IN ('cancelled', 'no_show')";
$bookingsStmt = $conn->prepare($bookingsSql);
$bookingsStmt->bind_param("ssss", $startDate, $endDate, $startDate, $endDate);
$bookingsStmt->execute();
$bookingsResult = $bookingsStmt->get_result();
$bookings = [];
if ($bookingsResult && $bookingsResult->num_rows > 0) {
    while ($row = $bookingsResult->fetch_assoc()) {
        $bookings[] = $row;
    }
}

// 生成日历数据
$daysInMonth = date('t', strtotime("$year-$month-01"));
$firstDayOfWeek = date('N', strtotime("$year-$month-01"));
$calendar = [];
$week = array_fill(0, 7, null);
$dayCount = 1;

// 填充第一周的空白日期
for ($i = 1; $i < $firstDayOfWeek; $i++) {
    $week[$i - 1] = null;
}

// 填充日期
for ($i = $firstDayOfWeek - 1; $i < 7; $i++) {
    if ($dayCount <= $daysInMonth) {
        $week[$i] = $dayCount++;
    }
}
$calendar[] = $week;

// 填充剩余周
while ($dayCount <= $daysInMonth) {
    $week = array_fill(0, 7, null);
    for ($i = 0; $i < 7 && $dayCount <= $daysInMonth; $i++) {
        $week[$i] = $dayCount++;
    }
    $calendar[] = $week;
}

// 计算房间占用率
$occupancyStats = [];
$totalRooms = count($rooms);
for ($day = 1; $day <= $daysInMonth; $day++) {
    $currentDate = date('Y-m-d', strtotime("$year-$month-$day"));
    $occupiedRooms = 0;

    foreach ($bookings as $booking) {
        $checkIn = strtotime($booking['check_in_date']);
        $checkOut = strtotime($booking['check_out_date']);
        $current = strtotime($currentDate);

        if ($current >= $checkIn && $current < $checkOut) {
            $occupiedRooms++;
        }
    }

    $occupancyStats[$day] = [
        'occupied' => $occupiedRooms,
        'available' => $totalRooms - $occupiedRooms,
        'rate' => $totalRooms > 0 ? round(($occupiedRooms / $totalRooms) * 100, 1) : 0
    ];
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>预订日历</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <span>预订日历</span>
        </nav>
    </div>

    <div class="calendar-controls">
        <div class="month-selector">
            <?php
            $prevMonth = $month - 1;
            $prevYear = $year;
            if ($prevMonth < 1) {
                $prevMonth = 12;
                $prevYear--;
            }

            $nextMonth = $month + 1;
            $nextYear = $year;
            if ($nextMonth > 12) {
                $nextMonth = 1;
                $nextYear++;
            }
            ?>
            <a href="?page=booking_calendar&year=<?php echo $prevYear; ?>&month=<?php echo $prevMonth; ?>" class="btn btn-secondary">&lt; 上月</a>
            <span class="current-month"><?php echo $year; ?>年<?php echo $month; ?>月</span>
            <a href="?page=booking_calendar&year=<?php echo $nextYear; ?>&month=<?php echo $nextMonth; ?>" class="btn btn-secondary">下月 &gt;</a>
        </div>

        <div class="view-controls">
            <button class="btn btn-primary" onclick="toggleView('calendar')">日历视图</button>
            <button class="btn btn-secondary" onclick="toggleView('list')">列表视图</button>
        </div>

        <div class="filter-controls">
            <select id="roomTypeFilter" onchange="filterCalendar()">
                <option value="">所有房型</option>
                <?php foreach ($roomTypes as $type): ?>
                    <option value="<?php echo $type['id']; ?>"><?php echo htmlspecialchars($type['name']); ?></option>
                <?php endforeach; ?>
            </select>

            <select id="floorFilter" onchange="filterCalendar()">
                <option value="">所有楼层</option>
                <?php
                $floors = array_unique(array_column($rooms, 'floor'));
                sort($floors);
                foreach ($floors as $floor):
                ?>
                    <option value="<?php echo $floor; ?>"><?php echo $floor; ?>楼</option>
                <?php endforeach; ?>
            </select>
        </div>
    </div>

    <div class="occupancy-stats">
        <div class="stats-header">
            <h3>入住率统计</h3>
            <div class="stats-legend">
                <span class="legend-item">
                    <span class="color-box high"></span> 高（≥80%）
                </span>
                <span class="legend-item">
                    <span class="color-box medium"></span> 中（50-79%）
                </span>
                <span class="legend-item">
                    <span class="color-box low"></span> 低（＜50%）
                </span>
            </div>
        </div>
        <div class="stats-grid">
            <?php for ($day = 1; $day <= $daysInMonth; $day++): ?>
                <?php
                $rate = $occupancyStats[$day]['rate'];
                $rateClass = $rate >= 80 ? 'high' : ($rate >= 50 ? 'medium' : 'low');
                ?>
                <div class="stats-day <?php echo $rateClass; ?>">
                    <div class="day-number"><?php echo $day; ?></div>
                    <div class="occupancy-rate"><?php echo $rate; ?>%</div>
                    <div class="room-count">
                        <span class="occupied"><?php echo $occupancyStats[$day]['occupied']; ?></span>/
                        <span class="total"><?php echo $totalRooms; ?></span>
                    </div>
                </div>
            <?php endfor; ?>
        </div>
    </div>

    <div id="calendarView" class="calendar-container">
        <table class="calendar">
            <thead>
                <tr>
                    <th>房间信息</th>
                    <?php for ($i = 1; $i <= $daysInMonth; $i++): ?>
                        <th><?php echo $i; ?></th>
                    <?php endfor; ?>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($rooms as $room): ?>
                    <tr class="room-row" data-room-type="<?php echo $room['room_type_id']; ?>" data-floor="<?php echo $room['floor']; ?>">
                        <td class="room-info">
                            <div class="room-number"><?php echo htmlspecialchars($room['room_number']); ?></div>
                            <div class="room-type"><?php echo htmlspecialchars($room['room_type']); ?></div>
                            <div class="room-floor"><?php echo htmlspecialchars($room['floor']); ?>楼</div>
                        </td>
                        <?php for ($day = 1; $day <= $daysInMonth; $day++): ?>
                            <?php
                            $currentDate = "$year-$month-" . str_pad($day, 2, '0', STR_PAD_LEFT);
                            $cellStatus = 'available';
                            $bookingInfo = null;

                            foreach ($bookings as $booking) {
                                if ($booking['room_id'] == $room['id']) {
                                    $checkIn = strtotime($booking['check_in_date']);
                                    $checkOut = strtotime($booking['check_out_date']);
                                    $current = strtotime($currentDate);

                                    if ($current >= $checkIn && $current < $checkOut) {
                                        $cellStatus = $booking['status'];
                                        $bookingInfo = $booking;
                                        break;
                                    }
                                }
                            }
                            ?>
                            <td class="calendar-cell <?php echo $cellStatus; ?>"
                                <?php if ($bookingInfo): ?>
                                data-booking-id="<?php echo $bookingInfo['id']; ?>"
                                onclick="showBookingDetails(<?php echo $bookingInfo['id']; ?>)"
                                <?php else: ?>
                                onclick="createBooking('<?php echo $currentDate; ?>', <?php echo $room['id']; ?>)"
                                <?php endif; ?>>
                                <div class="cell-content">
                                    <?php if ($bookingInfo): ?>
                                        <div class="booking-info">
                                            <span class="guest-name"><?php echo htmlspecialchars($bookingInfo['guest_name']); ?></span>
                                            <span class="booking-number"><?php echo htmlspecialchars($bookingInfo['booking_number']); ?></span>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </td>
                        <?php endfor; ?>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

    <div id="listView" class="list-container" style="display: none;">
        <table class="data-table">
            <thead>
                <tr>
                    <th>预订号</th>
                    <th>客人</th>
                    <th>房间</th>
                    <th>入住日期</th>
                    <th>退房日期</th>
                    <th>状态</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($bookings as $booking): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($booking['booking_number']); ?></td>
                        <td><?php echo htmlspecialchars($booking['guest_name']); ?></td>
                        <td>
                            <?php echo htmlspecialchars($booking['room_number']); ?>
                            (<?php echo htmlspecialchars($booking['room_type']); ?>)
                        </td>
                        <td><?php echo date('Y-m-d', strtotime($booking['check_in_date'])); ?></td>
                        <td><?php echo date('Y-m-d', strtotime($booking['check_out_date'])); ?></td>
                        <td>
                            <span class="status-badge status-<?php echo $booking['status']; ?>">
                                <?php
                                switch ($booking['status']) {
                                    case 'pending_payment':
                                        echo '待付款';
                                        break;
                                    case 'confirmed':
                                        echo '已确认';
                                        break;
                                    case 'checked_in':
                                        echo '已入住';
                                        break;
                                    case 'checked_out':
                                        echo '已退房';
                                        break;
                                    default:
                                        echo htmlspecialchars($booking['status']);
                                }
                                ?>
                            </span>
                        </td>
                        <td>
                            <a href="index.php?page=booking_view&id=<?php echo $booking['id']; ?>" class="btn btn-sm btn-primary">查看</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<!-- 预订详情弹窗 -->
<div id="bookingDetailsModal" class="modal">
    <div class="modal-content">
        <div class="modal-header">
            <h4>预订详情</h4>
            <span class="close">&times;</span>
        </div>
        <div class="modal-body">
            <div id="bookingDetailsContent"></div>
        </div>
    </div>
</div>

<style>
    .calendar-container {
        overflow-x: auto;
        margin-top: 20px;
    }

    .calendar {
        width: 100%;
        border-collapse: collapse;
        background: #fff;
    }

    .calendar th,
    .calendar td {
        border: 1px solid #ddd;
        padding: 8px;
        text-align: center;
        min-width: 40px;
    }

    .calendar th {
        background: #f8f9fa;
        position: sticky;
        top: 0;
        z-index: 1;
    }

    .room-info {
        position: sticky;
        left: 0;
        background: #fff;
        min-width: 120px;
        z-index: 2;
    }

    .room-number {
        font-weight: bold;
        color: #0066cc;
    }

    .room-type {
        font-size: 12px;
        color: #666;
    }

    .room-floor {
        font-size: 12px;
        color: #999;
    }

    .calendar-cell {
        position: relative;
        height: 40px;
        cursor: pointer;
    }

    .calendar-cell:hover {
        background-color: rgba(0, 0, 0, 0.05);
    }

    .calendar-cell.available {
        background: #d4edda;
    }

    .calendar-cell.pending_payment {
        background: #fff3cd;
    }

    .calendar-cell.confirmed {
        background: #cce5ff;
    }

    .calendar-cell.checked_in {
        background: #e2e3e5;
    }

    .booking-info {
        font-size: 11px;
        line-height: 1.2;
    }

    .guest-name {
        display: block;
        font-weight: bold;
    }

    .booking-number {
        display: block;
        color: #666;
    }

    .calendar-controls {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin: 20px 0;
        flex-wrap: wrap;
        gap: 10px;
    }

    .month-selector {
        display: flex;
        align-items: center;
        gap: 20px;
    }

    .current-month {
        font-size: 18px;
        font-weight: bold;
    }

    .view-controls,
    .filter-controls {
        display: flex;
        gap: 10px;
    }

    .occupancy-stats {
        margin: 20px 0;
        padding: 15px;
        background: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .stats-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 15px;
    }

    .stats-legend {
        display: flex;
        gap: 15px;
    }

    .legend-item {
        display: flex;
        align-items: center;
        gap: 5px;
    }

    .color-box {
        width: 15px;
        height: 15px;
        border-radius: 3px;
    }

    .color-box.high {
        background-color: #dc3545;
    }

    .color-box.medium {
        background-color: #ffc107;
    }

    .color-box.low {
        background-color: #28a745;
    }

    .stats-grid {
        display: grid;
        grid-template-columns: repeat(auto-fill, minmax(80px, 1fr));
        gap: 10px;
    }

    .stats-day {
        padding: 10px;
        border-radius: 4px;
        text-align: center;
    }

    .stats-day.high {
        background-color: rgba(220, 53, 69, 0.1);
    }

    .stats-day.medium {
        background-color: rgba(255, 193, 7, 0.1);
    }

    .stats-day.low {
        background-color: rgba(40, 167, 69, 0.1);
    }

    .day-number {
        font-weight: bold;
        font-size: 16px;
    }

    .occupancy-rate {
        font-size: 14px;
        color: #666;
    }

    .room-count {
        font-size: 12px;
        color: #999;
    }

    .modal {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
        z-index: 1000;
    }

    .modal-content {
        position: relative;
        background-color: #fff;
        margin: 10% auto;
        padding: 20px;
        width: 80%;
        max-width: 600px;
        border-radius: 8px;
    }

    .close {
        position: absolute;
        right: 20px;
        top: 20px;
        font-size: 24px;
        cursor: pointer;
    }

    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
    }

    .status-pending_payment {
        background-color: #fff3cd;
        color: #856404;
    }

    .status-confirmed {
        background-color: #d4edda;
        color: #155724;
    }

    .status-checked_in {
        background-color: #cce5ff;
        color: #004085;
    }

    .status-checked_out {
        background-color: #e2e3e5;
        color: #383d41;
    }

    @media (max-width: 768px) {
        .calendar-controls {
            flex-direction: column;
            align-items: stretch;
        }

        .month-selector {
            justify-content: center;
        }

        .view-controls,
        .filter-controls {
            justify-content: center;
        }
    }
</style>

<script>
    function toggleView(view) {
        const calendarView = document.getElementById('calendarView');
        const listView = document.getElementById('listView');

        if (view === 'calendar') {
            calendarView.style.display = 'block';
            listView.style.display = 'none';
        } else {
            calendarView.style.display = 'none';
            listView.style.display = 'block';
        }
    }

    function filterCalendar() {
        const roomTypeFilter = document.getElementById('roomTypeFilter').value;
        const floorFilter = document.getElementById('floorFilter').value;
        const rows = document.querySelectorAll('.room-row');

        rows.forEach(row => {
            const roomType = row.dataset.roomType;
            const floor = row.dataset.floor;
            let show = true;

            if (roomTypeFilter && roomType !== roomTypeFilter) {
                show = false;
            }

            if (floorFilter && floor !== floorFilter) {
                show = false;
            }

            row.style.display = show ? '' : 'none';
        });
    }

    function showBookingDetails(bookingId) {
        // 获取预订详情
        fetch(`index.php?page=booking_view&id=${bookingId}&format=json`)
            .then(response => response.json())
            .then(data => {
                const modal = document.getElementById('bookingDetailsModal');
                const content = document.getElementById('bookingDetailsContent');

                // 构建详情HTML
                let html = `
                <div class="booking-details">
                    <h4>预订号：${data.booking_number}</h4>
                    <p>客人：${data.guest_name}</p>
                    <p>联系电话：${data.guest_phone}</p>
                    <p>入住日期：${data.check_in_date}</p>
                    <p>退房日期：${data.check_out_date}</p>
                    <p>状态：${data.status}</p>
                    <div class="booking-actions">
                        <a href="index.php?page=booking_view&id=${data.id}" class="btn btn-primary">查看详情</a>
                    </div>
                </div>
            `;

                content.innerHTML = html;
                modal.style.display = 'block';
            });
    }

    function createBooking(date, roomId) {
        window.location.href = `index.php?page=booking_add&date=${date}&room_id=${roomId}`;
    }

    // 关闭模态框
    document.querySelector('.close').onclick = function() {
        document.getElementById('bookingDetailsModal').style.display = 'none';
    }

    window.onclick = function(event) {
        const modal = document.getElementById('bookingDetailsModal');
        if (event.target == modal) {
            modal.style.display = 'none';
        }
    }
</script>