<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 处理删除预订
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $bookingId = (int)$_GET['id'];

    // 检查预订是否存在
    $checkSql = "SELECT booking_number FROM bookings WHERE id = ?";
    $checkStmt = $conn->prepare($checkSql);
    $checkStmt->bind_param("i", $bookingId);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows > 0) {
        $bookingNumber = $checkResult->fetch_assoc()['booking_number'];

        // 删除预订房间关联
        $deleteRoomsSql = "DELETE FROM booking_rooms WHERE booking_id = ?";
        $deleteRoomsStmt = $conn->prepare($deleteRoomsSql);
        $deleteRoomsStmt->bind_param("i", $bookingId);
        $deleteRoomsStmt->execute();

        // 删除预订
        $deleteSql = "DELETE FROM bookings WHERE id = ?";
        $deleteStmt = $conn->prepare($deleteSql);
        $deleteStmt->bind_param("i", $bookingId);

        if ($deleteStmt->execute()) {
            // 记录操作日志
            logActivity('delete_booking', '删除预订: ' . $bookingNumber);

            // 设置成功消息
            $_SESSION['success_message'] = '预订删除成功';
        } else {
            $_SESSION['error_message'] = '删除预订失败: ' . $conn->error;
        }
    } else {
        $_SESSION['error_message'] = '预订不存在';
    }

    // 重定向回列表页
    header('Location: index.php?page=booking_list');
    exit;
}

// 处理更新预订状态
if (isset($_GET['action']) && $_GET['action'] == 'update_status' && isset($_GET['id']) && isset($_GET['status'])) {
    $bookingId = (int)$_GET['id'];
    $newStatus = sanitize($_GET['status']);

    // 验证状态值
    $validStatuses = ['pending', 'confirmed', 'checked_in', 'checked_out', 'cancelled', 'no_show'];
    if (!in_array($newStatus, $validStatuses)) {
        $_SESSION['error_message'] = '无效的状态值';
    } else {
        // 获取预订信息
        $getSql = "SELECT booking_number FROM bookings WHERE id = ?";
        $getStmt = $conn->prepare($getSql);
        $getStmt->bind_param("i", $bookingId);
        $getStmt->execute();
        $getResult = $getStmt->get_result();

        if ($getResult->num_rows === 0) {
            $_SESSION['error_message'] = '预订不存在';
        } else {
            $bookingNumber = $getResult->fetch_assoc()['booking_number'];

            // 更新预订状态
            $updateSql = "UPDATE bookings SET status = ? WHERE id = ?";
            $updateStmt = $conn->prepare($updateSql);
            $updateStmt->bind_param("si", $newStatus, $bookingId);

            if ($updateStmt->execute()) {
                // 记录操作日志
                logActivity('update_booking_status', '更新预订状态: ' . $bookingNumber . ' - ' . $newStatus);

                // 设置成功消息
                $_SESSION['success_message'] = '预订状态更新成功';
            } else {
                $_SESSION['error_message'] = '更新预订状态失败: ' . $conn->error;
            }
        }
    }

    // 重定向回列表页
    header('Location: index.php?page=booking_list');
    exit;
}

// 设置分页参数
$page = isset($_GET['p']) ? (int)$_GET['p'] : 1;
$perPage = 10;
$offset = ($page - 1) * $perPage;

// 获取筛选条件
$statusFilter = isset($_GET['status']) ? sanitize($_GET['status']) : '';
$sourceFilter = isset($_GET['booking_source']) ? sanitize($_GET['booking_source']) : '';
$searchTerm = isset($_GET['search']) ? sanitize($_GET['search']) : '';
$dateFrom = isset($_GET['date_from']) ? sanitize($_GET['date_from']) : '';
$dateTo = isset($_GET['date_to']) ? sanitize($_GET['date_to']) : '';

// 构建查询条件
$conditions = [];
$params = [];
$types = '';

if (!empty($statusFilter)) {
    $conditions[] = "b.status = ?";
    $params[] = $statusFilter;
    $types .= 's';
}

if (!empty($sourceFilter)) {
    $conditions[] = "b.booking_source = ?";
    $params[] = $sourceFilter;
    $types .= 's';
}

if (!empty($searchTerm)) {
    $conditions[] = "(b.booking_number LIKE ? OR b.guest_name LIKE ? OR b.guest_phone LIKE ? OR b.guest_email LIKE ?)";
    $searchParam = "%$searchTerm%";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $types .= 'ssss';
}

if (!empty($dateFrom)) {
    $conditions[] = "b.check_in_date >= ?";
    $params[] = $dateFrom;
    $types .= 's';
}

if (!empty($dateTo)) {
    $conditions[] = "b.check_out_date <= ?";
    $params[] = $dateTo;
    $types .= 's';
}

// 构建WHERE子句
$whereClause = '';
if (!empty($conditions)) {
    $whereClause = "WHERE " . implode(" AND ", $conditions);
}

// 获取总记录数
$countSql = "SELECT COUNT(*) as total FROM bookings b $whereClause";
$countStmt = $conn->prepare($countSql);

if (!empty($params)) {
    $countStmt->bind_param($types, ...$params);
}

$countStmt->execute();
$totalRecords = $countStmt->get_result()->fetch_assoc()['total'];
$totalPages = ceil($totalRecords / $perPage);

// 获取预订列表
$sql = "SELECT b.*, 
        (SELECT COUNT(*) FROM booking_rooms WHERE booking_id = b.id) as room_count 
        FROM bookings b 
        $whereClause 
        ORDER BY b.created_at DESC 
        LIMIT ?, ?";

$stmt = $conn->prepare($sql);

if (!empty($params)) {
    $params[] = $offset;
    $params[] = $perPage;
    $types .= 'ii';
    $stmt->bind_param($types, ...$params);
} else {
    $stmt->bind_param("ii", $offset, $perPage);
}

$stmt->execute();
$result = $stmt->get_result();
$bookings = [];

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $bookings[] = $row;
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>订单列表</h2>
        <div class="page-actions">
            <a href="index.php?page=booking_add" class="btn btn-primary">添加预订</a>
        </div>
    </div>

    <?php if (isset($_SESSION['success_message'])): ?>
        <div class="alert alert-success">
            <?php
            echo $_SESSION['success_message'];
            unset($_SESSION['success_message']);
            ?>
        </div>
    <?php endif; ?>

    <?php if (isset($_SESSION['error_message'])): ?>
        <div class="alert alert-error">
            <?php
            echo $_SESSION['error_message'];
            unset($_SESSION['error_message']);
            ?>
        </div>
    <?php endif; ?>

    <!-- 筛选表单 -->
    <div class="filter-form-container">
        <form method="get" action="" class="filter-form">
            <input type="hidden" name="page" value="booking_list">

            <div class="form-row">
                <div class="form-group">
                    <input type="text" name="search" placeholder="搜索预订号/客人姓名/电话/邮箱" value="<?php echo htmlspecialchars($searchTerm); ?>">
                </div>

                <div class="form-group">
                    <select name="status">
                        <option value="">所有状态</option>
                        <option value="pending" <?php echo $statusFilter == 'pending' ? 'selected' : ''; ?>>待支付</option>
                        <option value="confirmed" <?php echo $statusFilter == 'confirmed' ? 'selected' : ''; ?>>已确认</option>
                        <option value="checked_in" <?php echo $statusFilter == 'checked_in' ? 'selected' : ''; ?>>已入住</option>
                        <option value="checked_out" <?php echo $statusFilter == 'checked_out' ? 'selected' : ''; ?>>已完成</option>
                        <option value="cancelled" <?php echo $statusFilter == 'cancelled' ? 'selected' : ''; ?>>已取消</option>
                        <option value="no_show" <?php echo $statusFilter == 'no_show' ? 'selected' : ''; ?>>未入住</option>
                    </select>
                </div>

                <div class="form-group">
                    <select name="booking_source">
                        <option value="">所有来源</option>
                        <option value="direct" <?php echo $sourceFilter == 'direct' ? 'selected' : ''; ?>>直接预订</option>
                        <option value="website" <?php echo $sourceFilter == 'website' ? 'selected' : ''; ?>>官网</option>
                        <option value="phone" <?php echo $sourceFilter == 'phone' ? 'selected' : ''; ?>>电话</option>
                        <option value="email" <?php echo $sourceFilter == 'email' ? 'selected' : ''; ?>>邮件</option>
                        <option value="walk_in" <?php echo $sourceFilter == 'walk_in' ? 'selected' : ''; ?>>门店</option>
                        <option value="ota" <?php echo $sourceFilter == 'ota' ? 'selected' : ''; ?>>OTA平台</option>
                    </select>
                </div>
            </div>

            <div class="form-row">
                <div class="form-group">
                    <label for="date_from">入住日期从</label>
                    <input type="date" id="date_from" name="date_from" value="<?php echo htmlspecialchars($dateFrom); ?>">
                </div>

                <div class="form-group">
                    <label for="date_to">到</label>
                    <input type="date" id="date_to" name="date_to" value="<?php echo htmlspecialchars($dateTo); ?>">
                </div>

                <div class="form-group form-actions">
                    <button type="submit" class="btn btn-primary">筛选</button>
                    <a href="index.php?page=booking_list" class="btn btn-secondary">重置</a>
                </div>
            </div>
        </form>
    </div>

    <!-- 预订列表 -->
    <div class="table-responsive">
        <table class="data-table">
            <thead>
                <tr>
                    <th>预订号</th>
                    <th>客人姓名</th>
                    <th>联系方式</th>
                    <th>入住日期</th>
                    <th>退房日期</th>
                    <th>房间数</th>
                    <th>总金额</th>
                    <th>来源</th>
                    <th>状态</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($bookings)): ?>
                    <tr>
                        <td colspan="10" class="text-center">暂无预订数据</td>
                    </tr>
                <?php else: ?>
                    <?php foreach ($bookings as $booking): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($booking['booking_number']); ?></td>
                            <td><?php echo htmlspecialchars($booking['guest_name']); ?></td>
                            <td>
                                <?php echo htmlspecialchars($booking['guest_phone']); ?><br>
                                <small><?php echo htmlspecialchars($booking['guest_email']); ?></small>
                            </td>
                            <td><?php echo date('Y-m-d', strtotime($booking['check_in_date'])); ?></td>
                            <td><?php echo date('Y-m-d', strtotime($booking['check_out_date'])); ?></td>
                            <td><?php echo $booking['room_count']; ?></td>
                            <td>¥<?php echo number_format($booking['total_amount'], 2); ?></td>
                            <td>
                                <?php
                                switch ($booking['booking_source']) {
                                    case 'direct':
                                        echo '直接预订';
                                        break;
                                    case 'website':
                                        echo '官网';
                                        break;
                                    case 'phone':
                                        echo '电话';
                                        break;
                                    case 'email':
                                        echo '邮件';
                                        break;
                                    case 'walk_in':
                                        echo '门店';
                                        break;
                                    case 'ota':
                                        echo 'OTA平台';
                                        break;
                                    default:
                                        echo htmlspecialchars($booking['booking_source']);
                                }
                                ?>
                            </td>
                            <td>
                                <span class="status-badge status-<?php echo $booking['status']; ?>">
                                    <?php
                                    switch ($booking['status']) {
                                        case 'pending':
                                            echo '待支付';
                                            break;
                                        case 'confirmed':
                                            echo '已确认';
                                            break;
                                        case 'checked_in':
                                            echo '已入住';
                                            break;
                                        case 'checked_out':
                                            echo '已完成';
                                            break;
                                        case 'cancelled':
                                            echo '已取消';
                                            break;
                                        case 'no_show':
                                            echo '未入住';
                                            break;
                                        default:
                                            echo $booking['status'];
                                    }
                                    ?>
                                </span>
                            </td>
                            <td class="actions">
                                <div class="dropdown">
                                    <button class="btn btn-sm btn-secondary dropdown-toggle">操作</button>
                                    <div class="dropdown-menu">
                                        <a href="index.php?page=booking_view&id=<?php echo $booking['id']; ?>" class="dropdown-item">查看</a>
                                        <a href="index.php?page=booking_edit&id=<?php echo $booking['id']; ?>" class="dropdown-item">编辑</a>

                                        <?php if ($booking['status'] == 'pending'): ?>
                                            <a href="index.php?page=booking_list&action=update_status&id=<?php echo $booking['id']; ?>&status=confirmed" class="dropdown-item">确认预订</a>
                                        <?php endif; ?>

                                        <?php if ($booking['status'] == 'confirmed'): ?>
                                            <a href="index.php?page=check_in&booking_id=<?php echo $booking['id']; ?>" class="dropdown-item">办理入住</a>
                                            <a href="index.php?page=booking_list&action=update_status&id=<?php echo $booking['id']; ?>&status=cancelled" class="dropdown-item">取消预订</a>
                                        <?php endif; ?>

                                        <?php if ($booking['status'] == 'checked_in'): ?>
                                            <a href="index.php?page=check_out&booking_id=<?php echo $booking['id']; ?>" class="dropdown-item">办理退房</a>
                                        <?php endif; ?>

                                        <a href="index.php?page=booking_list&action=delete&id=<?php echo $booking['id']; ?>" class="dropdown-item text-danger" onclick="return confirm('确定要删除此预订吗？此操作不可恢复！');">删除</a>
                                    </div>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <!-- 分页 -->
    <?php if ($totalPages > 1): ?>
        <div class="pagination">
            <?php if ($page > 1): ?>
                <a href="index.php?page=booking_list&p=<?php echo ($page - 1); ?>&status=<?php echo urlencode($statusFilter); ?>&booking_source=<?php echo urlencode($sourceFilter); ?>&search=<?php echo urlencode($searchTerm); ?>&date_from=<?php echo urlencode($dateFrom); ?>&date_to=<?php echo urlencode($dateTo); ?>" class="pagination-item">&laquo; 上一页</a>
            <?php endif; ?>

            <?php
            $startPage = max(1, $page - 2);
            $endPage = min($totalPages, $page + 2);

            for ($i = $startPage; $i <= $endPage; $i++):
            ?>
                <a href="index.php?page=booking_list&p=<?php echo $i; ?>&status=<?php echo urlencode($statusFilter); ?>&booking_source=<?php echo urlencode($sourceFilter); ?>&search=<?php echo urlencode($searchTerm); ?>&date_from=<?php echo urlencode($dateFrom); ?>&date_to=<?php echo urlencode($dateTo); ?>" class="pagination-item <?php echo ($i == $page) ? 'active' : ''; ?>"><?php echo $i; ?></a>
            <?php endfor; ?>

            <?php if ($page < $totalPages): ?>
                <a href="index.php?page=booking_list&p=<?php echo ($page + 1); ?>&status=<?php echo urlencode($statusFilter); ?>&booking_source=<?php echo urlencode($sourceFilter); ?>&search=<?php echo urlencode($searchTerm); ?>&date_from=<?php echo urlencode($dateFrom); ?>&date_to=<?php echo urlencode($dateTo); ?>" class="pagination-item">下一页 &raquo;</a>
            <?php endif; ?>
        </div>
    <?php endif; ?>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 下拉菜单交互
        const dropdowns = document.querySelectorAll('.dropdown');

        dropdowns.forEach(dropdown => {
            const toggle = dropdown.querySelector('.dropdown-toggle');
            const menu = dropdown.querySelector('.dropdown-menu');

            toggle.addEventListener('click', function(e) {
                e.preventDefault();
                e.stopPropagation();

                // 关闭所有其他下拉菜单
                dropdowns.forEach(d => {
                    if (d !== dropdown) {
                        d.querySelector('.dropdown-menu').classList.remove('show');
                    }
                });

                // 切换当前下拉菜单
                menu.classList.toggle('show');
            });
        });

        // 点击页面其他地方关闭下拉菜单
        document.addEventListener('click', function() {
            dropdowns.forEach(dropdown => {
                const menu = dropdown.querySelector('.dropdown-menu');
                if (menu.classList.contains('show')) {
                    menu.classList.remove('show');
                }
            });
        });
    });
</script>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 20px;
    }

    .page-actions {
        display: flex;
        gap: 10px;
    }

    .filter-form-container {
        background-color: #f8f9fa;
        border-radius: 8px;
        padding: 15px;
        margin-bottom: 20px;
    }

    .filter-form {
        display: flex;
        flex-direction: column;
        gap: 15px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
    }

    .form-group {
        flex: 1;
        min-width: 200px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: bold;
    }

    .form-actions {
        display: flex;
        gap: 10px;
        align-items: flex-end;
    }

    .table-responsive {
        overflow-x: auto;
        margin-bottom: 20px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
        color: #495057;
    }

    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
        color: #fff;
    }

    .status-pending {
        background-color: #ffc107;
        color: #212529;
    }

    .status-confirmed {
        background-color: #17a2b8;
    }

    .status-checked_in {
        background-color: #28a745;
    }

    .status-checked_out {
        background-color: #0066cc;
    }

    .status-cancelled {
        background-color: #dc3545;
    }

    .status-no_show {
        background-color: #6c757d;
    }

    .actions {
        white-space: nowrap;
    }

    .dropdown {
        position: relative;
        display: inline-block;
    }

    .dropdown-toggle {
        cursor: pointer;
    }

    .dropdown-menu {
        display: none;
        position: absolute;
        right: 0;
        background-color: #fff;
        min-width: 160px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.2);
        z-index: 1;
        border-radius: 4px;
        padding: 5px 0;
    }

    .dropdown-menu.show {
        display: block;
    }

    .dropdown-item {
        display: block;
        padding: 8px 15px;
        color: #212529;
        text-decoration: none;
        font-size: 14px;
    }

    .dropdown-item:hover {
        background-color: #f8f9fa;
    }

    .text-danger {
        color: #dc3545;
    }

    .text-center {
        text-align: center;
    }

    .pagination {
        display: flex;
        justify-content: center;
        gap: 5px;
        margin-top: 20px;
    }

    .pagination-item {
        display: inline-block;
        padding: 5px 10px;
        border: 1px solid #dee2e6;
        border-radius: 4px;
        color: #0066cc;
        text-decoration: none;
    }

    .pagination-item:hover {
        background-color: #f8f9fa;
    }

    .pagination-item.active {
        background-color: #0066cc;
        color: #fff;
        border-color: #0066cc;
    }

    @media (max-width: 768px) {
        .form-group {
            min-width: 100%;
        }
    }
</style>