<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取渠道列表
$channelsSql = "SELECT * FROM booking_channels ORDER BY name";
$channelsResult = $conn->query($channelsSql);
$channels = [];
if ($channelsResult && $channelsResult->num_rows > 0) {
    while ($row = $channelsResult->fetch_assoc()) {
        $channels[] = $row;
    }
}

// 处理渠道订单同步
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    switch ($_POST['action']) {
        case 'sync_channel':
            $channelId = (int)$_POST['channel_id'];
            // TODO: 实现具体渠道的订单同步逻辑
            break;

        case 'update_channel_settings':
            $channelId = (int)$_POST['channel_id'];
            $apiKey = sanitize($_POST['api_key']);
            $apiSecret = sanitize($_POST['api_secret']);
            $isActive = isset($_POST['is_active']) ? 1 : 0;

            $updateSql = "UPDATE booking_channels SET 
                         api_key = ?, 
                         api_secret = ?,
                         is_active = ?,
                         updated_at = NOW() 
                         WHERE id = ?";
            $stmt = $conn->prepare($updateSql);
            $stmt->bind_param("ssii", $apiKey, $apiSecret, $isActive, $channelId);
            $stmt->execute();
            break;
    }
}

// 获取各渠道最近的订单
$recentBookingsSql = "SELECT b.*, bc.name as channel_name 
                      FROM bookings b 
                      JOIN booking_channels bc ON b.channel_id = bc.id 
                      WHERE b.created_at >= DATE_SUB(NOW(), INTERVAL 7 DAY) 
                      ORDER BY b.created_at DESC 
                      LIMIT 50";
$recentBookingsResult = $conn->query($recentBookingsSql);
$recentBookings = [];
if ($recentBookingsResult && $recentBookingsResult->num_rows > 0) {
    while ($row = $recentBookingsResult->fetch_assoc()) {
        $recentBookings[] = $row;
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>渠道管理</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <span>渠道管理</span>
        </nav>
    </div>

    <div class="channel-container">
        <div class="channels-list">
            <div class="card">
                <div class="card-header">
                    <h3>预订渠道</h3>
                </div>
                <div class="card-body">
                    <?php foreach ($channels as $channel): ?>
                        <div class="channel-item">
                            <div class="channel-info">
                                <h4><?php echo htmlspecialchars($channel['name']); ?></h4>
                                <p>状态: <?php echo $channel['is_active'] ? '已启用' : '已禁用'; ?></p>
                                <p>最后同步: <?php echo $channel['last_sync'] ? date('Y-m-d H:i', strtotime($channel['last_sync'])) : '从未'; ?></p>
                            </div>
                            <div class="channel-actions">
                                <button class="btn btn-primary" onclick="syncChannel(<?php echo $channel['id']; ?>)">同步订单</button>
                                <button class="btn btn-secondary" onclick="showSettings(<?php echo $channel['id']; ?>)">设置</button>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>

        <div class="recent-bookings">
            <div class="card">
                <div class="card-header">
                    <h3>最近订单</h3>
                </div>
                <div class="card-body">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>订单号</th>
                                <th>渠道</th>
                                <th>客人</th>
                                <th>入住日期</th>
                                <th>状态</th>
                                <th>创建时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($recentBookings as $booking): ?>
                                <tr>
                                    <td>
                                        <a href="index.php?page=booking_view&id=<?php echo $booking['id']; ?>">
                                            <?php echo htmlspecialchars($booking['booking_number']); ?>
                                        </a>
                                    </td>
                                    <td><?php echo htmlspecialchars($booking['channel_name']); ?></td>
                                    <td><?php echo htmlspecialchars($booking['guest_name']); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($booking['check_in_date'])); ?></td>
                                    <td>
                                        <span class="status-badge status-<?php echo $booking['status']; ?>">
                                            <?php
                                            switch ($booking['status']) {
                                                case 'pending_payment':
                                                    echo '待付款';
                                                    break;
                                                case 'confirmed':
                                                    echo '已确认';
                                                    break;
                                                case 'checked_in':
                                                    echo '已入住';
                                                    break;
                                                case 'checked_out':
                                                    echo '已退房';
                                                    break;
                                                case 'cancelled':
                                                    echo '已取消';
                                                    break;
                                                default:
                                                    echo htmlspecialchars($booking['status']);
                                            }
                                            ?>
                                        </span>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($booking['created_at'])); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- 渠道设置弹窗 -->
<div id="channelSettingsModal" class="modal">
    <div class="modal-content">
        <div class="modal-header">
            <h4>渠道设置</h4>
            <span class="close">&times;</span>
        </div>
        <div class="modal-body">
            <form id="channelSettingsForm" method="post">
                <input type="hidden" name="action" value="update_channel_settings">
                <input type="hidden" name="channel_id" id="settingsChannelId">

                <div class="form-group">
                    <label for="api_key">API密钥</label>
                    <input type="text" id="api_key" name="api_key" required>
                </div>

                <div class="form-group">
                    <label for="api_secret">API密钥</label>
                    <input type="password" id="api_secret" name="api_secret" required>
                </div>

                <div class="form-group">
                    <label>
                        <input type="checkbox" name="is_active" id="is_active">
                        启用此渠道
                    </label>
                </div>

                <div class="form-actions">
                    <button type="submit" class="btn btn-primary">保存设置</button>
                    <button type="button" class="btn btn-secondary" onclick="closeModal()">取消</button>
                </div>
            </form>
        </div>
    </div>
</div>

<style>
    .channel-container {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
    }

    .channels-list,
    .recent-bookings {
        flex: 1;
        min-width: 300px;
    }

    .channel-item {
        display: flex;
        justify-content: space-between;
        align-items: center;
        padding: 15px;
        border-bottom: 1px solid #eee;
    }

    .channel-item:last-child {
        border-bottom: none;
    }

    .channel-info h4 {
        margin: 0 0 5px 0;
        color: #0066cc;
    }

    .channel-info p {
        margin: 0;
        color: #666;
        font-size: 14px;
    }

    .channel-actions {
        display: flex;
        gap: 10px;
    }

    .modal {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
    }

    .modal-content {
        position: relative;
        background-color: #fff;
        margin: 15% auto;
        padding: 20px;
        border-radius: 8px;
        width: 80%;
        max-width: 500px;
    }

    .close {
        position: absolute;
        right: 20px;
        top: 20px;
        font-size: 24px;
        cursor: pointer;
    }

    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
    }

    .status-pending_payment {
        background-color: #fff3cd;
        color: #856404;
    }

    .status-confirmed {
        background-color: #d4edda;
        color: #155724;
    }

    .status-checked_in {
        background-color: #cce5ff;
        color: #004085;
    }

    .status-checked_out {
        background-color: #e2e3e5;
        color: #383d41;
    }

    .status-cancelled {
        background-color: #f8d7da;
        color: #721c24;
    }
</style>

<script>
    function syncChannel(channelId) {
        if (confirm('确定要同步此渠道的订单吗？')) {
            const form = document.createElement('form');
            form.method = 'POST';
            form.innerHTML = `
            <input type="hidden" name="action" value="sync_channel">
            <input type="hidden" name="channel_id" value="${channelId}">
        `;
            document.body.appendChild(form);
            form.submit();
        }
    }

    function showSettings(channelId) {
        document.getElementById('settingsChannelId').value = channelId;
        document.getElementById('channelSettingsModal').style.display = 'block';
    }

    function closeModal() {
        document.getElementById('channelSettingsModal').style.display = 'none';
    }

    // 关闭模态框
    document.querySelector('.close').onclick = closeModal;
    window.onclick = function(event) {
        const modal = document.getElementById('channelSettingsModal');
        if (event.target == modal) {
            closeModal();
        }
    }
</script>