<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取预订统计数据
// 总预订数
$totalBookingsSql = "SELECT COUNT(*) as count FROM bookings";
$totalBookingsResult = $conn->query($totalBookingsSql);
$totalBookings = $totalBookingsResult->fetch_assoc()['count'];

// 待支付预订数
$pendingPaymentSql = "SELECT COUNT(*) as count FROM bookings WHERE status = 'pending_payment'";
$pendingPaymentResult = $conn->query($pendingPaymentSql);
$pendingPayment = $pendingPaymentResult->fetch_assoc()['count'];

// 已确认预订数
$confirmedSql = "SELECT COUNT(*) as count FROM bookings WHERE status = 'confirmed'";
$confirmedResult = $conn->query($confirmedSql);
$confirmed = $confirmedResult->fetch_assoc()['count'];

// 已入住预订数
$checkedInSql = "SELECT COUNT(*) as count FROM bookings WHERE status = 'checked_in'";
$checkedInResult = $conn->query($checkedInSql);
$checkedIn = $checkedInResult->fetch_assoc()['count'];

// 已完成预订数
$completedSql = "SELECT COUNT(*) as count FROM bookings WHERE status = 'checked_out'";
$completedResult = $conn->query($completedSql);
$completed = $completedResult->fetch_assoc()['count'];

// 已取消预订数
$cancelledSql = "SELECT COUNT(*) as count FROM bookings WHERE status = 'cancelled'";
$cancelledResult = $conn->query($cancelledSql);
$cancelled = $cancelledResult->fetch_assoc()['count'];

// 今日预计入住数
$todayCheckInSql = "SELECT COUNT(*) as count FROM bookings WHERE DATE(check_in_date) = CURDATE() AND status = 'confirmed'";
$todayCheckInResult = $conn->query($todayCheckInSql);
$todayCheckIn = $todayCheckInResult->fetch_assoc()['count'];

// 今日预计退房数
$todayCheckOutSql = "SELECT COUNT(*) as count FROM bookings WHERE DATE(check_out_date) = CURDATE() AND status = 'checked_in'";
$todayCheckOutResult = $conn->query($todayCheckOutSql);
$todayCheckOut = $todayCheckOutResult->fetch_assoc()['count'];

// 获取最近预订
$recentBookingsSql = "SELECT b.*, 
                      (SELECT COUNT(*) FROM booking_rooms WHERE booking_id = b.id) as room_count 
                      FROM bookings b 
                      ORDER BY b.created_at DESC 
                      LIMIT 10";
$recentBookingsResult = $conn->query($recentBookingsSql);
$recentBookings = [];
if ($recentBookingsResult && $recentBookingsResult->num_rows > 0) {
    while ($row = $recentBookingsResult->fetch_assoc()) {
        $recentBookings[] = $row;
    }
}

// 获取预订来源统计
$bookingSourceSql = "SELECT source, COUNT(*) as count 
                     FROM bookings 
                     GROUP BY source 
                     ORDER BY count DESC";
$bookingSourceResult = $conn->query($bookingSourceSql);
$bookingSources = [];
if ($bookingSourceResult && $bookingSourceResult->num_rows > 0) {
    while ($row = $bookingSourceResult->fetch_assoc()) {
        $bookingSources[] = $row;
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>预订管理概览</h2>
    </div>

    <!-- 预订统计卡片 -->
    <div class="stats-cards">
        <div class="stat-card">
            <div class="stat-card-content">
                <div class="stat-card-title">总预订数</div>
                <div class="stat-card-value"><?php echo $totalBookings; ?></div>
            </div>
            <div class="stat-card-icon">
                <i class="icon-booking"></i>
            </div>
        </div>

        <div class="stat-card">
            <div class="stat-card-content">
                <div class="stat-card-title">待支付</div>
                <div class="stat-card-value"><?php echo $pendingPayment; ?></div>
            </div>
            <div class="stat-card-icon status-pending">
                <i class="icon-pending"></i>
            </div>
        </div>

        <div class="stat-card">
            <div class="stat-card-content">
                <div class="stat-card-title">已确认</div>
                <div class="stat-card-value"><?php echo $confirmed; ?></div>
            </div>
            <div class="stat-card-icon status-confirmed">
                <i class="icon-confirmed"></i>
            </div>
        </div>

        <div class="stat-card">
            <div class="stat-card-content">
                <div class="stat-card-title">已入住</div>
                <div class="stat-card-value"><?php echo $checkedIn; ?></div>
            </div>
            <div class="stat-card-icon status-checked-in">
                <i class="icon-checked-in"></i>
            </div>
        </div>

        <div class="stat-card">
            <div class="stat-card-content">
                <div class="stat-card-title">已完成</div>
                <div class="stat-card-value"><?php echo $completed; ?></div>
            </div>
            <div class="stat-card-icon status-completed">
                <i class="icon-completed"></i>
            </div>
        </div>

        <div class="stat-card">
            <div class="stat-card-content">
                <div class="stat-card-title">已取消</div>
                <div class="stat-card-value"><?php echo $cancelled; ?></div>
            </div>
            <div class="stat-card-icon status-cancelled">
                <i class="icon-cancelled"></i>
            </div>
        </div>
    </div>

    <!-- 今日入住/退房提醒 -->
    <div class="today-alerts">
        <div class="alert-card">
            <div class="alert-card-header">
                <h3>今日入住</h3>
                <span class="alert-count"><?php echo $todayCheckIn; ?></span>
            </div>
            <div class="alert-card-body">
                <?php if ($todayCheckIn > 0): ?>
                    <a href="index.php?page=check_in" class="btn btn-primary">查看详情</a>
                <?php else: ?>
                    <p>今日无预计入住</p>
                <?php endif; ?>
            </div>
        </div>

        <div class="alert-card">
            <div class="alert-card-header">
                <h3>今日退房</h3>
                <span class="alert-count"><?php echo $todayCheckOut; ?></span>
            </div>
            <div class="alert-card-body">
                <?php if ($todayCheckOut > 0): ?>
                    <a href="index.php?page=check_out" class="btn btn-primary">查看详情</a>
                <?php else: ?>
                    <p>今日无预计退房</p>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <div class="dashboard-row">
        <!-- 最近预订 -->
        <div class="dashboard-card">
            <div class="dashboard-card-header">
                <h3>最近预订</h3>
                <a href="index.php?page=booking_list" class="view-all">查看全部</a>
            </div>
            <div class="dashboard-card-body">
                <?php if (empty($recentBookings)): ?>
                    <p class="no-data">暂无预订数据</p>
                <?php else: ?>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>预订号</th>
                                <th>客人姓名</th>
                                <th>入住日期</th>
                                <th>退房日期</th>
                                <th>房间数</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($recentBookings as $booking): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($booking['booking_number']); ?></td>
                                    <td><?php echo htmlspecialchars($booking['guest_name']); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($booking['check_in_date'])); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($booking['check_out_date'])); ?></td>
                                    <td><?php echo $booking['room_count']; ?></td>
                                    <td>
                                        <span class="status-badge status-<?php echo $booking['status']; ?>">
                                            <?php
                                            switch ($booking['status']) {
                                                case 'pending_payment':
                                                    echo '待支付';
                                                    break;
                                                case 'confirmed':
                                                    echo '已确认';
                                                    break;
                                                case 'checked_in':
                                                    echo '已入住';
                                                    break;
                                                case 'checked_out':
                                                    echo '已完成';
                                                    break;
                                                case 'cancelled':
                                                    echo '已取消';
                                                    break;
                                                default:
                                                    echo $booking['status'];
                                            }
                                            ?>
                                        </span>
                                    </td>
                                    <td>
                                        <a href="index.php?page=booking_view&id=<?php echo $booking['id']; ?>" class="btn btn-sm btn-primary">查看</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php endif; ?>
            </div>
        </div>

        <!-- 预订来源统计 -->
        <div class="dashboard-card">
            <div class="dashboard-card-header">
                <h3>预订来源统计</h3>
            </div>
            <div class="dashboard-card-body">
                <?php if (empty($bookingSources)): ?>
                    <p class="no-data">暂无预订来源数据</p>
                <?php else: ?>
                    <div class="source-stats">
                        <?php foreach ($bookingSources as $source): ?>
                            <div class="source-item">
                                <div class="source-name">
                                    <?php
                                    switch ($source['source']) {
                                        case 'website':
                                            echo '官网';
                                            break;
                                        case 'phone':
                                            echo '电话';
                                            break;
                                        case 'walk_in':
                                            echo '门店';
                                            break;
                                        case 'ctrip':
                                            echo '携程';
                                            break;
                                        case 'meituan':
                                            echo '美团';
                                            break;
                                        case 'fliggy':
                                            echo '飞猪';
                                            break;
                                        default:
                                            echo htmlspecialchars($source['source']);
                                    }
                                    ?>
                                </div>
                                <div class="source-bar-container">
                                    <div class="source-bar" style="width: <?php echo min(100, ($source['count'] / $totalBookings) * 100); ?>%"></div>
                                </div>
                                <div class="source-count"><?php echo $source['count']; ?></div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .stats-cards {
        display: grid;
        grid-template-columns: repeat(auto-fill, minmax(200px, 1fr));
        gap: 15px;
        margin-bottom: 20px;
    }

    .stat-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .stat-card-title {
        color: #6c757d;
        font-size: 14px;
        margin-bottom: 5px;
    }

    .stat-card-value {
        font-size: 24px;
        font-weight: bold;
        color: #212529;
    }

    .stat-card-icon {
        width: 40px;
        height: 40px;
        border-radius: 50%;
        background-color: #f8f9fa;
        display: flex;
        align-items: center;
        justify-content: center;
        color: #0066cc;
    }

    .status-pending {
        color: #ffc107;
    }

    .status-confirmed {
        color: #17a2b8;
    }

    .status-checked-in {
        color: #28a745;
    }

    .status-completed {
        color: #0066cc;
    }

    .status-cancelled {
        color: #dc3545;
    }

    .today-alerts {
        display: grid;
        grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
        gap: 15px;
        margin-bottom: 20px;
    }

    .alert-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        overflow: hidden;
    }

    .alert-card-header {
        background-color: #f8f9fa;
        padding: 15px;
        display: flex;
        justify-content: space-between;
        align-items: center;
        border-bottom: 1px solid #e9ecef;
    }

    .alert-card-header h3 {
        margin: 0;
        font-size: 16px;
        color: #212529;
    }

    .alert-count {
        background-color: #0066cc;
        color: #fff;
        border-radius: 50%;
        width: 24px;
        height: 24px;
        display: flex;
        align-items: center;
        justify-content: center;
        font-size: 14px;
    }

    .alert-card-body {
        padding: 15px;
        text-align: center;
    }

    .dashboard-row {
        display: grid;
        grid-template-columns: 2fr 1fr;
        gap: 15px;
        margin-bottom: 20px;
    }

    .dashboard-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        overflow: hidden;
    }

    .dashboard-card-header {
        background-color: #f8f9fa;
        padding: 15px;
        display: flex;
        justify-content: space-between;
        align-items: center;
        border-bottom: 1px solid #e9ecef;
    }

    .dashboard-card-header h3 {
        margin: 0;
        font-size: 16px;
        color: #212529;
    }

    .view-all {
        font-size: 14px;
        color: #0066cc;
        text-decoration: none;
    }

    .dashboard-card-body {
        padding: 15px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
        color: #495057;
    }

    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
        color: #fff;
    }

    .status-pending_payment {
        background-color: #ffc107;
        color: #212529;
    }

    .status-confirmed {
        background-color: #17a2b8;
    }

    .status-checked_in {
        background-color: #28a745;
    }

    .status-checked_out {
        background-color: #0066cc;
    }

    .status-cancelled {
        background-color: #dc3545;
    }

    .btn-sm {
        padding: 3px 8px;
        font-size: 12px;
    }

    .no-data {
        text-align: center;
        color: #6c757d;
        padding: 20px;
    }

    .source-stats {
        display: flex;
        flex-direction: column;
        gap: 10px;
    }

    .source-item {
        display: flex;
        align-items: center;
        gap: 10px;
    }

    .source-name {
        width: 60px;
        font-size: 14px;
        color: #495057;
    }

    .source-bar-container {
        flex-grow: 1;
        height: 10px;
        background-color: #f8f9fa;
        border-radius: 5px;
        overflow: hidden;
    }

    .source-bar {
        height: 100%;
        background-color: #0066cc;
        border-radius: 5px;
    }

    .source-count {
        width: 30px;
        text-align: right;
        font-size: 14px;
        color: #495057;
    }

    @media (max-width: 768px) {
        .dashboard-row {
            grid-template-columns: 1fr;
        }
    }
</style>