<?php
session_start();
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前页面
$page = isset($_GET['page']) ? $_GET['page'] : 'dashboard';

// 设置页面标题
$pageTitle = '';
switch ($page) {
    case 'dashboard':
        $pageTitle = '预订管理概览';
        break;
    case 'booking_list':
        $pageTitle = '订单列表';
        break;
    case 'booking_add':
        $pageTitle = '添加预订';
        break;
    case 'booking_edit':
        $pageTitle = '编辑预订';
        break;
    case 'booking_view':
        $pageTitle = '预订详情';
        break;
    case 'booking_calendar':
        $pageTitle = '预订日历';
        break;
    case 'check_in':
        $pageTitle = '办理入住';
        break;
    case 'check_out':
        $pageTitle = '办理退房';
        break;
    case 'group_booking':
        $pageTitle = '团队预订';
        break;
    default:
        $pageTitle = '预订管理';
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - 宿易管</title>
    <link rel="stylesheet" href="../../assets/css/style.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/css/bootstrap.min.css">
    <script src="https://cdn.jsdelivr.net/npm/jquery@3.6.4/dist/jquery.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/js/bootstrap.bundle.min.js"></script>
    <style>
        .module-layout {
            display: flex;
            min-height: calc(100vh - 60px);
        }

        .module-sidebar {
            width: 250px;
            background-color: #f8f9fa;
            border-right: 1px solid #e9ecef;
            padding: 20px 0;
            flex-shrink: 0;
        }

        .module-sidebar-header {
            padding: 0 20px 15px;
            border-bottom: 1px solid #e9ecef;
            margin-bottom: 15px;
        }

        .module-sidebar-header h2 {
            margin: 0;
            font-size: 18px;
            color: #0066cc;
        }

        .module-nav {
            display: flex;
            flex-direction: column;
        }

        .module-nav-item {
            padding: 10px 20px;
            color: #495057;
            text-decoration: none;
            border-left: 3px solid transparent;
        }

        .module-nav-item:hover {
            background-color: #e9ecef;
            color: #0066cc;
        }

        .module-nav-item.active {
            background-color: #e9ecef;
            color: #0066cc;
            border-left-color: #0066cc;
            font-weight: bold;
        }

        .module-content {
            flex-grow: 1;
            padding: 20px;
            overflow-y: auto;
        }

        .module-content-header {
            margin-bottom: 20px;
            padding-bottom: 10px;
            border-bottom: 1px solid #e9ecef;
        }

        .module-content-header h2 {
            margin: 0;
            font-size: 24px;
            color: #212529;
        }
    </style>
</head>

<body>
    <header class="main-header">
        <div class="user-info">
            <span class="user-name"><?php echo $_SESSION['user_name']; ?></span>
            <span class="user-role"><?php echo $_SESSION['user_role']; ?></span>
        </div>

        <div class="site-title">
            <h1><?php echo SITE_NAME; ?></h1>
            <p><?php echo SITE_SUBTITLE; ?></p>
        </div>

        <div class="header-actions">
            <a href="../../logout.php" class="btn btn-logout">退出登录</a>
        </div>
    </header>

    <div class="module-layout">
        <aside class="module-sidebar">
            <div class="module-sidebar-header">
                <h2>预订与订单管理</h2>
            </div>

            <nav class="module-nav">
                <a href="../../home.php" class="module-nav-item">返回首页</a>
                <a href="index.php" class="module-nav-item <?php echo $page == 'dashboard' ? 'active' : ''; ?>">概览</a>
                <a href="index.php?page=booking_list" class="module-nav-item <?php echo $page == 'booking_list' ? 'active' : ''; ?>">订单列表</a>
                <a href="index.php?page=booking_add" class="module-nav-item <?php echo $page == 'booking_add' ? 'active' : ''; ?>">添加预订</a>
                <a href="index.php?page=booking_calendar" class="module-nav-item <?php echo $page == 'booking_calendar' ? 'active' : ''; ?>">预订日历</a>
                <a href="index.php?page=check_in" class="module-nav-item <?php echo $page == 'check_in' ? 'active' : ''; ?>">办理入住</a>
                <a href="index.php?page=check_out" class="module-nav-item <?php echo $page == 'check_out' ? 'active' : ''; ?>">办理退房</a>
                <a href="index.php?page=group_booking" class="module-nav-item <?php echo $page == 'group_booking' ? 'active' : ''; ?>">团队/长租预订</a>
            </nav>
        </aside>

        <main class="module-content">
            <?php
            // 加载对应的页面内容
            switch ($page) {
                case 'dashboard':
                    include 'dashboard.php';
                    break;
                case 'booking_list':
                    include 'booking_list.php';
                    break;
                case 'booking_add':
                    include 'booking_add.php';
                    break;
                case 'booking_edit':
                    include 'booking_edit.php';
                    break;
                case 'booking_view':
                    include 'booking_view.php';
                    break;
                case 'booking_calendar':
                    include 'booking_calendar.php';
                    break;
                case 'check_in':
                    include 'check_in.php';
                    break;
                case 'check_out':
                    include 'check_out.php';
                    break;
                case 'group_booking':
                    include 'group_booking.php';
                    break;
                default:
                    include 'dashboard.php';
            }
            ?>
        </main>
    </div>

    <script src="../../assets/js/script.js"></script>
</body>

</html>