<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取分析周期
$period = isset($_GET['period']) ? $_GET['period'] : 'month';
$year = isset($_GET['year']) ? intval($_GET['year']) : date('Y');
$month = isset($_GET['month']) ? intval($_GET['month']) : date('n');

// 获取当前日期
$currentDate = date('Y-m-d');
$currentYear = date('Y');
$currentMonth = date('n');

// 根据周期设置日期范围
$startDate = '';
$endDate = '';
$periodTitle = '';

switch ($period) {
    case 'year':
        // 按年统计
        $startDate = "$year-01-01";
        $endDate = "$year-12-31";
        $periodTitle = "{$year}年";
        break;
    case 'quarter':
        // 按季度统计
        $quarter = isset($_GET['quarter']) ? intval($_GET['quarter']) : ceil($currentMonth / 3);
        $startMonth = ($quarter - 1) * 3 + 1;
        $endMonth = $quarter * 3;
        $startDate = "$year-" . sprintf('%02d', $startMonth) . "-01";
        $endDate = "$year-" . sprintf('%02d', $endMonth) . "-" . date('t', strtotime("$year-$endMonth-01"));
        $periodTitle = "{$year}年第{$quarter}季度";
        break;
    case 'month':
    default:
        // 按月统计
        $startDate = "$year-" . sprintf('%02d', $month) . "-01";
        $endDate = "$year-" . sprintf('%02d', $month) . "-" . date('t', strtotime("$year-$month-01"));
        $periodTitle = "{$year}年{$month}月";
        break;
}

// 获取最受欢迎的房型数据
$sql = "SELECT 
            rt.id,
            rt.name,
            COUNT(br.id) as booking_count,
            SUM(br.room_rate) as total_revenue
        FROM booking_rooms br
        JOIN rooms r ON br.room_id = r.id
        JOIN room_types rt ON r.room_type_id = rt.id
        JOIN bookings b ON br.booking_id = b.id
        WHERE b.check_in_date BETWEEN '$startDate' AND '$endDate'
        GROUP BY rt.id
        ORDER BY booking_count DESC";
$result = $conn->query($sql);
$popularRoomTypes = [];

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $popularRoomTypes[] = $row;
    }
}

// 获取最受欢迎的旅游服务数据
$sql = "SELECT 
            ts.id,
            ts.name,
            ts.category,
            COUNT(tb.id) as booking_count,
            SUM(tb.total_price) as total_revenue
        FROM tourism_bookings tb
        JOIN tourism_services ts ON tb.service_id = ts.id
        WHERE tb.service_date BETWEEN '$startDate' AND '$endDate'
        GROUP BY ts.id
        ORDER BY booking_count DESC";
$result = $conn->query($sql);
$popularServices = [];

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $popularServices[] = $row;
    }
}

// 获取客户住宿天数分布
$sql = "SELECT 
            DATEDIFF(check_out_date, check_in_date) as stay_days,
            COUNT(*) as booking_count
        FROM bookings
        WHERE check_in_date BETWEEN '$startDate' AND '$endDate'
        GROUP BY stay_days
        ORDER BY stay_days";
$result = $conn->query($sql);
$stayDaysDistribution = [];

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $stayDaysDistribution[] = $row;
    }
}

// 获取客户预订提前天数分布
$sql = "SELECT 
            DATEDIFF(check_in_date, created_at) as advance_days,
            COUNT(*) as booking_count
        FROM bookings
        WHERE check_in_date BETWEEN '$startDate' AND '$endDate'
        GROUP BY advance_days
        ORDER BY advance_days";
$result = $conn->query($sql);
$advanceDaysDistribution = [];

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $advanceDaysDistribution[] = $row;
    }
}

// 获取客户来源分布
$sql = "SELECT 
            booking_source,
            COUNT(*) as booking_count
        FROM bookings
        WHERE check_in_date BETWEEN '$startDate' AND '$endDate'
        GROUP BY booking_source
        ORDER BY booking_count DESC";
$result = $conn->query($sql);
$sourceDistribution = [];

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $sourceDistribution[] = $row;
    }
}

// 获取会员等级分布
$sql = "SELECT 
            m.level,
            COUNT(b.id) as booking_count
        FROM bookings b
        JOIN members m ON b.member_id = m.id
        WHERE b.check_in_date BETWEEN '$startDate' AND '$endDate'
        GROUP BY m.level
        ORDER BY FIELD(m.level, 'regular', 'silver', 'gold', 'platinum')";
$result = $conn->query($sql);
$memberLevelDistribution = [];

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $memberLevelDistribution[] = $row;
    }
}

// 获取特殊请求分析
$sql = "SELECT 
            special_requests,
            COUNT(*) as request_count
        FROM bookings
        WHERE check_in_date BETWEEN '$startDate' AND '$endDate'
        AND special_requests IS NOT NULL
        AND special_requests != ''
        GROUP BY special_requests
        ORDER BY request_count DESC
        LIMIT 10";
$result = $conn->query($sql);
$specialRequests = [];

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $specialRequests[] = $row;
    }
}
?>

<div class="analysis-container">
    <div class="filter-section">
        <form method="get" action="index.php" class="filter-form">
            <input type="hidden" name="page" value="customer_preference">

            <div class="form-group">
                <label for="period">统计周期:</label>
                <select name="period" id="period" class="form-control" onchange="this.form.submit()">
                    <option value="month" <?php echo $period == 'month' ? 'selected' : ''; ?>>月度</option>
                    <option value="quarter" <?php echo $period == 'quarter' ? 'selected' : ''; ?>>季度</option>
                    <option value="year" <?php echo $period == 'year' ? 'selected' : ''; ?>>年度</option>
                </select>
            </div>

            <div class="form-group">
                <label for="year">年份:</label>
                <select name="year" id="year" class="form-control" onchange="this.form.submit()">
                    <?php for ($y = $currentYear - 5; $y <= $currentYear; $y++): ?>
                        <option value="<?php echo $y; ?>" <?php echo $year == $y ? 'selected' : ''; ?>><?php echo $y; ?>年</option>
                    <?php endfor; ?>
                </select>
            </div>

            <?php if ($period == 'month'): ?>
                <div class="form-group">
                    <label for="month">月份:</label>
                    <select name="month" id="month" class="form-control" onchange="this.form.submit()">
                        <?php for ($m = 1; $m <= 12; $m++): ?>
                            <option value="<?php echo $m; ?>" <?php echo $month == $m ? 'selected' : ''; ?>><?php echo $m; ?>月</option>
                        <?php endfor; ?>
                    </select>
                </div>
            <?php endif; ?>

            <?php if ($period == 'quarter'): ?>
                <div class="form-group">
                    <label for="quarter">季度:</label>
                    <select name="quarter" id="quarter" class="form-control" onchange="this.form.submit()">
                        <?php for ($q = 1; $q <= 4; $q++): ?>
                            <option value="<?php echo $q; ?>" <?php echo (isset($_GET['quarter']) ? intval($_GET['quarter']) : ceil($currentMonth / 3)) == $q ? 'selected' : ''; ?>>第<?php echo $q; ?>季度</option>
                        <?php endfor; ?>
                    </select>
                </div>
            <?php endif; ?>
        </form>
    </div>

    <div class="section-title">
        <h3><?php echo $periodTitle; ?>客户偏好分析</h3>
    </div>

    <div class="chart-section">
        <div class="chart-row">
            <div class="chart-card">
                <div class="card-header">
                    <h3>最受欢迎的房型</h3>
                </div>
                <div class="card-body">
                    <div class="chart-container">
                        <canvas id="popularRoomTypesChart"></canvas>
                    </div>
                </div>
            </div>

            <div class="chart-card">
                <div class="card-header">
                    <h3>最受欢迎的旅游服务</h3>
                </div>
                <div class="card-body">
                    <div class="chart-container">
                        <canvas id="popularServicesChart"></canvas>
                    </div>
                </div>
            </div>
        </div>

        <div class="chart-row">
            <div class="chart-card">
                <div class="card-header">
                    <h3>住宿天数分布</h3>
                </div>
                <div class="card-body">
                    <div class="chart-container">
                        <canvas id="stayDaysChart"></canvas>
                    </div>
                </div>
            </div>

            <div class="chart-card">
                <div class="card-header">
                    <h3>预订提前天数分布</h3>
                </div>
                <div class="card-body">
                    <div class="chart-container">
                        <canvas id="advanceDaysChart"></canvas>
                    </div>
                </div>
            </div>
        </div>

        <div class="chart-row">
            <div class="chart-card">
                <div class="card-header">
                    <h3>客户来源分布</h3>
                </div>
                <div class="card-body">
                    <div class="chart-container">
                        <canvas id="sourceDistributionChart"></canvas>
                    </div>
                </div>
            </div>

            <div class="chart-card">
                <div class="card-header">
                    <h3>会员等级分布</h3>
                </div>
                <div class="card-body">
                    <div class="chart-container">
                        <canvas id="memberLevelChart"></canvas>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="data-section">
        <div class="section-title">
            <h3>最受欢迎的房型详情</h3>
        </div>

        <table class="data-table">
            <thead>
                <tr>
                    <th>房型名称</th>
                    <th>预订次数</th>
                    <th>占比</th>
                    <th>总收入</th>
                    <th>平均单价</th>
                </tr>
            </thead>
            <tbody>
                <?php
                $totalBookings = 0;
                foreach ($popularRoomTypes as $roomType) {
                    $totalBookings += $roomType['booking_count'];
                }
                ?>
                <?php foreach ($popularRoomTypes as $roomType): ?>
                    <tr>
                        <td><?php echo $roomType['name']; ?></td>
                        <td><?php echo $roomType['booking_count']; ?></td>
                        <td><?php echo $totalBookings > 0 ? round(($roomType['booking_count'] / $totalBookings) * 100, 2) . '%' : '0%'; ?></td>
                        <td>¥<?php echo number_format($roomType['total_revenue'], 2); ?></td>
                        <td>¥<?php echo $roomType['booking_count'] > 0 ? number_format($roomType['total_revenue'] / $roomType['booking_count'], 2) : '0.00'; ?></td>
                    </tr>
                <?php endforeach; ?>
                <?php if (empty($popularRoomTypes)): ?>
                    <tr>
                        <td colspan="5">暂无数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <div class="data-section">
        <div class="section-title">
            <h3>最受欢迎的旅游服务详情</h3>
        </div>

        <table class="data-table">
            <thead>
                <tr>
                    <th>服务名称</th>
                    <th>类别</th>
                    <th>预订次数</th>
                    <th>占比</th>
                    <th>总收入</th>
                    <th>平均单价</th>
                </tr>
            </thead>
            <tbody>
                <?php
                $totalServiceBookings = 0;
                foreach ($popularServices as $service) {
                    $totalServiceBookings += $service['booking_count'];
                }
                ?>
                <?php foreach ($popularServices as $service): ?>
                    <tr>
                        <td><?php echo $service['name']; ?></td>
                        <td>
                            <?php
                            switch ($service['category']) {
                                case 'ticket':
                                    echo '门票';
                                    break;
                                case 'transport':
                                    echo '交通';
                                    break;
                                case 'guide':
                                    echo '导游';
                                    break;
                                case 'activity':
                                    echo '活动';
                                    break;
                                case 'other':
                                    echo '其他';
                                    break;
                                default:
                                    echo $service['category'];
                            }
                            ?>
                        </td>
                        <td><?php echo $service['booking_count']; ?></td>
                        <td><?php echo $totalServiceBookings > 0 ? round(($service['booking_count'] / $totalServiceBookings) * 100, 2) . '%' : '0%'; ?></td>
                        <td>¥<?php echo number_format($service['total_revenue'], 2); ?></td>
                        <td>¥<?php echo $service['booking_count'] > 0 ? number_format($service['total_revenue'] / $service['booking_count'], 2) : '0.00'; ?></td>
                    </tr>
                <?php endforeach; ?>
                <?php if (empty($popularServices)): ?>
                    <tr>
                        <td colspan="6">暂无数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <?php if (!empty($specialRequests)): ?>
        <div class="data-section">
            <div class="section-title">
                <h3>常见特殊请求</h3>
            </div>

            <table class="data-table">
                <thead>
                    <tr>
                        <th>特殊请求内容</th>
                        <th>出现次数</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($specialRequests as $request): ?>
                        <tr>
                            <td><?php echo $request['special_requests']; ?></td>
                            <td><?php echo $request['request_count']; ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>
</div>

<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 最受欢迎的房型图表
        const roomTypesCtx = document.getElementById('popularRoomTypesChart').getContext('2d');
        const roomTypesChart = new Chart(roomTypesCtx, {
            type: 'bar',
            data: {
                labels: [
                    <?php
                    foreach ($popularRoomTypes as $roomType) {
                        echo "'" . $roomType['name'] . "',";
                    }
                    ?>
                ],
                datasets: [{
                    label: '预订次数',
                    backgroundColor: '#4e73df',
                    hoverBackgroundColor: '#2e59d9',
                    borderColor: '#4e73df',
                    data: [
                        <?php
                        foreach ($popularRoomTypes as $roomType) {
                            echo $roomType['booking_count'] . ",";
                        }
                        ?>
                    ],
                }]
            },
            options: {
                maintainAspectRatio: false,
                layout: {
                    padding: {
                        left: 10,
                        right: 25,
                        top: 25,
                        bottom: 0
                    }
                },
                scales: {
                    xAxes: [{
                        gridLines: {
                            display: false,
                            drawBorder: false
                        }
                    }],
                    yAxes: [{
                        ticks: {
                            beginAtZero: true,
                            maxTicksLimit: 5,
                            padding: 10
                        },
                        gridLines: {
                            color: "rgb(234, 236, 244)",
                            zeroLineColor: "rgb(234, 236, 244)",
                            drawBorder: false,
                            borderDash: [2],
                            zeroLineBorderDash: [2]
                        }
                    }],
                },
                legend: {
                    display: false
                },
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    titleMarginBottom: 10,
                    titleFontColor: '#6e707e',
                    titleFontSize: 14,
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    intersect: false,
                    mode: 'index',
                    caretPadding: 10
                }
            }
        });

        // 最受欢迎的旅游服务图表
        const servicesCtx = document.getElementById('popularServicesChart').getContext('2d');
        const servicesChart = new Chart(servicesCtx, {
            type: 'bar',
            data: {
                labels: [
                    <?php
                    foreach ($popularServices as $service) {
                        echo "'" . $service['name'] . "',";
                    }
                    ?>
                ],
                datasets: [{
                    label: '预订次数',
                    backgroundColor: '#1cc88a',
                    hoverBackgroundColor: '#17a673',
                    borderColor: '#1cc88a',
                    data: [
                        <?php
                        foreach ($popularServices as $service) {
                            echo $service['booking_count'] . ",";
                        }
                        ?>
                    ],
                }]
            },
            options: {
                maintainAspectRatio: false,
                layout: {
                    padding: {
                        left: 10,
                        right: 25,
                        top: 25,
                        bottom: 0
                    }
                },
                scales: {
                    xAxes: [{
                        gridLines: {
                            display: false,
                            drawBorder: false
                        }
                    }],
                    yAxes: [{
                        ticks: {
                            beginAtZero: true,
                            maxTicksLimit: 5,
                            padding: 10
                        },
                        gridLines: {
                            color: "rgb(234, 236, 244)",
                            zeroLineColor: "rgb(234, 236, 244)",
                            drawBorder: false,
                            borderDash: [2],
                            zeroLineBorderDash: [2]
                        }
                    }],
                },
                legend: {
                    display: false
                },
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    titleMarginBottom: 10,
                    titleFontColor: '#6e707e',
                    titleFontSize: 14,
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    intersect: false,
                    mode: 'index',
                    caretPadding: 10
                }
            }
        });

        // 住宿天数分布图表
        const stayDaysCtx = document.getElementById('stayDaysChart').getContext('2d');
        const stayDaysChart = new Chart(stayDaysCtx, {
            type: 'line',
            data: {
                labels: [
                    <?php
                    foreach ($stayDaysDistribution as $item) {
                        echo "'" . $item['stay_days'] . "天',";
                    }
                    ?>
                ],
                datasets: [{
                    label: '预订数量',
                    backgroundColor: 'rgba(78, 115, 223, 0.05)',
                    borderColor: 'rgba(78, 115, 223, 1)',
                    pointBackgroundColor: 'rgba(78, 115, 223, 1)',
                    pointBorderColor: '#fff',
                    pointHoverBackgroundColor: '#fff',
                    pointHoverBorderColor: 'rgba(78, 115, 223, 1)',
                    borderWidth: 2,
                    fill: true,
                    data: [
                        <?php
                        foreach ($stayDaysDistribution as $item) {
                            echo $item['booking_count'] . ",";
                        }
                        ?>
                    ],
                }]
            },
            options: {
                maintainAspectRatio: false,
                layout: {
                    padding: {
                        left: 10,
                        right: 25,
                        top: 25,
                        bottom: 0
                    }
                },
                scales: {
                    xAxes: [{
                        gridLines: {
                            display: false,
                            drawBorder: false
                        }
                    }],
                    yAxes: [{
                        ticks: {
                            beginAtZero: true,
                            maxTicksLimit: 5,
                            padding: 10
                        },
                        gridLines: {
                            color: "rgb(234, 236, 244)",
                            zeroLineColor: "rgb(234, 236, 244)",
                            drawBorder: false,
                            borderDash: [2],
                            zeroLineBorderDash: [2]
                        }
                    }],
                },
                legend: {
                    display: false
                },
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    titleMarginBottom: 10,
                    titleFontColor: '#6e707e',
                    titleFontSize: 14,
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    intersect: false,
                    mode: 'index',
                    caretPadding: 10
                }
            }
        });

        // 预订提前天数分布图表
        const advanceDaysCtx = document.getElementById('advanceDaysChart').getContext('2d');
        const advanceDaysChart = new Chart(advanceDaysCtx, {
            type: 'line',
            data: {
                labels: [
                    <?php
                    foreach ($advanceDaysDistribution as $item) {
                        echo "'" . $item['advance_days'] . "天',";
                    }
                    ?>
                ],
                datasets: [{
                    label: '预订数量',
                    backgroundColor: 'rgba(28, 200, 138, 0.05)',
                    borderColor: 'rgba(28, 200, 138, 1)',
                    pointBackgroundColor: 'rgba(28, 200, 138, 1)',
                    pointBorderColor: '#fff',
                    pointHoverBackgroundColor: '#fff',
                    pointHoverBorderColor: 'rgba(28, 200, 138, 1)',
                    borderWidth: 2,
                    fill: true,
                    data: [
                        <?php
                        foreach ($advanceDaysDistribution as $item) {
                            echo $item['booking_count'] . ",";
                        }
                        ?>
                    ],
                }]
            },
            options: {
                maintainAspectRatio: false,
                layout: {
                    padding: {
                        left: 10,
                        right: 25,
                        top: 25,
                        bottom: 0
                    }
                },
                scales: {
                    xAxes: [{
                        gridLines: {
                            display: false,
                            drawBorder: false
                        }
                    }],
                    yAxes: [{
                        ticks: {
                            beginAtZero: true,
                            maxTicksLimit: 5,
                            padding: 10
                        },
                        gridLines: {
                            color: "rgb(234, 236, 244)",
                            zeroLineColor: "rgb(234, 236, 244)",
                            drawBorder: false,
                            borderDash: [2],
                            zeroLineBorderDash: [2]
                        }
                    }],
                },
                legend: {
                    display: false
                },
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    titleMarginBottom: 10,
                    titleFontColor: '#6e707e',
                    titleFontSize: 14,
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    intersect: false,
                    mode: 'index',
                    caretPadding: 10
                }
            }
        });

        // 客户来源分布图表
        const sourceCtx = document.getElementById('sourceDistributionChart').getContext('2d');
        const sourceChart = new Chart(sourceCtx, {
            type: 'doughnut',
            data: {
                labels: [
                    <?php
                    foreach ($sourceDistribution as $source) {
                        $label = '';
                        switch ($source['booking_source']) {
                            case 'direct':
                                $label = '直接预订';
                                break;
                            case 'website':
                                $label = '官网';
                                break;
                            case 'phone':
                                $label = '电话';
                                break;
                            case 'email':
                                $label = '邮件';
                                break;
                            case 'ota':
                                $label = 'OTA平台';
                                break;
                            case 'walk_in':
                                $label = '门店直接';
                                break;
                            default:
                                $label = $source['booking_source'];
                        }
                        echo "'" . $label . "',";
                    }
                    ?>
                ],
                datasets: [{
                    data: [
                        <?php
                        foreach ($sourceDistribution as $source) {
                            echo $source['booking_count'] . ",";
                        }
                        ?>
                    ],
                    backgroundColor: [
                        '#4e73df', '#1cc88a', '#36b9cc', '#f6c23e', '#e74a3b', '#858796'
                    ],
                    hoverBackgroundColor: [
                        '#2e59d9', '#17a673', '#2c9faf', '#dda20a', '#be2617', '#60616f'
                    ],
                    hoverBorderColor: "rgba(234, 236, 244, 1)",
                }]
            },
            options: {
                maintainAspectRatio: false,
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    caretPadding: 10,
                },
                legend: {
                    display: true,
                    position: 'bottom'
                },
                cutoutPercentage: 70,
            },
        });

        // 会员等级分布图表
        const memberLevelCtx = document.getElementById('memberLevelChart').getContext('2d');
        const memberLevelChart = new Chart(memberLevelCtx, {
            type: 'doughnut',
            data: {
                labels: [
                    <?php
                    foreach ($memberLevelDistribution as $level) {
                        $label = '';
                        switch ($level['level']) {
                            case 'regular':
                                $label = '普通会员';
                                break;
                            case 'silver':
                                $label = '白银会员';
                                break;
                            case 'gold':
                                $label = '黄金会员';
                                break;
                            case 'platinum':
                                $label = '铂金会员';
                                break;
                            default:
                                $label = $level['level'];
                        }
                        echo "'" . $label . "',";
                    }
                    ?>
                ],
                datasets: [{
                    data: [
                        <?php
                        foreach ($memberLevelDistribution as $level) {
                            echo $level['booking_count'] . ",";
                        }
                        ?>
                    ],
                    backgroundColor: ['#858796', '#f6c23e', '#e74a3b', '#4e73df'],
                    hoverBackgroundColor: ['#60616f', '#dda20a', '#be2617', '#2e59d9'],
                    hoverBorderColor: "rgba(234, 236, 244, 1)",
                }]
            },
            options: {
                maintainAspectRatio: false,
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    caretPadding: 10,
                },
                legend: {
                    display: true,
                    position: 'bottom'
                },
                cutoutPercentage: 70,
            },
        });
    });
</script>

<style>
    .analysis-container {
        padding: 15px 0;
    }

    .filter-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
    }

    .form-group {
        flex: 1;
        min-width: 150px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: 500;
        color: #333;
    }

    .form-control {
        width: 100%;
        padding: 8px 12px;
        border: 1px solid #d1d3e2;
        border-radius: 4px;
        background-color: #f8f9fc;
    }

    .section-title {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .section-title h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .chart-section {
        margin-bottom: 20px;
    }

    .chart-row {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .chart-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        flex: 1;
        min-width: 300px;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e3e6f0;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .card-body {
        padding: 15px;
    }

    .chart-container {
        height: 300px;
    }

    .data-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px 15px;
        text-align: left;
        border-bottom: 1px solid #e3e6f0;
    }

    .data-table th {
        background-color: #f8f9fc;
        font-weight: 600;
    }
</style>