<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取分析周期
$period = isset($_GET['period']) ? $_GET['period'] : 'month';
$year = isset($_GET['year']) ? intval($_GET['year']) : date('Y');
$month = isset($_GET['month']) ? intval($_GET['month']) : date('n');

// 获取当前日期
$currentDate = date('Y-m-d');
$currentYear = date('Y');
$currentMonth = date('n');

// 根据周期设置日期范围
$startDate = '';
$endDate = '';
$periodTitle = '';

switch ($period) {
    case 'year':
        // 按年统计
        $startDate = "$year-01-01";
        $endDate = "$year-12-31";
        $periodTitle = "{$year}年";
        break;
    case 'quarter':
        // 按季度统计
        $quarter = isset($_GET['quarter']) ? intval($_GET['quarter']) : ceil($currentMonth / 3);
        $startMonth = ($quarter - 1) * 3 + 1;
        $endMonth = $quarter * 3;
        $startDate = "$year-" . sprintf('%02d', $startMonth) . "-01";
        $endDate = "$year-" . sprintf('%02d', $endMonth) . "-" . date('t', strtotime("$year-$endMonth-01"));
        $periodTitle = "{$year}年第{$quarter}季度";
        break;
    case 'month':
    default:
        // 按月统计
        $startDate = "$year-" . sprintf('%02d', $month) . "-01";
        $endDate = "$year-" . sprintf('%02d', $month) . "-" . date('t', strtotime("$year-$month-01"));
        $periodTitle = "{$year}年{$month}月";
        break;
}

// 获取客户来源数据
$sql = "SELECT 
            booking_source,
            COUNT(*) as booking_count,
            SUM(total_amount) as total_revenue
        FROM bookings
        WHERE check_in_date BETWEEN '$startDate' AND '$endDate'
        GROUP BY booking_source
        ORDER BY booking_count DESC";
$result = $conn->query($sql);
$sourceData = [];
$totalBookings = 0;
$totalRevenue = 0;

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $sourceData[] = $row;
        $totalBookings += $row['booking_count'];
        $totalRevenue += $row['total_revenue'];
    }
}

// 获取OTA平台细分数据
$sql = "SELECT 
            ota_name,
            COUNT(*) as booking_count,
            SUM(total_amount) as total_revenue
        FROM bookings
        WHERE booking_source = 'ota'
        AND check_in_date BETWEEN '$startDate' AND '$endDate'
        GROUP BY ota_name
        ORDER BY booking_count DESC";
$result = $conn->query($sql);
$otaData = [];

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $otaData[] = $row;
    }
}

// 获取客户来源趋势数据
$trendData = [];
$trendLabels = [];

switch ($period) {
    case 'year':
        // 按月显示全年趋势
        for ($m = 1; $m <= 12; $m++) {
            $monthStart = "$year-" . sprintf('%02d', $m) . "-01";
            $monthEnd = "$year-" . sprintf('%02d', $m) . "-" . date('t', strtotime("$year-$m-01"));
            $trendLabels[] = $m . "月";

            $sql = "SELECT 
                        booking_source,
                        COUNT(*) as booking_count
                    FROM bookings
                    WHERE check_in_date BETWEEN '$monthStart' AND '$monthEnd'
                    GROUP BY booking_source";
            $result = $conn->query($sql);

            $monthData = [
                'direct' => 0,
                'website' => 0,
                'phone' => 0,
                'email' => 0,
                'ota' => 0,
                'walk_in' => 0
            ];

            if ($result && $result->num_rows > 0) {
                while ($row = $result->fetch_assoc()) {
                    $monthData[$row['booking_source']] = $row['booking_count'];
                }
            }

            $trendData[] = $monthData;
        }
        break;

    case 'quarter':
        // 按月显示季度趋势
        $quarter = isset($_GET['quarter']) ? intval($_GET['quarter']) : ceil($currentMonth / 3);
        $startMonth = ($quarter - 1) * 3 + 1;
        $endMonth = $quarter * 3;

        for ($m = $startMonth; $m <= $endMonth; $m++) {
            $monthStart = "$year-" . sprintf('%02d', $m) . "-01";
            $monthEnd = "$year-" . sprintf('%02d', $m) . "-" . date('t', strtotime("$year-$m-01"));
            $trendLabels[] = $m . "月";

            $sql = "SELECT 
                        booking_source,
                        COUNT(*) as booking_count
                    FROM bookings
                    WHERE check_in_date BETWEEN '$monthStart' AND '$monthEnd'
                    GROUP BY booking_source";
            $result = $conn->query($sql);

            $monthData = [
                'direct' => 0,
                'website' => 0,
                'phone' => 0,
                'email' => 0,
                'ota' => 0,
                'walk_in' => 0
            ];

            if ($result && $result->num_rows > 0) {
                while ($row = $result->fetch_assoc()) {
                    $monthData[$row['booking_source']] = $row['booking_count'];
                }
            }

            $trendData[] = $monthData;
        }
        break;

    case 'month':
    default:
        // 按周显示月度趋势
        $daysInMonth = date('t', strtotime("$year-$month-01"));
        $weeksInMonth = ceil($daysInMonth / 7);

        for ($w = 1; $w <= $weeksInMonth; $w++) {
            $weekStart = ($w - 1) * 7 + 1;
            $weekEnd = min($w * 7, $daysInMonth);
            $weekStartDate = "$year-" . sprintf('%02d', $month) . "-" . sprintf('%02d', $weekStart);
            $weekEndDate = "$year-" . sprintf('%02d', $month) . "-" . sprintf('%02d', $weekEnd);
            $trendLabels[] = "第{$w}周";

            $sql = "SELECT 
                        booking_source,
                        COUNT(*) as booking_count
                    FROM bookings
                    WHERE check_in_date BETWEEN '$weekStartDate' AND '$weekEndDate'
                    GROUP BY booking_source";
            $result = $conn->query($sql);

            $weekData = [
                'direct' => 0,
                'website' => 0,
                'phone' => 0,
                'email' => 0,
                'ota' => 0,
                'walk_in' => 0
            ];

            if ($result && $result->num_rows > 0) {
                while ($row = $result->fetch_assoc()) {
                    $weekData[$row['booking_source']] = $row['booking_count'];
                }
            }

            $trendData[] = $weekData;
        }
        break;
}

// 获取会员与非会员数据
$sql = "SELECT 
            CASE WHEN member_id IS NOT NULL THEN '会员' ELSE '非会员' END as member_type,
            COUNT(*) as booking_count,
            SUM(total_amount) as total_revenue
        FROM bookings
        WHERE check_in_date BETWEEN '$startDate' AND '$endDate'
        GROUP BY member_type";
$result = $conn->query($sql);
$memberData = [
    '会员' => ['booking_count' => 0, 'total_revenue' => 0],
    '非会员' => ['booking_count' => 0, 'total_revenue' => 0]
];

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $memberData[$row['member_type']] = [
            'booking_count' => $row['booking_count'],
            'total_revenue' => $row['total_revenue']
        ];
    }
}
?>

<div class="analysis-container">
    <div class="filter-section">
        <form method="get" action="index.php" class="filter-form">
            <input type="hidden" name="page" value="customer_source">

            <div class="form-group">
                <label for="period">统计周期:</label>
                <select name="period" id="period" class="form-control" onchange="this.form.submit()">
                    <option value="month" <?php echo $period == 'month' ? 'selected' : ''; ?>>月度</option>
                    <option value="quarter" <?php echo $period == 'quarter' ? 'selected' : ''; ?>>季度</option>
                    <option value="year" <?php echo $period == 'year' ? 'selected' : ''; ?>>年度</option>
                </select>
            </div>

            <div class="form-group">
                <label for="year">年份:</label>
                <select name="year" id="year" class="form-control" onchange="this.form.submit()">
                    <?php for ($y = $currentYear - 5; $y <= $currentYear; $y++): ?>
                        <option value="<?php echo $y; ?>" <?php echo $year == $y ? 'selected' : ''; ?>><?php echo $y; ?>年</option>
                    <?php endfor; ?>
                </select>
            </div>

            <?php if ($period == 'month'): ?>
                <div class="form-group">
                    <label for="month">月份:</label>
                    <select name="month" id="month" class="form-control" onchange="this.form.submit()">
                        <?php for ($m = 1; $m <= 12; $m++): ?>
                            <option value="<?php echo $m; ?>" <?php echo $month == $m ? 'selected' : ''; ?>><?php echo $m; ?>月</option>
                        <?php endfor; ?>
                    </select>
                </div>
            <?php endif; ?>

            <?php if ($period == 'quarter'): ?>
                <div class="form-group">
                    <label for="quarter">季度:</label>
                    <select name="quarter" id="quarter" class="form-control" onchange="this.form.submit()">
                        <?php for ($q = 1; $q <= 4; $q++): ?>
                            <option value="<?php echo $q; ?>" <?php echo (isset($_GET['quarter']) ? intval($_GET['quarter']) : ceil($currentMonth / 3)) == $q ? 'selected' : ''; ?>>第<?php echo $q; ?>季度</option>
                        <?php endfor; ?>
                    </select>
                </div>
            <?php endif; ?>
        </form>
    </div>

    <div class="summary-section">
        <div class="section-title">
            <h3><?php echo $periodTitle; ?>客户来源概览</h3>
        </div>

        <div class="summary-cards">
            <div class="summary-card">
                <div class="summary-title">总预订数</div>
                <div class="summary-value"><?php echo $totalBookings; ?></div>
            </div>
            <div class="summary-card">
                <div class="summary-title">总营收</div>
                <div class="summary-value">¥<?php echo number_format($totalRevenue, 2); ?></div>
            </div>
            <div class="summary-card">
                <div class="summary-title">会员预订占比</div>
                <div class="summary-value">
                    <?php
                    $memberPercentage = $totalBookings > 0 ? round(($memberData['会员']['booking_count'] / $totalBookings) * 100, 2) : 0;
                    echo $memberPercentage . '%';
                    ?>
                </div>
            </div>
            <div class="summary-card">
                <div class="summary-title">非会员预订占比</div>
                <div class="summary-value">
                    <?php
                    $nonMemberPercentage = $totalBookings > 0 ? round(($memberData['非会员']['booking_count'] / $totalBookings) * 100, 2) : 0;
                    echo $nonMemberPercentage . '%';
                    ?>
                </div>
            </div>
        </div>
    </div>

    <div class="chart-section">
        <div class="chart-row">
            <div class="chart-card">
                <div class="card-header">
                    <h3>客户来源分布</h3>
                </div>
                <div class="card-body">
                    <div class="chart-container">
                        <canvas id="sourceDistributionChart"></canvas>
                    </div>
                </div>
            </div>

            <div class="chart-card">
                <div class="card-header">
                    <h3>会员与非会员分布</h3>
                </div>
                <div class="card-body">
                    <div class="chart-container">
                        <canvas id="memberDistributionChart"></canvas>
                    </div>
                </div>
            </div>
        </div>

        <div class="chart-card">
            <div class="card-header">
                <h3>客户来源趋势</h3>
            </div>
            <div class="card-body">
                <div class="chart-container">
                    <canvas id="sourceTrendChart"></canvas>
                </div>
            </div>
        </div>
    </div>

    <div class="data-section">
        <div class="section-title">
            <h3>客户来源详细数据</h3>
        </div>

        <table class="data-table">
            <thead>
                <tr>
                    <th>来源</th>
                    <th>预订数量</th>
                    <th>占比</th>
                    <th>营收金额</th>
                    <th>平均订单金额</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($sourceData as $source): ?>
                    <tr>
                        <td>
                            <?php
                            switch ($source['booking_source']) {
                                case 'direct':
                                    echo '直接预订';
                                    break;
                                case 'website':
                                    echo '官网';
                                    break;
                                case 'phone':
                                    echo '电话';
                                    break;
                                case 'email':
                                    echo '邮件';
                                    break;
                                case 'ota':
                                    echo 'OTA平台';
                                    break;
                                case 'walk_in':
                                    echo '门店直接';
                                    break;
                                default:
                                    echo $source['booking_source'];
                            }
                            ?>
                        </td>
                        <td><?php echo $source['booking_count']; ?></td>
                        <td><?php echo $totalBookings > 0 ? round(($source['booking_count'] / $totalBookings) * 100, 2) . '%' : '0%'; ?></td>
                        <td>¥<?php echo number_format($source['total_revenue'], 2); ?></td>
                        <td>¥<?php echo $source['booking_count'] > 0 ? number_format($source['total_revenue'] / $source['booking_count'], 2) : '0.00'; ?></td>
                    </tr>
                <?php endforeach; ?>
                <?php if (empty($sourceData)): ?>
                    <tr>
                        <td colspan="5">暂无数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <?php if (!empty($otaData)): ?>
        <div class="data-section">
            <div class="section-title">
                <h3>OTA平台细分数据</h3>
            </div>

            <table class="data-table">
                <thead>
                    <tr>
                        <th>OTA平台</th>
                        <th>预订数量</th>
                        <th>占OTA总量比例</th>
                        <th>营收金额</th>
                        <th>平均订单金额</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    $otaTotalBookings = 0;
                    foreach ($otaData as $ota) {
                        $otaTotalBookings += $ota['booking_count'];
                    }
                    ?>
                    <?php foreach ($otaData as $ota): ?>
                        <tr>
                            <td><?php echo $ota['ota_name'] ? $ota['ota_name'] : '未指定'; ?></td>
                            <td><?php echo $ota['booking_count']; ?></td>
                            <td><?php echo $otaTotalBookings > 0 ? round(($ota['booking_count'] / $otaTotalBookings) * 100, 2) . '%' : '0%'; ?></td>
                            <td>¥<?php echo number_format($ota['total_revenue'], 2); ?></td>
                            <td>¥<?php echo $ota['booking_count'] > 0 ? number_format($ota['total_revenue'] / $ota['booking_count'], 2) : '0.00'; ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>
</div>

<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 客户来源分布图表
        const sourceCtx = document.getElementById('sourceDistributionChart').getContext('2d');
        const sourceChart = new Chart(sourceCtx, {
            type: 'doughnut',
            data: {
                labels: [
                    <?php
                    foreach ($sourceData as $source) {
                        $label = '';
                        switch ($source['booking_source']) {
                            case 'direct':
                                $label = '直接预订';
                                break;
                            case 'website':
                                $label = '官网';
                                break;
                            case 'phone':
                                $label = '电话';
                                break;
                            case 'email':
                                $label = '邮件';
                                break;
                            case 'ota':
                                $label = 'OTA平台';
                                break;
                            case 'walk_in':
                                $label = '门店直接';
                                break;
                            default:
                                $label = $source['booking_source'];
                        }
                        echo "'" . $label . "',";
                    }
                    ?>
                ],
                datasets: [{
                    data: [
                        <?php
                        foreach ($sourceData as $source) {
                            echo $source['booking_count'] . ",";
                        }
                        ?>
                    ],
                    backgroundColor: [
                        '#4e73df', '#1cc88a', '#36b9cc', '#f6c23e', '#e74a3b', '#858796'
                    ],
                    hoverBackgroundColor: [
                        '#2e59d9', '#17a673', '#2c9faf', '#dda20a', '#be2617', '#60616f'
                    ],
                    hoverBorderColor: "rgba(234, 236, 244, 1)",
                }]
            },
            options: {
                maintainAspectRatio: false,
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    caretPadding: 10,
                },
                legend: {
                    display: true,
                    position: 'bottom'
                },
                cutoutPercentage: 70,
            },
        });

        // 会员与非会员分布图表
        const memberCtx = document.getElementById('memberDistributionChart').getContext('2d');
        const memberChart = new Chart(memberCtx, {
            type: 'doughnut',
            data: {
                labels: ['会员', '非会员'],
                datasets: [{
                    data: [
                        <?php echo $memberData['会员']['booking_count']; ?>,
                        <?php echo $memberData['非会员']['booking_count']; ?>
                    ],
                    backgroundColor: ['#4e73df', '#1cc88a'],
                    hoverBackgroundColor: ['#2e59d9', '#17a673'],
                    hoverBorderColor: "rgba(234, 236, 244, 1)",
                }]
            },
            options: {
                maintainAspectRatio: false,
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    caretPadding: 10,
                },
                legend: {
                    display: true,
                    position: 'bottom'
                },
                cutoutPercentage: 70,
            },
        });

        // 客户来源趋势图表
        const trendCtx = document.getElementById('sourceTrendChart').getContext('2d');
        const trendChart = new Chart(trendCtx, {
            type: 'bar',
            data: {
                labels: <?php echo json_encode($trendLabels); ?>,
                datasets: [{
                        label: '直接预订',
                        backgroundColor: '#4e73df',
                        data: [
                            <?php
                            foreach ($trendData as $data) {
                                echo $data['direct'] . ",";
                            }
                            ?>
                        ],
                    },
                    {
                        label: '官网',
                        backgroundColor: '#1cc88a',
                        data: [
                            <?php
                            foreach ($trendData as $data) {
                                echo $data['website'] . ",";
                            }
                            ?>
                        ],
                    },
                    {
                        label: '电话',
                        backgroundColor: '#36b9cc',
                        data: [
                            <?php
                            foreach ($trendData as $data) {
                                echo $data['phone'] . ",";
                            }
                            ?>
                        ],
                    },
                    {
                        label: '邮件',
                        backgroundColor: '#f6c23e',
                        data: [
                            <?php
                            foreach ($trendData as $data) {
                                echo $data['email'] . ",";
                            }
                            ?>
                        ],
                    },
                    {
                        label: 'OTA平台',
                        backgroundColor: '#e74a3b',
                        data: [
                            <?php
                            foreach ($trendData as $data) {
                                echo $data['ota'] . ",";
                            }
                            ?>
                        ],
                    },
                    {
                        label: '门店直接',
                        backgroundColor: '#858796',
                        data: [
                            <?php
                            foreach ($trendData as $data) {
                                echo $data['walk_in'] . ",";
                            }
                            ?>
                        ],
                    }
                ]
            },
            options: {
                maintainAspectRatio: false,
                layout: {
                    padding: {
                        left: 10,
                        right: 25,
                        top: 25,
                        bottom: 0
                    }
                },
                scales: {
                    xAxes: [{
                        stacked: true,
                        gridLines: {
                            display: false,
                            drawBorder: false
                        }
                    }],
                    yAxes: [{
                        stacked: true,
                        ticks: {
                            min: 0,
                            maxTicksLimit: 5,
                            padding: 10
                        },
                        gridLines: {
                            color: "rgb(234, 236, 244)",
                            zeroLineColor: "rgb(234, 236, 244)",
                            drawBorder: false,
                            borderDash: [2],
                            zeroLineBorderDash: [2]
                        }
                    }],
                },
                legend: {
                    display: true,
                    position: 'bottom'
                },
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    titleMarginBottom: 10,
                    titleFontColor: '#6e707e',
                    titleFontSize: 14,
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: true,
                    intersect: false,
                    mode: 'index',
                    caretPadding: 10
                }
            }
        });
    });
</script>

<style>
    .analysis-container {
        padding: 15px 0;
    }

    .filter-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
    }

    .form-group {
        flex: 1;
        min-width: 150px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: 500;
        color: #333;
    }

    .form-control {
        width: 100%;
        padding: 8px 12px;
        border: 1px solid #d1d3e2;
        border-radius: 4px;
        background-color: #f8f9fc;
    }

    .summary-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .section-title {
        margin-bottom: 15px;
    }

    .section-title h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .summary-cards {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
    }

    .summary-card {
        background-color: #f8f9fc;
        border-radius: 8px;
        padding: 15px;
        flex: 1;
        min-width: 150px;
        text-align: center;
    }

    .summary-title {
        font-size: 14px;
        color: #6c757d;
        margin-bottom: 5px;
    }

    .summary-value {
        font-size: 24px;
        font-weight: bold;
        color: #0066cc;
    }

    .chart-section {
        margin-bottom: 20px;
    }

    .chart-row {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .chart-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        flex: 1;
        min-width: 300px;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e3e6f0;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .card-body {
        padding: 15px;
    }

    .chart-container {
        height: 300px;
    }

    .data-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px 15px;
        text-align: left;
        border-bottom: 1px solid #e3e6f0;
    }

    .data-table th {
        background-color: #f8f9fc;
        font-weight: 600;
    }
</style>