<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前日期和上个月的日期
$currentDate = date('Y-m-d');
$lastMonthDate = date('Y-m-d', strtotime('-1 month'));
$currentMonth = date('Y-m');
$lastMonth = date('Y-m', strtotime('-1 month'));

// 获取统计数据
$stats = array();

// 获取本月入住率
$sql = "SELECT 
            COUNT(DISTINCT br.room_id) as occupied_rooms,
            (SELECT COUNT(*) FROM rooms) as total_rooms
        FROM booking_rooms br
        JOIN bookings b ON br.booking_id = b.id
        WHERE br.status = 'checked_in' 
        AND DATE_FORMAT(b.check_in_date, '%Y-%m') = '$currentMonth'";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['occupancy_rate'] = $row['total_rooms'] > 0 ? round(($row['occupied_rooms'] / $row['total_rooms']) * 100, 2) : 0;
} else {
    $stats['occupancy_rate'] = 0;
}

// 获取本月营收
$sql = "SELECT SUM(total_amount) as revenue
        FROM bookings
        WHERE DATE_FORMAT(check_in_date, '%Y-%m') = '$currentMonth'
        AND status IN ('confirmed', 'checked_in', 'checked_out')";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['monthly_revenue'] = $row['revenue'] ? $row['revenue'] : 0;
} else {
    $stats['monthly_revenue'] = 0;
}

// 获取本月客户数量
$sql = "SELECT COUNT(DISTINCT guest_id_number) as customer_count
        FROM bookings
        WHERE DATE_FORMAT(check_in_date, '%Y-%m') = '$currentMonth'";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['customer_count'] = $row['customer_count'];
} else {
    $stats['customer_count'] = 0;
}

// 获取本月平均住宿天数
$sql = "SELECT AVG(DATEDIFF(check_out_date, check_in_date)) as avg_stay
        FROM bookings
        WHERE DATE_FORMAT(check_in_date, '%Y-%m') = '$currentMonth'
        AND status IN ('confirmed', 'checked_in', 'checked_out')";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['avg_stay'] = $row['avg_stay'] ? round($row['avg_stay'], 1) : 0;
} else {
    $stats['avg_stay'] = 0;
}

// 获取本月运营成本
$sql = "SELECT 
            (SELECT COALESCE(SUM(cost), 0) FROM utility_usage WHERE DATE_FORMAT(reading_date, '%Y-%m') = '$currentMonth') +
            (SELECT COALESCE(SUM(cost), 0) FROM maintenance_records WHERE DATE_FORMAT(reported_date, '%Y-%m') = '$currentMonth') as operation_cost";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['operation_cost'] = $row['operation_cost'] ? $row['operation_cost'] : 0;
} else {
    $stats['operation_cost'] = 0;
}

// 获取客户来源分布
$sql = "SELECT booking_source, COUNT(*) as count
        FROM bookings
        WHERE DATE_FORMAT(check_in_date, '%Y-%m') = '$currentMonth'
        GROUP BY booking_source
        ORDER BY count DESC";
$result = $conn->query($sql);
$customerSources = array();
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $customerSources[] = $row;
    }
}

// 获取最受欢迎的房型
$sql = "SELECT rt.name, COUNT(br.id) as booking_count
        FROM booking_rooms br
        JOIN rooms r ON br.room_id = r.id
        JOIN room_types rt ON r.room_type_id = rt.id
        JOIN bookings b ON br.booking_id = b.id
        WHERE DATE_FORMAT(b.check_in_date, '%Y-%m') = '$currentMonth'
        GROUP BY rt.id
        ORDER BY booking_count DESC
        LIMIT 5";
$result = $conn->query($sql);
$popularRoomTypes = array();
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $popularRoomTypes[] = $row;
    }
}
?>

<div class="dashboard">
    <div class="dashboard-stats">
        <div class="stat-card">
            <div class="stat-value"><?php echo $stats['occupancy_rate']; ?>%</div>
            <div class="stat-label">本月入住率</div>
        </div>
        <div class="stat-card">
            <div class="stat-value">¥<?php echo number_format($stats['monthly_revenue'], 2); ?></div>
            <div class="stat-label">本月营收</div>
        </div>
        <div class="stat-card">
            <div class="stat-value"><?php echo $stats['customer_count']; ?></div>
            <div class="stat-label">本月客户数</div>
        </div>
        <div class="stat-card">
            <div class="stat-value"><?php echo $stats['avg_stay']; ?> 天</div>
            <div class="stat-label">平均住宿天数</div>
        </div>
        <div class="stat-card">
            <div class="stat-value">¥<?php echo number_format($stats['operation_cost'], 2); ?></div>
            <div class="stat-label">本月运营成本</div>
        </div>
    </div>

    <div class="dashboard-row">
        <div class="dashboard-card">
            <div class="card-header">
                <h3>客户来源分布</h3>
            </div>
            <div class="card-body">
                <div class="chart-container">
                    <canvas id="customerSourceChart"></canvas>
                </div>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>来源</th>
                            <th>数量</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($customerSources as $source): ?>
                            <tr>
                                <td>
                                    <?php
                                    switch ($source['booking_source']) {
                                        case 'direct':
                                            echo '直接预订';
                                            break;
                                        case 'website':
                                            echo '官网';
                                            break;
                                        case 'phone':
                                            echo '电话';
                                            break;
                                        case 'email':
                                            echo '邮件';
                                            break;
                                        case 'ota':
                                            echo 'OTA平台';
                                            break;
                                        case 'walk_in':
                                            echo '门店直接';
                                            break;
                                        default:
                                            echo $source['booking_source'];
                                    }
                                    ?>
                                </td>
                                <td><?php echo $source['count']; ?></td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($customerSources)): ?>
                            <tr>
                                <td colspan="2">暂无数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <div class="dashboard-card">
            <div class="card-header">
                <h3>最受欢迎的房型</h3>
            </div>
            <div class="card-body">
                <div class="chart-container">
                    <canvas id="popularRoomTypesChart"></canvas>
                </div>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>房型名称</th>
                            <th>预订次数</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($popularRoomTypes as $type): ?>
                            <tr>
                                <td><?php echo $type['name']; ?></td>
                                <td><?php echo $type['booking_count']; ?></td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($popularRoomTypes)): ?>
                            <tr>
                                <td colspan="2">暂无数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <div class="dashboard-actions">
        <a href="index.php?page=occupancy" class="btn btn-primary">查看入住率详情</a>
        <a href="index.php?page=revenue_trend" class="btn btn-secondary">查看营收趋势</a>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 客户来源分布图表
        const customerSourceCtx = document.getElementById('customerSourceChart').getContext('2d');
        const customerSourceData = {
            labels: [
                <?php
                foreach ($customerSources as $source) {
                    $label = '';
                    switch ($source['booking_source']) {
                        case 'direct':
                            $label = '直接预订';
                            break;
                        case 'website':
                            $label = '官网';
                            break;
                        case 'phone':
                            $label = '电话';
                            break;
                        case 'email':
                            $label = '邮件';
                            break;
                        case 'ota':
                            $label = 'OTA平台';
                            break;
                        case 'walk_in':
                            $label = '门店直接';
                            break;
                        default:
                            $label = $source['booking_source'];
                    }
                    echo "'" . $label . "',";
                }
                ?>
            ],
            datasets: [{
                data: [
                    <?php
                    foreach ($customerSources as $source) {
                        echo $source['count'] . ",";
                    }
                    ?>
                ],
                backgroundColor: [
                    '#4e73df', '#1cc88a', '#36b9cc', '#f6c23e', '#e74a3b', '#858796'
                ],
                hoverBackgroundColor: [
                    '#2e59d9', '#17a673', '#2c9faf', '#dda20a', '#be2617', '#60616f'
                ],
                hoverBorderColor: "rgba(234, 236, 244, 1)",
            }]
        };
        new Chart(customerSourceCtx, {
            type: 'doughnut',
            data: customerSourceData,
            options: {
                maintainAspectRatio: false,
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    caretPadding: 10,
                },
                legend: {
                    display: false
                },
                cutoutPercentage: 70,
            },
        });

        // 最受欢迎的房型图表
        const popularRoomTypesCtx = document.getElementById('popularRoomTypesChart').getContext('2d');
        const popularRoomTypesData = {
            labels: [
                <?php
                foreach ($popularRoomTypes as $type) {
                    echo "'" . $type['name'] . "',";
                }
                ?>
            ],
            datasets: [{
                label: '预订次数',
                data: [
                    <?php
                    foreach ($popularRoomTypes as $type) {
                        echo $type['booking_count'] . ",";
                    }
                    ?>
                ],
                backgroundColor: '#4e73df',
                hoverBackgroundColor: '#2e59d9',
                borderColor: '#4e73df',
            }]
        };
        new Chart(popularRoomTypesCtx, {
            type: 'bar',
            data: popularRoomTypesData,
            options: {
                maintainAspectRatio: false,
                scales: {
                    yAxes: [{
                        ticks: {
                            beginAtZero: true
                        }
                    }]
                },
                legend: {
                    display: false
                }
            }
        });
    });
</script>

<style>
    .dashboard {
        padding: 15px 0;
    }

    .dashboard-stats {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        margin-bottom: 20px;
    }

    .stat-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        flex: 1;
        min-width: 150px;
        text-align: center;
    }

    .stat-value {
        font-size: 24px;
        font-weight: bold;
        color: #0066cc;
        margin-bottom: 5px;
    }

    .stat-label {
        color: #6c757d;
        font-size: 14px;
    }

    .dashboard-row {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .dashboard-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        flex: 1;
        min-width: 300px;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e3e6f0;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .card-body {
        padding: 15px;
    }

    .chart-container {
        height: 250px;
        margin-bottom: 15px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 8px 12px;
        text-align: left;
        border-bottom: 1px solid #e3e6f0;
    }

    .data-table th {
        background-color: #f8f9fc;
        font-weight: 600;
    }

    .dashboard-actions {
        display: flex;
        gap: 10px;
        justify-content: flex-end;
    }

    .btn {
        display: inline-block;
        padding: 8px 16px;
        border-radius: 4px;
        text-decoration: none;
        font-weight: 500;
        cursor: pointer;
        transition: background-color 0.2s;
    }

    .btn-primary {
        background-color: #0066cc;
        color: #fff;
    }

    .btn-primary:hover {
        background-color: #0056b3;
    }

    .btn-secondary {
        background-color: #6c757d;
        color: #fff;
    }

    .btn-secondary:hover {
        background-color: #5a6268;
    }
</style>