<?php
session_start();
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前页面
$page = isset($_GET['page']) ? $_GET['page'] : 'dashboard';

// 页面标题
$pageTitle = '数据分析与报表';

// 获取子页面内容
$contentFile = '';
switch ($page) {
    case 'occupancy':
        $contentFile = 'occupancy.php';
        $subTitle = '房间入住率分析';
        break;
    case 'customer_source':
        $contentFile = 'customer_source.php';
        $subTitle = '客户来源分析';
        break;
    case 'revenue_trend':
        $contentFile = 'revenue_trend.php';
        $subTitle = '营收趋势分析';
        break;
    case 'customer_preference':
        $contentFile = 'customer_preference.php';
        $subTitle = '客户偏好分析';
        break;
    case 'operation_cost':
        $contentFile = 'operation_cost.php';
        $subTitle = '运营成本分析';
        break;
    default:
        $contentFile = 'dashboard.php';
        $subTitle = '概览';
        break;
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $subTitle; ?> - <?php echo $pageTitle; ?> - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="../../assets/css/style.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/css/bootstrap.min.css">
    <script src="https://cdn.jsdelivr.net/npm/jquery@3.6.4/dist/jquery.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/js/bootstrap.bundle.min.js"></script>
</head>

<body>
    <header class="main-header">
        <div class="user-info">
            <span class="user-name"><?php echo $_SESSION['user_name']; ?></span>
            <span class="user-role"><?php echo $_SESSION['user_role']; ?></span>
        </div>

        <div class="site-title">
            <h1><?php echo SITE_NAME; ?></h1>
            <p><?php echo SITE_SUBTITLE; ?></p>
        </div>

        <div class="header-actions">
            <a href="../../logout.php" class="btn btn-logout">退出登录</a>
        </div>
    </header>

    <div class="module-layout">
        <aside class="module-sidebar">
            <div class="module-sidebar-header">
                <h2><?php echo $pageTitle; ?></h2>
            </div>

            <nav class="module-nav">
                <a href="../../home.php" class="module-nav-item">返回首页</a>
                <a href="index.php" class="module-nav-item <?php echo $page == 'dashboard' ? 'active' : ''; ?>">概览</a>
                <a href="index.php?page=occupancy" class="module-nav-item <?php echo $page == 'occupancy' ? 'active' : ''; ?>">房间入住率分析</a>
                <a href="index.php?page=customer_source" class="module-nav-item <?php echo $page == 'customer_source' ? 'active' : ''; ?>">客户来源分析</a>
                <a href="index.php?page=revenue_trend" class="module-nav-item <?php echo $page == 'revenue_trend' ? 'active' : ''; ?>">营收趋势分析</a>
                <a href="index.php?page=customer_preference" class="module-nav-item <?php echo $page == 'customer_preference' ? 'active' : ''; ?>">客户偏好分析</a>
                <a href="index.php?page=operation_cost" class="module-nav-item <?php echo $page == 'operation_cost' ? 'active' : ''; ?>">运营成本分析</a>
            </nav>
        </aside>

        <main class="module-content">
            <div class="module-content-header">
                <h2><?php echo $subTitle; ?></h2>
            </div>

            <?php
            // 包含子页面内容
            if (file_exists($contentFile)) {
                include $contentFile;
            } else {
                echo '<div class="alert alert-error">页面不存在</div>';
            }
            ?>
        </main>
    </div>

    <footer class="main-footer">
        <p>&copy; <?php echo date('Y'); ?> <?php echo SITE_NAME; ?> - 版权所有</p>
    </footer>

    <script src="../../assets/js/script.js"></script>
</body>

</html>