<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取分析周期
$period = isset($_GET['period']) ? $_GET['period'] : 'month';
$year = isset($_GET['year']) ? intval($_GET['year']) : date('Y');
$month = isset($_GET['month']) ? intval($_GET['month']) : date('n');

// 获取当前日期
$currentDate = date('Y-m-d');
$currentYear = date('Y');
$currentMonth = date('n');

// 根据周期设置日期范围
$startDate = '';
$endDate = '';
$dateFormat = '';
$groupBy = '';
$chartLabels = [];

switch ($period) {
    case 'day':
        // 按日统计，显示当月每天的入住率
        $startDate = date('Y-m-01', strtotime("$year-$month-01"));
        $endDate = date('Y-m-t', strtotime("$year-$month-01"));
        $dateFormat = 'Y-m-d';
        $groupBy = "DATE(b.check_in_date)";

        // 生成当月所有日期
        $start = new DateTime($startDate);
        $end = new DateTime($endDate);
        $interval = new DateInterval('P1D');
        $dateRange = new DatePeriod($start, $interval, $end->modify('+1 day'));

        foreach ($dateRange as $date) {
            $chartLabels[] = $date->format('d');
        }
        break;

    case 'week':
        // 按周统计，显示当年每周的入住率
        $startDate = date('Y-01-01', strtotime("$year-01-01"));
        $endDate = date('Y-12-31', strtotime("$year-12-31"));
        $dateFormat = 'Y-W';
        $groupBy = "YEARWEEK(b.check_in_date, 1)";

        // 生成当年所有周
        for ($i = 1; $i <= 53; $i++) {
            $chartLabels[] = "第{$i}周";
        }
        break;

    case 'month':
    default:
        // 按月统计，显示当年每月的入住率
        $startDate = date('Y-01-01', strtotime("$year-01-01"));
        $endDate = date('Y-12-31', strtotime("$year-12-31"));
        $dateFormat = 'Y-m';
        $groupBy = "DATE_FORMAT(b.check_in_date, '%Y-%m')";

        // 生成当年所有月份
        for ($i = 1; $i <= 12; $i++) {
            $chartLabels[] = date('n月', strtotime("$year-$i-01"));
        }
        break;
}

// 获取房间总数
$sql = "SELECT COUNT(*) as total FROM rooms";
$result = $conn->query($sql);
$totalRooms = 0;
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $totalRooms = $row['total'];
}

// 获取入住率数据
$occupancyData = [];
$occupancyRates = [];

if ($totalRooms > 0) {
    switch ($period) {
        case 'day':
            $sql = "SELECT 
                        DATE(b.check_in_date) as date,
                        COUNT(DISTINCT br.room_id) as occupied_rooms
                    FROM booking_rooms br
                    JOIN bookings b ON br.booking_id = b.id
                    WHERE br.status = 'checked_in' 
                    AND b.check_in_date BETWEEN '$startDate' AND '$endDate'
                    GROUP BY DATE(b.check_in_date)
                    ORDER BY DATE(b.check_in_date)";
            break;

        case 'week':
            $sql = "SELECT 
                        YEARWEEK(b.check_in_date, 1) as week,
                        COUNT(DISTINCT br.room_id) as occupied_rooms
                    FROM booking_rooms br
                    JOIN bookings b ON br.booking_id = b.id
                    WHERE br.status = 'checked_in' 
                    AND b.check_in_date BETWEEN '$startDate' AND '$endDate'
                    GROUP BY YEARWEEK(b.check_in_date, 1)
                    ORDER BY YEARWEEK(b.check_in_date, 1)";
            break;

        case 'month':
        default:
            $sql = "SELECT 
                        DATE_FORMAT(b.check_in_date, '%Y-%m') as month,
                        COUNT(DISTINCT br.room_id) as occupied_rooms
                    FROM booking_rooms br
                    JOIN bookings b ON br.booking_id = b.id
                    WHERE br.status = 'checked_in' 
                    AND b.check_in_date BETWEEN '$startDate' AND '$endDate'
                    GROUP BY DATE_FORMAT(b.check_in_date, '%Y-%m')
                    ORDER BY DATE_FORMAT(b.check_in_date, '%Y-%m')";
            break;
    }

    $result = $conn->query($sql);
    if ($result && $result->num_rows > 0) {
        while ($row = $result->fetch_assoc()) {
            $key = isset($row['date']) ? $row['date'] : (isset($row['week']) ? $row['week'] : $row['month']);
            $occupancyData[$key] = $row['occupied_rooms'];
        }
    }

    // 计算每个时间段的入住率
    switch ($period) {
        case 'day':
            $start = new DateTime($startDate);
            $end = new DateTime($endDate);
            $interval = new DateInterval('P1D');
            $dateRange = new DatePeriod($start, $interval, $end->modify('+1 day'));

            foreach ($dateRange as $date) {
                $dateKey = $date->format('Y-m-d');
                $occupiedRooms = isset($occupancyData[$dateKey]) ? $occupancyData[$dateKey] : 0;
                $occupancyRates[$date->format('d')] = round(($occupiedRooms / $totalRooms) * 100, 2);
            }
            break;

        case 'week':
            for ($i = 1; $i <= 53; $i++) {
                $weekKey = date('Y') . sprintf('%02d', $i);
                $occupiedRooms = isset($occupancyData[$weekKey]) ? $occupancyData[$weekKey] : 0;
                $occupancyRates["第{$i}周"] = round(($occupiedRooms / $totalRooms) * 100, 2);
            }
            break;

        case 'month':
        default:
            for ($i = 1; $i <= 12; $i++) {
                $monthKey = $year . '-' . sprintf('%02d', $i);
                $occupiedRooms = isset($occupancyData[$monthKey]) ? $occupancyData[$monthKey] : 0;
                $occupancyRates[date('n月', strtotime("$year-$i-01"))] = round(($occupiedRooms / $totalRooms) * 100, 2);
            }
            break;
    }
}

// 获取房型入住率数据
$sql = "SELECT 
            rt.id,
            rt.name,
            COUNT(DISTINCT r.id) as total_rooms
        FROM room_types rt
        LEFT JOIN rooms r ON rt.id = r.room_type_id
        GROUP BY rt.id";
$result = $conn->query($sql);
$roomTypes = [];
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $roomTypes[$row['id']] = [
            'name' => $row['name'],
            'total_rooms' => $row['total_rooms'],
            'occupied_rooms' => 0,
            'occupancy_rate' => 0
        ];
    }
}

// 获取当前选定周期的房型入住数据
$sql = "SELECT 
            rt.id,
            COUNT(DISTINCT br.room_id) as occupied_rooms
        FROM booking_rooms br
        JOIN rooms r ON br.room_id = r.id
        JOIN room_types rt ON r.room_type_id = rt.id
        JOIN bookings b ON br.booking_id = b.id
        WHERE br.status = 'checked_in'";

switch ($period) {
    case 'day':
        $sql .= " AND DATE(b.check_in_date) = '$currentDate'";
        break;
    case 'week':
        $sql .= " AND YEARWEEK(b.check_in_date, 1) = YEARWEEK('$currentDate', 1)";
        break;
    case 'month':
    default:
        $sql .= " AND DATE_FORMAT(b.check_in_date, '%Y-%m') = DATE_FORMAT('$currentDate', '%Y-%m')";
        break;
}

$sql .= " GROUP BY rt.id";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        if (isset($roomTypes[$row['id']])) {
            $roomTypes[$row['id']]['occupied_rooms'] = $row['occupied_rooms'];
            if ($roomTypes[$row['id']]['total_rooms'] > 0) {
                $roomTypes[$row['id']]['occupancy_rate'] = round(($row['occupied_rooms'] / $roomTypes[$row['id']]['total_rooms']) * 100, 2);
            }
        }
    }
}
?>

<div class="analysis-container">
    <div class="filter-section">
        <form method="get" action="index.php" class="filter-form">
            <input type="hidden" name="page" value="occupancy">

            <div class="form-group">
                <label for="period">统计周期:</label>
                <select name="period" id="period" class="form-control" onchange="this.form.submit()">
                    <option value="day" <?php echo $period == 'day' ? 'selected' : ''; ?>>按日</option>
                    <option value="week" <?php echo $period == 'week' ? 'selected' : ''; ?>>按周</option>
                    <option value="month" <?php echo $period == 'month' ? 'selected' : ''; ?>>按月</option>
                </select>
            </div>

            <div class="form-group">
                <label for="year">年份:</label>
                <select name="year" id="year" class="form-control" onchange="this.form.submit()">
                    <?php for ($y = $currentYear - 5; $y <= $currentYear; $y++): ?>
                        <option value="<?php echo $y; ?>" <?php echo $year == $y ? 'selected' : ''; ?>><?php echo $y; ?>年</option>
                    <?php endfor; ?>
                </select>
            </div>

            <?php if ($period == 'day'): ?>
                <div class="form-group">
                    <label for="month">月份:</label>
                    <select name="month" id="month" class="form-control" onchange="this.form.submit()">
                        <?php for ($m = 1; $m <= 12; $m++): ?>
                            <option value="<?php echo $m; ?>" <?php echo $month == $m ? 'selected' : ''; ?>><?php echo $m; ?>月</option>
                        <?php endfor; ?>
                    </select>
                </div>
            <?php endif; ?>
        </form>
    </div>

    <div class="chart-section">
        <div class="chart-container">
            <canvas id="occupancyChart"></canvas>
        </div>
    </div>

    <div class="data-section">
        <div class="section-title">
            <h3>房型入住率分析</h3>
            <p class="section-subtitle">
                <?php
                switch ($period) {
                    case 'day':
                        echo date('Y年m月d日', strtotime($currentDate));
                        break;
                    case 'week':
                        echo date('Y年', strtotime($currentDate)) . '第' . date('W', strtotime($currentDate)) . '周';
                        break;
                    case 'month':
                    default:
                        echo date('Y年m月', strtotime($currentDate));
                        break;
                }
                ?>
            </p>
        </div>

        <table class="data-table">
            <thead>
                <tr>
                    <th>房型名称</th>
                    <th>房间总数</th>
                    <th>已入住房间</th>
                    <th>入住率</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($roomTypes as $roomType): ?>
                    <tr>
                        <td><?php echo $roomType['name']; ?></td>
                        <td><?php echo $roomType['total_rooms']; ?></td>
                        <td><?php echo $roomType['occupied_rooms']; ?></td>
                        <td>
                            <div class="progress-bar-container">
                                <div class="progress-bar" style="width: <?php echo $roomType['occupancy_rate']; ?>%"></div>
                                <span class="progress-text"><?php echo $roomType['occupancy_rate']; ?>%</span>
                            </div>
                        </td>
                    </tr>
                <?php endforeach; ?>
                <?php if (empty($roomTypes)): ?>
                    <tr>
                        <td colspan="4">暂无数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <div class="summary-section">
        <div class="summary-card">
            <div class="summary-title">平均入住率</div>
            <div class="summary-value">
                <?php
                $avgOccupancyRate = !empty($occupancyRates) ? array_sum($occupancyRates) / count($occupancyRates) : 0;
                echo round($avgOccupancyRate, 2) . '%';
                ?>
            </div>
        </div>
        <div class="summary-card">
            <div class="summary-title">最高入住率</div>
            <div class="summary-value">
                <?php
                $maxOccupancyRate = !empty($occupancyRates) ? max($occupancyRates) : 0;
                echo $maxOccupancyRate . '%';
                ?>
            </div>
        </div>
        <div class="summary-card">
            <div class="summary-title">最低入住率</div>
            <div class="summary-value">
                <?php
                $minOccupancyRate = !empty($occupancyRates) ? min($occupancyRates) : 0;
                echo $minOccupancyRate . '%';
                ?>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        const ctx = document.getElementById('occupancyChart').getContext('2d');
        const occupancyChart = new Chart(ctx, {
            type: 'line',
            data: {
                labels: <?php echo json_encode($chartLabels); ?>,
                datasets: [{
                    label: '入住率 (%)',
                    data: <?php echo json_encode(array_values($occupancyRates)); ?>,
                    backgroundColor: 'rgba(78, 115, 223, 0.05)',
                    borderColor: 'rgba(78, 115, 223, 1)',
                    pointBackgroundColor: 'rgba(78, 115, 223, 1)',
                    pointBorderColor: '#fff',
                    pointHoverBackgroundColor: '#fff',
                    pointHoverBorderColor: 'rgba(78, 115, 223, 1)',
                    borderWidth: 2,
                    fill: true
                }]
            },
            options: {
                maintainAspectRatio: false,
                layout: {
                    padding: {
                        left: 10,
                        right: 25,
                        top: 25,
                        bottom: 0
                    }
                },
                scales: {
                    xAxes: [{
                        gridLines: {
                            display: false,
                            drawBorder: false
                        },
                        ticks: {
                            maxTicksLimit: 12
                        }
                    }],
                    yAxes: [{
                        ticks: {
                            min: 0,
                            max: 100,
                            maxTicksLimit: 5,
                            padding: 10,
                            callback: function(value) {
                                return value + '%';
                            }
                        },
                        gridLines: {
                            color: "rgb(234, 236, 244)",
                            zeroLineColor: "rgb(234, 236, 244)",
                            drawBorder: false,
                            borderDash: [2],
                            zeroLineBorderDash: [2]
                        }
                    }],
                },
                legend: {
                    display: false
                },
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    titleMarginBottom: 10,
                    titleFontColor: '#6e707e',
                    titleFontSize: 14,
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    intersect: false,
                    mode: 'index',
                    caretPadding: 10,
                    callbacks: {
                        label: function(tooltipItem, chart) {
                            return '入住率: ' + tooltipItem.yLabel + '%';
                        }
                    }
                }
            }
        });
    });
</script>

<style>
    .analysis-container {
        padding: 15px 0;
    }

    .filter-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
    }

    .form-group {
        flex: 1;
        min-width: 150px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: 500;
        color: #333;
    }

    .form-control {
        width: 100%;
        padding: 8px 12px;
        border: 1px solid #d1d3e2;
        border-radius: 4px;
        background-color: #f8f9fc;
    }

    .chart-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .chart-container {
        height: 350px;
    }

    .data-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .section-title {
        margin-bottom: 15px;
    }

    .section-title h3 {
        margin: 0 0 5px 0;
        font-size: 18px;
        color: #333;
    }

    .section-subtitle {
        color: #6c757d;
        margin: 0;
        font-size: 14px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px 15px;
        text-align: left;
        border-bottom: 1px solid #e3e6f0;
    }

    .data-table th {
        background-color: #f8f9fc;
        font-weight: 600;
    }

    .progress-bar-container {
        width: 100%;
        background-color: #e9ecef;
        border-radius: 4px;
        height: 20px;
        position: relative;
        overflow: hidden;
    }

    .progress-bar {
        height: 100%;
        background-color: #4e73df;
        border-radius: 4px;
    }

    .progress-text {
        position: absolute;
        right: 10px;
        top: 0;
        line-height: 20px;
        color: #333;
        font-size: 12px;
        font-weight: 500;
    }

    .summary-section {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
    }

    .summary-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        flex: 1;
        min-width: 150px;
        text-align: center;
    }

    .summary-title {
        font-size: 14px;
        color: #6c757d;
        margin-bottom: 5px;
    }

    .summary-value {
        font-size: 24px;
        font-weight: bold;
        color: #0066cc;
    }
</style>