<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 获取日期范围
$start_date = $_GET['start_date'] ?? date('Y-m-01'); // 默认本月第一天
$end_date = $_GET['end_date'] ?? date('Y-m-t'); // 默认本月最后一天

// 获取能耗成本
$sql = "SELECT 
            utility_type,
            SUM(consumption) as total_consumption,
            SUM(cost) as total_cost
        FROM utility_usage 
        WHERE reading_date BETWEEN ? AND ?
        GROUP BY utility_type";
$stmt = $conn->prepare($sql);
$stmt->bind_param("ss", $start_date, $end_date);
$stmt->execute();
$utility_costs = $stmt->get_result();

// 获取维修成本
$sql = "SELECT 
            COUNT(*) as maintenance_count,
            SUM(cost) as total_cost,
            priority,
            status
        FROM maintenance_records 
        WHERE reported_date BETWEEN ? AND ?
        GROUP BY priority, status";
$stmt = $conn->prepare($sql);
$stmt->bind_param("ss", $start_date, $end_date);
$stmt->execute();
$maintenance_costs = $stmt->get_result();

// 获取库存消耗成本
$sql = "SELECT 
            ic.name as category_name,
            SUM(it.total_price) as total_cost,
            COUNT(*) as transaction_count
        FROM inventory_transactions it
        JOIN inventory_items ii ON it.item_id = ii.id
        JOIN inventory_categories ic ON ii.category_id = ic.id
        WHERE it.transaction_type = 'consumption'
        AND it.transaction_date BETWEEN ? AND ?
        GROUP BY ic.id";
$stmt = $conn->prepare($sql);
$stmt->bind_param("ss", $start_date, $end_date);
$stmt->execute();
$inventory_costs = $stmt->get_result();

// 计算总成本
$total_utility_cost = 0;
$total_maintenance_cost = 0;
$total_inventory_cost = 0;

$utility_stats = [];
while ($row = $utility_costs->fetch_assoc()) {
    $total_utility_cost += $row['total_cost'];
    $utility_stats[] = $row;
}

$maintenance_stats = [];
while ($row = $maintenance_costs->fetch_assoc()) {
    $total_maintenance_cost += $row['total_cost'];
    $maintenance_stats[] = $row;
}

$inventory_stats = [];
while ($row = $inventory_costs->fetch_assoc()) {
    $total_inventory_cost += $row['total_cost'];
    $inventory_stats[] = $row;
}

$total_operation_cost = $total_utility_cost + $total_maintenance_cost + $total_inventory_cost;

// 获取成本趋势数据
$trend_sql = "SELECT 
    DATE_FORMAT(t.date, '%Y-%m-%d') as date,
    COALESCE(u.total_cost, 0) as utility_cost,
    COALESCE(m.total_cost, 0) as maintenance_cost,
    COALESCE(i.total_cost, 0) as inventory_cost
FROM (
    SELECT CURDATE() - INTERVAL (a.a + (10 * b.a) + (100 * c.a)) DAY as date
    FROM (SELECT 0 as a UNION ALL SELECT 1 UNION ALL SELECT 2 UNION ALL SELECT 3 UNION ALL SELECT 4 UNION ALL SELECT 5 UNION ALL SELECT 6 UNION ALL SELECT 7 UNION ALL SELECT 8 UNION ALL SELECT 9) as a
    CROSS JOIN (SELECT 0 as a UNION ALL SELECT 1 UNION ALL SELECT 2 UNION ALL SELECT 3 UNION ALL SELECT 4 UNION ALL SELECT 5 UNION ALL SELECT 6 UNION ALL SELECT 7 UNION ALL SELECT 8 UNION ALL SELECT 9) as b
    CROSS JOIN (SELECT 0 as a UNION ALL SELECT 1 UNION ALL SELECT 2 UNION ALL SELECT 3 UNION ALL SELECT 4 UNION ALL SELECT 5 UNION ALL SELECT 6 UNION ALL SELECT 7 UNION ALL SELECT 8 UNION ALL SELECT 9) as c
) t
LEFT JOIN (
    SELECT DATE(reading_date) as date, SUM(cost) as total_cost 
    FROM utility_usage 
    GROUP BY DATE(reading_date)
) u ON t.date = u.date
LEFT JOIN (
    SELECT DATE(reported_date) as date, SUM(cost) as total_cost 
    FROM maintenance_records 
    GROUP BY DATE(reported_date)
) m ON t.date = m.date
LEFT JOIN (
    SELECT DATE(transaction_date) as date, SUM(total_price) as total_cost 
    FROM inventory_transactions 
    WHERE transaction_type = 'consumption'
    GROUP BY DATE(transaction_date)
) i ON t.date = i.date
WHERE t.date BETWEEN ? AND ?
ORDER BY t.date";

$stmt = $conn->prepare($trend_sql);
$stmt->bind_param("ss", $start_date, $end_date);
$stmt->execute();
$trend_result = $stmt->get_result();

$trend_dates = [];
$trend_utility = [];
$trend_maintenance = [];
$trend_inventory = [];

while ($row = $trend_result->fetch_assoc()) {
    $trend_dates[] = $row['date'];
    $trend_utility[] = floatval($row['utility_cost']);
    $trend_maintenance[] = floatval($row['maintenance_cost']);
    $trend_inventory[] = floatval($row['inventory_cost']);
}

// 处理导出Excel请求
if (isset($_GET['export']) && $_GET['export'] == 'excel') {
    // 设置header为Excel文件
    header('Content-Type: application/vnd.ms-excel');
    header('Content-Disposition: attachment;filename="运营成本分析_' . date('Ymd') . '.xls"');
    header('Cache-Control: max-age=0');

    // 输出Excel内容
    echo "运营成本分析报表\n";
    echo "统计期间：{$start_date} 至 {$end_date}\n\n";

    // 总成本概览
    echo "总成本概览\n";
    echo "项目\t金额(元)\t占比\n";
    echo "总运营成本\t" . number_format($total_operation_cost, 2) . "\t100%\n";
    echo "能耗成本\t" . number_format($total_utility_cost, 2) . "\t" .
        ($total_operation_cost > 0 ? round(($total_utility_cost / $total_operation_cost) * 100, 1) : 0) . "%\n";
    echo "维修成本\t" . number_format($total_maintenance_cost, 2) . "\t" .
        ($total_operation_cost > 0 ? round(($total_maintenance_cost / $total_operation_cost) * 100, 1) : 0) . "%\n";
    echo "物资消耗\t" . number_format($total_inventory_cost, 2) . "\t" .
        ($total_operation_cost > 0 ? round(($total_inventory_cost / $total_operation_cost) * 100, 1) : 0) . "%\n\n";

    // 能耗成本详情
    echo "能耗成本详情\n";
    echo "能耗类型\t消耗量\t总成本(元)\t占比\n";
    foreach ($utility_stats as $stat) {
        $type = '';
        $unit = '';
        switch ($stat['utility_type']) {
            case 'electricity':
                $type = '电';
                $unit = 'kWh';
                break;
            case 'water':
                $type = '水';
                $unit = '吨';
                break;
            case 'gas':
                $type = '气';
                $unit = '立方米';
                break;
            default:
                $type = '其他';
                $unit = '';
        }
        echo $type . "\t" .
            number_format($stat['total_consumption'], 2) . $unit . "\t" .
            number_format($stat['total_cost'], 2) . "\t" .
            ($total_utility_cost > 0 ? round(($stat['total_cost'] / $total_utility_cost) * 100, 1) : 0) . "%\n";
    }
    echo "\n";

    // 维修成本详情
    echo "维修成本详情\n";
    echo "优先级\t状态\t维修次数\t总成本(元)\t占比\n";
    foreach ($maintenance_stats as $stat) {
        echo $stat['priority'] . "\t" .
            $stat['status'] . "\t" .
            $stat['maintenance_count'] . "\t" .
            number_format($stat['total_cost'], 2) . "\t" .
            ($total_maintenance_cost > 0 ? round(($stat['total_cost'] / $total_maintenance_cost) * 100, 1) : 0) . "%\n";
    }
    echo "\n";

    // 物资消耗详情
    echo "物资消耗详情\n";
    echo "物资类别\t消耗次数\t总成本(元)\t占比\n";
    foreach ($inventory_stats as $stat) {
        echo $stat['category_name'] . "\t" .
            $stat['transaction_count'] . "\t" .
            number_format($stat['total_cost'], 2) . "\t" .
            ($total_inventory_cost > 0 ? round(($stat['total_cost'] / $total_inventory_cost) * 100, 1) : 0) . "%\n";
    }

    exit;
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content">
    <div class="page-header">
        <h2>运营成本分析</h2>
        <div class="action-buttons">
            <a href="?<?php echo http_build_query(array_merge($_GET, ['export' => 'excel'])); ?>" class="btn btn-success">
                <i class="fas fa-file-excel"></i> 导出Excel
            </a>
            <button onclick="window.print()" class="btn btn-primary">
                <i class="fas fa-print"></i> 打印报表
            </button>
        </div>
    </div>

    <!-- 日期筛选 -->
    <div class="filter-section">
        <form method="get" class="date-filter-form">
            <input type="hidden" name="page" value="operation_cost">
            <div class="form-group">
                <label>起始日期：</label>
                <input type="date" name="start_date" value="<?php echo $start_date; ?>" class="form-control">
            </div>
            <div class="form-group">
                <label>结束日期：</label>
                <input type="date" name="end_date" value="<?php echo $end_date; ?>" class="form-control">
            </div>
            <button type="submit" class="btn btn-primary">筛选</button>
        </form>
    </div>

    <!-- 总成本概览 -->
    <div class="cost-overview">
        <div class="overview-card total">
            <h3>总运营成本</h3>
            <div class="amount">¥<?php echo number_format($total_operation_cost, 2); ?></div>
        </div>
        <div class="overview-card">
            <h3>能耗成本</h3>
            <div class="amount">¥<?php echo number_format($total_utility_cost, 2); ?></div>
            <div class="percent"><?php echo $total_operation_cost > 0 ? round(($total_utility_cost / $total_operation_cost) * 100, 1) : 0; ?>%</div>
        </div>
        <div class="overview-card">
            <h3>维修成本</h3>
            <div class="amount">¥<?php echo number_format($total_maintenance_cost, 2); ?></div>
            <div class="percent"><?php echo $total_operation_cost > 0 ? round(($total_maintenance_cost / $total_operation_cost) * 100, 1) : 0; ?>%</div>
        </div>
        <div class="overview-card">
            <h3>物资消耗</h3>
            <div class="amount">¥<?php echo number_format($total_inventory_cost, 2); ?></div>
            <div class="percent"><?php echo $total_operation_cost > 0 ? round(($total_inventory_cost / $total_operation_cost) * 100, 1) : 0; ?>%</div>
        </div>
    </div>

    <!-- 详细数据表格 -->
    <div class="data-tables">
        <!-- 能耗成本详情 -->
        <div class="table-section">
            <h3>能耗成本详情</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>能耗类型</th>
                        <th>消耗量</th>
                        <th>总成本(元)</th>
                        <th>占比</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($utility_stats as $stat): ?>
                        <tr>
                            <td>
                                <?php
                                switch ($stat['utility_type']) {
                                    case 'electricity':
                                        echo '电';
                                        $unit = 'kWh';
                                        break;
                                    case 'water':
                                        echo '水';
                                        $unit = '吨';
                                        break;
                                    case 'gas':
                                        echo '气';
                                        $unit = '立方米';
                                        break;
                                    default:
                                        echo '其他';
                                        $unit = '';
                                }
                                ?>
                            </td>
                            <td><?php echo number_format($stat['total_consumption'], 2) . ' ' . $unit; ?></td>
                            <td><?php echo number_format($stat['total_cost'], 2); ?></td>
                            <td><?php echo $total_utility_cost > 0 ? round(($stat['total_cost'] / $total_utility_cost) * 100, 1) : 0; ?>%</td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- 维修成本详情 -->
        <div class="table-section">
            <h3>维修成本详情</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>优先级</th>
                        <th>状态</th>
                        <th>维修次数</th>
                        <th>总成本(元)</th>
                        <th>占比</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($maintenance_stats as $stat): ?>
                        <tr>
                            <td><?php echo $stat['priority']; ?></td>
                            <td><?php echo $stat['status']; ?></td>
                            <td><?php echo $stat['maintenance_count']; ?></td>
                            <td><?php echo number_format($stat['total_cost'], 2); ?></td>
                            <td><?php echo $total_maintenance_cost > 0 ? round(($stat['total_cost'] / $total_maintenance_cost) * 100, 1) : 0; ?>%</td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- 物资消耗详情 -->
        <div class="table-section">
            <h3>物资消耗详情</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>物资类别</th>
                        <th>消耗次数</th>
                        <th>总成本(元)</th>
                        <th>占比</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($inventory_stats as $stat): ?>
                        <tr>
                            <td><?php echo $stat['category_name']; ?></td>
                            <td><?php echo $stat['transaction_count']; ?></td>
                            <td><?php echo number_format($stat['total_cost'], 2); ?></td>
                            <td><?php echo $total_inventory_cost > 0 ? round(($stat['total_cost'] / $total_inventory_cost) * 100, 1) : 0; ?>%</td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- 图表展示 -->
    <div class="charts-container">
        <div class="chart-section">
            <h3>成本构成分析</h3>
            <canvas id="costCompositionChart"></canvas>
        </div>
        <div class="chart-section">
            <h3>成本趋势分析</h3>
            <canvas id="costTrendChart"></canvas>
        </div>
    </div>
</div>

<style>
    .content {
        padding: 20px;
    }

    .filter-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        margin-bottom: 20px;
    }

    .date-filter-form {
        display: flex;
        gap: 20px;
        align-items: flex-end;
    }

    .date-filter-form .form-group {
        flex: 1;
    }

    .cost-overview {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
        gap: 20px;
        margin-bottom: 30px;
    }

    .overview-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        text-align: center;
    }

    .overview-card.total {
        background-color: #1a73e8;
        color: white;
    }

    .overview-card h3 {
        margin: 0;
        font-size: 16px;
        color: inherit;
        margin-bottom: 10px;
    }

    .overview-card .amount {
        font-size: 24px;
        font-weight: bold;
        margin-bottom: 5px;
    }

    .overview-card .percent {
        font-size: 14px;
        color: #666;
    }

    .overview-card.total .percent {
        color: #fff;
    }

    .data-tables {
        display: grid;
        gap: 20px;
    }

    .table-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
    }

    .table-section h3 {
        margin: 0 0 15px 0;
        font-size: 18px;
        color: #333;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: 600;
    }

    .data-table tr:hover {
        background-color: #f8f9fa;
    }

    .charts-container {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(400px, 1fr));
        gap: 20px;
        margin-top: 20px;
    }

    .chart-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
    }

    .chart-section h3 {
        margin: 0 0 15px 0;
        font-size: 18px;
        color: #333;
    }

    canvas {
        width: 100% !important;
        height: 300px !important;
    }

    .page-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 20px;
    }

    .action-buttons {
        display: flex;
        gap: 10px;
    }

    .btn {
        display: inline-flex;
        align-items: center;
        gap: 5px;
        padding: 8px 16px;
        border: none;
        border-radius: 4px;
        cursor: pointer;
        font-size: 14px;
        text-decoration: none;
    }

    .btn-success {
        background-color: #1cc88a;
        color: white;
    }

    .btn-primary {
        background-color: #4e73df;
        color: white;
    }

    .btn i {
        font-size: 16px;
    }

    /* 打印样式 */
    @media print {

        .filter-section,
        .action-buttons {
            display: none;
        }

        .content {
            padding: 0;
        }

        .overview-card,
        .table-section,
        .chart-section {
            break-inside: avoid;
            margin: 15px 0;
            box-shadow: none;
        }

        .data-table th {
            background-color: #f8f9fa !important;
            -webkit-print-color-adjust: exact;
            print-color-adjust: exact;
        }
    }
</style>

<!-- 引入Chart.js -->
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>

<!-- 引入Font Awesome图标 -->
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">

<script>
    // 成本构成饼图
    const compositionCtx = document.getElementById('costCompositionChart').getContext('2d');
    new Chart(compositionCtx, {
        type: 'pie',
        data: {
            labels: ['能耗成本', '维修成本', '物资消耗'],
            datasets: [{
                data: [
                    <?php echo $total_utility_cost; ?>,
                    <?php echo $total_maintenance_cost; ?>,
                    <?php echo $total_inventory_cost; ?>
                ],
                backgroundColor: [
                    '#4e73df',
                    '#1cc88a',
                    '#36b9cc'
                ]
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: {
                    position: 'bottom'
                }
            }
        }
    });

    // 成本趋势折线图
    const trendCtx = document.getElementById('costTrendChart').getContext('2d');
    new Chart(trendCtx, {
        type: 'line',
        data: {
            labels: <?php echo json_encode($trend_dates); ?>,
            datasets: [{
                label: '能耗成本',
                data: <?php echo json_encode($trend_utility); ?>,
                borderColor: '#4e73df',
                fill: false
            }, {
                label: '维修成本',
                data: <?php echo json_encode($trend_maintenance); ?>,
                borderColor: '#1cc88a',
                fill: false
            }, {
                label: '物资消耗',
                data: <?php echo json_encode($trend_inventory); ?>,
                borderColor: '#36b9cc',
                fill: false
            }]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            scales: {
                x: {
                    grid: {
                        display: false
                    }
                },
                y: {
                    beginAtZero: true,
                    ticks: {
                        callback: function(value) {
                            return '¥' + value.toLocaleString();
                        }
                    }
                }
            },
            plugins: {
                legend: {
                    position: 'bottom'
                }
            }
        }
    });
</script>