<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取分析周期
$period = isset($_GET['period']) ? $_GET['period'] : 'month';
$year = isset($_GET['year']) ? intval($_GET['year']) : date('Y');
$month = isset($_GET['month']) ? intval($_GET['month']) : date('n');

// 获取当前日期
$currentDate = date('Y-m-d');
$currentYear = date('Y');
$currentMonth = date('n');

// 根据周期设置日期范围
$startDate = '';
$endDate = '';
$periodTitle = '';

switch ($period) {
    case 'year':
        // 按年统计
        $startDate = "$year-01-01";
        $endDate = "$year-12-31";
        $periodTitle = "{$year}年";
        break;
    case 'quarter':
        // 按季度统计
        $quarter = isset($_GET['quarter']) ? intval($_GET['quarter']) : ceil($currentMonth / 3);
        $startMonth = ($quarter - 1) * 3 + 1;
        $endMonth = $quarter * 3;
        $startDate = "$year-" . sprintf('%02d', $startMonth) . "-01";
        $endDate = "$year-" . sprintf('%02d', $endMonth) . "-" . date('t', strtotime("$year-$endMonth-01"));
        $periodTitle = "{$year}年第{$quarter}季度";
        break;
    case 'month':
    default:
        // 按月统计
        $startDate = "$year-" . sprintf('%02d', $month) . "-01";
        $endDate = "$year-" . sprintf('%02d', $month) . "-" . date('t', strtotime("$year-$month-01"));
        $periodTitle = "{$year}年{$month}月";
        break;
}

// 获取总营收数据
$sql = "SELECT 
            SUM(total_amount) as total_revenue,
            COUNT(*) as booking_count,
            AVG(total_amount) as avg_revenue
        FROM bookings
        WHERE check_in_date BETWEEN '$startDate' AND '$endDate'
        AND status IN ('confirmed', 'checked_in', 'checked_out')";
$result = $conn->query($sql);
$revenueStats = [
    'total_revenue' => 0,
    'booking_count' => 0,
    'avg_revenue' => 0
];

if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $revenueStats = [
        'total_revenue' => $row['total_revenue'] ? $row['total_revenue'] : 0,
        'booking_count' => $row['booking_count'] ? $row['booking_count'] : 0,
        'avg_revenue' => $row['avg_revenue'] ? $row['avg_revenue'] : 0
    ];
}

// 获取上一周期的数据进行比较
$prevStartDate = '';
$prevEndDate = '';

switch ($period) {
    case 'year':
        $prevStartDate = ($year - 1) . "-01-01";
        $prevEndDate = ($year - 1) . "-12-31";
        break;
    case 'quarter':
        $prevYear = $year;
        $prevQuarter = $quarter - 1;
        if ($prevQuarter <= 0) {
            $prevQuarter = 4;
            $prevYear--;
        }
        $prevStartMonth = ($prevQuarter - 1) * 3 + 1;
        $prevEndMonth = $prevQuarter * 3;
        $prevStartDate = "$prevYear-" . sprintf('%02d', $prevStartMonth) . "-01";
        $prevEndDate = "$prevYear-" . sprintf('%02d', $prevEndMonth) . "-" . date('t', strtotime("$prevYear-$prevEndMonth-01"));
        break;
    case 'month':
    default:
        $prevYear = $year;
        $prevMonth = $month - 1;
        if ($prevMonth <= 0) {
            $prevMonth = 12;
            $prevYear--;
        }
        $prevStartDate = "$prevYear-" . sprintf('%02d', $prevMonth) . "-01";
        $prevEndDate = "$prevYear-" . sprintf('%02d', $prevMonth) . "-" . date('t', strtotime("$prevYear-$prevMonth-01"));
        break;
}

$sql = "SELECT 
            SUM(total_amount) as total_revenue
        FROM bookings
        WHERE check_in_date BETWEEN '$prevStartDate' AND '$prevEndDate'
        AND status IN ('confirmed', 'checked_in', 'checked_out')";
$result = $conn->query($sql);
$prevRevenue = 0;

if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $prevRevenue = $row['total_revenue'] ? $row['total_revenue'] : 0;
}

// 计算环比增长率
$growthRate = 0;
if ($prevRevenue > 0) {
    $growthRate = (($revenueStats['total_revenue'] - $prevRevenue) / $prevRevenue) * 100;
}

// 获取各业务收入数据
// 1. 房费收入
$sql = "SELECT 
            SUM(total_amount) as room_revenue
        FROM bookings
        WHERE check_in_date BETWEEN '$startDate' AND '$endDate'
        AND status IN ('confirmed', 'checked_in', 'checked_out')";
$result = $conn->query($sql);
$roomRevenue = 0;

if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $roomRevenue = $row['room_revenue'] ? $row['room_revenue'] : 0;
}

// 2. 旅游服务收入
$sql = "SELECT 
            SUM(total_price) as tourism_revenue
        FROM tourism_bookings
        WHERE service_date BETWEEN '$startDate' AND '$endDate'
        AND status IN ('confirmed', 'completed')";
$result = $conn->query($sql);
$tourismRevenue = 0;

if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $tourismRevenue = $row['tourism_revenue'] ? $row['tourism_revenue'] : 0;
}

// 获取营收趋势数据
$trendData = [];
$trendLabels = [];

switch ($period) {
    case 'year':
        // 按月显示全年趋势
        for ($m = 1; $m <= 12; $m++) {
            $monthStart = "$year-" . sprintf('%02d', $m) . "-01";
            $monthEnd = "$year-" . sprintf('%02d', $m) . "-" . date('t', strtotime("$year-$m-01"));
            $trendLabels[] = $m . "月";

            // 房费收入
            $sql = "SELECT 
                        SUM(total_amount) as room_revenue
                    FROM bookings
                    WHERE check_in_date BETWEEN '$monthStart' AND '$monthEnd'
                    AND status IN ('confirmed', 'checked_in', 'checked_out')";
            $result = $conn->query($sql);
            $monthRoomRevenue = 0;

            if ($result && $result->num_rows > 0) {
                $row = $result->fetch_assoc();
                $monthRoomRevenue = $row['room_revenue'] ? $row['room_revenue'] : 0;
            }

            // 旅游服务收入
            $sql = "SELECT 
                        SUM(total_price) as tourism_revenue
                    FROM tourism_bookings
                    WHERE service_date BETWEEN '$monthStart' AND '$monthEnd'
                    AND status IN ('confirmed', 'completed')";
            $result = $conn->query($sql);
            $monthTourismRevenue = 0;

            if ($result && $result->num_rows > 0) {
                $row = $result->fetch_assoc();
                $monthTourismRevenue = $row['tourism_revenue'] ? $row['tourism_revenue'] : 0;
            }

            $trendData[] = [
                'room_revenue' => $monthRoomRevenue,
                'tourism_revenue' => $monthTourismRevenue,
                'total_revenue' => $monthRoomRevenue + $monthTourismRevenue
            ];
        }
        break;

    case 'quarter':
        // 按月显示季度趋势
        $quarter = isset($_GET['quarter']) ? intval($_GET['quarter']) : ceil($currentMonth / 3);
        $startMonth = ($quarter - 1) * 3 + 1;
        $endMonth = $quarter * 3;

        for ($m = $startMonth; $m <= $endMonth; $m++) {
            $monthStart = "$year-" . sprintf('%02d', $m) . "-01";
            $monthEnd = "$year-" . sprintf('%02d', $m) . "-" . date('t', strtotime("$year-$m-01"));
            $trendLabels[] = $m . "月";

            // 房费收入
            $sql = "SELECT 
                        SUM(total_amount) as room_revenue
                    FROM bookings
                    WHERE check_in_date BETWEEN '$monthStart' AND '$monthEnd'
                    AND status IN ('confirmed', 'checked_in', 'checked_out')";
            $result = $conn->query($sql);
            $monthRoomRevenue = 0;

            if ($result && $result->num_rows > 0) {
                $row = $result->fetch_assoc();
                $monthRoomRevenue = $row['room_revenue'] ? $row['room_revenue'] : 0;
            }

            // 旅游服务收入
            $sql = "SELECT 
                        SUM(total_price) as tourism_revenue
                    FROM tourism_bookings
                    WHERE service_date BETWEEN '$monthStart' AND '$monthEnd'
                    AND status IN ('confirmed', 'completed')";
            $result = $conn->query($sql);
            $monthTourismRevenue = 0;

            if ($result && $result->num_rows > 0) {
                $row = $result->fetch_assoc();
                $monthTourismRevenue = $row['tourism_revenue'] ? $row['tourism_revenue'] : 0;
            }

            $trendData[] = [
                'room_revenue' => $monthRoomRevenue,
                'tourism_revenue' => $monthTourismRevenue,
                'total_revenue' => $monthRoomRevenue + $monthTourismRevenue
            ];
        }
        break;

    case 'month':
    default:
        // 按周显示月度趋势
        $daysInMonth = date('t', strtotime("$year-$month-01"));
        $weeksInMonth = ceil($daysInMonth / 7);

        for ($w = 1; $w <= $weeksInMonth; $w++) {
            $weekStart = ($w - 1) * 7 + 1;
            $weekEnd = min($w * 7, $daysInMonth);
            $weekStartDate = "$year-" . sprintf('%02d', $month) . "-" . sprintf('%02d', $weekStart);
            $weekEndDate = "$year-" . sprintf('%02d', $month) . "-" . sprintf('%02d', $weekEnd);
            $trendLabels[] = "第{$w}周";

            // 房费收入
            $sql = "SELECT 
                        SUM(total_amount) as room_revenue
                    FROM bookings
                    WHERE check_in_date BETWEEN '$weekStartDate' AND '$weekEndDate'
                    AND status IN ('confirmed', 'checked_in', 'checked_out')";
            $result = $conn->query($sql);
            $weekRoomRevenue = 0;

            if ($result && $result->num_rows > 0) {
                $row = $result->fetch_assoc();
                $weekRoomRevenue = $row['room_revenue'] ? $row['room_revenue'] : 0;
            }

            // 旅游服务收入
            $sql = "SELECT 
                        SUM(total_price) as tourism_revenue
                    FROM tourism_bookings
                    WHERE service_date BETWEEN '$weekStartDate' AND '$weekEndDate'
                    AND status IN ('confirmed', 'completed')";
            $result = $conn->query($sql);
            $weekTourismRevenue = 0;

            if ($result && $result->num_rows > 0) {
                $row = $result->fetch_assoc();
                $weekTourismRevenue = $row['tourism_revenue'] ? $row['tourism_revenue'] : 0;
            }

            $trendData[] = [
                'room_revenue' => $weekRoomRevenue,
                'tourism_revenue' => $weekTourismRevenue,
                'total_revenue' => $weekRoomRevenue + $weekTourismRevenue
            ];
        }
        break;
}

// 获取房型收入数据
$sql = "SELECT 
            rt.name,
            SUM(br.room_rate) as revenue,
            COUNT(br.id) as booking_count
        FROM booking_rooms br
        JOIN rooms r ON br.room_id = r.id
        JOIN room_types rt ON r.room_type_id = rt.id
        JOIN bookings b ON br.booking_id = b.id
        WHERE b.check_in_date BETWEEN '$startDate' AND '$endDate'
        AND b.status IN ('confirmed', 'checked_in', 'checked_out')
        GROUP BY rt.id
        ORDER BY revenue DESC";
$result = $conn->query($sql);
$roomTypeRevenue = [];

if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $roomTypeRevenue[] = $row;
    }
}
?>

<div class="analysis-container">
    <div class="filter-section">
        <form method="get" action="index.php" class="filter-form">
            <input type="hidden" name="page" value="revenue_trend">

            <div class="form-group">
                <label for="period">统计周期:</label>
                <select name="period" id="period" class="form-control" onchange="this.form.submit()">
                    <option value="month" <?php echo $period == 'month' ? 'selected' : ''; ?>>月度</option>
                    <option value="quarter" <?php echo $period == 'quarter' ? 'selected' : ''; ?>>季度</option>
                    <option value="year" <?php echo $period == 'year' ? 'selected' : ''; ?>>年度</option>
                </select>
            </div>

            <div class="form-group">
                <label for="year">年份:</label>
                <select name="year" id="year" class="form-control" onchange="this.form.submit()">
                    <?php for ($y = $currentYear - 5; $y <= $currentYear; $y++): ?>
                        <option value="<?php echo $y; ?>" <?php echo $year == $y ? 'selected' : ''; ?>><?php echo $y; ?>年</option>
                    <?php endfor; ?>
                </select>
            </div>

            <?php if ($period == 'month'): ?>
                <div class="form-group">
                    <label for="month">月份:</label>
                    <select name="month" id="month" class="form-control" onchange="this.form.submit()">
                        <?php for ($m = 1; $m <= 12; $m++): ?>
                            <option value="<?php echo $m; ?>" <?php echo $month == $m ? 'selected' : ''; ?>><?php echo $m; ?>月</option>
                        <?php endfor; ?>
                    </select>
                </div>
            <?php endif; ?>

            <?php if ($period == 'quarter'): ?>
                <div class="form-group">
                    <label for="quarter">季度:</label>
                    <select name="quarter" id="quarter" class="form-control" onchange="this.form.submit()">
                        <?php for ($q = 1; $q <= 4; $q++): ?>
                            <option value="<?php echo $q; ?>" <?php echo (isset($_GET['quarter']) ? intval($_GET['quarter']) : ceil($currentMonth / 3)) == $q ? 'selected' : ''; ?>>第<?php echo $q; ?>季度</option>
                        <?php endfor; ?>
                    </select>
                </div>
            <?php endif; ?>
        </form>
    </div>

    <div class="summary-section">
        <div class="section-title">
            <h3><?php echo $periodTitle; ?>营收概览</h3>
        </div>

        <div class="summary-cards">
            <div class="summary-card">
                <div class="summary-title">总营收</div>
                <div class="summary-value">¥<?php echo number_format($revenueStats['total_revenue'], 2); ?></div>
                <div class="summary-change <?php echo $growthRate >= 0 ? 'positive' : 'negative'; ?>">
                    <?php echo $growthRate >= 0 ? '+' : ''; ?><?php echo round($growthRate, 2); ?>%
                </div>
            </div>
            <div class="summary-card">
                <div class="summary-title">预订数量</div>
                <div class="summary-value"><?php echo $revenueStats['booking_count']; ?></div>
            </div>
            <div class="summary-card">
                <div class="summary-title">平均订单金额</div>
                <div class="summary-value">¥<?php echo number_format($revenueStats['avg_revenue'], 2); ?></div>
            </div>
            <div class="summary-card">
                <div class="summary-title">房费收入</div>
                <div class="summary-value">¥<?php echo number_format($roomRevenue, 2); ?></div>
                <div class="summary-percent"><?php echo $revenueStats['total_revenue'] > 0 ? round(($roomRevenue / $revenueStats['total_revenue']) * 100, 2) . '%' : '0%'; ?></div>
            </div>
            <div class="summary-card">
                <div class="summary-title">旅游服务收入</div>
                <div class="summary-value">¥<?php echo number_format($tourismRevenue, 2); ?></div>
                <div class="summary-percent"><?php echo $revenueStats['total_revenue'] > 0 ? round(($tourismRevenue / $revenueStats['total_revenue']) * 100, 2) . '%' : '0%'; ?></div>
            </div>
        </div>
    </div>

    <div class="chart-section">
        <div class="chart-card">
            <div class="card-header">
                <h3>营收趋势</h3>
            </div>
            <div class="card-body">
                <div class="chart-container">
                    <canvas id="revenueTrendChart"></canvas>
                </div>
            </div>
        </div>
    </div>

    <div class="chart-section">
        <div class="chart-row">
            <div class="chart-card">
                <div class="card-header">
                    <h3>业务收入分布</h3>
                </div>
                <div class="card-body">
                    <div class="chart-container">
                        <canvas id="revenueDistributionChart"></canvas>
                    </div>
                </div>
            </div>

            <div class="chart-card">
                <div class="card-header">
                    <h3>房型收入分布</h3>
                </div>
                <div class="card-body">
                    <div class="chart-container">
                        <canvas id="roomTypeRevenueChart"></canvas>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="data-section">
        <div class="section-title">
            <h3>房型收入详细数据</h3>
        </div>

        <table class="data-table">
            <thead>
                <tr>
                    <th>房型名称</th>
                    <th>预订次数</th>
                    <th>总收入</th>
                    <th>占总收入比例</th>
                    <th>平均单价</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($roomTypeRevenue as $roomType): ?>
                    <tr>
                        <td><?php echo $roomType['name']; ?></td>
                        <td><?php echo $roomType['booking_count']; ?></td>
                        <td>¥<?php echo number_format($roomType['revenue'], 2); ?></td>
                        <td><?php echo $roomRevenue > 0 ? round(($roomType['revenue'] / $roomRevenue) * 100, 2) . '%' : '0%'; ?></td>
                        <td>¥<?php echo $roomType['booking_count'] > 0 ? number_format($roomType['revenue'] / $roomType['booking_count'], 2) : '0.00'; ?></td>
                    </tr>
                <?php endforeach; ?>
                <?php if (empty($roomTypeRevenue)): ?>
                    <tr>
                        <td colspan="5">暂无数据</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 营收趋势图表
        const trendCtx = document.getElementById('revenueTrendChart').getContext('2d');
        const trendChart = new Chart(trendCtx, {
            type: 'line',
            data: {
                labels: <?php echo json_encode($trendLabels); ?>,
                datasets: [{
                        label: '总营收',
                        backgroundColor: 'rgba(78, 115, 223, 0.05)',
                        borderColor: 'rgba(78, 115, 223, 1)',
                        pointBackgroundColor: 'rgba(78, 115, 223, 1)',
                        pointBorderColor: '#fff',
                        pointHoverBackgroundColor: '#fff',
                        pointHoverBorderColor: 'rgba(78, 115, 223, 1)',
                        borderWidth: 2,
                        fill: true,
                        data: [
                            <?php
                            foreach ($trendData as $data) {
                                echo $data['total_revenue'] . ",";
                            }
                            ?>
                        ],
                    },
                    {
                        label: '房费收入',
                        backgroundColor: 'rgba(28, 200, 138, 0.05)',
                        borderColor: 'rgba(28, 200, 138, 1)',
                        pointBackgroundColor: 'rgba(28, 200, 138, 1)',
                        pointBorderColor: '#fff',
                        pointHoverBackgroundColor: '#fff',
                        pointHoverBorderColor: 'rgba(28, 200, 138, 1)',
                        borderWidth: 2,
                        fill: false,
                        data: [
                            <?php
                            foreach ($trendData as $data) {
                                echo $data['room_revenue'] . ",";
                            }
                            ?>
                        ],
                    },
                    {
                        label: '旅游服务收入',
                        backgroundColor: 'rgba(246, 194, 62, 0.05)',
                        borderColor: 'rgba(246, 194, 62, 1)',
                        pointBackgroundColor: 'rgba(246, 194, 62, 1)',
                        pointBorderColor: '#fff',
                        pointHoverBackgroundColor: '#fff',
                        pointHoverBorderColor: 'rgba(246, 194, 62, 1)',
                        borderWidth: 2,
                        fill: false,
                        data: [
                            <?php
                            foreach ($trendData as $data) {
                                echo $data['tourism_revenue'] . ",";
                            }
                            ?>
                        ],
                    }
                ]
            },
            options: {
                maintainAspectRatio: false,
                layout: {
                    padding: {
                        left: 10,
                        right: 25,
                        top: 25,
                        bottom: 0
                    }
                },
                scales: {
                    xAxes: [{
                        gridLines: {
                            display: false,
                            drawBorder: false
                        }
                    }],
                    yAxes: [{
                        ticks: {
                            beginAtZero: true,
                            maxTicksLimit: 5,
                            padding: 10,
                            callback: function(value) {
                                return '¥' + value.toLocaleString();
                            }
                        },
                        gridLines: {
                            color: "rgb(234, 236, 244)",
                            zeroLineColor: "rgb(234, 236, 244)",
                            drawBorder: false,
                            borderDash: [2],
                            zeroLineBorderDash: [2]
                        }
                    }],
                },
                legend: {
                    display: true,
                    position: 'bottom'
                },
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    titleMarginBottom: 10,
                    titleFontColor: '#6e707e',
                    titleFontSize: 14,
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: true,
                    intersect: false,
                    mode: 'index',
                    caretPadding: 10,
                    callbacks: {
                        label: function(tooltipItem, chart) {
                            return chart.datasets[tooltipItem.datasetIndex].label + ': ¥' + tooltipItem.yLabel.toLocaleString();
                        }
                    }
                }
            }
        });

        // 业务收入分布图表
        const distributionCtx = document.getElementById('revenueDistributionChart').getContext('2d');
        const distributionChart = new Chart(distributionCtx, {
            type: 'doughnut',
            data: {
                labels: ['房费收入', '旅游服务收入'],
                datasets: [{
                    data: [
                        <?php echo $roomRevenue; ?>,
                        <?php echo $tourismRevenue; ?>
                    ],
                    backgroundColor: ['#4e73df', '#1cc88a'],
                    hoverBackgroundColor: ['#2e59d9', '#17a673'],
                    hoverBorderColor: "rgba(234, 236, 244, 1)",
                }]
            },
            options: {
                maintainAspectRatio: false,
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    caretPadding: 10,
                    callbacks: {
                        label: function(tooltipItem, data) {
                            var dataset = data.datasets[tooltipItem.datasetIndex];
                            var total = dataset.data.reduce(function(previousValue, currentValue) {
                                return previousValue + currentValue;
                            });
                            var currentValue = dataset.data[tooltipItem.index];
                            var percentage = Math.round((currentValue / total) * 100);
                            return data.labels[tooltipItem.index] + ': ¥' + currentValue.toLocaleString() + ' (' + percentage + '%)';
                        }
                    }
                },
                legend: {
                    display: true,
                    position: 'bottom'
                },
                cutoutPercentage: 70,
            },
        });

        // 房型收入分布图表
        const roomTypeCtx = document.getElementById('roomTypeRevenueChart').getContext('2d');
        const roomTypeChart = new Chart(roomTypeCtx, {
            type: 'bar',
            data: {
                labels: [
                    <?php
                    foreach ($roomTypeRevenue as $roomType) {
                        echo "'" . $roomType['name'] . "',";
                    }
                    ?>
                ],
                datasets: [{
                    label: '收入金额',
                    backgroundColor: '#4e73df',
                    hoverBackgroundColor: '#2e59d9',
                    borderColor: '#4e73df',
                    data: [
                        <?php
                        foreach ($roomTypeRevenue as $roomType) {
                            echo $roomType['revenue'] . ",";
                        }
                        ?>
                    ],
                }]
            },
            options: {
                maintainAspectRatio: false,
                layout: {
                    padding: {
                        left: 10,
                        right: 25,
                        top: 25,
                        bottom: 0
                    }
                },
                scales: {
                    xAxes: [{
                        gridLines: {
                            display: false,
                            drawBorder: false
                        }
                    }],
                    yAxes: [{
                        ticks: {
                            beginAtZero: true,
                            maxTicksLimit: 5,
                            padding: 10,
                            callback: function(value) {
                                return '¥' + value.toLocaleString();
                            }
                        },
                        gridLines: {
                            color: "rgb(234, 236, 244)",
                            zeroLineColor: "rgb(234, 236, 244)",
                            drawBorder: false,
                            borderDash: [2],
                            zeroLineBorderDash: [2]
                        }
                    }],
                },
                legend: {
                    display: false
                },
                tooltips: {
                    backgroundColor: "rgb(255,255,255)",
                    bodyFontColor: "#858796",
                    titleMarginBottom: 10,
                    titleFontColor: '#6e707e',
                    titleFontSize: 14,
                    borderColor: '#dddfeb',
                    borderWidth: 1,
                    xPadding: 15,
                    yPadding: 15,
                    displayColors: false,
                    intersect: false,
                    mode: 'index',
                    caretPadding: 10,
                    callbacks: {
                        label: function(tooltipItem, chart) {
                            return '收入金额: ¥' + tooltipItem.yLabel.toLocaleString();
                        }
                    }
                }
            }
        });
    });
</script>

<style>
    .analysis-container {
        padding: 15px 0;
    }

    .filter-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
    }

    .form-group {
        flex: 1;
        min-width: 150px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: 500;
        color: #333;
    }

    .form-control {
        width: 100%;
        padding: 8px 12px;
        border: 1px solid #d1d3e2;
        border-radius: 4px;
        background-color: #f8f9fc;
    }

    .summary-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .section-title {
        margin-bottom: 15px;
    }

    .section-title h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .summary-cards {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
    }

    .summary-card {
        background-color: #f8f9fc;
        border-radius: 8px;
        padding: 15px;
        flex: 1;
        min-width: 150px;
        text-align: center;
    }

    .summary-title {
        font-size: 14px;
        color: #6c757d;
        margin-bottom: 5px;
    }

    .summary-value {
        font-size: 24px;
        font-weight: bold;
        color: #0066cc;
        margin-bottom: 5px;
    }

    .summary-change {
        font-size: 14px;
        font-weight: 500;
    }

    .summary-change.positive {
        color: #1cc88a;
    }

    .summary-change.negative {
        color: #e74a3b;
    }

    .summary-percent {
        font-size: 14px;
        color: #6c757d;
    }

    .chart-section {
        margin-bottom: 20px;
    }

    .chart-row {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .chart-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        flex: 1;
        min-width: 300px;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e3e6f0;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .card-body {
        padding: 15px;
    }

    .chart-container {
        height: 300px;
    }

    .data-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        margin-bottom: 20px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px 15px;
        text-align: left;
        border-bottom: 1px solid #e3e6f0;
    }

    .data-table th {
        background-color: #f8f9fc;
        font-weight: 600;
    }
</style>