<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 设置每页显示的记录数
$records_per_page = 10;
$page = isset($_GET['p']) ? intval($_GET['p']) : 1;
$offset = ($page - 1) * $records_per_page;

// 获取筛选参数
$filter_type = isset($_GET['filter_type']) ? $_GET['filter_type'] : '';
$filter_value = isset($_GET['filter_value']) ? $_GET['filter_value'] : '';
$date_from = isset($_GET['date_from']) ? $_GET['date_from'] : '';
$date_to = isset($_GET['date_to']) ? $_GET['date_to'] : '';

// 构建查询条件
$where_clause = "1=1";
$params = [];
$param_types = "";

if ($filter_type && $filter_value) {
    switch ($filter_type) {
        case 'booking_number':
            $where_clause .= " AND b.booking_number LIKE ?";
            $params[] = "%$filter_value%";
            $param_types .= "s";
            break;
        case 'guest_name':
            $where_clause .= " AND b.guest_name LIKE ?";
            $params[] = "%$filter_value%";
            $param_types .= "s";
            break;
        case 'payment_method':
            $where_clause .= " AND p.payment_method = ?";
            $params[] = $filter_value;
            $param_types .= "s";
            break;
    }
}

if ($date_from) {
    $where_clause .= " AND DATE(p.payment_date) >= ?";
    $params[] = $date_from;
    $param_types .= "s";
}

if ($date_to) {
    $where_clause .= " AND DATE(p.payment_date) <= ?";
    $params[] = $date_to;
    $param_types .= "s";
}

// 获取支付记录总数
$total_records = 0;
$count_sql = "SELECT COUNT(*) as count FROM payments p JOIN bookings b ON p.booking_id = b.id WHERE $where_clause";
$stmt = $conn->prepare($count_sql);

if ($params) {
    $stmt->bind_param($param_types, ...$params);
}

$stmt->execute();
$result = $stmt->get_result();
if ($row = $result->fetch_assoc()) {
    $total_records = $row['count'];
}

$total_pages = ceil($total_records / $records_per_page);

// 获取支付记录
$payments = [];
$sql = "SELECT p.*, b.booking_number, b.guest_name, b.guest_phone 
        FROM payments p 
        JOIN bookings b ON p.booking_id = b.id 
        WHERE $where_clause 
        ORDER BY p.payment_date DESC 
        LIMIT ?, ?";

$stmt = $conn->prepare($sql);
$param_types .= "ii";
$params[] = $offset;
$params[] = $records_per_page;

$stmt->bind_param($param_types, ...$params);
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $payments[] = $row;
}

// 获取发票记录
$invoices = [];
$sql = "SELECT i.*, b.booking_number, b.guest_name 
        FROM invoices i 
        JOIN bookings b ON i.booking_id = b.id 
        ORDER BY i.created_at DESC 
        LIMIT 10";
$result = mysqli_query($conn, $sql);

if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        $invoices[] = $row;
    }
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content-wrapper">
    <div class="tabs">
        <div class="tab-header">
            <div class="tab-btn active" data-tab="payments">支付记录</div>
            <div class="tab-btn" data-tab="invoices">发票管理</div>
            <div class="tab-btn" data-tab="add-payment">添加支付记录</div>
        </div>

        <div class="tab-content">
            <!-- 支付记录 -->
            <div class="tab-pane active" id="payments">
                <div class="card">
                    <div class="card-header">
                        <h3>支付记录列表</h3>
                        <div class="card-tools">
                            <form method="get" class="filter-form">
                                <input type="hidden" name="page" value="bill_management">
                                <div class="filter-row">
                                    <div class="filter-item">
                                        <select name="filter_type" class="form-control">
                                            <option value="">筛选条件</option>
                                            <option value="booking_number" <?php echo $filter_type == 'booking_number' ? 'selected' : ''; ?>>订单号</option>
                                            <option value="guest_name" <?php echo $filter_type == 'guest_name' ? 'selected' : ''; ?>>客人姓名</option>
                                            <option value="payment_method" <?php echo $filter_type == 'payment_method' ? 'selected' : ''; ?>>支付方式</option>
                                        </select>
                                    </div>
                                    <div class="filter-item">
                                        <input type="text" name="filter_value" class="form-control" placeholder="搜索关键词" value="<?php echo htmlspecialchars($filter_value); ?>">
                                    </div>
                                    <div class="filter-item">
                                        <input type="date" name="date_from" class="form-control" placeholder="开始日期" value="<?php echo $date_from; ?>">
                                    </div>
                                    <div class="filter-item">
                                        <input type="date" name="date_to" class="form-control" placeholder="结束日期" value="<?php echo $date_to; ?>">
                                    </div>
                                    <div class="filter-item">
                                        <button type="submit" class="btn btn-primary">筛选</button>
                                        <a href="index.php?page=bill_management" class="btn btn-secondary">重置</a>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                    <div class="card-body">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>订单号</th>
                                    <th>客人</th>
                                    <th>金额</th>
                                    <th>支付方式</th>
                                    <th>交易ID</th>
                                    <th>支付时间</th>
                                    <th>备注</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (empty($payments)): ?>
                                    <tr>
                                        <td colspan="8" class="text-center">暂无支付记录</td>
                                    </tr>
                                <?php else: ?>
                                    <?php foreach ($payments as $payment): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($payment['booking_number']); ?></td>
                                            <td><?php echo htmlspecialchars($payment['guest_name']); ?></td>
                                            <td>¥<?php echo number_format($payment['amount'], 2); ?></td>
                                            <td>
                                                <?php
                                                $methodLabels = [
                                                    'cash' => '现金',
                                                    'credit_card' => '信用卡',
                                                    'debit_card' => '借记卡',
                                                    'bank_transfer' => '银行转账',
                                                    'alipay' => '支付宝',
                                                    'wechat_pay' => '微信支付',
                                                    'other' => '其他'
                                                ];
                                                echo $methodLabels[$payment['payment_method']] ?? $payment['payment_method'];
                                                ?>
                                            </td>
                                            <td><?php echo htmlspecialchars($payment['transaction_id'] ?? '-'); ?></td>
                                            <td><?php echo date('Y-m-d H:i', strtotime($payment['payment_date'])); ?></td>
                                            <td><?php echo htmlspecialchars($payment['notes'] ?? ''); ?></td>
                                            <td>
                                                <a href="javascript:void(0);" class="btn btn-sm btn-info view-payment-btn" data-id="<?php echo $payment['id']; ?>">查看</a>
                                                <a href="javascript:void(0);" class="btn btn-sm btn-primary create-invoice-btn" data-booking-id="<?php echo $payment['booking_id']; ?>">开具发票</a>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            </tbody>
                        </table>

                        <!-- 分页 -->
                        <?php if ($total_pages > 1): ?>
                            <div class="pagination">
                                <?php if ($page > 1): ?>
                                    <a href="index.php?page=bill_management&p=<?php echo $page - 1; ?>&filter_type=<?php echo urlencode($filter_type); ?>&filter_value=<?php echo urlencode($filter_value); ?>&date_from=<?php echo urlencode($date_from); ?>&date_to=<?php echo urlencode($date_to); ?>" class="page-link">&laquo; 上一页</a>
                                <?php endif; ?>

                                <?php for ($i = max(1, $page - 2); $i <= min($page + 2, $total_pages); $i++): ?>
                                    <a href="index.php?page=bill_management&p=<?php echo $i; ?>&filter_type=<?php echo urlencode($filter_type); ?>&filter_value=<?php echo urlencode($filter_value); ?>&date_from=<?php echo urlencode($date_from); ?>&date_to=<?php echo urlencode($date_to); ?>" class="page-link <?php echo $i == $page ? 'active' : ''; ?>"><?php echo $i; ?></a>
                                <?php endfor; ?>

                                <?php if ($page < $total_pages): ?>
                                    <a href="index.php?page=bill_management&p=<?php echo $page + 1; ?>&filter_type=<?php echo urlencode($filter_type); ?>&filter_value=<?php echo urlencode($filter_value); ?>&date_from=<?php echo urlencode($date_from); ?>&date_to=<?php echo urlencode($date_to); ?>" class="page-link">下一页 &raquo;</a>
                                <?php endif; ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

            <!-- 发票管理 -->
            <div class="tab-pane" id="invoices">
                <div class="card">
                    <div class="card-header">
                        <h3>发票记录</h3>
                    </div>
                    <div class="card-body">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>发票号</th>
                                    <th>订单号</th>
                                    <th>客人</th>
                                    <th>发票类型</th>
                                    <th>抬头</th>
                                    <th>金额</th>
                                    <th>状态</th>
                                    <th>开具日期</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (empty($invoices)): ?>
                                    <tr>
                                        <td colspan="9" class="text-center">暂无发票记录</td>
                                    </tr>
                                <?php else: ?>
                                    <?php foreach ($invoices as $invoice): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($invoice['invoice_number']); ?></td>
                                            <td><?php echo htmlspecialchars($invoice['booking_number']); ?></td>
                                            <td><?php echo htmlspecialchars($invoice['guest_name']); ?></td>
                                            <td>
                                                <?php echo $invoice['invoice_type'] == 'personal' ? '个人' : '公司'; ?>
                                            </td>
                                            <td><?php echo htmlspecialchars($invoice['invoice_title']); ?></td>
                                            <td>¥<?php echo number_format($invoice['amount'], 2); ?></td>
                                            <td>
                                                <?php
                                                $statusLabels = [
                                                    'pending' => '<span class="badge badge-warning">待开具</span>',
                                                    'issued' => '<span class="badge badge-success">已开具</span>',
                                                    'cancelled' => '<span class="badge badge-danger">已取消</span>'
                                                ];
                                                echo $statusLabels[$invoice['status']] ?? $invoice['status'];
                                                ?>
                                            </td>
                                            <td><?php echo date('Y-m-d', strtotime($invoice['issue_date'])); ?></td>
                                            <td>
                                                <a href="javascript:void(0);" class="btn btn-sm btn-info view-invoice-btn" data-id="<?php echo $invoice['id']; ?>">查看</a>
                                                <?php if ($invoice['status'] == 'pending'): ?>
                                                    <a href="javascript:void(0);" class="btn btn-sm btn-success issue-invoice-btn" data-id="<?php echo $invoice['id']; ?>">开具</a>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <!-- 添加支付记录 -->
            <div class="tab-pane" id="add-payment">
                <div class="card">
                    <div class="card-header">
                        <h3>添加支付记录</h3>
                    </div>
                    <div class="card-body">
                        <form method="post" id="addPaymentForm">
                            <div class="form-group">
                                <label>订单号</label>
                                <div class="input-group">
                                    <input type="text" class="form-control" id="bookingNumber" name="booking_number" placeholder="输入订单号" required>
                                    <div class="input-group-append">
                                        <button type="button" class="btn btn-primary" id="searchBookingBtn">查找</button>
                                    </div>
                                </div>
                            </div>

                            <div id="bookingDetails" style="display: none;">
                                <div class="form-group">
                                    <label>客人姓名</label>
                                    <input type="text" class="form-control" id="guestName" readonly>
                                </div>

                                <div class="form-group">
                                    <label>订单总金额</label>
                                    <input type="text" class="form-control" id="totalAmount" readonly>
                                </div>

                                <div class="form-group">
                                    <label>已支付金额</label>
                                    <input type="text" class="form-control" id="paidAmount" readonly>
                                </div>

                                <div class="form-group">
                                    <label>待支付金额</label>
                                    <input type="text" class="form-control" id="dueAmount" readonly>
                                </div>

                                <div class="form-group">
                                    <label>支付金额</label>
                                    <input type="number" class="form-control" name="amount" id="paymentAmount" step="0.01" required>
                                </div>

                                <div class="form-group">
                                    <label>支付方式</label>
                                    <select class="form-control" name="payment_method" required>
                                        <option value="">请选择支付方式</option>
                                        <option value="cash">现金</option>
                                        <option value="credit_card">信用卡</option>
                                        <option value="debit_card">借记卡</option>
                                        <option value="bank_transfer">银行转账</option>
                                        <option value="alipay">支付宝</option>
                                        <option value="wechat_pay">微信支付</option>
                                        <option value="other">其他</option>
                                    </select>
                                </div>

                                <div class="form-group">
                                    <label>交易ID</label>
                                    <input type="text" class="form-control" name="transaction_id" placeholder="可选">
                                </div>

                                <div class="form-group">
                                    <label>支付日期</label>
                                    <input type="datetime-local" class="form-control" name="payment_date" required>
                                </div>

                                <div class="form-group">
                                    <label>备注</label>
                                    <textarea class="form-control" name="notes" rows="3"></textarea>
                                </div>

                                <input type="hidden" name="booking_id" id="bookingId">
                                <button type="submit" name="add_payment" class="btn btn-primary">保存支付记录</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .tabs {
        margin-bottom: 20px;
    }

    .tab-header {
        display: flex;
        border-bottom: 1px solid #dee2e6;
        margin-bottom: 20px;
    }

    .tab-btn {
        padding: 10px 20px;
        cursor: pointer;
        border: 1px solid transparent;
        border-radius: 4px 4px 0 0;
        margin-bottom: -1px;
    }

    .tab-btn.active {
        border-color: #dee2e6 #dee2e6 #fff;
        background-color: #fff;
        color: #0066cc;
        font-weight: bold;
    }

    .tab-pane {
        display: none;
    }

    .tab-pane.active {
        display: block;
    }

    .filter-form {
        margin-bottom: 20px;
    }

    .filter-row {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        align-items: center;
    }

    .filter-item {
        flex: 1;
        min-width: 150px;
    }

    .pagination {
        display: flex;
        justify-content: center;
        margin-top: 20px;
    }

    .page-link {
        padding: 5px 10px;
        margin: 0 5px;
        border: 1px solid #dee2e6;
        text-decoration: none;
        color: #0066cc;
    }

    .page-link.active {
        background-color: #0066cc;
        color: white;
        border-color: #0066cc;
    }

    .badge {
        padding: 5px 10px;
        border-radius: 4px;
        font-size: 12px;
        font-weight: normal;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #212529;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }

    .input-group {
        display: flex;
    }

    .input-group-append {
        margin-left: -1px;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 标签页切换
        const tabBtns = document.querySelectorAll('.tab-btn');
        const tabPanes = document.querySelectorAll('.tab-pane');

        tabBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const tabId = this.getAttribute('data-tab');

                // 移除所有活动状态
                tabBtns.forEach(b => b.classList.remove('active'));
                tabPanes.forEach(p => p.classList.remove('active'));

                // 设置当前标签为活动状态
                this.classList.add('active');
                document.getElementById(tabId).classList.add('active');
            });
        });

        // 查找订单
        const searchBookingBtn = document.getElementById('searchBookingBtn');
        if (searchBookingBtn) {
            searchBookingBtn.addEventListener('click', function() {
                const bookingNumber = document.getElementById('bookingNumber').value;
                if (!bookingNumber) {
                    alert('请输入订单号');
                    return;
                }

                // 这里应该发送AJAX请求获取订单信息
                // 为了演示，我们假设已经获取到了订单信息
                document.getElementById('bookingDetails').style.display = 'block';

                // 在实际应用中，这里应该填充从服务器获取的订单信息
                document.getElementById('guestName').value = '示例客人';
                document.getElementById('totalAmount').value = '¥1000.00';
                document.getElementById('paidAmount').value = '¥500.00';
                document.getElementById('dueAmount').value = '¥500.00';
                document.getElementById('paymentAmount').value = '500.00';
                document.getElementById('bookingId').value = '1';

                // 设置当前日期时间为默认支付时间
                const now = new Date();
                const year = now.getFullYear();
                const month = String(now.getMonth() + 1).padStart(2, '0');
                const day = String(now.getDate()).padStart(2, '0');
                const hours = String(now.getHours()).padStart(2, '0');
                const minutes = String(now.getMinutes()).padStart(2, '0');

                document.querySelector('input[name="payment_date"]').value = `${year}-${month}-${day}T${hours}:${minutes}`;
            });
        }

        // 绑定按钮点击事件的函数
        function bindButtonEvents() {
            // 查看支付记录
            const viewPaymentBtns = document.querySelectorAll('.view-payment-btn');
            viewPaymentBtns.forEach(btn => {
                btn.addEventListener('click', function() {
                    const paymentId = this.getAttribute('data-id');
                    // 这里应该发送AJAX请求获取支付记录详情
                    // 为了演示，我们使用alert显示
                    alert('查看支付记录ID: ' + paymentId);

                    // 实际应用中，应该打开一个模态框显示支付记录详情
                    // 例如：
                    // fetch('get_payment_details.php?id=' + paymentId)
                    //     .then(response => response.json())
                    //     .then(data => {
                    //         // 显示支付详情
                    //     });
                });
            });

            // 开具发票
            const createInvoiceBtns = document.querySelectorAll('.create-invoice-btn');
            createInvoiceBtns.forEach(btn => {
                btn.addEventListener('click', function() {
                    const bookingId = this.getAttribute('data-booking-id');

                    // 创建模态框HTML
                    const modalHtml = `
                        <div class="modal" id="createInvoiceModal" style="display: block;">
                            <div class="modal-dialog">
                                <div class="modal-content">
                                    <div class="modal-header">
                                        <h4 class="modal-title">开具发票</h4>
                                        <button type="button" class="close" id="closeInvoiceModal">&times;</button>
                                    </div>
                                    <form method="post" action="index.php?page=bill_management">
                                        <div class="modal-body">
                                            <input type="hidden" name="booking_id" value="${bookingId}">
                                            
                                            <div class="form-group">
                                                <label>发票类型</label>
                                                <select class="form-control" name="invoice_type" required>
                                                    <option value="personal">个人</option>
                                                    <option value="company">公司</option>
                                                </select>
                                            </div>
                                            
                                            <div class="form-group">
                                                <label>发票抬头</label>
                                                <input type="text" class="form-control" name="invoice_title" required>
                                            </div>
                                            
                                            <div class="form-group company-field" style="display: none;">
                                                <label>税号</label>
                                                <input type="text" class="form-control" name="tax_number">
                                            </div>
                                            
                                            <div class="form-group">
                                                <label>发票金额</label>
                                                <input type="number" class="form-control" name="amount" step="0.01" required>
                                            </div>
                                            
                                            <div class="form-group">
                                                <label>备注</label>
                                                <textarea class="form-control" name="notes" rows="3"></textarea>
                                            </div>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-secondary" id="cancelInvoiceModal">取消</button>
                                            <button type="submit" name="create_invoice" class="btn btn-primary">保存</button>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    `;

                    // 添加模态框到页面
                    document.body.insertAdjacentHTML('beforeend', modalHtml);

                    // 处理发票类型变化
                    const invoiceTypeSelect = document.querySelector('select[name="invoice_type"]');
                    const companyField = document.querySelector('.company-field');

                    invoiceTypeSelect.addEventListener('change', function() {
                        if (this.value === 'company') {
                            companyField.style.display = 'block';
                        } else {
                            companyField.style.display = 'none';
                        }
                    });

                    // 关闭模态框
                    document.getElementById('closeInvoiceModal').addEventListener('click', function() {
                        document.getElementById('createInvoiceModal').remove();
                    });

                    document.getElementById('cancelInvoiceModal').addEventListener('click', function() {
                        document.getElementById('createInvoiceModal').remove();
                    });

                    // 点击模态框外部关闭
                    window.addEventListener('click', function(event) {
                        const modal = document.getElementById('createInvoiceModal');
                        if (event.target === modal) {
                            modal.remove();
                        }
                    });
                });
            });

            // 查看发票
            const viewInvoiceBtns = document.querySelectorAll('.view-invoice-btn');
            viewInvoiceBtns.forEach(btn => {
                btn.addEventListener('click', function() {
                    const invoiceId = this.getAttribute('data-id');
                    // 这里应该发送AJAX请求获取发票详情
                    // 为了演示，我们使用alert显示
                    alert('查看发票ID: ' + invoiceId);

                    // 实际应用中，应该打开一个模态框显示发票详情
                });
            });

            // 开具发票
            const issueInvoiceBtns = document.querySelectorAll('.issue-invoice-btn');
            issueInvoiceBtns.forEach(btn => {
                btn.addEventListener('click', function() {
                    const invoiceId = this.getAttribute('data-id');
                    if (confirm('确定要开具此发票吗？')) {
                        // 这里应该发送AJAX请求或提交表单来开具发票
                        // 为了演示，我们使用alert显示
                        alert('发票ID: ' + invoiceId + ' 已开具');

                        // 实际应用中，应该提交表单或发送AJAX请求
                        // 例如：
                        // const form = document.createElement('form');
                        // form.method = 'POST';
                        // form.action = 'index.php?page=bill_management';
                        // const input = document.createElement('input');
                        // input.type = 'hidden';
                        // input.name = 'issue_invoice';
                        // input.value = invoiceId;
                        // form.appendChild(input);
                        // document.body.appendChild(form);
                        // form.submit();
                    }
                });
            });
        }

        // 初始绑定按钮事件
        bindButtonEvents();

        // 当标签页切换时，重新绑定按钮事件
        tabBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                // 延迟一点时间确保DOM已更新
                setTimeout(bindButtonEvents, 100);
            });
        });
    });
</script>