<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 获取今日收入
$today = date('Y-m-d');
$todayIncome = 0;
$stmt = $conn->prepare("SELECT SUM(amount) AS total FROM payments WHERE DATE(payment_date) = ?");
$stmt->bind_param("s", $today);
$stmt->execute();
$result = $stmt->get_result();
if ($row = $result->fetch_assoc()) {
    $todayIncome = $row['total'] ?: 0;
}

// 获取本月收入
$monthStart = date('Y-m-01');
$monthEnd = date('Y-m-t');
$monthlyIncome = 0;
$stmt = $conn->prepare("SELECT SUM(amount) AS total FROM payments WHERE payment_date BETWEEN ? AND ?");
$stmt->bind_param("ss", $monthStart, $monthEnd);
$stmt->execute();
$result = $stmt->get_result();
if ($row = $result->fetch_assoc()) {
    $monthlyIncome = $row['total'] ?: 0;
}

// 获取待处理发票数量
$pendingInvoices = 0;
$stmt = $conn->prepare("SELECT COUNT(*) AS count FROM invoices WHERE status = 'pending'");
$stmt->execute();
$result = $stmt->get_result();
if ($row = $result->fetch_assoc()) {
    $pendingInvoices = $row['count'];
}

// 获取未结算OTA订单数量
$pendingOtaBookings = 0;
$stmt = $conn->prepare("SELECT COUNT(*) AS count FROM bookings WHERE booking_source = 'ota' AND status = 'checked_out' AND payment_status != 'paid'");
$stmt->execute();
$result = $stmt->get_result();
if ($row = $result->fetch_assoc()) {
    $pendingOtaBookings = $row['count'];
}

// 获取最近5笔支付记录
$recentPayments = [];
$stmt = $conn->prepare("
    SELECT p.*, b.booking_number, b.guest_name 
    FROM payments p
    JOIN bookings b ON p.booking_id = b.id
    ORDER BY p.payment_date DESC
    LIMIT 5
");
$stmt->execute();
$result = $stmt->get_result();
while ($row = $result->fetch_assoc()) {
    $recentPayments[] = $row;
}

// 获取支付方式统计
$paymentMethods = [];
$stmt = $conn->prepare("
    SELECT payment_method, COUNT(*) as count, SUM(amount) as total
    FROM payments
    WHERE MONTH(payment_date) = MONTH(CURRENT_DATE())
    GROUP BY payment_method
    ORDER BY total DESC
");
$stmt->execute();
$result = $stmt->get_result();
while ($row = $result->fetch_assoc()) {
    $paymentMethods[] = $row;
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="dashboard">
    <div class="dashboard-stats">
        <div class="stat-card">
            <div class="stat-card-header">今日收入</div>
            <div class="stat-card-value">¥<?php echo number_format($todayIncome, 2); ?></div>
        </div>
        <div class="stat-card">
            <div class="stat-card-header">本月收入</div>
            <div class="stat-card-value">¥<?php echo number_format($monthlyIncome, 2); ?></div>
        </div>
        <div class="stat-card">
            <div class="stat-card-header">待处理发票</div>
            <div class="stat-card-value"><?php echo $pendingInvoices; ?></div>
            <div class="stat-card-action">
                <a href="index.php?page=bill_management" class="btn btn-sm">查看详情</a>
            </div>
        </div>
        <div class="stat-card">
            <div class="stat-card-header">待结算OTA订单</div>
            <div class="stat-card-value"><?php echo $pendingOtaBookings; ?></div>
            <div class="stat-card-action">
                <a href="index.php?page=ota_settlement" class="btn btn-sm">查看详情</a>
            </div>
        </div>
    </div>

    <div class="dashboard-row">
        <div class="dashboard-col">
            <div class="card">
                <div class="card-header">
                    <h3>最近支付记录</h3>
                </div>
                <div class="card-body">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>订单号</th>
                                <th>客人</th>
                                <th>金额</th>
                                <th>支付方式</th>
                                <th>支付时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($recentPayments)): ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无支付记录</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($recentPayments as $payment): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($payment['booking_number']); ?></td>
                                        <td><?php echo htmlspecialchars($payment['guest_name']); ?></td>
                                        <td>¥<?php echo number_format($payment['amount'], 2); ?></td>
                                        <td>
                                            <?php
                                            $methodLabels = [
                                                'cash' => '现金',
                                                'credit_card' => '信用卡',
                                                'debit_card' => '借记卡',
                                                'bank_transfer' => '银行转账',
                                                'alipay' => '支付宝',
                                                'wechat_pay' => '微信支付',
                                                'other' => '其他'
                                            ];
                                            echo $methodLabels[$payment['payment_method']] ?? $payment['payment_method'];
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($payment['payment_date'])); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                    <div class="card-footer">
                        <a href="index.php?page=bill_management" class="btn btn-primary">查看所有支付记录</a>
                    </div>
                </div>
            </div>
        </div>

        <div class="dashboard-col">
            <div class="card">
                <div class="card-header">
                    <h3>本月支付方式统计</h3>
                </div>
                <div class="card-body">
                    <?php if (empty($paymentMethods)): ?>
                        <p class="text-center">暂无支付数据</p>
                    <?php else: ?>
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>支付方式</th>
                                    <th>交易次数</th>
                                    <th>交易金额</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($paymentMethods as $method): ?>
                                    <tr>
                                        <td>
                                            <?php
                                            $methodLabels = [
                                                'cash' => '现金',
                                                'credit_card' => '信用卡',
                                                'debit_card' => '借记卡',
                                                'bank_transfer' => '银行转账',
                                                'alipay' => '支付宝',
                                                'wechat_pay' => '微信支付',
                                                'other' => '其他'
                                            ];
                                            echo $methodLabels[$method['payment_method']] ?? $method['payment_method'];
                                            ?>
                                        </td>
                                        <td><?php echo $method['count']; ?></td>
                                        <td>¥<?php echo number_format($method['total'], 2); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    <?php endif; ?>
                </div>
            </div>

            <div class="card mt-4">
                <div class="card-header">
                    <h3>快速操作</h3>
                </div>
                <div class="card-body">
                    <div class="quick-actions">
                        <a href="index.php?page=room_fee" class="btn btn-primary">房费管理</a>
                        <a href="index.php?page=bill_management" class="btn btn-primary">账单管理</a>
                        <a href="index.php?page=income_expense" class="btn btn-primary">收支统计</a>
                        <a href="index.php?page=refund" class="btn btn-primary">退款管理</a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .dashboard-stats {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .stat-card {
        flex: 1;
        min-width: 200px;
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        text-align: center;
    }

    .stat-card-header {
        font-size: 14px;
        color: #666;
        margin-bottom: 10px;
    }

    .stat-card-value {
        font-size: 24px;
        font-weight: bold;
        color: #0066cc;
        margin-bottom: 10px;
    }

    .stat-card-action {
        margin-top: 10px;
    }

    .dashboard-row {
        display: flex;
        gap: 20px;
        margin-bottom: 20px;
    }

    .dashboard-col {
        flex: 1;
        min-width: 0;
    }

    .quick-actions {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
    }

    .mt-4 {
        margin-top: 20px;
    }

    .card-footer {
        padding-top: 15px;
        text-align: center;
    }
</style>