<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 获取统计周期
$period = isset($_GET['period']) ? $_GET['period'] : 'month';
$custom_start = isset($_GET['start_date']) ? $_GET['start_date'] : '';
$custom_end = isset($_GET['end_date']) ? $_GET['end_date'] : '';

// 根据周期设置日期范围
$start_date = '';
$end_date = date('Y-m-d');

switch ($period) {
    case 'week':
        $start_date = date('Y-m-d', strtotime('-7 days'));
        break;
    case 'month':
        $start_date = date('Y-m-01');
        break;
    case 'quarter':
        $current_month = date('n');
        $current_quarter = ceil($current_month / 3);
        $quarter_start_month = ($current_quarter - 1) * 3 + 1;
        $start_date = date('Y-' . str_pad($quarter_start_month, 2, '0', STR_PAD_LEFT) . '-01');
        break;
    case 'year':
        $start_date = date('Y-01-01');
        break;
    case 'custom':
        $start_date = $custom_start;
        $end_date = $custom_end ?: date('Y-m-d');
        break;
}

// 获取收入数据
$income_data = [];

// 房费收入
$stmt = $conn->prepare("
    SELECT SUM(p.amount) as total
    FROM payments p
    JOIN bookings b ON p.booking_id = b.id
    WHERE p.payment_date BETWEEN ? AND ?
");
$stmt->bind_param("ss", $start_date, $end_date);
$stmt->execute();
$result = $stmt->get_result();
$row = $result->fetch_assoc();
$room_income = $row['total'] ?: 0;
$income_data[] = [
    'category' => '房费收入',
    'amount' => $room_income
];

// 总收入
$total_income = $room_income;

// 获取支出数据（假设有一个expenses表）
$expense_data = [];
$total_expense = 0;

// 检查是否存在expenses表
$result = $conn->query("SHOW TABLES LIKE 'expenses'");
if ($result->num_rows > 0) {
    // 获取支出分类数据
    $stmt = $conn->prepare("
        SELECT category, SUM(amount) as total
        FROM expenses
        WHERE expense_date BETWEEN ? AND ?
        GROUP BY category
        ORDER BY total DESC
    ");
    $stmt->bind_param("ss", $start_date, $end_date);
    $stmt->execute();
    $result = $stmt->get_result();

    while ($row = $result->fetch_assoc()) {
        $expense_data[] = [
            'category' => $row['category'],
            'amount' => $row['total']
        ];
        $total_expense += $row['total'];
    }
} else {
    // 如果没有expenses表，使用模拟数据
    $expense_data = [
        ['category' => '人工成本', 'amount' => 15000],
        ['category' => '水电费', 'amount' => 5000],
        ['category' => '维修费用', 'amount' => 3000],
        ['category' => '清洁用品', 'amount' => 2000],
        ['category' => '其他支出', 'amount' => 1000]
    ];
    $total_expense = array_sum(array_column($expense_data, 'amount'));
}

// 计算净利润
$net_profit = $total_income - $total_expense;

// 获取每月收入趋势
$monthly_trend = [];
$year = date('Y');
$stmt = $conn->prepare("
    SELECT 
        MONTH(p.payment_date) as month,
        SUM(p.amount) as total
    FROM payments p
    WHERE YEAR(p.payment_date) = ?
    GROUP BY MONTH(p.payment_date)
    ORDER BY month
");
$stmt->bind_param("i", $year);
$stmt->execute();
$result = $stmt->get_result();

$months = [
    1 => '一月',
    2 => '二月',
    3 => '三月',
    4 => '四月',
    5 => '五月',
    6 => '六月',
    7 => '七月',
    8 => '八月',
    9 => '九月',
    10 => '十月',
    11 => '十一月',
    12 => '十二月'
];

while ($row = $result->fetch_assoc()) {
    $monthly_trend[] = [
        'month' => $months[$row['month']],
        'amount' => $row['total']
    ];
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content-wrapper">
    <!-- 统计周期选择 -->
    <div class="card">
        <div class="card-header">
            <h3>收支统计</h3>
            <div class="card-tools">
                <form method="get" class="period-form">
                    <input type="hidden" name="page" value="income_expense">
                    <div class="period-selector">
                        <div class="period-item">
                            <select name="period" id="periodSelect" class="form-control">
                                <option value="week" <?php echo $period == 'week' ? 'selected' : ''; ?>>最近一周</option>
                                <option value="month" <?php echo $period == 'month' ? 'selected' : ''; ?>>本月</option>
                                <option value="quarter" <?php echo $period == 'quarter' ? 'selected' : ''; ?>>本季度</option>
                                <option value="year" <?php echo $period == 'year' ? 'selected' : ''; ?>>本年度</option>
                                <option value="custom" <?php echo $period == 'custom' ? 'selected' : ''; ?>>自定义</option>
                            </select>
                        </div>
                        <div class="period-item custom-date" style="display: <?php echo $period == 'custom' ? 'flex' : 'none'; ?>;">
                            <input type="date" name="start_date" class="form-control" value="<?php echo $custom_start; ?>">
                            <span class="date-separator">至</span>
                            <input type="date" name="end_date" class="form-control" value="<?php echo $custom_end; ?>">
                        </div>
                        <div class="period-item">
                            <button type="submit" class="btn btn-primary">查询</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
        <div class="card-body">
            <div class="summary-cards">
                <div class="summary-card income">
                    <div class="summary-icon">
                        <i class="fas fa-arrow-down"></i>
                    </div>
                    <div class="summary-content">
                        <div class="summary-title">总收入</div>
                        <div class="summary-value">¥<?php echo number_format($total_income, 2); ?></div>
                    </div>
                </div>
                <div class="summary-card expense">
                    <div class="summary-icon">
                        <i class="fas fa-arrow-up"></i>
                    </div>
                    <div class="summary-content">
                        <div class="summary-title">总支出</div>
                        <div class="summary-value">¥<?php echo number_format($total_expense, 2); ?></div>
                    </div>
                </div>
                <div class="summary-card profit <?php echo $net_profit >= 0 ? 'positive' : 'negative'; ?>">
                    <div class="summary-icon">
                        <i class="fas fa-chart-line"></i>
                    </div>
                    <div class="summary-content">
                        <div class="summary-title">净利润</div>
                        <div class="summary-value">¥<?php echo number_format($net_profit, 2); ?></div>
                    </div>
                </div>
            </div>

            <div class="stats-row">
                <div class="stats-col">
                    <div class="card">
                        <div class="card-header">
                            <h4>收入明细</h4>
                        </div>
                        <div class="card-body">
                            <table class="data-table">
                                <thead>
                                    <tr>
                                        <th>收入类别</th>
                                        <th>金额</th>
                                        <th>占比</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (empty($income_data)): ?>
                                        <tr>
                                            <td colspan="3" class="text-center">暂无收入数据</td>
                                        </tr>
                                    <?php else: ?>
                                        <?php foreach ($income_data as $income): ?>
                                            <tr>
                                                <td><?php echo htmlspecialchars($income['category']); ?></td>
                                                <td>¥<?php echo number_format($income['amount'], 2); ?></td>
                                                <td>
                                                    <?php
                                                    $percentage = $total_income > 0 ? ($income['amount'] / $total_income * 100) : 0;
                                                    echo number_format($percentage, 2) . '%';
                                                    ?>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                </tbody>
                                <tfoot>
                                    <tr>
                                        <th>总计</th>
                                        <th>¥<?php echo number_format($total_income, 2); ?></th>
                                        <th>100%</th>
                                    </tr>
                                </tfoot>
                            </table>
                        </div>
                    </div>
                </div>

                <div class="stats-col">
                    <div class="card">
                        <div class="card-header">
                            <h4>支出明细</h4>
                        </div>
                        <div class="card-body">
                            <table class="data-table">
                                <thead>
                                    <tr>
                                        <th>支出类别</th>
                                        <th>金额</th>
                                        <th>占比</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (empty($expense_data)): ?>
                                        <tr>
                                            <td colspan="3" class="text-center">暂无支出数据</td>
                                        </tr>
                                    <?php else: ?>
                                        <?php foreach ($expense_data as $expense): ?>
                                            <tr>
                                                <td><?php echo htmlspecialchars($expense['category']); ?></td>
                                                <td>¥<?php echo number_format($expense['amount'], 2); ?></td>
                                                <td>
                                                    <?php
                                                    $percentage = $total_expense > 0 ? ($expense['amount'] / $total_expense * 100) : 0;
                                                    echo number_format($percentage, 2) . '%';
                                                    ?>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                </tbody>
                                <tfoot>
                                    <tr>
                                        <th>总计</th>
                                        <th>¥<?php echo number_format($total_expense, 2); ?></th>
                                        <th>100%</th>
                                    </tr>
                                </tfoot>
                            </table>
                        </div>
                    </div>
                </div>
            </div>

            <div class="card mt-4">
                <div class="card-header">
                    <h4><?php echo date('Y'); ?>年月度收入趋势</h4>
                </div>
                <div class="card-body">
                    <div class="chart-container">
                        <canvas id="monthlyTrendChart"></canvas>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .period-form {
        margin-bottom: 20px;
    }

    .period-selector {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        align-items: center;
    }

    .period-item {
        flex: 1;
        min-width: 150px;
    }

    .custom-date {
        display: flex;
        align-items: center;
        gap: 10px;
    }

    .date-separator {
        flex-shrink: 0;
    }

    .summary-cards {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .summary-card {
        flex: 1;
        min-width: 200px;
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        display: flex;
        align-items: center;
    }

    .summary-icon {
        width: 50px;
        height: 50px;
        border-radius: 50%;
        display: flex;
        align-items: center;
        justify-content: center;
        margin-right: 15px;
        font-size: 20px;
        color: white;
    }

    .summary-content {
        flex-grow: 1;
    }

    .summary-title {
        font-size: 14px;
        color: #666;
        margin-bottom: 5px;
    }

    .summary-value {
        font-size: 24px;
        font-weight: bold;
    }

    .income .summary-icon {
        background-color: #28a745;
    }

    .expense .summary-icon {
        background-color: #dc3545;
    }

    .profit .summary-icon {
        background-color: #0066cc;
    }

    .profit.positive .summary-value {
        color: #28a745;
    }

    .profit.negative .summary-value {
        color: #dc3545;
    }

    .stats-row {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .stats-col {
        flex: 1;
        min-width: 300px;
    }

    .chart-container {
        height: 300px;
    }

    .mt-4 {
        margin-top: 20px;
    }
</style>

<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 周期选择器
        const periodSelect = document.getElementById('periodSelect');
        const customDateDiv = document.querySelector('.custom-date');

        periodSelect.addEventListener('change', function() {
            if (this.value === 'custom') {
                customDateDiv.style.display = 'flex';
            } else {
                customDateDiv.style.display = 'none';
            }
        });

        // 月度趋势图表
        const monthlyData = <?php echo json_encode($monthly_trend); ?>;
        const months = monthlyData.map(item => item.month);
        const amounts = monthlyData.map(item => item.amount);

        const ctx = document.getElementById('monthlyTrendChart').getContext('2d');
        new Chart(ctx, {
            type: 'bar',
            data: {
                labels: months,
                datasets: [{
                    label: '月度收入',
                    data: amounts,
                    backgroundColor: 'rgba(0, 102, 204, 0.7)',
                    borderColor: 'rgba(0, 102, 204, 1)',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        ticks: {
                            callback: function(value) {
                                return '¥' + value.toLocaleString();
                            }
                        }
                    }
                },
                plugins: {
                    tooltip: {
                        callbacks: {
                            label: function(context) {
                                return '收入: ¥' + context.raw.toLocaleString();
                            }
                        }
                    }
                }
            }
        });
    });
</script>