<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 处理OTA结算
if (isset($_POST['settle_ota'])) {
    $booking_ids = $_POST['booking_ids'] ?? [];
    $settlement_amount = $_POST['settlement_amount'];
    $settlement_date = $_POST['settlement_date'];
    $transaction_id = $_POST['transaction_id'] ?? '';
    $notes = $_POST['notes'] ?? '';

    if (!empty($booking_ids)) {
        // 检查是否存在ota_settlements表
        $result = $conn->query("SHOW TABLES LIKE 'ota_settlements'");
        if ($result->num_rows == 0) {
            // 创建ota_settlements表
            $conn->query("
                CREATE TABLE IF NOT EXISTS ota_settlements (
                    id INT AUTO_INCREMENT PRIMARY KEY,
                    ota_name VARCHAR(50) NOT NULL,
                    settlement_amount DECIMAL(12, 2) NOT NULL,
                    settlement_date DATE NOT NULL,
                    transaction_id VARCHAR(100),
                    notes TEXT,
                    created_by INT NOT NULL,
                    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
                    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE CASCADE
                ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4
            ");

            // 创建ota_settlement_items表
            $conn->query("
                CREATE TABLE IF NOT EXISTS ota_settlement_items (
                    id INT AUTO_INCREMENT PRIMARY KEY,
                    settlement_id INT NOT NULL,
                    booking_id INT NOT NULL,
                    amount DECIMAL(12, 2) NOT NULL,
                    commission DECIMAL(12, 2) NOT NULL,
                    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
                    FOREIGN KEY (settlement_id) REFERENCES ota_settlements(id) ON DELETE CASCADE,
                    FOREIGN KEY (booking_id) REFERENCES bookings(id) ON DELETE CASCADE
                ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4
            ");
        }

        // 获取OTA名称（假设所有选中的订单都来自同一个OTA平台）
        $booking_id = $booking_ids[0];
        $stmt = $conn->prepare("SELECT ota_name FROM bookings WHERE id = ?");
        $stmt->bind_param("i", $booking_id);
        $stmt->execute();
        $result = $stmt->get_result();
        $booking = $result->fetch_assoc();
        $ota_name = $booking['ota_name'] ?? 'unknown';

        // 开始事务
        $conn->begin_transaction();

        try {
            // 插入结算记录
            $user_id = $_SESSION['user_id'];
            $stmt = $conn->prepare("
                INSERT INTO ota_settlements (ota_name, settlement_amount, settlement_date, transaction_id, notes, created_by)
                VALUES (?, ?, ?, ?, ?, ?)
            ");
            $stmt->bind_param("sdsssi", $ota_name, $settlement_amount, $settlement_date, $transaction_id, $notes, $user_id);
            $stmt->execute();
            $settlement_id = $conn->insert_id;

            // 插入结算明细
            $total_commission = 0;
            foreach ($booking_ids as $booking_id) {
                // 获取订单金额和佣金
                $stmt = $conn->prepare("SELECT total_amount FROM bookings WHERE id = ?");
                $stmt->bind_param("i", $booking_id);
                $stmt->execute();
                $result = $stmt->get_result();
                $booking = $result->fetch_assoc();
                $booking_amount = $booking['total_amount'];

                // 假设佣金为订单金额的10%
                $commission = $booking_amount * 0.1;
                $total_commission += $commission;

                // 插入结算明细
                $stmt = $conn->prepare("
                    INSERT INTO ota_settlement_items (settlement_id, booking_id, amount, commission)
                    VALUES (?, ?, ?, ?)
                ");
                $stmt->bind_param("iidd", $settlement_id, $booking_id, $booking_amount, $commission);
                $stmt->execute();

                // 更新订单状态为已结算
                $stmt = $conn->prepare("UPDATE bookings SET payment_status = 'paid' WHERE id = ?");
                $stmt->bind_param("i", $booking_id);
                $stmt->execute();
            }

            // 记录系统日志
            $description = "已完成OTA平台 {$ota_name} 结算，金额：{$settlement_amount}，佣金：{$total_commission}";
            $ip = $_SERVER['REMOTE_ADDR'] ?? '';

            $stmt = $conn->prepare("INSERT INTO system_logs (user_id, action, description, ip_address) VALUES (?, 'ota_settlement', ?, ?)");
            if ($stmt) {
                $stmt->bind_param("iss", $user_id, $description, $ip);
                $stmt->execute();
            }

            // 提交事务
            $conn->commit();
            $success_message = "OTA平台结算已成功处理";
        } catch (Exception $e) {
            // 回滚事务
            $conn->rollback();
            $error_message = "处理OTA结算失败: " . $e->getMessage();
        }
    } else {
        $error_message = "请选择至少一个订单进行结算";
    }
}

// 获取OTA平台列表
$ota_platforms = [];
$sql = "SELECT DISTINCT ota_name FROM bookings WHERE ota_name IS NOT NULL AND ota_name != ''";
$result = mysqli_query($conn, $sql);
if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        $ota_platforms[] = $row['ota_name'];
    }
}

// 获取待结算订单
$pending_bookings = [];
$selected_ota = isset($_GET['ota']) ? $_GET['ota'] : '';

$sql = "
    SELECT b.id, b.booking_number, b.guest_name, b.check_in_date, b.check_out_date, 
           b.total_amount, b.ota_name, b.ota_booking_id,
           (SELECT SUM(amount) FROM payments WHERE booking_id = b.id) as paid_amount
    FROM bookings b
    WHERE b.booking_source = 'ota'
    AND b.status = 'checked_out'
    AND b.payment_status != 'paid'
";

if ($selected_ota) {
    $sql .= " AND b.ota_name = '" . mysqli_real_escape_string($conn, $selected_ota) . "'";
}

$sql .= " ORDER BY b.check_out_date DESC LIMIT 100";

$result = mysqli_query($conn, $sql);
if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        $pending_bookings[] = $row;
    }
}

// 获取结算记录
$settlements = [];
$settlementsTableExists = false;

$result = $conn->query("SHOW TABLES LIKE 'ota_settlements'");
if ($result->num_rows > 0) {
    $settlementsTableExists = true;

    $sql = "
        SELECT s.*, COUNT(si.booking_id) as booking_count, SUM(si.commission) as total_commission
        FROM ota_settlements s
        LEFT JOIN ota_settlement_items si ON s.id = si.settlement_id
        GROUP BY s.id
        ORDER BY s.settlement_date DESC
        LIMIT 20
    ";

    $result = mysqli_query($conn, $sql);
    if ($result) {
        while ($row = mysqli_fetch_assoc($result)) {
            $settlements[] = $row;
        }
    }
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content-wrapper">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="tabs">
        <div class="tab-header">
            <div class="tab-btn active" data-tab="pending-bookings">待结算订单</div>
            <div class="tab-btn" data-tab="settlement-records">结算记录</div>
        </div>

        <div class="tab-content">
            <!-- 待结算订单 -->
            <div class="tab-pane active" id="pending-bookings">
                <div class="card">
                    <div class="card-header">
                        <h3>待结算OTA订单</h3>
                        <div class="card-tools">
                            <form method="get" class="filter-form">
                                <input type="hidden" name="page" value="ota_settlement">
                                <div class="filter-row">
                                    <div class="filter-item">
                                        <select name="ota" class="form-control">
                                            <option value="">所有OTA平台</option>
                                            <?php foreach ($ota_platforms as $platform): ?>
                                                <option value="<?php echo htmlspecialchars($platform); ?>" <?php echo $selected_ota == $platform ? 'selected' : ''; ?>>
                                                    <?php echo htmlspecialchars($platform); ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </div>
                                    <div class="filter-item">
                                        <button type="submit" class="btn btn-primary">筛选</button>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                    <div class="card-body">
                        <?php if (empty($pending_bookings)): ?>
                            <div class="alert alert-info">
                                暂无待结算OTA订单。
                            </div>
                        <?php else: ?>
                            <form method="post" id="settlementForm">
                                <div class="table-responsive">
                                    <table class="data-table">
                                        <thead>
                                            <tr>
                                                <th><input type="checkbox" id="selectAll"></th>
                                                <th>订单号</th>
                                                <th>OTA平台</th>
                                                <th>OTA订单号</th>
                                                <th>客人</th>
                                                <th>入住日期</th>
                                                <th>离店日期</th>
                                                <th>订单金额</th>
                                                <th>已收金额</th>
                                                <th>预估佣金</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach ($pending_bookings as $booking): ?>
                                                <?php
                                                // 计算预估佣金（假设为订单金额的10%）
                                                $commission = $booking['total_amount'] * 0.1;
                                                ?>
                                                <tr>
                                                    <td>
                                                        <input type="checkbox" name="booking_ids[]" value="<?php echo $booking['id']; ?>" class="booking-checkbox" data-amount="<?php echo $booking['total_amount']; ?>" data-commission="<?php echo $commission; ?>">
                                                    </td>
                                                    <td><?php echo htmlspecialchars($booking['booking_number']); ?></td>
                                                    <td><?php echo htmlspecialchars($booking['ota_name']); ?></td>
                                                    <td><?php echo htmlspecialchars($booking['ota_booking_id'] ?? '-'); ?></td>
                                                    <td><?php echo htmlspecialchars($booking['guest_name']); ?></td>
                                                    <td><?php echo date('Y-m-d', strtotime($booking['check_in_date'])); ?></td>
                                                    <td><?php echo date('Y-m-d', strtotime($booking['check_out_date'])); ?></td>
                                                    <td>¥<?php echo number_format($booking['total_amount'], 2); ?></td>
                                                    <td>¥<?php echo number_format($booking['paid_amount'] ?? 0, 2); ?></td>
                                                    <td>¥<?php echo number_format($commission, 2); ?></td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>

                                <div class="settlement-summary" style="display: none;">
                                    <div class="card mt-4">
                                        <div class="card-header">
                                            <h4>结算信息</h4>
                                        </div>
                                        <div class="card-body">
                                            <div class="row">
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label>选中订单数</label>
                                                        <input type="text" class="form-control" id="selectedCount" readonly>
                                                    </div>

                                                    <div class="form-group">
                                                        <label>订单总金额</label>
                                                        <input type="text" class="form-control" id="totalAmount" readonly>
                                                    </div>

                                                    <div class="form-group">
                                                        <label>预估佣金总额</label>
                                                        <input type="text" class="form-control" id="totalCommission" readonly>
                                                    </div>
                                                </div>

                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label>结算金额</label>
                                                        <input type="number" class="form-control" name="settlement_amount" id="settlementAmount" step="0.01" required>
                                                    </div>

                                                    <div class="form-group">
                                                        <label>结算日期</label>
                                                        <input type="date" class="form-control" name="settlement_date" value="<?php echo date('Y-m-d'); ?>" required>
                                                    </div>

                                                    <div class="form-group">
                                                        <label>交易ID</label>
                                                        <input type="text" class="form-control" name="transaction_id" placeholder="可选">
                                                    </div>

                                                    <div class="form-group">
                                                        <label>备注</label>
                                                        <textarea class="form-control" name="notes" rows="3"></textarea>
                                                    </div>
                                                </div>
                                            </div>

                                            <button type="submit" name="settle_ota" class="btn btn-primary">提交结算</button>
                                        </div>
                                    </div>
                                </div>
                            </form>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

            <!-- 结算记录 -->
            <div class="tab-pane" id="settlement-records">
                <div class="card">
                    <div class="card-header">
                        <h3>OTA结算记录</h3>
                    </div>
                    <div class="card-body">
                        <?php if (!$settlementsTableExists): ?>
                            <div class="alert alert-info">
                                尚未创建结算记录表，请先进行一次OTA结算。
                            </div>
                        <?php elseif (empty($settlements)): ?>
                            <div class="alert alert-info">
                                暂无OTA结算记录。
                            </div>
                        <?php else: ?>
                            <table class="data-table">
                                <thead>
                                    <tr>
                                        <th>结算ID</th>
                                        <th>OTA平台</th>
                                        <th>结算金额</th>
                                        <th>佣金总额</th>
                                        <th>订单数量</th>
                                        <th>结算日期</th>
                                        <th>交易ID</th>
                                        <th>创建时间</th>
                                        <th>操作</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($settlements as $settlement): ?>
                                        <tr>
                                            <td><?php echo $settlement['id']; ?></td>
                                            <td><?php echo htmlspecialchars($settlement['ota_name']); ?></td>
                                            <td>¥<?php echo number_format($settlement['settlement_amount'], 2); ?></td>
                                            <td>¥<?php echo number_format($settlement['total_commission'], 2); ?></td>
                                            <td><?php echo $settlement['booking_count']; ?></td>
                                            <td><?php echo date('Y-m-d', strtotime($settlement['settlement_date'])); ?></td>
                                            <td><?php echo htmlspecialchars($settlement['transaction_id'] ?? '-'); ?></td>
                                            <td><?php echo date('Y-m-d H:i', strtotime($settlement['created_at'])); ?></td>
                                            <td>
                                                <a href="javascript:void(0);" class="btn btn-sm btn-info view-settlement-btn" data-id="<?php echo $settlement['id']; ?>">查看详情</a>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .tabs {
        margin-bottom: 20px;
    }

    .tab-header {
        display: flex;
        border-bottom: 1px solid #dee2e6;
        margin-bottom: 20px;
    }

    .tab-btn {
        padding: 10px 20px;
        cursor: pointer;
        border: 1px solid transparent;
        border-radius: 4px 4px 0 0;
        margin-bottom: -1px;
    }

    .tab-btn.active {
        border-color: #dee2e6 #dee2e6 #fff;
        background-color: #fff;
        color: #0066cc;
        font-weight: bold;
    }

    .tab-pane {
        display: none;
    }

    .tab-pane.active {
        display: block;
    }

    .filter-form {
        margin-bottom: 20px;
    }

    .filter-row {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        align-items: center;
    }

    .filter-item {
        flex: 1;
        min-width: 150px;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-danger {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }

    .alert-info {
        color: #0c5460;
        background-color: #d1ecf1;
        border-color: #bee5eb;
    }

    .table-responsive {
        overflow-x: auto;
    }

    .mt-4 {
        margin-top: 20px;
    }

    .row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -15px;
        margin-left: -15px;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 15px;
        padding-left: 15px;
    }

    @media (max-width: 768px) {
        .col-md-6 {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 标签页切换
        const tabBtns = document.querySelectorAll('.tab-btn');
        const tabPanes = document.querySelectorAll('.tab-pane');

        tabBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const tabId = this.getAttribute('data-tab');

                // 移除所有活动状态
                tabBtns.forEach(b => b.classList.remove('active'));
                tabPanes.forEach(p => p.classList.remove('active'));

                // 设置当前标签为活动状态
                this.classList.add('active');
                document.getElementById(tabId).classList.add('active');
            });
        });

        // 全选/取消全选
        const selectAllCheckbox = document.getElementById('selectAll');
        const bookingCheckboxes = document.querySelectorAll('.booking-checkbox');
        const settlementSummary = document.querySelector('.settlement-summary');

        if (selectAllCheckbox) {
            selectAllCheckbox.addEventListener('change', function() {
                const isChecked = this.checked;

                bookingCheckboxes.forEach(checkbox => {
                    checkbox.checked = isChecked;
                });

                updateSettlementSummary();
            });
        }

        // 单个复选框变化
        bookingCheckboxes.forEach(checkbox => {
            checkbox.addEventListener('change', function() {
                updateSettlementSummary();

                // 检查是否所有复选框都被选中
                const allChecked = Array.from(bookingCheckboxes).every(cb => cb.checked);
                if (selectAllCheckbox) {
                    selectAllCheckbox.checked = allChecked;
                }
            });
        });

        // 更新结算摘要
        function updateSettlementSummary() {
            const selectedCheckboxes = document.querySelectorAll('.booking-checkbox:checked');
            const selectedCount = selectedCheckboxes.length;

            if (selectedCount > 0) {
                let totalAmount = 0;
                let totalCommission = 0;

                selectedCheckboxes.forEach(checkbox => {
                    totalAmount += parseFloat(checkbox.getAttribute('data-amount'));
                    totalCommission += parseFloat(checkbox.getAttribute('data-commission'));
                });

                document.getElementById('selectedCount').value = selectedCount;
                document.getElementById('totalAmount').value = '¥' + totalAmount.toFixed(2);
                document.getElementById('totalCommission').value = '¥' + totalCommission.toFixed(2);
                document.getElementById('settlementAmount').value = (totalAmount - totalCommission).toFixed(2);

                settlementSummary.style.display = 'block';
            } else {
                settlementSummary.style.display = 'none';
            }
        }

        // 表单提交验证
        const settlementForm = document.getElementById('settlementForm');
        if (settlementForm) {
            settlementForm.addEventListener('submit', function(event) {
                const selectedCheckboxes = document.querySelectorAll('.booking-checkbox:checked');

                if (selectedCheckboxes.length === 0) {
                    alert('请选择至少一个订单进行结算');
                    event.preventDefault();
                    return;
                }

                const settlementAmount = parseFloat(document.getElementById('settlementAmount').value);
                if (isNaN(settlementAmount) || settlementAmount <= 0) {
                    alert('请输入有效的结算金额');
                    event.preventDefault();
                    return;
                }
            });
        }
    });
</script>