<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 处理退款申请
if (isset($_POST['process_refund'])) {
    $booking_id = $_POST['booking_id'];
    $refund_amount = $_POST['refund_amount'];
    $refund_method = $_POST['refund_method'];
    $refund_reason = $_POST['refund_reason'];
    $refund_status = $_POST['refund_status'];
    $transaction_id = $_POST['transaction_id'] ?? '';
    $notes = $_POST['notes'] ?? '';

    // 检查是否存在refunds表
    $result = $conn->query("SHOW TABLES LIKE 'refunds'");
    if ($result->num_rows == 0) {
        // 创建refunds表
        $conn->query("
            CREATE TABLE IF NOT EXISTS refunds (
                id INT AUTO_INCREMENT PRIMARY KEY,
                booking_id INT NOT NULL,
                amount DECIMAL(12, 2) NOT NULL,
                refund_method ENUM('cash', 'credit_card', 'debit_card', 'bank_transfer', 'alipay', 'wechat_pay', 'other') NOT NULL,
                transaction_id VARCHAR(100),
                reason TEXT NOT NULL,
                status ENUM('pending', 'approved', 'completed', 'rejected') NOT NULL,
                notes TEXT,
                processed_by INT,
                processed_at DATETIME,
                created_by INT NOT NULL,
                created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
                FOREIGN KEY (booking_id) REFERENCES bookings(id) ON DELETE CASCADE,
                FOREIGN KEY (processed_by) REFERENCES users(id) ON DELETE SET NULL,
                FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE CASCADE
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4
        ");
    }

    // 插入退款记录
    $user_id = $_SESSION['user_id'];
    $processed_at = $refund_status == 'completed' ? date('Y-m-d H:i:s') : null;

    $stmt = $conn->prepare("
        INSERT INTO refunds (booking_id, amount, refund_method, transaction_id, reason, status, notes, processed_by, processed_at, created_by)
        VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
    ");

    $stmt->bind_param(
        "idsssssiis",
        $booking_id,
        $refund_amount,
        $refund_method,
        $transaction_id,
        $refund_reason,
        $refund_status,
        $notes,
        $user_id,
        $processed_at,
        $user_id
    );

    if ($stmt->execute()) {
        // 如果退款已完成，更新订单状态
        if ($refund_status == 'completed') {
            $stmt = $conn->prepare("UPDATE bookings SET status = 'cancelled' WHERE id = ?");
            $stmt->bind_param("i", $booking_id);
            $stmt->execute();

            // 记录系统日志
            $description = "订单 {$booking_id} 已退款 {$refund_amount} 元，原因：{$refund_reason}";
            $ip = $_SERVER['REMOTE_ADDR'] ?? '';

            $stmt = $conn->prepare("INSERT INTO system_logs (user_id, action, description, ip_address) VALUES (?, 'refund_completed', ?, ?)");
            if ($stmt) {
                $stmt->bind_param("iss", $user_id, $description, $ip);
                $stmt->execute();
            }
        }

        $success_message = "退款申请已成功处理";
    } else {
        $error_message = "处理退款申请失败: " . $stmt->error;
    }
}

// 获取退款记录
$refunds = [];
$refundsTableExists = false;

$result = $conn->query("SHOW TABLES LIKE 'refunds'");
if ($result->num_rows > 0) {
    $refundsTableExists = true;

    $sql = "
        SELECT r.*, b.booking_number, b.guest_name, b.total_amount
        FROM refunds r
        JOIN bookings b ON r.booking_id = b.id
        ORDER BY r.created_at DESC
        LIMIT 50
    ";

    $result = mysqli_query($conn, $sql);
    if ($result) {
        while ($row = mysqli_fetch_assoc($result)) {
            $refunds[] = $row;
        }
    }
}

// 获取可退款的订单
$refundable_bookings = [];
$sql = "
    SELECT b.id, b.booking_number, b.guest_name, b.total_amount, 
           (SELECT SUM(amount) FROM payments WHERE booking_id = b.id) as paid_amount
    FROM bookings b
    WHERE b.status IN ('pending', 'confirmed', 'checked_out')
    AND (SELECT SUM(amount) FROM payments WHERE booking_id = b.id) > 0
    ORDER BY b.created_at DESC
    LIMIT 50
";

$result = mysqli_query($conn, $sql);
if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        $refundable_bookings[] = $row;
    }
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content-wrapper">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="tabs">
        <div class="tab-header">
            <div class="tab-btn active" data-tab="refund-list">退款记录</div>
            <div class="tab-btn" data-tab="new-refund">申请退款</div>
        </div>

        <div class="tab-content">
            <!-- 退款记录 -->
            <div class="tab-pane active" id="refund-list">
                <div class="card">
                    <div class="card-header">
                        <h3>退款记录列表</h3>
                    </div>
                    <div class="card-body">
                        <?php if (!$refundsTableExists): ?>
                            <div class="alert alert-info">
                                尚未创建退款记录表，请先申请一笔退款。
                            </div>
                        <?php elseif (empty($refunds)): ?>
                            <div class="alert alert-info">
                                暂无退款记录。
                            </div>
                        <?php else: ?>
                            <table class="data-table">
                                <thead>
                                    <tr>
                                        <th>订单号</th>
                                        <th>客人</th>
                                        <th>订单金额</th>
                                        <th>退款金额</th>
                                        <th>退款方式</th>
                                        <th>退款原因</th>
                                        <th>状态</th>
                                        <th>申请时间</th>
                                        <th>操作</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($refunds as $refund): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($refund['booking_number']); ?></td>
                                            <td><?php echo htmlspecialchars($refund['guest_name']); ?></td>
                                            <td>¥<?php echo number_format($refund['total_amount'], 2); ?></td>
                                            <td>¥<?php echo number_format($refund['amount'], 2); ?></td>
                                            <td>
                                                <?php
                                                $methodLabels = [
                                                    'cash' => '现金',
                                                    'credit_card' => '信用卡',
                                                    'debit_card' => '借记卡',
                                                    'bank_transfer' => '银行转账',
                                                    'alipay' => '支付宝',
                                                    'wechat_pay' => '微信支付',
                                                    'other' => '其他'
                                                ];
                                                echo $methodLabels[$refund['refund_method']] ?? $refund['refund_method'];
                                                ?>
                                            </td>
                                            <td><?php echo htmlspecialchars($refund['reason']); ?></td>
                                            <td>
                                                <?php
                                                $statusLabels = [
                                                    'pending' => '<span class="badge badge-warning">待处理</span>',
                                                    'approved' => '<span class="badge badge-info">已批准</span>',
                                                    'completed' => '<span class="badge badge-success">已完成</span>',
                                                    'rejected' => '<span class="badge badge-danger">已拒绝</span>'
                                                ];
                                                echo $statusLabels[$refund['status']] ?? $refund['status'];
                                                ?>
                                            </td>
                                            <td><?php echo date('Y-m-d H:i', strtotime($refund['created_at'])); ?></td>
                                            <td>
                                                <a href="javascript:void(0);" class="btn btn-sm btn-info view-refund-btn" data-id="<?php echo $refund['id']; ?>">查看</a>
                                                <?php if ($refund['status'] == 'pending' || $refund['status'] == 'approved'): ?>
                                                    <a href="javascript:void(0);" class="btn btn-sm btn-primary process-refund-btn"
                                                        data-id="<?php echo $refund['id']; ?>"
                                                        data-booking-id="<?php echo $refund['booking_id']; ?>"
                                                        data-amount="<?php echo $refund['amount']; ?>"
                                                        data-method="<?php echo $refund['refund_method']; ?>"
                                                        data-reason="<?php echo htmlspecialchars($refund['reason']); ?>"
                                                        data-status="<?php echo $refund['status']; ?>">
                                                        处理
                                                    </a>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

            <!-- 申请退款 -->
            <div class="tab-pane" id="new-refund">
                <div class="card">
                    <div class="card-header">
                        <h3>申请退款</h3>
                    </div>
                    <div class="card-body">
                        <form method="post" id="refundForm">
                            <div class="form-group">
                                <label>选择订单</label>
                                <select name="booking_id" id="bookingSelect" class="form-control" required>
                                    <option value="">请选择订单</option>
                                    <?php foreach ($refundable_bookings as $booking): ?>
                                        <option value="<?php echo $booking['id']; ?>"
                                            data-booking-number="<?php echo htmlspecialchars($booking['booking_number']); ?>"
                                            data-guest-name="<?php echo htmlspecialchars($booking['guest_name']); ?>"
                                            data-total-amount="<?php echo $booking['total_amount']; ?>"
                                            data-paid-amount="<?php echo $booking['paid_amount']; ?>">
                                            <?php echo htmlspecialchars($booking['booking_number']); ?> -
                                            <?php echo htmlspecialchars($booking['guest_name']); ?>
                                            (已支付: ¥<?php echo number_format($booking['paid_amount'], 2); ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div id="refundDetails" style="display: none;">
                                <div class="form-group">
                                    <label>订单号</label>
                                    <input type="text" class="form-control" id="bookingNumber" readonly>
                                </div>

                                <div class="form-group">
                                    <label>客人姓名</label>
                                    <input type="text" class="form-control" id="guestName" readonly>
                                </div>

                                <div class="form-group">
                                    <label>订单总金额</label>
                                    <input type="text" class="form-control" id="totalAmount" readonly>
                                </div>

                                <div class="form-group">
                                    <label>已支付金额</label>
                                    <input type="text" class="form-control" id="paidAmount" readonly>
                                </div>

                                <div class="form-group">
                                    <label>退款金额</label>
                                    <input type="number" class="form-control" name="refund_amount" id="refundAmount" step="0.01" required>
                                    <small class="form-text text-muted">退款金额不能超过已支付金额</small>
                                </div>

                                <div class="form-group">
                                    <label>退款方式</label>
                                    <select class="form-control" name="refund_method" required>
                                        <option value="">请选择退款方式</option>
                                        <option value="cash">现金</option>
                                        <option value="credit_card">信用卡</option>
                                        <option value="debit_card">借记卡</option>
                                        <option value="bank_transfer">银行转账</option>
                                        <option value="alipay">支付宝</option>
                                        <option value="wechat_pay">微信支付</option>
                                        <option value="other">其他</option>
                                    </select>
                                </div>

                                <div class="form-group">
                                    <label>交易ID</label>
                                    <input type="text" class="form-control" name="transaction_id" placeholder="可选">
                                </div>

                                <div class="form-group">
                                    <label>退款原因</label>
                                    <textarea class="form-control" name="refund_reason" rows="3" required></textarea>
                                </div>

                                <div class="form-group">
                                    <label>退款状态</label>
                                    <select class="form-control" name="refund_status" required>
                                        <option value="pending">待处理</option>
                                        <option value="approved">已批准</option>
                                        <option value="completed">已完成</option>
                                        <option value="rejected">已拒绝</option>
                                    </select>
                                </div>

                                <div class="form-group">
                                    <label>备注</label>
                                    <textarea class="form-control" name="notes" rows="3"></textarea>
                                </div>

                                <button type="submit" name="process_refund" class="btn btn-primary">提交退款申请</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .tabs {
        margin-bottom: 20px;
    }

    .tab-header {
        display: flex;
        border-bottom: 1px solid #dee2e6;
        margin-bottom: 20px;
    }

    .tab-btn {
        padding: 10px 20px;
        cursor: pointer;
        border: 1px solid transparent;
        border-radius: 4px 4px 0 0;
        margin-bottom: -1px;
    }

    .tab-btn.active {
        border-color: #dee2e6 #dee2e6 #fff;
        background-color: #fff;
        color: #0066cc;
        font-weight: bold;
    }

    .tab-pane {
        display: none;
    }

    .tab-pane.active {
        display: block;
    }

    .badge {
        padding: 5px 10px;
        border-radius: 4px;
        font-size: 12px;
        font-weight: normal;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #212529;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }

    .badge-info {
        background-color: #17a2b8;
        color: white;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-danger {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }

    .alert-info {
        color: #0c5460;
        background-color: #d1ecf1;
        border-color: #bee5eb;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 标签页切换
        const tabBtns = document.querySelectorAll('.tab-btn');
        const tabPanes = document.querySelectorAll('.tab-pane');

        tabBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const tabId = this.getAttribute('data-tab');

                // 移除所有活动状态
                tabBtns.forEach(b => b.classList.remove('active'));
                tabPanes.forEach(p => p.classList.remove('active'));

                // 设置当前标签为活动状态
                this.classList.add('active');
                document.getElementById(tabId).classList.add('active');
            });
        });

        // 订单选择
        const bookingSelect = document.getElementById('bookingSelect');
        const refundDetails = document.getElementById('refundDetails');

        if (bookingSelect) {
            bookingSelect.addEventListener('change', function() {
                if (this.value) {
                    const option = this.options[this.selectedIndex];
                    const bookingNumber = option.getAttribute('data-booking-number');
                    const guestName = option.getAttribute('data-guest-name');
                    const totalAmount = parseFloat(option.getAttribute('data-total-amount'));
                    const paidAmount = parseFloat(option.getAttribute('data-paid-amount'));

                    document.getElementById('bookingNumber').value = bookingNumber;
                    document.getElementById('guestName').value = guestName;
                    document.getElementById('totalAmount').value = '¥' + totalAmount.toFixed(2);
                    document.getElementById('paidAmount').value = '¥' + paidAmount.toFixed(2);
                    document.getElementById('refundAmount').value = paidAmount.toFixed(2);
                    document.getElementById('refundAmount').max = paidAmount;

                    refundDetails.style.display = 'block';
                } else {
                    refundDetails.style.display = 'none';
                }
            });
        }

        // 验证退款金额
        const refundForm = document.getElementById('refundForm');
        if (refundForm) {
            refundForm.addEventListener('submit', function(event) {
                const bookingSelect = document.getElementById('bookingSelect');
                const refundAmount = document.getElementById('refundAmount');

                if (bookingSelect.value === '') {
                    alert('请选择订单');
                    event.preventDefault();
                    return;
                }

                const option = bookingSelect.options[bookingSelect.selectedIndex];
                const paidAmount = parseFloat(option.getAttribute('data-paid-amount'));
                const amount = parseFloat(refundAmount.value);

                if (isNaN(amount) || amount <= 0) {
                    alert('请输入有效的退款金额');
                    event.preventDefault();
                    return;
                }

                if (amount > paidAmount) {
                    alert('退款金额不能超过已支付金额');
                    event.preventDefault();
                    return;
                }
            });
        }

        // 绑定按钮点击事件的函数
        function bindButtonEvents() {
            // 查看退款详情
            const viewRefundBtns = document.querySelectorAll('.view-refund-btn');
            viewRefundBtns.forEach(btn => {
                btn.addEventListener('click', function() {
                    const refundId = this.getAttribute('data-id');
                    // 这里应该发送AJAX请求获取退款详情
                    // 为了演示，我们使用alert显示
                    alert('查看退款ID: ' + refundId);

                    // 实际应用中，应该打开一个模态框显示退款详情
                    // 例如：
                    // fetch('get_refund_details.php?id=' + refundId)
                    //     .then(response => response.json())
                    //     .then(data => {
                    //         // 显示退款详情
                    //     });
                });
            });

            // 处理退款
            const processRefundBtns = document.querySelectorAll('.process-refund-btn');
            processRefundBtns.forEach(btn => {
                btn.addEventListener('click', function() {
                    const refundId = this.getAttribute('data-id');
                    const bookingId = this.getAttribute('data-booking-id');
                    const amount = this.getAttribute('data-amount');
                    const method = this.getAttribute('data-method');
                    const reason = this.getAttribute('data-reason');
                    const status = this.getAttribute('data-status');

                    // 创建模态框HTML
                    const modalHtml = `
                        <div class="modal" id="processRefundModal" style="display: block;">
                            <div class="modal-dialog">
                                <div class="modal-content">
                                    <div class="modal-header">
                                        <h4 class="modal-title">处理退款</h4>
                                        <button type="button" class="close" id="closeRefundModal">&times;</button>
                                    </div>
                                    <form method="post" action="index.php?page=refund">
                                        <div class="modal-body">
                                            <input type="hidden" name="refund_id" value="${refundId}">
                                            <input type="hidden" name="booking_id" value="${bookingId}">
                                            
                                            <div class="form-group">
                                                <label>退款金额</label>
                                                <input type="number" class="form-control" name="refund_amount" value="${amount}" step="0.01" required readonly>
                                            </div>
                                            
                                            <div class="form-group">
                                                <label>退款方式</label>
                                                <select class="form-control" name="refund_method" required>
                                                    <option value="cash" ${method === 'cash' ? 'selected' : ''}>现金</option>
                                                    <option value="credit_card" ${method === 'credit_card' ? 'selected' : ''}>信用卡</option>
                                                    <option value="debit_card" ${method === 'debit_card' ? 'selected' : ''}>借记卡</option>
                                                    <option value="bank_transfer" ${method === 'bank_transfer' ? 'selected' : ''}>银行转账</option>
                                                    <option value="alipay" ${method === 'alipay' ? 'selected' : ''}>支付宝</option>
                                                    <option value="wechat_pay" ${method === 'wechat_pay' ? 'selected' : ''}>微信支付</option>
                                                    <option value="other" ${method === 'other' ? 'selected' : ''}>其他</option>
                                                </select>
                                            </div>
                                            
                                            <div class="form-group">
                                                <label>交易ID</label>
                                                <input type="text" class="form-control" name="transaction_id" placeholder="可选">
                                            </div>
                                            
                                            <div class="form-group">
                                                <label>退款原因</label>
                                                <textarea class="form-control" name="refund_reason" rows="3" readonly>${reason}</textarea>
                                            </div>
                                            
                                            <div class="form-group">
                                                <label>退款状态</label>
                                                <select class="form-control" name="refund_status" required>
                                                    <option value="pending" ${status === 'pending' ? 'selected' : ''}>待处理</option>
                                                    <option value="approved" ${status === 'approved' ? 'selected' : ''}>已批准</option>
                                                    <option value="completed" ${status === 'completed' ? 'selected' : ''}>已完成</option>
                                                    <option value="rejected" ${status === 'rejected' ? 'selected' : ''}>已拒绝</option>
                                                </select>
                                            </div>
                                            
                                            <div class="form-group">
                                                <label>备注</label>
                                                <textarea class="form-control" name="notes" rows="3"></textarea>
                                            </div>
                                        </div>
                                        <div class="modal-footer">
                                            <button type="button" class="btn btn-secondary" id="cancelRefundModal">取消</button>
                                            <button type="submit" name="update_refund" class="btn btn-primary">保存</button>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    `;

                    // 添加模态框到页面
                    document.body.insertAdjacentHTML('beforeend', modalHtml);

                    // 关闭模态框
                    document.getElementById('closeRefundModal').addEventListener('click', function() {
                        document.getElementById('processRefundModal').remove();
                    });

                    document.getElementById('cancelRefundModal').addEventListener('click', function() {
                        document.getElementById('processRefundModal').remove();
                    });

                    // 点击模态框外部关闭
                    window.addEventListener('click', function(event) {
                        const modal = document.getElementById('processRefundModal');
                        if (event.target === modal) {
                            modal.remove();
                        }
                    });
                });
            });
        }

        // 初始绑定按钮事件
        bindButtonEvents();

        // 当标签页切换时，重新绑定按钮事件
        tabBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                // 延迟一点时间确保DOM已更新
                setTimeout(bindButtonEvents, 100);
            });
        });
    });
</script>