<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 处理房费调整
if (isset($_POST['adjust_room_fee'])) {
    $room_id = $_POST['room_id'];
    $new_price = $_POST['new_price'];
    $reason = $_POST['reason'];

    // 获取房间的房型ID
    $stmt = $conn->prepare("SELECT room_type_id FROM rooms WHERE id = ?");
    $stmt->bind_param("i", $room_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $room = $result->fetch_assoc();

    if ($room) {
        // 计算价格调整值（与基础价格的差值）
        $stmt = $conn->prepare("SELECT base_price FROM room_types WHERE id = ?");
        $stmt->bind_param("i", $room['room_type_id']);
        $stmt->execute();
        $result = $stmt->get_result();
        $roomType = $result->fetch_assoc();

        $basePrice = $roomType['base_price'];
        $priceAdjustment = $new_price - $basePrice;

        // 更新房间价格调整值
        $stmt = $conn->prepare("UPDATE rooms SET price_adjustment = ? WHERE id = ?");
        $stmt->bind_param("di", $priceAdjustment, $room_id);

        if ($stmt->execute()) {
            // 记录价格调整
            $user_id = $_SESSION['user_id'];
            $description = "房间 {$room_id} 价格从 {$_POST['old_price']} 调整为 {$new_price}，原因：{$reason}";
            $ip = $_SERVER['REMOTE_ADDR'] ?? '';

            $stmt = $conn->prepare("INSERT INTO system_logs (user_id, action, description, ip_address) VALUES (?, 'price_update', ?, ?)");
            if ($stmt) {
                $stmt->bind_param("iss", $user_id, $description, $ip);
                $stmt->execute();
            }

            $success_message = "房间价格已成功更新";
        } else {
            $error_message = "更新价格失败: " . $stmt->error;
        }
    } else {
        $error_message = "找不到指定的房间";
    }
}

// 处理押金设置
if (isset($_POST['set_deposit'])) {
    $room_type_id = $_POST['room_type_id'];
    $deposit_amount = $_POST['deposit_amount'];

    // 添加deposit_amount字段到room_types表（如果不存在）
    $checkField = $conn->query("SHOW COLUMNS FROM room_types LIKE 'deposit_amount'");
    if ($checkField->num_rows == 0) {
        $conn->query("ALTER TABLE room_types ADD deposit_amount DECIMAL(10, 2) DEFAULT 0.00 AFTER base_price");
    }

    // 更新房型押金
    $stmt = $conn->prepare("UPDATE room_types SET deposit_amount = ? WHERE id = ?");
    $stmt->bind_param("di", $deposit_amount, $room_type_id);

    if ($stmt->execute()) {
        $success_message = "押金金额已成功更新";
    } else {
        $error_message = "更新押金失败: " . $stmt->error;
    }
}

// 获取所有房间信息
$rooms = [];
$sql = "SELECT r.*, rt.name as room_type_name, rt.base_price 
        FROM rooms r 
        JOIN room_types rt ON r.room_type_id = rt.id 
        ORDER BY r.room_number";
$result = mysqli_query($conn, $sql);
if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        // 计算实际价格（基础价格 + 调整值）
        $row['actual_price'] = $row['base_price'] + $row['price_adjustment'];
        $rooms[] = $row;
    }
}

// 获取所有房型信息
$roomTypes = [];
$sql = "SELECT * FROM room_types ORDER BY name";
$result = mysqli_query($conn, $sql);
if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        // 如果deposit_amount字段不存在，设置默认值
        if (!isset($row['deposit_amount'])) {
            $row['deposit_amount'] = 0.00;
        }
        $roomTypes[] = $row;
    }
}

// 获取价格策略
$priceStrategies = [];
$sql = "SELECT ps.*, rt.name as room_type_name 
        FROM price_strategies ps 
        LEFT JOIN room_types rt ON ps.room_type_id = rt.id 
        ORDER BY ps.start_date DESC";
$result = mysqli_query($conn, $sql);
if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        $priceStrategies[] = $row;
    }
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content-wrapper">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="tabs">
        <div class="tab-header">
            <div class="tab-btn active" data-tab="room-prices">房间价格管理</div>
            <div class="tab-btn" data-tab="deposits">押金管理</div>
            <div class="tab-btn" data-tab="price-strategies">价格策略</div>
        </div>

        <div class="tab-content">
            <!-- 房间价格管理 -->
            <div class="tab-pane active" id="room-prices">
                <div class="card">
                    <div class="card-header">
                        <h3>房间价格列表</h3>
                        <div class="card-tools">
                            <input type="text" id="roomSearchInput" class="form-control" placeholder="搜索房间...">
                        </div>
                    </div>
                    <div class="card-body">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>房间号</th>
                                    <th>房型</th>
                                    <th>基础价格</th>
                                    <th>价格调整</th>
                                    <th>实际价格</th>
                                    <th>状态</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (empty($rooms)): ?>
                                    <tr>
                                        <td colspan="7" class="text-center">暂无房间数据</td>
                                    </tr>
                                <?php else: ?>
                                    <?php foreach ($rooms as $room): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($room['room_number']); ?></td>
                                            <td><?php echo htmlspecialchars($room['room_type_name']); ?></td>
                                            <td>¥<?php echo number_format($room['base_price'], 2); ?></td>
                                            <td>
                                                <?php
                                                if ($room['price_adjustment'] > 0) {
                                                    echo '<span class="text-success">+¥' . number_format($room['price_adjustment'], 2) . '</span>';
                                                } elseif ($room['price_adjustment'] < 0) {
                                                    echo '<span class="text-danger">-¥' . number_format(abs($room['price_adjustment']), 2) . '</span>';
                                                } else {
                                                    echo '¥0.00';
                                                }
                                                ?>
                                            </td>
                                            <td>¥<?php echo number_format($room['actual_price'], 2); ?></td>
                                            <td>
                                                <?php
                                                $statusLabels = [
                                                    'available' => '<span class="badge badge-success">可预订</span>',
                                                    'occupied' => '<span class="badge badge-danger">已入住</span>',
                                                    'booked' => '<span class="badge badge-warning">已预订</span>',
                                                    'maintenance' => '<span class="badge badge-secondary">维修中</span>'
                                                ];
                                                echo $statusLabels[$room['status']] ?? $room['status'];
                                                ?>
                                            </td>
                                            <td>
                                                <button class="btn btn-sm btn-primary adjust-price-btn"
                                                    data-room-id="<?php echo $room['id']; ?>"
                                                    data-room-number="<?php echo htmlspecialchars($room['room_number']); ?>"
                                                    data-base-price="<?php echo $room['base_price']; ?>"
                                                    data-current-price="<?php echo $room['actual_price']; ?>">
                                                    调整价格
                                                </button>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <!-- 押金管理 -->
            <div class="tab-pane" id="deposits">
                <div class="card">
                    <div class="card-header">
                        <h3>房型押金设置</h3>
                    </div>
                    <div class="card-body">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>房型名称</th>
                                    <th>当前押金金额</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (empty($roomTypes)): ?>
                                    <tr>
                                        <td colspan="3" class="text-center">暂无房型数据</td>
                                    </tr>
                                <?php else: ?>
                                    <?php foreach ($roomTypes as $type): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($type['name']); ?></td>
                                            <td>¥<?php echo number_format($type['deposit_amount'], 2); ?></td>
                                            <td>
                                                <button class="btn btn-sm btn-primary set-deposit-btn"
                                                    data-type-id="<?php echo $type['id']; ?>"
                                                    data-type-name="<?php echo htmlspecialchars($type['name']); ?>"
                                                    data-current-deposit="<?php echo $type['deposit_amount']; ?>">
                                                    设置押金
                                                </button>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>

                <div class="card mt-4">
                    <div class="card-header">
                        <h3>押金说明</h3>
                    </div>
                    <div class="card-body">
                        <p>押金将在客人入住时收取，并在退房时退还（扣除相应费用后）。</p>
                        <ul>
                            <li>押金用于担保客人在住宿期间可能产生的额外费用或损坏赔偿</li>
                            <li>押金金额应根据房型价值和设施配置合理设置</li>
                            <li>押金可以通过预授权或实际收取的方式进行</li>
                        </ul>
                    </div>
                </div>
            </div>

            <!-- 价格策略 -->
            <div class="tab-pane" id="price-strategies">
                <div class="card">
                    <div class="card-header">
                        <h3>价格策略列表</h3>
                        <div class="card-tools">
                            <a href="../room_management/index.php?page=pricing" class="btn btn-primary">管理价格策略</a>
                        </div>
                    </div>
                    <div class="card-body">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>策略名称</th>
                                    <th>适用房型</th>
                                    <th>调整类型</th>
                                    <th>调整值</th>
                                    <th>有效期</th>
                                    <th>状态</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (empty($priceStrategies)): ?>
                                    <tr>
                                        <td colspan="6" class="text-center">暂无价格策略数据</td>
                                    </tr>
                                <?php else: ?>
                                    <?php foreach ($priceStrategies as $strategy): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($strategy['name']); ?></td>
                                            <td><?php echo $strategy['room_type_id'] ? htmlspecialchars($strategy['room_type_name']) : '所有房型'; ?></td>
                                            <td>
                                                <?php
                                                echo $strategy['adjustment_type'] == 'percentage' ? '百分比' : '固定金额';
                                                ?>
                                            </td>
                                            <td>
                                                <?php
                                                if ($strategy['adjustment_type'] == 'percentage') {
                                                    echo number_format($strategy['adjustment_value'], 2) . '%';
                                                } else {
                                                    echo '¥' . number_format($strategy['adjustment_value'], 2);
                                                }
                                                ?>
                                            </td>
                                            <td>
                                                <?php echo date('Y-m-d', strtotime($strategy['start_date'])); ?> 至
                                                <?php echo date('Y-m-d', strtotime($strategy['end_date'])); ?>
                                            </td>
                                            <td>
                                                <?php
                                                $statusLabels = [
                                                    'active' => '<span class="badge badge-success">启用</span>',
                                                    'inactive' => '<span class="badge badge-secondary">禁用</span>'
                                                ];
                                                echo $statusLabels[$strategy['status']] ?? $strategy['status'];
                                                ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- 调整价格模态框 -->
<div class="modal" id="adjustPriceModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">调整房间价格</h4>
                <button type="button" class="close" data-dismiss="modal">&times;</button>
            </div>
            <form method="post">
                <div class="modal-body">
                    <input type="hidden" name="room_id" id="roomId">
                    <input type="hidden" name="old_price" id="oldPrice">
                    <input type="hidden" name="base_price" id="basePrice">

                    <div class="form-group">
                        <label>房间号</label>
                        <input type="text" class="form-control" id="roomNumber" readonly>
                    </div>

                    <div class="form-group">
                        <label>基础价格</label>
                        <input type="text" class="form-control" id="displayBasePrice" readonly>
                    </div>

                    <div class="form-group">
                        <label>当前价格</label>
                        <input type="text" class="form-control" id="currentPrice" readonly>
                    </div>

                    <div class="form-group">
                        <label>新价格</label>
                        <input type="number" class="form-control" name="new_price" id="newPrice" step="0.01" required>
                    </div>

                    <div class="form-group">
                        <label>调整原因</label>
                        <textarea class="form-control" name="reason" rows="3" required></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">取消</button>
                    <button type="submit" name="adjust_room_fee" class="btn btn-primary">保存</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- 设置押金模态框 -->
<div class="modal" id="setDepositModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">设置房型押金</h4>
                <button type="button" class="close" data-dismiss="modal">&times;</button>
            </div>
            <form method="post">
                <div class="modal-body">
                    <input type="hidden" name="room_type_id" id="roomTypeId">

                    <div class="form-group">
                        <label>房型名称</label>
                        <input type="text" class="form-control" id="roomTypeName" readonly>
                    </div>

                    <div class="form-group">
                        <label>当前押金金额</label>
                        <input type="text" class="form-control" id="currentDeposit" readonly>
                    </div>

                    <div class="form-group">
                        <label>新押金金额</label>
                        <input type="number" class="form-control" name="deposit_amount" id="newDeposit" step="0.01" required>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">取消</button>
                    <button type="submit" name="set_deposit" class="btn btn-primary">保存</button>
                </div>
            </form>
        </div>
    </div>
</div>

<style>
    .tabs {
        margin-bottom: 20px;
    }

    .tab-header {
        display: flex;
        border-bottom: 1px solid #dee2e6;
        margin-bottom: 20px;
    }

    .tab-btn {
        padding: 10px 20px;
        cursor: pointer;
        border: 1px solid transparent;
        border-radius: 4px 4px 0 0;
        margin-bottom: -1px;
    }

    .tab-btn.active {
        border-color: #dee2e6 #dee2e6 #fff;
        background-color: #fff;
        color: #0066cc;
        font-weight: bold;
    }

    .tab-pane {
        display: none;
    }

    .tab-pane.active {
        display: block;
    }

    .badge {
        padding: 5px 10px;
        border-radius: 4px;
        font-size: 12px;
        font-weight: normal;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #212529;
    }

    .badge-secondary {
        background-color: #6c757d;
        color: white;
    }

    .text-success {
        color: #28a745;
    }

    .text-danger {
        color: #dc3545;
    }

    .modal {
        display: none;
        position: fixed;
        z-index: 1000;
        left: 0;
        top: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
    }

    .modal-dialog {
        margin: 10% auto;
        width: 500px;
        max-width: 90%;
    }

    .modal-content {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 3px 6px rgba(0, 0, 0, 0.16);
    }

    .modal-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .modal-body {
        padding: 15px;
    }

    .modal-footer {
        padding: 15px;
        border-top: 1px solid #e9ecef;
        display: flex;
        justify-content: flex-end;
    }

    .close {
        font-size: 24px;
        font-weight: bold;
        cursor: pointer;
        border: none;
        background: transparent;
    }

    .mt-4 {
        margin-top: 20px;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 标签页切换
        const tabBtns = document.querySelectorAll('.tab-btn');
        const tabPanes = document.querySelectorAll('.tab-pane');

        tabBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const tabId = this.getAttribute('data-tab');

                // 移除所有活动状态
                tabBtns.forEach(b => b.classList.remove('active'));
                tabPanes.forEach(p => p.classList.remove('active'));

                // 设置当前标签为活动状态
                this.classList.add('active');
                document.getElementById(tabId).classList.add('active');
            });
        });

        // 调整价格模态框
        const adjustPriceBtns = document.querySelectorAll('.adjust-price-btn');
        const adjustPriceModal = document.getElementById('adjustPriceModal');

        adjustPriceBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const roomId = this.getAttribute('data-room-id');
                const roomNumber = this.getAttribute('data-room-number');
                const basePrice = this.getAttribute('data-base-price');
                const currentPrice = this.getAttribute('data-current-price');

                document.getElementById('roomId').value = roomId;
                document.getElementById('roomNumber').value = roomNumber;
                document.getElementById('basePrice').value = basePrice;
                document.getElementById('displayBasePrice').value = '¥' + parseFloat(basePrice).toFixed(2);
                document.getElementById('currentPrice').value = '¥' + parseFloat(currentPrice).toFixed(2);
                document.getElementById('oldPrice').value = currentPrice;
                document.getElementById('newPrice').value = currentPrice;

                adjustPriceModal.style.display = 'block';
            });
        });

        // 设置押金模态框
        const setDepositBtns = document.querySelectorAll('.set-deposit-btn');
        const setDepositModal = document.getElementById('setDepositModal');

        setDepositBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const typeId = this.getAttribute('data-type-id');
                const typeName = this.getAttribute('data-type-name');
                const currentDeposit = this.getAttribute('data-current-deposit');

                document.getElementById('roomTypeId').value = typeId;
                document.getElementById('roomTypeName').value = typeName;
                document.getElementById('currentDeposit').value = '¥' + parseFloat(currentDeposit).toFixed(2);
                document.getElementById('newDeposit').value = currentDeposit;

                setDepositModal.style.display = 'block';
            });
        });

        // 关闭模态框
        const closeBtns = document.querySelectorAll('.close, .btn-secondary');

        closeBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                adjustPriceModal.style.display = 'none';
                setDepositModal.style.display = 'none';
            });
        });

        // 点击模态框外部关闭
        window.addEventListener('click', function(event) {
            if (event.target === adjustPriceModal) {
                adjustPriceModal.style.display = 'none';
            }
            if (event.target === setDepositModal) {
                setDepositModal.style.display = 'none';
            }
        });

        // 房间搜索功能
        const roomSearchInput = document.getElementById('roomSearchInput');

        roomSearchInput.addEventListener('keyup', function() {
            const searchValue = this.value.toLowerCase();
            const rows = document.querySelectorAll('#room-prices tbody tr');

            rows.forEach(row => {
                const roomNumber = row.cells[0].textContent.toLowerCase();
                const roomType = row.cells[1].textContent.toLowerCase();

                if (roomNumber.includes(searchValue) || roomType.includes(searchValue)) {
                    row.style.display = '';
                } else {
                    row.style.display = 'none';
                }
            });
        });
    });
</script>