<?php
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取活动的促销活动数量
$stmt = $conn->query("SELECT COUNT(*) FROM promotions WHERE status = 'active'");
$activePromotions = $stmt->fetch_row()[0];

// 获取本月推荐新用户数量
$firstDayOfMonth = date('Y-m-01');
$lastDayOfMonth = date('Y-m-t');
$stmt = $conn->prepare("SELECT COUNT(*) FROM point_history WHERE reason LIKE '推荐新用户%' AND created_at BETWEEN ? AND ?");
$stmt->bind_param("ss", $firstDayOfMonth, $lastDayOfMonth);
$stmt->execute();
$stmt->bind_result($monthlyReferrals);
$stmt->fetch();
$stmt->close();

// 获取积分兑换总次数
$stmt = $conn->query("SELECT COUNT(*) FROM point_history WHERE change_type = 'deduct' AND reason LIKE '积分兑换%'");
$totalPointExchanges = $stmt->fetch_row()[0];

// 获取最近的营销活动
$stmt = $conn->query("SELECT * FROM promotions ORDER BY created_at DESC LIMIT 5");
$recentPromotions = [];
while ($row = $stmt->fetch_assoc()) {
    $recentPromotions[] = $row;
}
?>

<div class="dashboard-grid">
    <div class="dashboard-card">
        <h3>活动促销活动</h3>
        <div class="card-content">
            <div class="stat-number"><?php echo $activePromotions; ?></div>
            <p>个活动进行中</p>
        </div>
        <a href="index.php?page=promotion" class="card-link">查看详情</a>
    </div>

    <div class="dashboard-card">
        <h3>本月推荐</h3>
        <div class="card-content">
            <div class="stat-number"><?php echo $monthlyReferrals; ?></div>
            <p>位新用户</p>
        </div>
        <a href="index.php?page=referral" class="card-link">查看详情</a>
    </div>

    <div class="dashboard-card">
        <h3>积分兑换</h3>
        <div class="card-content">
            <div class="stat-number"><?php echo $totalPointExchanges; ?></div>
            <p>次兑换记录</p>
        </div>
        <a href="index.php?page=points_exchange" class="card-link">查看详情</a>
    </div>
</div>

<div class="dashboard-section">
    <h3>最近促销活动</h3>
    <div class="table-responsive">
        <table class="data-table">
            <thead>
                <tr>
                    <th>活动名称</th>
                    <th>类型</th>
                    <th>开始日期</th>
                    <th>结束日期</th>
                    <th>状态</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($recentPromotions as $promotion): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($promotion['name']); ?></td>
                        <td><?php echo getPromotionTypeName($promotion['promotion_type']); ?></td>
                        <td><?php echo date('Y-m-d', strtotime($promotion['start_date'])); ?></td>
                        <td><?php echo date('Y-m-d', strtotime($promotion['end_date'])); ?></td>
                        <td>
                            <span class="status-badge <?php echo $promotion['status']; ?>">
                                <?php echo $promotion['status'] == 'active' ? '进行中' : '已结束'; ?>
                            </span>
                        </td>
                    </tr>
                <?php endforeach; ?>
                <?php if (empty($recentPromotions)): ?>
                    <tr>
                        <td colspan="5" class="text-center">暂无促销活动</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
</div>

<style>
    .dashboard-grid {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
        gap: 20px;
        margin-bottom: 30px;
    }

    .dashboard-card {
        background: #fff;
        border-radius: 8px;
        padding: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .dashboard-card h3 {
        margin: 0 0 15px 0;
        color: #333;
    }

    .card-content {
        text-align: center;
        margin-bottom: 15px;
    }

    .stat-number {
        font-size: 2.5em;
        font-weight: bold;
        color: #4a90e2;
        margin-bottom: 5px;
    }

    .card-link {
        display: block;
        text-align: center;
        color: #4a90e2;
        text-decoration: none;
        padding: 8px;
        border-top: 1px solid #eee;
        margin: 0 -20px -20px;
    }

    .card-link:hover {
        background: #f8f9fa;
    }

    .dashboard-section {
        background: #fff;
        border-radius: 8px;
        padding: 20px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .status-badge {
        display: inline-block;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 0.9em;
    }

    .status-badge.active {
        background: #e3f2fd;
        color: #1976d2;
    }

    .status-badge.inactive {
        background: #ffebee;
        color: #c62828;
    }
</style>

<?php
function getPromotionTypeName($type)
{
    $types = [
        'discount' => '折扣',
        'package' => '套餐',
        'gift' => '赠品',
        'points' => '积分',
        'other' => '其他'
    ];
    return isset($types[$type]) ? $types[$type] : $type;
}
?>