<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查并创建营销消息模板表（如果不存在）
$sql = "CREATE TABLE IF NOT EXISTS message_templates (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    content TEXT NOT NULL,
    type ENUM('sms', 'wechat', 'both') NOT NULL,
    category ENUM('promotion', 'birthday', 'holiday', 'reminder', 'other') NOT NULL,
    variables TEXT COMMENT '可用变量，JSON格式',
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE SET NULL
)";
$conn->query($sql);

// 检查并创建营销消息发送记录表（如果不存在）
$sql = "CREATE TABLE IF NOT EXISTS message_sending_records (
    id INT AUTO_INCREMENT PRIMARY KEY,
    template_id INT,
    member_id INT,
    send_type ENUM('sms', 'wechat') NOT NULL,
    content TEXT NOT NULL,
    send_status ENUM('pending', 'sent', 'failed') NOT NULL DEFAULT 'pending',
    send_time DATETIME,
    error_message TEXT,
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (template_id) REFERENCES message_templates(id) ON DELETE SET NULL,
    FOREIGN KEY (member_id) REFERENCES members(id) ON DELETE SET NULL,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE SET NULL
)";
$conn->query($sql);

// 处理模板添加/编辑
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['save_template'])) {
    $id = isset($_POST['id']) ? $_POST['id'] : null;
    $name = $_POST['name'];
    $content = $_POST['content'];
    $type = $_POST['type'];
    $category = $_POST['category'];
    $variables = $_POST['variables'];
    $status = $_POST['status'];

    try {
        if ($id) {
            // 更新模板
            $stmt = $conn->prepare("UPDATE message_templates SET 
                name = ?, content = ?, type = ?, category = ?, variables = ?, status = ?
                WHERE id = ?");
            $stmt->bind_param("ssssssi", $name, $content, $type, $category, $variables, $status, $id);
            $stmt->execute();
            $success_message = "消息模板更新成功!";
        } else {
            // 添加新模板
            $stmt = $conn->prepare("INSERT INTO message_templates 
                (name, content, type, category, variables, status, created_by) 
                VALUES (?, ?, ?, ?, ?, ?, ?)");
            $stmt->bind_param("ssssssi", $name, $content, $type, $category, $variables, $status, $_SESSION['user_id']);
            $stmt->execute();
            $success_message = "消息模板添加成功!";
        }
    } catch (Exception $e) {
        $error_message = "操作失败: " . $e->getMessage();
    }
}

// 处理删除模板
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $id = $_GET['id'];
    try {
        $stmt = $conn->prepare("DELETE FROM message_templates WHERE id = ?");
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $success_message = "消息模板删除成功!";
    } catch (Exception $e) {
        $error_message = "删除失败: " . $e->getMessage();
    }
}

// 处理群发消息
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['send_message'])) {
    $template_id = $_POST['template_id'];
    $member_ids = $_POST['member_ids'];
    $send_type = $_POST['send_type'];
    $scheduled_time = !empty($_POST['scheduled_time']) ? $_POST['scheduled_time'] : date('Y-m-d H:i:s');

    try {
        $conn->begin_transaction();

        // 获取模板内容
        $stmt = $conn->prepare("SELECT content FROM message_templates WHERE id = ?");
        $stmt->bind_param("i", $template_id);
        $stmt->execute();
        $result = $stmt->get_result();
        $template = $result->fetch_assoc();

        if ($template) {
            // 为每个会员创建发送记录
            $stmt = $conn->prepare("INSERT INTO message_sending_records 
                (template_id, member_id, send_type, content, send_status, send_time, created_by) 
                VALUES (?, ?, ?, ?, 'pending', ?, ?)");

            foreach ($member_ids as $member_id) {
                $content = $template['content']; // 实际应用中，这里应该替换模板中的变量
                $stmt->bind_param("iisssi", $template_id, $member_id, $send_type, $content, $scheduled_time, $_SESSION['user_id']);
                $stmt->execute();
            }

            $conn->commit();
            $success_message = "消息已安排发送，共" . count($member_ids) . "条!";
        } else {
            $error_message = "模板不存在!";
            $conn->rollback();
        }
    } catch (Exception $e) {
        $conn->rollback();
        $error_message = "发送失败: " . $e->getMessage();
    }
}

// 获取编辑的模板数据
$editing = false;
$template = [
    'name' => '',
    'content' => '',
    'type' => 'both',
    'category' => 'promotion',
    'variables' => '{"member_name": "会员姓名", "booking_id": "订单号", "checkin_date": "入住日期", "checkout_date": "退房日期"}',
    'status' => 'active'
];

if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $id = $_GET['id'];
    $stmt = $conn->prepare("SELECT * FROM message_templates WHERE id = ?");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $editing = true;
        $template = $result->fetch_assoc();
    }
}

// 获取模板列表
$result = $conn->query("SELECT * FROM message_templates ORDER BY created_at DESC");
$templates = [];
while ($row = $result->fetch_assoc()) {
    $templates[] = $row;
}

// 获取会员列表（用于群发消息）
$result = $conn->query("SELECT id, name, phone FROM members WHERE status = 'active' ORDER BY name ASC");
$members = [];
while ($row = $result->fetch_assoc()) {
    $members[] = $row;
}

// 获取最近的发送记录
$stmt = $conn->prepare("SELECT 
                        msr.*,
                        mt.name as template_name,
                        m.name as member_name,
                        m.phone as member_phone
                      FROM message_sending_records msr
                      LEFT JOIN message_templates mt ON msr.template_id = mt.id
                      LEFT JOIN members m ON msr.member_id = m.id
                      ORDER BY msr.created_at DESC
                      LIMIT 50");
$stmt->execute();
$result = $stmt->get_result();
$sending_records = [];
while ($row = $result->fetch_assoc()) {
    $sending_records[] = $row;
}
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success"><?php echo $success_message; ?></div>
    <?php endif; ?>
    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger"><?php echo $error_message; ?></div>
    <?php endif; ?>

    <!-- 操作按钮 -->
    <div class="action-buttons mb-4">
        <button class="btn btn-primary" onclick="showTemplateTab()">消息模板管理</button>
        <button class="btn btn-success" onclick="showSendTab()">发送营销消息</button>
        <button class="btn btn-info" onclick="showRecordsTab()">查看发送记录</button>
    </div>

    <!-- 模板管理 -->
    <div class="tab-pane" id="template-tab">
        <!-- 添加/编辑模板表单 -->
        <div class="card mb-4">
            <div class="card-header">
                <h3><?php echo $editing ? '编辑消息模板' : '添加消息模板'; ?></h3>
            </div>
            <div class="card-body">
                <form method="post" id="templateForm">
                    <?php if ($editing): ?>
                        <input type="hidden" name="id" value="<?php echo $template['id']; ?>">
                    <?php endif; ?>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="name">模板名称</label>
                            <input type="text" class="form-control" id="name" name="name" required
                                value="<?php echo htmlspecialchars($template['name']); ?>">
                        </div>
                        <div class="form-group col-md-6">
                            <label for="type">消息类型</label>
                            <select class="form-control" id="type" name="type" required>
                                <option value="sms" <?php echo $template['type'] == 'sms' ? 'selected' : ''; ?>>短信</option>
                                <option value="wechat" <?php echo $template['type'] == 'wechat' ? 'selected' : ''; ?>>微信</option>
                                <option value="both" <?php echo $template['type'] == 'both' ? 'selected' : ''; ?>>两者都适用</option>
                            </select>
                        </div>
                    </div>

                    <div class="form-group">
                        <label for="category">模板分类</label>
                        <select class="form-control" id="category" name="category" required>
                            <option value="promotion" <?php echo $template['category'] == 'promotion' ? 'selected' : ''; ?>>促销活动</option>
                            <option value="birthday" <?php echo $template['category'] == 'birthday' ? 'selected' : ''; ?>>生日祝福</option>
                            <option value="holiday" <?php echo $template['category'] == 'holiday' ? 'selected' : ''; ?>>节假日问候</option>
                            <option value="reminder" <?php echo $template['category'] == 'reminder' ? 'selected' : ''; ?>>提醒通知</option>
                            <option value="other" <?php echo $template['category'] == 'other' ? 'selected' : ''; ?>>其他</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="content">模板内容</label>
                        <textarea class="form-control" id="content" name="content" rows="5" required><?php echo htmlspecialchars($template['content']); ?></textarea>
                        <small class="form-text text-muted">可使用变量如：{member_name}、{booking_id}等</small>
                    </div>

                    <div class="form-group">
                        <label for="variables">可用变量列表 (JSON格式)</label>
                        <textarea class="form-control" id="variables" name="variables" rows="3"><?php echo htmlspecialchars($template['variables']); ?></textarea>
                        <small class="form-text text-muted">格式：{"变量名": "变量说明", ...}</small>
                    </div>

                    <div class="form-group">
                        <label for="status">状态</label>
                        <select class="form-control" id="status" name="status" required>
                            <option value="active" <?php echo $template['status'] == 'active' ? 'selected' : ''; ?>>启用</option>
                            <option value="inactive" <?php echo $template['status'] == 'inactive' ? 'selected' : ''; ?>>停用</option>
                        </select>
                    </div>

                    <button type="submit" name="save_template" class="btn btn-primary"><?php echo $editing ? '更新模板' : '添加模板'; ?></button>
                    <?php if ($editing): ?>
                        <a href="index.php?page=message_marketing" class="btn btn-secondary">取消编辑</a>
                    <?php endif; ?>
                </form>
            </div>
        </div>

        <!-- 模板列表 -->
        <div class="card">
            <div class="card-header">
                <h3>消息模板列表</h3>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table">
                        <thead>
                            <tr>
                                <th>模板名称</th>
                                <th>类型</th>
                                <th>分类</th>
                                <th>内容预览</th>
                                <th>状态</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($templates as $t): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($t['name']); ?></td>
                                    <td><?php echo getMessageTypeName($t['type']); ?></td>
                                    <td><?php echo getCategoryName($t['category']); ?></td>
                                    <td><?php echo mb_substr(htmlspecialchars($t['content']), 0, 30) . (mb_strlen($t['content']) > 30 ? '...' : ''); ?></td>
                                    <td>
                                        <span class="status-badge <?php echo $t['status']; ?>">
                                            <?php echo $t['status'] == 'active' ? '启用' : '停用'; ?>
                                        </span>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($t['created_at'])); ?></td>
                                    <td>
                                        <a href="index.php?page=message_marketing&action=edit&id=<?php echo $t['id']; ?>"
                                            class="btn btn-sm btn-primary">编辑</a>
                                        <a href="index.php?page=message_marketing&action=delete&id=<?php echo $t['id']; ?>"
                                            class="btn btn-sm btn-danger"
                                            onclick="return confirm('确定要删除此模板吗？')">删除</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                            <?php if (empty($templates)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无消息模板</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>

    <!-- 发送消息 -->
    <div class="tab-pane" id="send-tab" style="display: none;">
        <div class="card">
            <div class="card-header">
                <h3>发送营销消息</h3>
            </div>
            <div class="card-body">
                <form method="post" id="sendForm">
                    <div class="form-group">
                        <label for="template_id">选择消息模板</label>
                        <select class="form-control" id="template_id" name="template_id" required>
                            <option value="">-- 请选择模板 --</option>
                            <?php foreach ($templates as $t): ?>
                                <?php if ($t['status'] == 'active'): ?>
                                    <option value="<?php echo $t['id']; ?>" data-content="<?php echo htmlspecialchars($t['content']); ?>" data-type="<?php echo $t['type']; ?>">
                                        <?php echo htmlspecialchars($t['name']) . ' (' . getMessageTypeName($t['type']) . ')'; ?>
                                    </option>
                                <?php endif; ?>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="content_preview">内容预览</label>
                        <div id="content_preview" class="p-3 border rounded bg-light"></div>
                    </div>

                    <div class="form-group">
                        <label for="send_type">发送方式</label>
                        <select class="form-control" id="send_type" name="send_type" required>
                            <option value="sms">短信</option>
                            <option value="wechat">微信</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>选择接收会员</label>
                        <div style="max-height: 300px; overflow-y: auto; border: 1px solid #ddd; padding: 10px;">
                            <div class="d-flex justify-content-end mb-2">
                                <button type="button" class="btn btn-sm btn-outline-secondary mr-2" onclick="selectAllMembers()">全选</button>
                                <button type="button" class="btn btn-sm btn-outline-secondary" onclick="deselectAllMembers()">取消全选</button>
                            </div>
                            <?php foreach ($members as $member): ?>
                                <div class="custom-control custom-checkbox">
                                    <input type="checkbox" class="custom-control-input member-checkbox" id="member_<?php echo $member['id']; ?>" name="member_ids[]" value="<?php echo $member['id']; ?>">
                                    <label class="custom-control-label" for="member_<?php echo $member['id']; ?>">
                                        <?php echo htmlspecialchars($member['name']) . ' (' . $member['phone'] . ')'; ?>
                                    </label>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>

                    <div class="form-group">
                        <label for="scheduled_time">定时发送 (可选)</label>
                        <input type="datetime-local" class="form-control" id="scheduled_time" name="scheduled_time">
                        <small class="form-text text-muted">留空表示立即发送</small>
                    </div>

                    <button type="submit" name="send_message" class="btn btn-primary" onclick="return confirmSend()">发送消息</button>
                </form>
            </div>
        </div>
    </div>

    <!-- 发送记录 -->
    <div class="tab-pane" id="records-tab" style="display: none;">
        <div class="card">
            <div class="card-header">
                <h3>消息发送记录</h3>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table">
                        <thead>
                            <tr>
                                <th>接收会员</th>
                                <th>模板名称</th>
                                <th>发送类型</th>
                                <th>内容</th>
                                <th>发送状态</th>
                                <th>发送/计划时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($sending_records as $record): ?>
                                <tr>
                                    <td>
                                        <?php echo htmlspecialchars($record['member_name'] ?? '未知'); ?><br>
                                        <small class="text-muted"><?php echo $record['member_phone'] ?? ''; ?></small>
                                    </td>
                                    <td><?php echo htmlspecialchars($record['template_name'] ?? '未知模板'); ?></td>
                                    <td><?php echo getMessageTypeName($record['send_type']); ?></td>
                                    <td><?php echo mb_substr(htmlspecialchars($record['content']), 0, 30) . (mb_strlen($record['content']) > 30 ? '...' : ''); ?></td>
                                    <td>
                                        <span class="status-badge <?php echo $record['send_status']; ?>">
                                            <?php echo getSendStatusName($record['send_status']); ?>
                                        </span>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($record['send_time'])); ?></td>
                                </tr>
                            <?php endforeach; ?>
                            <?php if (empty($sending_records)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无发送记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
    // 页面加载时默认显示模板管理
    $(document).ready(function() {
        showTemplateTab();

        // 模板选择变化时更新预览
        $('#template_id').change(function() {
            var content = $(this).find('option:selected').data('content') || '';
            $('#content_preview').text(content);

            // 更新发送方式选择框
            var type = $(this).find('option:selected').data('type');
            if (type === 'sms') {
                $('#send_type').val('sms').prop('disabled', true);
            } else if (type === 'wechat') {
                $('#send_type').val('wechat').prop('disabled', true);
            } else {
                $('#send_type').prop('disabled', false);
            }
        });
    });

    // 显示模板管理标签页
    function showTemplateTab() {
        $('.tab-pane').hide();
        $('#template-tab').show();
        $('.action-buttons .btn').removeClass('active');
        $('.action-buttons .btn:eq(0)').addClass('active');
    }

    // 显示发送消息标签页
    function showSendTab() {
        $('.tab-pane').hide();
        $('#send-tab').show();
        $('.action-buttons .btn').removeClass('active');
        $('.action-buttons .btn:eq(1)').addClass('active');
    }

    // 显示发送记录标签页
    function showRecordsTab() {
        $('.tab-pane').hide();
        $('#records-tab').show();
        $('.action-buttons .btn').removeClass('active');
        $('.action-buttons .btn:eq(2)').addClass('active');
    }

    // 全选会员
    function selectAllMembers() {
        $('.member-checkbox').prop('checked', true);
    }

    // 取消全选会员
    function deselectAllMembers() {
        $('.member-checkbox').prop('checked', false);
    }

    // 确认发送
    function confirmSend() {
        var selectedCount = $('input[name="member_ids[]"]:checked').length;
        if (selectedCount === 0) {
            alert('请至少选择一位会员！');
            return false;
        }

        return confirm('确定要向' + selectedCount + '位会员发送此消息吗？');
    }
</script>

<style>
    .tab-pane {
        margin-bottom: 30px;
    }

    .action-buttons {
        display: flex;
        gap: 10px;
    }

    .action-buttons .btn {
        flex: 1;
        border-radius: 4px;
    }

    .action-buttons .btn.active {
        box-shadow: 0 0 0 3px rgba(0, 123, 255, 0.25);
    }

    .status-badge {
        display: inline-block;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 0.9em;
    }

    .status-badge.active {
        background: #e3f2fd;
        color: #1976d2;
    }

    .status-badge.inactive {
        background: #ffebee;
        color: #c62828;
    }

    .status-badge.pending {
        background: #fff8e1;
        color: #f57f17;
    }

    .status-badge.sent {
        background: #e8f5e9;
        color: #2e7d32;
    }

    .status-badge.failed {
        background: #ffebee;
        color: #c62828;
    }
</style>

<?php
function getMessageTypeName($type)
{
    $types = [
        'sms' => '短信',
        'wechat' => '微信',
        'both' => '短信+微信'
    ];
    return isset($types[$type]) ? $types[$type] : $type;
}

function getCategoryName($category)
{
    $categories = [
        'promotion' => '促销活动',
        'birthday' => '生日祝福',
        'holiday' => '节假日问候',
        'reminder' => '提醒通知',
        'other' => '其他'
    ];
    return isset($categories[$category]) ? $categories[$category] : $category;
}

function getSendStatusName($status)
{
    $statuses = [
        'pending' => '待发送',
        'sent' => '已发送',
        'failed' => '发送失败'
    ];
    return isset($statuses[$status]) ? $statuses[$status] : $status;
}
?>