<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 处理促销活动的添加和编辑
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['save_promotion'])) {
    $id = isset($_POST['id']) ? $_POST['id'] : null;
    $name = $_POST['name'];
    $description = $_POST['description'];
    $promotion_type = $_POST['promotion_type'];
    $discount_type = isset($_POST['discount_type']) ? $_POST['discount_type'] : null;
    $discount_value = isset($_POST['discount_value']) ? $_POST['discount_value'] : null;
    $start_date = $_POST['start_date'];
    $end_date = $_POST['end_date'];
    $applicable_room_types = isset($_POST['applicable_room_types']) ? implode(',', $_POST['applicable_room_types']) : '';
    $min_stay_nights = $_POST['min_stay_nights'] ? $_POST['min_stay_nights'] : null;
    $min_booking_amount = $_POST['min_booking_amount'] ? $_POST['min_booking_amount'] : null;
    $usage_limit = $_POST['usage_limit'] ? $_POST['usage_limit'] : null;
    $status = $_POST['status'];

    try {
        if ($id) {
            // 更新促销活动
            $stmt = $conn->prepare("UPDATE promotions SET 
                name = ?, description = ?, promotion_type = ?, discount_type = ?, 
                discount_value = ?, start_date = ?, end_date = ?, applicable_room_types = ?,
                min_stay_nights = ?, min_booking_amount = ?, usage_limit = ?, status = ?
                WHERE id = ?");
            $stmt->bind_param(
                "ssssdsssiidsi",
                $name,
                $description,
                $promotion_type,
                $discount_type,
                $discount_value,
                $start_date,
                $end_date,
                $applicable_room_types,
                $min_stay_nights,
                $min_booking_amount,
                $usage_limit,
                $status,
                $id
            );
            $stmt->execute();
            $success_message = "促销活动更新成功!";
        } else {
            // 添加新促销活动
            $stmt = $conn->prepare("INSERT INTO promotions 
                (name, description, promotion_type, discount_type, discount_value, 
                start_date, end_date, applicable_room_types, min_stay_nights, 
                min_booking_amount, usage_limit, status, created_by) 
                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
            $stmt->bind_param(
                "ssssdsssiidsi",
                $name,
                $description,
                $promotion_type,
                $discount_type,
                $discount_value,
                $start_date,
                $end_date,
                $applicable_room_types,
                $min_stay_nights,
                $min_booking_amount,
                $usage_limit,
                $status,
                $_SESSION['user_id']
            );
            $stmt->execute();
            $success_message = "促销活动添加成功!";
        }
    } catch (Exception $e) {
        $error_message = "操作失败: " . $e->getMessage();
    }
}

// 处理删除促销活动
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $id = $_GET['id'];
    try {
        $stmt = $conn->prepare("DELETE FROM promotions WHERE id = ?");
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $success_message = "促销活动删除成功!";
    } catch (Exception $e) {
        $error_message = "删除失败: " . $e->getMessage();
    }
}

// 获取编辑的促销活动数据
$editing = false;
$promotion = [
    'name' => '',
    'description' => '',
    'promotion_type' => 'discount',
    'discount_type' => 'percentage',
    'discount_value' => '',
    'start_date' => date('Y-m-d'),
    'end_date' => date('Y-m-d', strtotime('+30 days')),
    'applicable_room_types' => '',
    'min_stay_nights' => '',
    'min_booking_amount' => '',
    'usage_limit' => '',
    'status' => 'active'
];

if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $id = $_GET['id'];
    $stmt = $conn->prepare("SELECT * FROM promotions WHERE id = ?");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $editing = true;
        $promotion = $result->fetch_assoc();
    }
}

// 获取所有房型
$result = $conn->query("SELECT id, name FROM room_types WHERE status = 'active'");
$room_types = [];
while ($row = $result->fetch_assoc()) {
    $room_types[] = $row;
}

// 获取促销活动列表
$result = $conn->query("SELECT * FROM promotions ORDER BY created_at DESC");
$promotions = [];
while ($row = $result->fetch_assoc()) {
    $promotions[] = $row;
}
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success"><?php echo $success_message; ?></div>
    <?php endif; ?>
    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger"><?php echo $error_message; ?></div>
    <?php endif; ?>

    <!-- 添加/编辑促销活动表单 -->
    <div class="card mb-4">
        <div class="card-header">
            <h3><?php echo $editing ? '编辑促销活动' : '添加促销活动'; ?></h3>
        </div>
        <div class="card-body">
            <form method="post" id="promotionForm">
                <?php if ($editing): ?>
                    <input type="hidden" name="id" value="<?php echo $promotion['id']; ?>">
                <?php endif; ?>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="name">活动名称</label>
                        <input type="text" class="form-control" id="name" name="name" required
                            value="<?php echo htmlspecialchars($promotion['name']); ?>">
                    </div>
                    <div class="form-group col-md-6">
                        <label for="promotion_type">活动类型</label>
                        <select class="form-control" id="promotion_type" name="promotion_type" required>
                            <option value="discount" <?php echo $promotion['promotion_type'] == 'discount' ? 'selected' : ''; ?>>折扣</option>
                            <option value="package" <?php echo $promotion['promotion_type'] == 'package' ? 'selected' : ''; ?>>套餐</option>
                            <option value="gift" <?php echo $promotion['promotion_type'] == 'gift' ? 'selected' : ''; ?>>赠品</option>
                            <option value="points" <?php echo $promotion['promotion_type'] == 'points' ? 'selected' : ''; ?>>积分</option>
                            <option value="other" <?php echo $promotion['promotion_type'] == 'other' ? 'selected' : ''; ?>>其他</option>
                        </select>
                    </div>
                </div>

                <div class="form-group">
                    <label for="description">活动描述</label>
                    <textarea class="form-control" id="description" name="description" rows="3"><?php echo htmlspecialchars($promotion['description']); ?></textarea>
                </div>

                <div class="form-row" id="discount-fields">
                    <div class="form-group col-md-6">
                        <label for="discount_type">折扣类型</label>
                        <select class="form-control" id="discount_type" name="discount_type">
                            <option value="percentage" <?php echo $promotion['discount_type'] == 'percentage' ? 'selected' : ''; ?>>百分比</option>
                            <option value="fixed_amount" <?php echo $promotion['discount_type'] == 'fixed_amount' ? 'selected' : ''; ?>>固定金额</option>
                        </select>
                    </div>
                    <div class="form-group col-md-6">
                        <label for="discount_value">折扣值</label>
                        <input type="number" class="form-control" id="discount_value" name="discount_value" step="0.01"
                            value="<?php echo $promotion['discount_value']; ?>">
                    </div>
                </div>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="start_date">开始日期</label>
                        <input type="date" class="form-control" id="start_date" name="start_date" required
                            value="<?php echo $promotion['start_date']; ?>">
                    </div>
                    <div class="form-group col-md-6">
                        <label for="end_date">结束日期</label>
                        <input type="date" class="form-control" id="end_date" name="end_date" required
                            value="<?php echo $promotion['end_date']; ?>">
                    </div>
                </div>

                <div class="form-group">
                    <label for="applicable_room_types">适用房型</label>
                    <select class="form-control" id="applicable_room_types" name="applicable_room_types[]" multiple>
                        <?php
                        $applicable_types = explode(',', $promotion['applicable_room_types']);
                        foreach ($room_types as $room_type):
                        ?>
                            <option value="<?php echo $room_type['id']; ?>"
                                <?php echo in_array($room_type['id'], $applicable_types) ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($room_type['name']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                    <small class="form-text text-muted">不选择表示适用于所有房型</small>
                </div>

                <div class="form-row">
                    <div class="form-group col-md-4">
                        <label for="min_stay_nights">最少入住晚数</label>
                        <input type="number" class="form-control" id="min_stay_nights" name="min_stay_nights"
                            value="<?php echo $promotion['min_stay_nights']; ?>">
                    </div>
                    <div class="form-group col-md-4">
                        <label for="min_booking_amount">最低预订金额</label>
                        <input type="number" class="form-control" id="min_booking_amount" name="min_booking_amount" step="0.01"
                            value="<?php echo $promotion['min_booking_amount']; ?>">
                    </div>
                    <div class="form-group col-md-4">
                        <label for="usage_limit">使用限制次数</label>
                        <input type="number" class="form-control" id="usage_limit" name="usage_limit"
                            value="<?php echo $promotion['usage_limit']; ?>">
                        <small class="form-text text-muted">0或空表示不限制</small>
                    </div>
                </div>

                <div class="form-group">
                    <label for="status">状态</label>
                    <select class="form-control" id="status" name="status" required>
                        <option value="active" <?php echo $promotion['status'] == 'active' ? 'selected' : ''; ?>>启用</option>
                        <option value="inactive" <?php echo $promotion['status'] == 'inactive' ? 'selected' : ''; ?>>停用</option>
                    </select>
                </div>

                <button type="submit" name="save_promotion" class="btn btn-primary"><?php echo $editing ? '更新活动' : '添加活动'; ?></button>
                <?php if ($editing): ?>
                    <a href="index.php?page=promotion" class="btn btn-secondary">取消编辑</a>
                <?php endif; ?>
            </form>
        </div>
    </div>

    <!-- 促销活动列表 -->
    <div class="card">
        <div class="card-header">
            <h3>促销活动列表</h3>
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th>活动名称</th>
                            <th>活动类型</th>
                            <th>折扣内容</th>
                            <th>有效期</th>
                            <th>使用次数</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($promotions as $promo): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($promo['name']); ?></td>
                                <td><?php echo getPromotionTypeName($promo['promotion_type']); ?></td>
                                <td>
                                    <?php
                                    if ($promo['promotion_type'] == 'discount') {
                                        if ($promo['discount_type'] == 'percentage') {
                                            echo number_format($promo['discount_value'], 0) . '%折扣';
                                        } else {
                                            echo '减' . number_format($promo['discount_value'], 2) . '元';
                                        }
                                    } elseif ($promo['promotion_type'] == 'points') {
                                        echo '奖励' . number_format($promo['discount_value'], 0) . '积分';
                                    }
                                    ?>
                                </td>
                                <td>
                                    <?php echo date('Y-m-d', strtotime($promo['start_date'])); ?> 至
                                    <?php echo date('Y-m-d', strtotime($promo['end_date'])); ?>
                                </td>
                                <td>
                                    <?php
                                    if ($promo['usage_limit']) {
                                        echo $promo['used_count'] . '/' . $promo['usage_limit'];
                                    } else {
                                        echo $promo['used_count'] . '/不限';
                                    }
                                    ?>
                                </td>
                                <td>
                                    <span class="status-badge <?php echo $promo['status']; ?>">
                                        <?php echo $promo['status'] == 'active' ? '启用' : '停用'; ?>
                                    </span>
                                </td>
                                <td>
                                    <a href="index.php?page=promotion&action=edit&id=<?php echo $promo['id']; ?>"
                                        class="btn btn-sm btn-primary">编辑</a>
                                    <a href="index.php?page=promotion&action=delete&id=<?php echo $promo['id']; ?>"
                                        class="btn btn-sm btn-danger"
                                        onclick="return confirm('确定要删除此促销活动吗？')">删除</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($promotions)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无促销活动</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

<script>
    $(document).ready(function() {
        // 根据促销类型显示/隐藏折扣字段
        $('#promotion_type').change(function() {
            if ($(this).val() === 'discount') {
                $('#discount-fields').show();
            } else {
                $('#discount-fields').hide();
            }
        });

        // 初始化页面时触发一次
        $('#promotion_type').trigger('change');

        // 日期验证
        $('#promotionForm').submit(function() {
            var startDate = new Date($('#start_date').val());
            var endDate = new Date($('#end_date').val());

            if (endDate < startDate) {
                alert('结束日期不能早于开始日期');
                return false;
            }
            return true;
        });
    });
</script>

<style>
    .status-badge {
        display: inline-block;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 0.9em;
    }

    .status-badge.active {
        background: #e3f2fd;
        color: #1976d2;
    }

    .status-badge.inactive {
        background: #ffebee;
        color: #c62828;
    }
</style>

<?php
function getPromotionTypeName($type)
{
    $types = [
        'discount' => '折扣',
        'package' => '套餐',
        'gift' => '赠品',
        'points' => '积分',
        'other' => '其他'
    ];
    return isset($types[$type]) ? $types[$type] : $type;
}
?>