<?php
// 检查用户是否已登录
// session_start();
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
require_once '../../config/config.php';
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 检查并创建返利规则表（如果不存在）
$sql = "CREATE TABLE IF NOT EXISTS referral_rules (
    id INT AUTO_INCREMENT PRIMARY KEY,
    reward_type ENUM('points', 'cash') NOT NULL,
    reward_value DECIMAL(10,2) NOT NULL,
    min_booking_amount DECIMAL(10,2),
    min_stay_nights INT,
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
)";
$conn->query($sql);

// 检查并创建返利记录表（如果不存在）
$sql = "CREATE TABLE IF NOT EXISTS referral_records (
    id INT AUTO_INCREMENT PRIMARY KEY,
    referrer_id INT NOT NULL,
    referred_id INT NOT NULL,
    booking_id INT NOT NULL,
    reward_type ENUM('points', 'cash') NOT NULL,
    reward_value DECIMAL(10,2) NOT NULL,
    status ENUM('pending', 'approved', 'rejected') NOT NULL DEFAULT 'pending',
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (referrer_id) REFERENCES members(id),
    FOREIGN KEY (referred_id) REFERENCES members(id),
    FOREIGN KEY (booking_id) REFERENCES bookings(id)
)";
$conn->query($sql);

// 处理保存返利规则
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['save_rule'])) {
    $reward_type = $_POST['reward_type'];
    $reward_value = $_POST['reward_value'];
    $min_booking_amount = $_POST['min_booking_amount'] ? $_POST['min_booking_amount'] : null;
    $min_stay_nights = $_POST['min_stay_nights'] ? $_POST['min_stay_nights'] : null;
    $status = $_POST['status'];

    // 先将所有规则设置为非活动状态
    $sql = "UPDATE referral_rules SET status = 'inactive'";
    $conn->query($sql);

    // 检查是否存在活动规则
    $sql = "SELECT id FROM referral_rules WHERE status = 'active'";
    $result = $conn->query($sql);

    if ($result->num_rows > 0) {
        // 更新现有规则
        $sql = "UPDATE referral_rules SET 
                reward_type = ?, 
                reward_value = ?, 
                min_booking_amount = ?, 
                min_stay_nights = ?, 
                status = ?
                WHERE status = 'active'";
    } else {
        // 插入新规则
        $sql = "INSERT INTO referral_rules 
                (reward_type, reward_value, min_booking_amount, min_stay_nights, status) 
                VALUES (?, ?, ?, ?, ?)";
    }

    $stmt = $conn->prepare($sql);
    $stmt->bind_param("sdiis", $reward_type, $reward_value, $min_booking_amount, $min_stay_nights, $status);

    if ($stmt->execute()) {
        $success_message = "返利规则保存成功！";
    } else {
        $error_message = "保存失败：" . $stmt->error;
    }
}

// 处理返利记录审核
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['review_record'])) {
    $record_id = $_POST['record_id'];
    $status = $_POST['review_status'];

    $sql = "UPDATE referral_records SET status = ? WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("si", $status, $record_id);

    if ($stmt->execute()) {
        if ($status == 'approved') {
            // 获取返利记录信息
            $sql = "SELECT referrer_id, reward_type, reward_value FROM referral_records WHERE id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param("i", $record_id);
            $stmt->execute();
            $result = $stmt->get_result();
            $record = $result->fetch_assoc();

            if ($record['reward_type'] == 'points') {
                // 更新会员积分
                $sql = "UPDATE members SET points = points + ? WHERE id = ?";
                $stmt = $conn->prepare($sql);
                $stmt->bind_param("di", $record['reward_value'], $record['referrer_id']);
                $stmt->execute();

                // 添加积分历史记录
                $sql = "INSERT INTO point_history (member_id, points_change, change_type, reason, created_by) 
                        VALUES (?, ?, 'add', '推荐返利奖励', ?)";
                $stmt = $conn->prepare($sql);
                $stmt->bind_param("idi", $record['referrer_id'], $record['reward_value'], $_SESSION['user_id']);
                $stmt->execute();
            }
        }
        $success_message = "返利记录审核完成！";
    } else {
        $error_message = "审核失败：" . $stmt->error;
    }
}

// 获取当前返利规则
$current_rule = null;
$sql = "SELECT * FROM referral_rules WHERE status = 'active'";
$result = $conn->query($sql);
if ($result->num_rows > 0) {
    $current_rule = $result->fetch_assoc();
}

// 获取返利记录列表
$sql = "SELECT 
            rr.*,
            m1.name as referrer_name,
            m1.phone as referrer_phone,
            m2.name as referred_name,
            m2.phone as referred_phone,
            b.booking_number,
            b.total_amount
        FROM referral_records rr
        JOIN members m1 ON rr.referrer_id = m1.id
        JOIN members m2 ON rr.referred_id = m2.id
        JOIN bookings b ON rr.booking_id = b.id
        ORDER BY rr.created_at DESC";
$result = $conn->query($sql);
$referral_records = [];
if ($result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $referral_records[] = $row;
    }
}
?>

<div class="content">
    <div class="page-header">
        <h2>推荐返利管理</h2>
    </div>

    <?php if (isset($success_message)): ?>
        <div class="alert alert-success"><?php echo $success_message; ?></div>
    <?php endif; ?>
    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger"><?php echo $error_message; ?></div>
    <?php endif; ?>

    <!-- 返利规则设置 -->
    <div class="card mb-4">
        <div class="card-header">
            <h3>返利规则设置</h3>
        </div>
        <div class="card-body">
            <form method="post" id="ruleForm">
                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="reward_type">奖励类型</label>
                        <select class="form-control" id="reward_type" name="reward_type" required>
                            <option value="points" <?php echo $current_rule && $current_rule['reward_type'] == 'points' ? 'selected' : ''; ?>>积分</option>
                            <option value="cash" <?php echo $current_rule && $current_rule['reward_type'] == 'cash' ? 'selected' : ''; ?>>现金</option>
                        </select>
                    </div>
                    <div class="form-group col-md-6">
                        <label for="reward_value">奖励值</label>
                        <input type="number" class="form-control" id="reward_value" name="reward_value" step="0.01" required
                            value="<?php echo $current_rule ? $current_rule['reward_value'] : ''; ?>">
                    </div>
                </div>
                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="min_booking_amount">最低预订金额</label>
                        <input type="number" class="form-control" id="min_booking_amount" name="min_booking_amount" step="0.01"
                            value="<?php echo $current_rule ? $current_rule['min_booking_amount'] : ''; ?>">
                    </div>
                    <div class="form-group col-md-6">
                        <label for="min_stay_nights">最少入住晚数</label>
                        <input type="number" class="form-control" id="min_stay_nights" name="min_stay_nights"
                            value="<?php echo $current_rule ? $current_rule['min_stay_nights'] : ''; ?>">
                    </div>
                </div>
                <div class="form-group">
                    <label for="status">状态</label>
                    <select class="form-control" id="status" name="status" required>
                        <option value="active" <?php echo $current_rule && $current_rule['status'] == 'active' ? 'selected' : ''; ?>>启用</option>
                        <option value="inactive" <?php echo $current_rule && $current_rule['status'] == 'inactive' ? 'selected' : ''; ?>>停用</option>
                    </select>
                </div>
                <button type="submit" name="save_rule" class="btn btn-primary">保存规则</button>
            </form>
        </div>
    </div>

    <!-- 返利记录列表 -->
    <div class="card">
        <div class="card-header">
            <h3>返利记录</h3>
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th>推荐人</th>
                            <th>被推荐人</th>
                            <th>订单号</th>
                            <th>订单金额</th>
                            <th>奖励类型</th>
                            <th>奖励值</th>
                            <th>状态</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($referral_records as $record): ?>
                            <tr>
                                <td>
                                    <?php echo $record['referrer_name']; ?><br>
                                    <small class="text-muted"><?php echo $record['referrer_phone']; ?></small>
                                </td>
                                <td>
                                    <?php echo $record['referred_name']; ?><br>
                                    <small class="text-muted"><?php echo $record['referred_phone']; ?></small>
                                </td>
                                <td><?php echo $record['booking_number']; ?></td>
                                <td>¥<?php echo number_format($record['total_amount'], 2); ?></td>
                                <td>
                                    <?php echo $record['reward_type'] == 'points' ? '积分' : '现金'; ?>
                                </td>
                                <td>
                                    <?php
                                    if ($record['reward_type'] == 'points') {
                                        echo $record['reward_value'] . '积分';
                                    } else {
                                        echo '¥' . number_format($record['reward_value'], 2);
                                    }
                                    ?>
                                </td>
                                <td>
                                    <span class="badge badge-<?php
                                                                switch ($record['status']) {
                                                                    case 'pending':
                                                                        echo 'warning';
                                                                        break;
                                                                    case 'approved':
                                                                        echo 'success';
                                                                        break;
                                                                    case 'rejected':
                                                                        echo 'danger';
                                                                        break;
                                                                }
                                                                ?>">
                                        <?php
                                        switch ($record['status']) {
                                            case 'pending':
                                                echo '待审核';
                                                break;
                                            case 'approved':
                                                echo '已通过';
                                                break;
                                            case 'rejected':
                                                echo '已拒绝';
                                                break;
                                        }
                                        ?>
                                    </span>
                                </td>
                                <td><?php echo date('Y-m-d H:i', strtotime($record['created_at'])); ?></td>
                                <td>
                                    <?php if ($record['status'] == 'pending'): ?>
                                        <form method="post" class="d-inline">
                                            <input type="hidden" name="record_id" value="<?php echo $record['id']; ?>">
                                            <input type="hidden" name="review_status" value="approved">
                                            <button type="submit" name="review_record" class="btn btn-sm btn-success">
                                                <i class="fas fa-check"></i> 通过
                                            </button>
                                        </form>
                                        <form method="post" class="d-inline">
                                            <input type="hidden" name="record_id" value="<?php echo $record['id']; ?>">
                                            <input type="hidden" name="review_status" value="rejected">
                                            <button type="submit" name="review_record" class="btn btn-sm btn-danger">
                                                <i class="fas fa-times"></i> 拒绝
                                            </button>
                                        </form>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($referral_records)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无返利记录</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

<style>
    .content {
        padding: 20px;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
    }

    .card-header {
        padding: 15px 20px;
        border-bottom: 1px solid #e3e6f0;
        background-color: #f8f9fc;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .card-body {
        padding: 20px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -5px;
        margin-left: -5px;
    }

    .form-row>.col,
    .form-row>[class*="col-"] {
        padding-right: 5px;
        padding-left: 5px;
    }

    .table {
        width: 100%;
        margin-bottom: 1rem;
        color: #212529;
    }

    .table th,
    .table td {
        padding: 0.75rem;
        vertical-align: middle;
        border-top: 1px solid #dee2e6;
    }

    .badge {
        display: inline-block;
        padding: 0.4em 0.6em;
        font-size: 75%;
        font-weight: 700;
        line-height: 1;
        text-align: center;
        white-space: nowrap;
        vertical-align: baseline;
        border-radius: 0.25rem;
    }

    .badge-warning {
        color: #212529;
        background-color: #ffc107;
    }

    .badge-success {
        color: #fff;
        background-color: #28a745;
    }

    .badge-danger {
        color: #fff;
        background-color: #dc3545;
    }

    .btn-sm {
        padding: 0.25rem 0.5rem;
        font-size: 0.875rem;
        line-height: 1.5;
        border-radius: 0.2rem;
    }

    .text-muted {
        color: #6c757d;
    }

    .alert {
        position: relative;
        padding: 0.75rem 1.25rem;
        margin-bottom: 1rem;
        border: 1px solid transparent;
        border-radius: 0.25rem;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-danger {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 表单验证
        const ruleForm = document.getElementById('ruleForm');
        const rewardType = document.getElementById('reward_type');
        const rewardValue = document.getElementById('reward_value');

        ruleForm.addEventListener('submit', function(e) {
            if (rewardType.value === 'points' && !Number.isInteger(parseFloat(rewardValue.value))) {
                e.preventDefault();
                alert('积分奖励必须为整数！');
            }
        });
    });
</script>