<?php
require_once '../../../config/config.php';
require_once '../../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    echo json_encode(['success' => false, 'message' => '未登录或会话已过期']);
    exit;
}

// 获取POST数据
$data = json_decode(file_get_contents('php://input'), true);
$memberId = isset($data['member_id']) ? (int)$data['member_id'] : 0;
$currentStatus = isset($data['current_status']) ? $data['current_status'] : '';

// 验证数据
if (!$memberId || !in_array($currentStatus, ['active', 'inactive'])) {
    echo json_encode(['success' => false, 'message' => '无效的参数']);
    exit;
}

try {
    // 更新会员状态
    $newStatus = $currentStatus == 'active' ? 'inactive' : 'active';
    $sql = "UPDATE members SET status = ?, updated_at = NOW() WHERE id = ?";

    $stmt = $conn->prepare($sql);
    if ($stmt === false) {
        throw new Exception("准备SQL语句失败: " . $conn->error);
    }

    $stmt->bind_param('si', $newStatus, $memberId);
    if (!$stmt->execute()) {
        throw new Exception("执行SQL语句失败: " . $stmt->error);
    }

    if ($stmt->affected_rows > 0) {
        // 记录操作日志
        $action = $newStatus == 'active' ? '启用' : '停用';
        logActivity('member_management', $action . '会员 ID: ' . $memberId);

        echo json_encode(['success' => true]);
    } else {
        echo json_encode(['success' => false, 'message' => '未找到指定会员或状态未发生变化']);
    }
} catch (Exception $e) {
    echo json_encode(['success' => false, 'message' => $e->getMessage()]);
}
