<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取统计数据
$stats = array();

// 获取会员总数
$sql = "SELECT COUNT(*) as total FROM members";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['total_members'] = $row['total'];
} else {
    $stats['total_members'] = 0;
}

// 获取活跃会员数
$sql = "SELECT COUNT(*) as active FROM members WHERE status = 'active'";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['active_members'] = $row['active'];
} else {
    $stats['active_members'] = 0;
}

// 获取不同等级会员数量
$sql = "SELECT level, COUNT(*) as count FROM members GROUP BY level";
$result = $conn->query($sql);
$memberLevels = array();
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $memberLevels[$row['level']] = $row['count'];
    }
}

// 确保所有等级都有值
$allLevels = ['regular', 'silver', 'gold', 'platinum'];
foreach ($allLevels as $level) {
    if (!isset($memberLevels[$level])) {
        $memberLevels[$level] = 0;
    }
}

// 获取本月新增会员数
$firstDayOfMonth = date('Y-m-01');
$sql = "SELECT COUNT(*) as new_members FROM members WHERE registration_date >= ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("s", $firstDayOfMonth);
$stmt->execute();
$result = $stmt->get_result();
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['new_members'] = $row['new_members'];
} else {
    $stats['new_members'] = 0;
}

// 获取总积分
$sql = "SELECT SUM(points) as total_points FROM members";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['total_points'] = $row['total_points'] ? $row['total_points'] : 0;
} else {
    $stats['total_points'] = 0;
}

// 获取最近注册的会员
$sql = "SELECT id, name, phone, email, level, points, registration_date 
        FROM members 
        ORDER BY registration_date DESC 
        LIMIT 5";
$result = $conn->query($sql);
$recentMembers = array();
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $recentMembers[] = $row;
    }
}

// 获取积分最高的会员
$sql = "SELECT id, name, phone, email, level, points 
        FROM members 
        ORDER BY points DESC 
        LIMIT 5";
$result = $conn->query($sql);
$topPointsMembers = array();
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $topPointsMembers[] = $row;
    }
}
?>

<div class="dashboard">
    <div class="dashboard-stats">
        <div class="stat-card">
            <div class="stat-value"><?php echo $stats['total_members']; ?></div>
            <div class="stat-label">会员总数</div>
        </div>
        <div class="stat-card">
            <div class="stat-value"><?php echo $stats['active_members']; ?></div>
            <div class="stat-label">活跃会员</div>
        </div>
        <div class="stat-card">
            <div class="stat-value"><?php echo $stats['new_members']; ?></div>
            <div class="stat-label">本月新增</div>
        </div>
        <div class="stat-card">
            <div class="stat-value"><?php echo number_format($stats['total_points']); ?></div>
            <div class="stat-label">总积分</div>
        </div>
    </div>

    <div class="dashboard-row">
        <div class="dashboard-card">
            <div class="card-header">
                <h3>会员等级分布</h3>
            </div>
            <div class="card-body">
                <div class="level-chart">
                    <div class="level-bar">
                        <div class="level-segment level-regular" style="width: <?php echo ($stats['total_members'] > 0) ? ($memberLevels['regular'] / $stats['total_members'] * 100) : 0; ?>%">
                            <?php echo $memberLevels['regular']; ?>
                        </div>
                        <div class="level-segment level-silver" style="width: <?php echo ($stats['total_members'] > 0) ? ($memberLevels['silver'] / $stats['total_members'] * 100) : 0; ?>%">
                            <?php echo $memberLevels['silver']; ?>
                        </div>
                        <div class="level-segment level-gold" style="width: <?php echo ($stats['total_members'] > 0) ? ($memberLevels['gold'] / $stats['total_members'] * 100) : 0; ?>%">
                            <?php echo $memberLevels['gold']; ?>
                        </div>
                        <div class="level-segment level-platinum" style="width: <?php echo ($stats['total_members'] > 0) ? ($memberLevels['platinum'] / $stats['total_members'] * 100) : 0; ?>%">
                            <?php echo $memberLevels['platinum']; ?>
                        </div>
                    </div>
                    <div class="level-legend">
                        <div class="legend-item">
                            <span class="legend-color level-regular"></span>
                            <span class="legend-label">普通会员</span>
                        </div>
                        <div class="legend-item">
                            <span class="legend-color level-silver"></span>
                            <span class="legend-label">银卡会员</span>
                        </div>
                        <div class="legend-item">
                            <span class="legend-color level-gold"></span>
                            <span class="legend-label">金卡会员</span>
                        </div>
                        <div class="legend-item">
                            <span class="legend-color level-platinum"></span>
                            <span class="legend-label">白金会员</span>
                        </div>
                    </div>
                </div>

                <table class="data-table mt-15">
                    <thead>
                        <tr>
                            <th>会员等级</th>
                            <th>会员数量</th>
                            <th>占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>普通会员</td>
                            <td><?php echo $memberLevels['regular']; ?></td>
                            <td><?php echo ($stats['total_members'] > 0) ? number_format($memberLevels['regular'] / $stats['total_members'] * 100, 2) : 0; ?>%</td>
                        </tr>
                        <tr>
                            <td>银卡会员</td>
                            <td><?php echo $memberLevels['silver']; ?></td>
                            <td><?php echo ($stats['total_members'] > 0) ? number_format($memberLevels['silver'] / $stats['total_members'] * 100, 2) : 0; ?>%</td>
                        </tr>
                        <tr>
                            <td>金卡会员</td>
                            <td><?php echo $memberLevels['gold']; ?></td>
                            <td><?php echo ($stats['total_members'] > 0) ? number_format($memberLevels['gold'] / $stats['total_members'] * 100, 2) : 0; ?>%</td>
                        </tr>
                        <tr>
                            <td>白金会员</td>
                            <td><?php echo $memberLevels['platinum']; ?></td>
                            <td><?php echo ($stats['total_members'] > 0) ? number_format($memberLevels['platinum'] / $stats['total_members'] * 100, 2) : 0; ?>%</td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <div class="dashboard-card">
            <div class="card-header">
                <h3>最近注册会员</h3>
            </div>
            <div class="card-body">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>姓名</th>
                            <th>联系方式</th>
                            <th>会员等级</th>
                            <th>积分</th>
                            <th>注册日期</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($recentMembers)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无会员数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($recentMembers as $member): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($member['name']); ?></td>
                                    <td><?php echo htmlspecialchars($member['phone']); ?></td>
                                    <td>
                                        <span class="level-badge level-<?php echo $member['level']; ?>">
                                            <?php
                                            switch ($member['level']) {
                                                case 'regular':
                                                    echo '普通会员';
                                                    break;
                                                case 'silver':
                                                    echo '银卡会员';
                                                    break;
                                                case 'gold':
                                                    echo '金卡会员';
                                                    break;
                                                case 'platinum':
                                                    echo '白金会员';
                                                    break;
                                                default:
                                                    echo $member['level'];
                                            }
                                            ?>
                                        </span>
                                    </td>
                                    <td><?php echo number_format($member['points']); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($member['registration_date'])); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <div class="dashboard-row">
        <div class="dashboard-card">
            <div class="card-header">
                <h3>积分排行榜</h3>
            </div>
            <div class="card-body">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>排名</th>
                            <th>姓名</th>
                            <th>联系方式</th>
                            <th>会员等级</th>
                            <th>积分</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($topPointsMembers)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无会员数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($topPointsMembers as $index => $member): ?>
                                <tr>
                                    <td><?php echo $index + 1; ?></td>
                                    <td><?php echo htmlspecialchars($member['name']); ?></td>
                                    <td><?php echo htmlspecialchars($member['phone']); ?></td>
                                    <td>
                                        <span class="level-badge level-<?php echo $member['level']; ?>">
                                            <?php
                                            switch ($member['level']) {
                                                case 'regular':
                                                    echo '普通会员';
                                                    break;
                                                case 'silver':
                                                    echo '银卡会员';
                                                    break;
                                                case 'gold':
                                                    echo '金卡会员';
                                                    break;
                                                case 'platinum':
                                                    echo '白金会员';
                                                    break;
                                                default:
                                                    echo $member['level'];
                                            }
                                            ?>
                                        </span>
                                    </td>
                                    <td><?php echo number_format($member['points']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <div class="dashboard-actions">
        <a href="index.php?page=member_add" class="btn btn-primary">添加会员</a>
        <a href="index.php?page=member_list" class="btn btn-secondary">查看所有会员</a>
        <a href="index.php?page=points_management" class="btn btn-secondary">积分管理</a>
    </div>
</div>

<style>
    .dashboard {
        padding: 15px 0;
    }

    .dashboard-stats {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        margin-bottom: 20px;
    }

    .stat-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        flex: 1;
        min-width: 150px;
        text-align: center;
    }

    .stat-value {
        font-size: 24px;
        font-weight: bold;
        color: #0066cc;
        margin-bottom: 5px;
    }

    .stat-label {
        color: #6c757d;
        font-size: 14px;
    }

    .dashboard-row {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .dashboard-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        flex: 1;
        min-width: 300px;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
    }

    .card-header h3 {
        margin: 0;
        font-size: 16px;
        color: #0066cc;
    }

    .card-body {
        padding: 15px;
    }

    .dashboard-actions {
        display: flex;
        gap: 10px;
    }

    .level-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
        color: #fff;
    }

    .level-regular {
        background-color: #6c757d;
    }

    .level-silver {
        background-color: #17a2b8;
    }

    .level-gold {
        background-color: #ffc107;
        color: #212529;
    }

    .level-platinum {
        background-color: #343a40;
    }

    .text-center {
        text-align: center;
    }

    .level-chart {
        margin-bottom: 20px;
    }

    .level-bar {
        height: 30px;
        display: flex;
        border-radius: 4px;
        overflow: hidden;
        margin-bottom: 10px;
    }

    .level-segment {
        display: flex;
        align-items: center;
        justify-content: center;
        color: #fff;
        font-size: 12px;
        min-width: 30px;
    }

    .level-legend {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
    }

    .legend-item {
        display: flex;
        align-items: center;
        font-size: 12px;
    }

    .legend-color {
        width: 15px;
        height: 15px;
        border-radius: 3px;
        margin-right: 5px;
    }

    .legend-label {
        color: #6c757d;
    }

    .mt-15 {
        margin-top: 15px;
    }
</style>