<?php
session_start();
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前页面
$page = isset($_GET['page']) ? $_GET['page'] : 'dashboard';

// 设置页面标题
$pageTitle = '';
switch ($page) {
    case 'dashboard':
        $pageTitle = '会员管理概览';
        break;
    case 'member_list':
        $pageTitle = '会员列表';
        break;
    case 'member_add':
        $pageTitle = '添加会员';
        break;
    case 'member_edit':
        $pageTitle = '编辑会员';
        break;
    case 'member_profile':
        $pageTitle = '会员详情';
        break;
    case 'member_points':
        $pageTitle = '积分管理';
        break;
    case 'member_level':
        $pageTitle = '会员等级';
        break;
    case 'member_feedback':
        $pageTitle = '会员反馈';
        break;
    default:
        $pageTitle = '会员管理';
}

?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle; ?> - 宿易管</title>
    <link rel="stylesheet" href="../../assets/css/style.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/css/bootstrap.min.css">
    <script src="https://cdn.jsdelivr.net/npm/jquery@3.6.4/dist/jquery.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/js/bootstrap.bundle.min.js"></script>
    <style>
        .module-layout {
            display: flex;
            min-height: calc(100vh - 60px);
        }

        .module-sidebar {
            width: 250px;
            background-color: #f8f9fa;
            border-right: 1px solid #e9ecef;
            padding: 20px 0;
            flex-shrink: 0;
        }

        .module-sidebar-header {
            padding: 0 20px 15px;
            border-bottom: 1px solid #e9ecef;
            margin-bottom: 15px;
        }

        .module-sidebar-header h2 {
            margin: 0;
            font-size: 18px;
            color: #0066cc;
        }

        .module-nav {
            display: flex;
            flex-direction: column;
        }

        .module-nav-item {
            padding: 10px 20px;
            color: #495057;
            text-decoration: none;
            border-left: 3px solid transparent;
        }

        .module-nav-item:hover {
            background-color: #e9ecef;
            color: #0066cc;
        }

        .module-nav-item.active {
            background-color: #e9ecef;
            color: #0066cc;
            border-left-color: #0066cc;
            font-weight: bold;
        }

        .module-content {
            flex-grow: 1;
            padding: 20px;
            overflow-y: auto;
        }

        .module-content-header {
            margin-bottom: 20px;
            padding-bottom: 10px;
            border-bottom: 1px solid #e9ecef;
        }

        .module-content-header h2 {
            margin: 0;
            font-size: 24px;
            color: #212529;
        }
    </style>
</head>

<body>
    <header class="main-header">
        <div class="user-info">
            <span class="user-name"><?php echo $_SESSION['user_name']; ?></span>
            <span class="user-role"><?php echo $_SESSION['user_role']; ?></span>
        </div>

        <div class="site-title">
            <h1><?php echo SITE_NAME; ?></h1>
            <p><?php echo SITE_SUBTITLE; ?></p>
        </div>

        <div class="header-actions">
            <a href="../../logout.php" class="btn btn-logout">退出登录</a>
        </div>
    </header>

    <div class="module-layout">
        <aside class="module-sidebar">
            <div class="module-sidebar-header">
                <h2>会员与客户管理</h2>
            </div>

            <nav class="module-nav">
                <a href="../../home.php" class="module-nav-item">返回首页</a>
                <a href="index.php" class="module-nav-item <?php echo $page == 'dashboard' ? 'active' : ''; ?>">概览</a>
                <a href="index.php?page=member_list" class="module-nav-item <?php echo $page == 'member_list' ? 'active' : ''; ?>">会员列表</a>
                <a href="index.php?page=member_add" class="module-nav-item <?php echo $page == 'member_add' ? 'active' : ''; ?>">添加会员</a>
                <a href="index.php?page=member_level" class="module-nav-item <?php echo $page == 'member_level' ? 'active' : ''; ?>">会员等级</a>
                <a href="index.php?page=member_points" class="module-nav-item <?php echo $page == 'member_points' ? 'active' : ''; ?>">积分管理</a>
                <a href="index.php?page=member_feedback" class="module-nav-item <?php echo $page == 'member_feedback' ? 'active' : ''; ?>">客户反馈</a>
            </nav>
        </aside>

        <main class="module-content">
            <div class="module-content-header">
                <h2><?php echo $pageTitle; ?></h2>
            </div>

            <?php
            // 加载对应的页面内容
            switch ($page) {
                case 'dashboard':
                    include 'dashboard.php';
                    break;
                case 'member_list':
                    include 'member_list.php';
                    break;
                case 'member_add':
                    include 'member_edit.php'; // 使用相同的编辑页面，但是是添加模式
                    break;
                case 'member_edit':
                    include 'member_edit.php';
                    break;
                case 'member_profile':
                    include 'member_profile.php';
                    break;
                case 'member_points':
                    include 'member_points.php';
                    break;
                case 'member_level':
                    include 'member_level.php';
                    break;
                case 'member_feedback':
                    include 'member_feedback.php';
                    break;
                default:
                    include 'dashboard.php';
            }
            ?>
        </main>
    </div>

    <script src="../../assets/js/script.js"></script>
</body>

</html>