<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 由于数据库中没有专门的反馈表，我们需要创建一个临时的反馈数据结构
// 在实际项目中，应该创建一个专门的反馈表

// 模拟的反馈数据
$feedbacks = [
    [
        'id' => 1,
        'member_id' => 3,
        'member_name' => '张三',
        'room_id' => 101,
        'room_name' => '海景大床房',
        'booking_id' => 'B202403001',
        'rating' => 5,
        'content' => '房间非常干净，服务也很周到，景色很美，下次还会再来！',
        'reply' => '感谢您的好评，期待您的再次光临！',
        'status' => 'replied',
        'created_at' => '2024-03-05 14:30:00',
        'updated_at' => '2024-03-06 09:15:00'
    ],
    [
        'id' => 2,
        'member_id' => 5,
        'member_name' => '李四',
        'room_id' => 203,
        'room_name' => '山景双床房',
        'booking_id' => 'B202403015',
        'rating' => 3,
        'content' => '房间还可以，但是隔音效果不太好，能听到隔壁的声音。希望能改进。',
        'reply' => '非常抱歉给您带来不便，我们会尽快改进隔音问题。感谢您的反馈！',
        'status' => 'replied',
        'created_at' => '2024-03-08 20:45:00',
        'updated_at' => '2024-03-09 10:20:00'
    ],
    [
        'id' => 3,
        'member_id' => 8,
        'member_name' => '王五',
        'room_id' => 305,
        'room_name' => '豪华套房',
        'booking_id' => 'B202403022',
        'rating' => 4,
        'content' => '整体体验很好，但是早餐品种可以再丰富一些。',
        'reply' => '',
        'status' => 'pending',
        'created_at' => '2024-03-10 08:30:00',
        'updated_at' => '2024-03-10 08:30:00'
    ],
    [
        'id' => 4,
        'member_id' => 12,
        'member_name' => '赵六',
        'room_id' => 402,
        'room_name' => '家庭套房',
        'booking_id' => 'B202403030',
        'rating' => 2,
        'content' => '房间设施有些陈旧，空调噪音很大，影响睡眠。希望能更新设备。',
        'reply' => '',
        'status' => 'pending',
        'created_at' => '2024-03-10 09:15:00',
        'updated_at' => '2024-03-10 09:15:00'
    ],
    [
        'id' => 5,
        'member_id' => 15,
        'member_name' => '孙七',
        'room_id' => 506,
        'room_name' => '总统套房',
        'booking_id' => 'B202403035',
        'rating' => 5,
        'content' => '服务非常周到，房间宽敞明亮，设施齐全，非常满意！',
        'reply' => '',
        'status' => 'pending',
        'created_at' => '2024-03-10 11:30:00',
        'updated_at' => '2024-03-10 11:30:00'
    ]
];

// 处理回复操作
$message = '';
$messageType = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'reply') {
    $feedbackId = isset($_POST['feedback_id']) ? intval($_POST['feedback_id']) : 0;
    $reply = isset($_POST['reply']) ? trim($_POST['reply']) : '';

    if ($feedbackId > 0 && !empty($reply)) {
        // 在实际项目中，这里应该更新数据库
        // 这里只是模拟更新
        foreach ($feedbacks as &$feedback) {
            if ($feedback['id'] === $feedbackId) {
                $feedback['reply'] = $reply;
                $feedback['status'] = 'replied';
                $feedback['updated_at'] = date('Y-m-d H:i:s');
                break;
            }
        }

        $message = '回复成功！';
        $messageType = 'success';
    } else {
        $message = '回复失败，请检查输入！';
        $messageType = 'error';
    }
}

// 获取筛选条件
$filter = isset($_GET['filter']) ? $_GET['filter'] : 'all';
$rating = isset($_GET['rating']) ? intval($_GET['rating']) : 0;

// 根据筛选条件过滤反馈
$filteredFeedbacks = [];
foreach ($feedbacks as $feedback) {
    $include = true;

    // 根据状态筛选
    if ($filter === 'pending' && $feedback['status'] !== 'pending') {
        $include = false;
    } elseif ($filter === 'replied' && $feedback['status'] !== 'replied') {
        $include = false;
    }

    // 根据评分筛选
    if ($rating > 0 && $feedback['rating'] !== $rating) {
        $include = false;
    }

    if ($include) {
        $filteredFeedbacks[] = $feedback;
    }
}

// 获取统计数据
$stats = [
    'total' => count($feedbacks),
    'pending' => 0,
    'replied' => 0,
    'rating_5' => 0,
    'rating_4' => 0,
    'rating_3' => 0,
    'rating_2' => 0,
    'rating_1' => 0,
    'avg_rating' => 0
];

$totalRating = 0;
foreach ($feedbacks as $feedback) {
    if ($feedback['status'] === 'pending') {
        $stats['pending']++;
    } else {
        $stats['replied']++;
    }

    $stats['rating_' . $feedback['rating']]++;
    $totalRating += $feedback['rating'];
}

$stats['avg_rating'] = $stats['total'] > 0 ? round($totalRating / $stats['total'], 1) : 0;
?>

<div class="content-wrapper">
    <?php if ($message): ?>
        <div class="alert alert-<?php echo $messageType; ?>">
            <?php echo $message; ?>
        </div>
    <?php endif; ?>

    <div class="row">
        <div class="col-12">
            <div class="card mb-4">
                <div class="card-header">
                    <h5 class="card-title">反馈统计</h5>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-3 col-sm-6">
                            <div class="stat-card">
                                <h3>总反馈数</h3>
                                <p class="stat-value"><?php echo $stats['total']; ?></p>
                            </div>
                        </div>
                        <div class="col-md-3 col-sm-6">
                            <div class="stat-card">
                                <h3>待回复</h3>
                                <p class="stat-value"><?php echo $stats['pending']; ?></p>
                            </div>
                        </div>
                        <div class="col-md-3 col-sm-6">
                            <div class="stat-card">
                                <h3>已回复</h3>
                                <p class="stat-value"><?php echo $stats['replied']; ?></p>
                            </div>
                        </div>
                        <div class="col-md-3 col-sm-6">
                            <div class="stat-card">
                                <h3>平均评分</h3>
                                <p class="stat-value"><?php echo $stats['avg_rating']; ?> <small>/ 5</small></p>
                                <div class="rating-stars">
                                    <?php for ($i = 1; $i <= 5; $i++): ?>
                                        <span class="star <?php echo $i <= $stats['avg_rating'] ? 'filled' : ''; ?>">★</span>
                                    <?php endfor; ?>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="rating-distribution mt-4">
                        <h5>评分分布</h5>
                        <div class="row">
                            <?php for ($i = 5; $i >= 1; $i--): ?>
                                <?php
                                $count = $stats['rating_' . $i];
                                $percentage = $stats['total'] > 0 ? round(($count / $stats['total']) * 100) : 0;
                                ?>
                                <div class="col-12 mb-2">
                                    <div class="rating-bar">
                                        <div class="rating-label"><?php echo $i; ?> 星</div>
                                        <div class="progress">
                                            <div class="progress-bar" role="progressbar" style="width: <?php echo $percentage; ?>%;" aria-valuenow="<?php echo $percentage; ?>" aria-valuemin="0" aria-valuemax="100"><?php echo $count; ?></div>
                                        </div>
                                        <div class="rating-percentage"><?php echo $percentage; ?>%</div>
                                    </div>
                                </div>
                            <?php endfor; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-header d-flex justify-content-between align-items-center">
                    <h5 class="card-title">客户反馈列表</h5>
                    <div class="filter-controls">
                        <form method="get" class="d-flex">
                            <select name="filter" class="form-control mr-2">
                                <option value="all" <?php echo $filter === 'all' ? 'selected' : ''; ?>>全部</option>
                                <option value="pending" <?php echo $filter === 'pending' ? 'selected' : ''; ?>>待回复</option>
                                <option value="replied" <?php echo $filter === 'replied' ? 'selected' : ''; ?>>已回复</option>
                            </select>
                            <select name="rating" class="form-control mr-2">
                                <option value="0" <?php echo $rating === 0 ? 'selected' : ''; ?>>全部评分</option>
                                <option value="5" <?php echo $rating === 5 ? 'selected' : ''; ?>>5星</option>
                                <option value="4" <?php echo $rating === 4 ? 'selected' : ''; ?>>4星</option>
                                <option value="3" <?php echo $rating === 3 ? 'selected' : ''; ?>>3星</option>
                                <option value="2" <?php echo $rating === 2 ? 'selected' : ''; ?>>2星</option>
                                <option value="1" <?php echo $rating === 1 ? 'selected' : ''; ?>>1星</option>
                            </select>
                            <button type="submit" class="btn btn-primary">筛选</button>
                        </form>
                    </div>
                </div>
                <div class="card-body">
                    <?php if (empty($filteredFeedbacks)): ?>
                        <div class="alert alert-info">没有符合条件的反馈记录</div>
                    <?php else: ?>
                        <div class="feedback-list">
                            <?php foreach ($filteredFeedbacks as $feedback): ?>
                                <div class="feedback-item">
                                    <div class="feedback-header">
                                        <div class="feedback-info">
                                            <span class="member-name"><?php echo $feedback['member_name']; ?></span>
                                            <span class="room-name"><?php echo $feedback['room_name']; ?></span>
                                            <span class="booking-id">订单号: <?php echo $feedback['booking_id']; ?></span>
                                            <span class="feedback-date"><?php echo date('Y-m-d', strtotime($feedback['created_at'])); ?></span>
                                        </div>
                                        <div class="feedback-rating">
                                            <?php for ($i = 1; $i <= 5; $i++): ?>
                                                <span class="star <?php echo $i <= $feedback['rating'] ? 'filled' : ''; ?>">★</span>
                                            <?php endfor; ?>
                                        </div>
                                    </div>
                                    <div class="feedback-content">
                                        <p><?php echo $feedback['content']; ?></p>
                                    </div>
                                    <?php if (!empty($feedback['reply'])): ?>
                                        <div class="feedback-reply">
                                            <div class="reply-header">
                                                <span class="reply-label">回复</span>
                                                <span class="reply-date"><?php echo date('Y-m-d H:i', strtotime($feedback['updated_at'])); ?></span>
                                            </div>
                                            <p><?php echo $feedback['reply']; ?></p>
                                        </div>
                                    <?php else: ?>
                                        <div class="feedback-actions">
                                            <button type="button" class="btn btn-primary btn-sm reply-btn" data-toggle="modal" data-target="#replyModal" data-id="<?php echo $feedback['id']; ?>">
                                                回复
                                            </button>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- 回复模态框 -->
<div class="modal fade" id="replyModal" tabindex="-1" role="dialog" aria-labelledby="replyModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="replyModalLabel">回复客户反馈</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <form method="post" action="">
                <div class="modal-body">
                    <input type="hidden" name="action" value="reply">
                    <input type="hidden" name="feedback_id" id="feedback_id" value="">
                    <div class="form-group">
                        <label for="reply">回复内容</label>
                        <textarea class="form-control" id="reply" name="reply" rows="5" required></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">取消</button>
                    <button type="submit" class="btn btn-primary">提交回复</button>
                </div>
            </form>
        </div>
    </div>
</div>

<style>
    .stat-card {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        margin-bottom: 20px;
        text-align: center;
    }

    .stat-card h3 {
        margin-top: 0;
        font-size: 16px;
        color: #6c757d;
    }

    .stat-value {
        font-size: 28px;
        font-weight: bold;
        margin: 10px 0;
        color: #0066cc;
    }

    .rating-stars {
        font-size: 20px;
    }

    .star {
        color: #e0e0e0;
    }

    .star.filled {
        color: #ffc107;
    }

    .rating-distribution {
        background-color: #f8f9fa;
        padding: 15px;
        border-radius: 5px;
    }

    .rating-bar {
        display: flex;
        align-items: center;
        margin-bottom: 5px;
    }

    .rating-label {
        width: 50px;
        text-align: right;
        padding-right: 10px;
    }

    .progress {
        flex-grow: 1;
        height: 20px;
    }

    .rating-percentage {
        width: 50px;
        text-align: left;
        padding-left: 10px;
    }

    .feedback-list {
        margin-top: 20px;
    }

    .feedback-item {
        background-color: #fff;
        border: 1px solid #e9ecef;
        border-radius: 5px;
        padding: 15px;
        margin-bottom: 15px;
    }

    .feedback-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 10px;
    }

    .feedback-info {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
    }

    .member-name {
        font-weight: bold;
    }

    .room-name,
    .booking-id,
    .feedback-date {
        color: #6c757d;
    }

    .feedback-content {
        margin-bottom: 15px;
    }

    .feedback-reply {
        background-color: #f8f9fa;
        padding: 10px;
        border-radius: 5px;
        margin-top: 10px;
    }

    .reply-header {
        display: flex;
        justify-content: space-between;
        margin-bottom: 5px;
    }

    .reply-label {
        font-weight: bold;
        color: #0066cc;
    }

    .reply-date {
        color: #6c757d;
        font-size: 0.9em;
    }

    .filter-controls {
        display: flex;
    }

    .filter-controls select {
        margin-right: 10px;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 处理回复按钮点击事件
        const replyButtons = document.querySelectorAll('.reply-btn');
        replyButtons.forEach(button => {
            button.addEventListener('click', function() {
                const feedbackId = this.getAttribute('data-id');
                document.getElementById('feedback_id').value = feedbackId;

                // 显示模态框
                $('#replyModal').modal('show');
            });
        });
    });
</script>