<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 会员等级信息
$memberLevels = [
    'regular' => [
        'name' => '普通会员',
        'description' => '基础会员等级，享受基本服务和优惠',
        'discount' => '0%',
        'points_rate' => '1倍',
        'min_points' => '0',
        'color' => '#6c757d',
        'benefits' => [
            '基础会员价格',
            '积分累计（1元=1积分）',
            '生日礼遇',
            '会员专属活动参与资格'
        ]
    ],
    'silver' => [
        'name' => '白银会员',
        'description' => '中级会员，享受更多优惠和特权',
        'discount' => '5%',
        'points_rate' => '1.2倍',
        'min_points' => '1000',
        'color' => '#adb5bd',
        'benefits' => [
            '房费95折优惠',
            '积分累计（1元=1.2积分）',
            '延迟退房（14:00前）',
            '生日礼遇',
            '会员专属活动优先参与'
        ]
    ],
    'gold' => [
        'name' => '黄金会员',
        'description' => '高级会员，享受优质服务和显著优惠',
        'discount' => '10%',
        'points_rate' => '1.5倍',
        'min_points' => '5000',
        'color' => '#ffc107',
        'benefits' => [
            '房费9折优惠',
            '积分累计（1元=1.5积分）',
            '优先预订权',
            '延迟退房（16:00前）',
            '免费迷你吧饮品',
            '生日礼遇升级',
            '专属客服通道'
        ]
    ],
    'platinum' => [
        'name' => '铂金会员',
        'description' => '尊贵会员，享受最高级别的服务和特权',
        'discount' => '15%',
        'points_rate' => '2倍',
        'min_points' => '20000',
        'color' => '#17a2b8',
        'benefits' => [
            '房费85折优惠',
            '积分累计（1元=2积分）',
            '优先预订权',
            '免费升级房型（视情况而定）',
            '延迟退房（18:00前）',
            '免费迷你吧',
            '免费欢迎水果',
            '生日礼遇豪华版',
            '专属管家服务',
            '专属旅游顾问'
        ]
    ]
];

// 获取各等级会员数量
$levelCounts = [];
$sql = "SELECT level, COUNT(*) as count FROM members GROUP BY level";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $levelCounts[$row['level']] = $row['count'];
    }
}

// 确保所有等级都有值
foreach (array_keys($memberLevels) as $level) {
    if (!isset($levelCounts[$level])) {
        $levelCounts[$level] = 0;
    }
}

// 处理等级规则更新
$message = '';
$messageType = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'update_rules') {
    // 这里可以添加更新等级规则的逻辑
    // 实际项目中，这些规则可能存储在数据库中
    $message = '等级规则更新成功！';
    $messageType = 'success';
}
?>

<div class="content-wrapper">
    <?php if ($message): ?>
        <div class="alert alert-<?php echo $messageType; ?>">
            <?php echo $message; ?>
        </div>
    <?php endif; ?>

    <div class="row">
        <div class="col-12">
            <div class="card mb-4">
                <div class="card-header">
                    <h5 class="card-title">会员等级概览</h5>
                </div>
                <div class="card-body">
                    <div class="row">
                        <?php foreach ($memberLevels as $levelKey => $level): ?>
                            <div class="col-md-3 col-sm-6">
                                <div class="level-card" style="border-top: 3px solid <?php echo $level['color']; ?>">
                                    <h3><?php echo $level['name']; ?></h3>
                                    <p class="level-count"><?php echo $levelCounts[$levelKey]; ?> 位会员</p>
                                    <p class="level-discount">折扣：<?php echo $level['discount']; ?></p>
                                    <p class="level-points">积分倍率：<?php echo $level['points_rate']; ?></p>
                                    <p class="level-min-points">所需积分：<?php echo $level['min_points']; ?>+</p>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-header d-flex justify-content-between align-items-center">
                    <h5 class="card-title">会员等级详情</h5>
                </div>
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-bordered table-hover">
                            <thead>
                                <tr>
                                    <th>等级</th>
                                    <th>描述</th>
                                    <th>房费折扣</th>
                                    <th>积分倍率</th>
                                    <th>所需积分</th>
                                    <th>会员权益</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($memberLevels as $levelKey => $level): ?>
                                    <tr>
                                        <td>
                                            <span class="level-badge" style="background-color: <?php echo $level['color']; ?>">
                                                <?php echo $level['name']; ?>
                                            </span>
                                        </td>
                                        <td><?php echo $level['description']; ?></td>
                                        <td><?php echo $level['discount']; ?></td>
                                        <td><?php echo $level['points_rate']; ?></td>
                                        <td><?php echo $level['min_points']; ?>+</td>
                                        <td>
                                            <ul class="benefits-list">
                                                <?php foreach ($level['benefits'] as $benefit): ?>
                                                    <li><?php echo $benefit; ?></li>
                                                <?php endforeach; ?>
                                            </ul>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="row mt-4">
        <div class="col-12">
            <div class="card">
                <div class="card-header">
                    <h5 class="card-title">等级规则设置</h5>
                </div>
                <div class="card-body">
                    <form method="post" action="">
                        <input type="hidden" name="action" value="update_rules">

                        <div class="form-group row mb-3">
                            <label class="col-sm-3 col-form-label">白银会员所需积分</label>
                            <div class="col-sm-9">
                                <input type="number" class="form-control" name="silver_points" value="1000">
                            </div>
                        </div>

                        <div class="form-group row mb-3">
                            <label class="col-sm-3 col-form-label">黄金会员所需积分</label>
                            <div class="col-sm-9">
                                <input type="number" class="form-control" name="gold_points" value="5000">
                            </div>
                        </div>

                        <div class="form-group row mb-3">
                            <label class="col-sm-3 col-form-label">铂金会员所需积分</label>
                            <div class="col-sm-9">
                                <input type="number" class="form-control" name="platinum_points" value="20000">
                            </div>
                        </div>

                        <div class="form-group row mb-3">
                            <label class="col-sm-3 col-form-label">白银会员折扣</label>
                            <div class="col-sm-9">
                                <div class="input-group">
                                    <input type="number" class="form-control" name="silver_discount" value="5">
                                    <div class="input-group-append">
                                        <span class="input-group-text">%</span>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="form-group row mb-3">
                            <label class="col-sm-3 col-form-label">黄金会员折扣</label>
                            <div class="col-sm-9">
                                <div class="input-group">
                                    <input type="number" class="form-control" name="gold_discount" value="10">
                                    <div class="input-group-append">
                                        <span class="input-group-text">%</span>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="form-group row mb-3">
                            <label class="col-sm-3 col-form-label">铂金会员折扣</label>
                            <div class="col-sm-9">
                                <div class="input-group">
                                    <input type="number" class="form-control" name="platinum_discount" value="15">
                                    <div class="input-group-append">
                                        <span class="input-group-text">%</span>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="form-group row">
                            <div class="col-sm-9 offset-sm-3">
                                <button type="submit" class="btn btn-primary">保存规则设置</button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .level-card {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        margin-bottom: 20px;
        transition: transform 0.3s;
    }

    .level-card:hover {
        transform: translateY(-5px);
    }

    .level-card h3 {
        margin-top: 0;
        font-size: 18px;
        font-weight: bold;
    }

    .level-count {
        font-size: 24px;
        font-weight: bold;
        margin: 10px 0;
    }

    .level-badge {
        display: inline-block;
        padding: 5px 10px;
        color: white;
        border-radius: 3px;
        font-weight: bold;
    }

    .benefits-list {
        padding-left: 20px;
        margin-bottom: 0;
    }

    .benefits-list li {
        margin-bottom: 5px;
    }
</style>