<?php
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取会员等级名称
function getLevelName($level)
{
    $levels = [
        'regular' => '普通会员',
        'silver' => '白银会员',
        'gold' => '黄金会员',
        'platinum' => '铂金会员'
    ];
    return $levels[$level] ?? $level;
}

// 获取会员等级对应的CSS类名
function getLevelClass($level)
{
    return $level; // 直接返回level值作为CSS类名
}





// 处理搜索条件
$search = isset($_GET['search']) ? sanitize($_GET['search']) : '';
$level = isset($_GET['level']) ? sanitize($_GET['level']) : '';
$status = isset($_GET['status']) ? sanitize($_GET['status']) : '';

// 构建SQL查询
$sql = "SELECT m.*, 
        COUNT(b.id) as total_bookings,
        SUM(CASE WHEN b.status IN ('checked_out') THEN b.total_amount ELSE 0 END) as total_spent
        FROM members m 
        LEFT JOIN bookings b ON m.id = b.member_id";

$conditions = [];
$params = [];
$types = '';

if (!empty($search)) {
    $conditions[] = "(m.name LIKE ? OR m.phone LIKE ? OR m.email LIKE ?)";
    $searchParam = "%$search%";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $params[] = $searchParam;
    $types .= 'sss';
}

if (!empty($level)) {
    $conditions[] = "m.level = ?";
    $params[] = $level;
    $types .= 's';
}

if (!empty($status)) {
    $conditions[] = "m.status = ?";
    $params[] = $status;
    $types .= 's';
}

if (!empty($conditions)) {
    $sql .= " WHERE " . implode(' AND ', $conditions);
}

$sql .= " GROUP BY m.id ORDER BY m.id DESC";

// 准备并执行查询
$stmt = $conn->prepare($sql);
if (!empty($params)) {
    $stmt->bind_param($types, ...$params);
}
$stmt->execute();
$result = $stmt->get_result();
$members = [];
while ($row = $result->fetch_assoc()) {
    $members[] = $row;
}

// 处理删除操作
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'delete') {
    $deleteId = isset($_POST['delete_id']) ? (int)$_POST['delete_id'] : 0;

    if ($deleteId > 0) {
        // 检查是否有关联的预订
        $checkSql = "SELECT COUNT(*) as count FROM bookings WHERE member_id = ?";
        $checkStmt = $conn->prepare($checkSql);
        $checkStmt->bind_param('i', $deleteId);
        $checkStmt->execute();
        $checkResult = $checkStmt->get_result();
        $checkRow = $checkResult->fetch_assoc();

        if ($checkRow['count'] > 0) {
            $deleteError = "无法删除该会员，存在关联的预订记录";
        } else {
            // 删除会员
            $deleteSql = "DELETE FROM members WHERE id = ?";
            $deleteStmt = $conn->prepare($deleteSql);
            $deleteStmt->bind_param('i', $deleteId);

            if ($deleteStmt->execute()) {
                $deleteSuccess = "会员删除成功";
                // 刷新页面以更新列表
                header("Location: index.php?page=member_list&deleted=1");
                exit;
            } else {
                $deleteError = "删除失败: " . $conn->error;
            }
        }
    }
}

// 显示删除成功消息
$showDeleteSuccess = isset($_GET['deleted']) && $_GET['deleted'] == '1';
?>

<div class="content-wrapper">
    <?php if (isset($deleteError)): ?>
        <div class="alert alert-danger">
            <?php echo $deleteError; ?>
        </div>
    <?php endif; ?>

    <?php if ($showDeleteSuccess): ?>
        <div class="alert alert-success">
            会员删除成功
        </div>
    <?php endif; ?>

    <div class="card mb-4">
        <div class="card-header d-flex justify-content-between align-items-center">
            <h5 class="card-title">会员搜索</h5>
        </div>
        <div class="card-body">
            <form method="get" action="" class="search-form">
                <input type="hidden" name="page" value="member_list">
                <div class="row">
                    <div class="col-md-4">
                        <div class="form-group mb-3">
                            <label for="search">搜索</label>
                            <input type="text" class="form-control" id="search" name="search" placeholder="姓名/手机号/邮箱" value="<?php echo htmlspecialchars($search); ?>">
                        </div>
                    </div>
                    <div class="col-md-3">
                        <div class="form-group mb-3">
                            <label for="level">会员等级</label>
                            <select class="form-control" id="level" name="level">
                                <option value="">全部等级</option>
                                <option value="regular" <?php echo $level === 'regular' ? 'selected' : ''; ?>>普通会员</option>
                                <option value="silver" <?php echo $level === 'silver' ? 'selected' : ''; ?>>白银会员</option>
                                <option value="gold" <?php echo $level === 'gold' ? 'selected' : ''; ?>>黄金会员</option>
                                <option value="platinum" <?php echo $level === 'platinum' ? 'selected' : ''; ?>>铂金会员</option>
                            </select>
                        </div>
                    </div>
                    <div class="col-md-3">
                        <div class="form-group mb-3">
                            <label for="status">状态</label>
                            <select class="form-control" id="status" name="status">
                                <option value="">全部状态</option>
                                <option value="active" <?php echo $status === 'active' ? 'selected' : ''; ?>>活跃</option>
                                <option value="inactive" <?php echo $status === 'inactive' ? 'selected' : ''; ?>>不活跃</option>
                            </select>
                        </div>
                    </div>
                    <div class="col-md-2 d-flex align-items-end">
                        <div class="form-group mb-3 w-100">
                            <button type="submit" class="btn btn-primary w-100">搜索</button>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>

    <div class="card">
        <div class="card-header d-flex justify-content-between align-items-center">
            <h5 class="card-title">会员列表</h5>
            <a href="index.php?page=member_add" class="btn btn-primary">添加会员</a>
        </div>
        <div class="card-body">
            <?php if (empty($members)): ?>
                <div class="alert alert-info">没有找到符合条件的会员</div>
            <?php else: ?>
                <div class="table-responsive">
                    <table class="table table-bordered table-hover">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>姓名</th>
                                <th>手机号</th>
                                <th>会员等级</th>
                                <th>积分</th>
                                <th>注册日期</th>
                                <th>入住次数</th>
                                <th>消费总额</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($members as $member): ?>
                                <tr>
                                    <td><?php echo $member['id']; ?></td>
                                    <td><?php echo htmlspecialchars($member['name']); ?></td>
                                    <td><?php echo htmlspecialchars($member['phone']); ?></td>
                                    <td>
                                        <span class="badge badge-<?php echo getLevelClass($member['level']); ?>">
                                            <?php echo getLevelName($member['level']); ?>
                                        </span>
                                    </td>
                                    <td><?php echo $member['points']; ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($member['registration_date'])); ?></td>
                                    <td><?php echo $member['total_stays']; ?></td>
                                    <td><?php echo number_format($member['total_spent'], 2); ?> 元</td>
                                    <td>
                                        <span class="badge badge-<?php echo $member['status'] === 'active' ? 'success' : 'secondary'; ?>">
                                            <?php echo $member['status'] === 'active' ? '活跃' : '不活跃'; ?>
                                        </span>
                                    </td>
                                    <td>
                                        <div class="btn-group">
                                            <a href="index.php?page=member_profile&id=<?php echo $member['id']; ?>" class="btn btn-sm btn-info">详情</a>
                                            <a href="index.php?page=member_edit&id=<?php echo $member['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                            <button type="button" class="btn btn-sm btn-danger delete-btn" data-id="<?php echo $member['id']; ?>" data-name="<?php echo htmlspecialchars($member['name']); ?>">删除</button>
                                        </div>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<!-- 删除确认模态框 -->
<div class="modal fade" id="deleteModal" tabindex="-1" role="dialog" aria-labelledby="deleteModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="deleteModalLabel">确认删除</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                确定要删除会员 <span id="deleteMemberName"></span> 吗？此操作不可恢复。
            </div>
            <div class="modal-footer">
                <form method="post" action="">
                    <input type="hidden" name="action" value="delete">
                    <input type="hidden" name="delete_id" id="deleteMemberId" value="">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">取消</button>
                    <button type="submit" class="btn btn-danger">确认删除</button>
                </form>
            </div>
        </div>
    </div>
</div>

<style>
    .badge {
        padding: 5px 10px;
        border-radius: 4px;
        font-weight: normal;
    }

    .badge-regular {
        background-color: #6c757d;
        color: white;
    }

    .badge-silver {
        background-color: #adb5bd;
        color: white;
    }

    .badge-gold {
        background-color: #ffc107;
        color: #212529;
    }

    .badge-platinum {
        background-color: #17a2b8;
        color: white;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-secondary {
        background-color: #6c757d;
        color: white;
    }

    .btn-group {
        display: flex;
        gap: 5px;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 处理删除按钮点击事件
        const deleteButtons = document.querySelectorAll('.delete-btn');
        deleteButtons.forEach(button => {
            button.addEventListener('click', function() {
                const memberId = this.getAttribute('data-id');
                const memberName = this.getAttribute('data-name');

                document.getElementById('deleteMemberId').value = memberId;
                document.getElementById('deleteMemberName').textContent = memberName;

                // 显示模态框
                $('#deleteModal').modal('show');
            });
        });
    });
</script>