<?php
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 处理积分调整
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['adjust_points'])) {
    $memberId = (int)$_POST['member_id'];
    $points = (int)$_POST['points'];
    $reason = sanitize($_POST['reason']);
    $type = sanitize($_POST['type']); // add 或 deduct

    try {
        $conn->begin_transaction();

        // 更新会员积分
        $sql = "UPDATE members SET 
                points = points " . ($type == 'add' ? '+' : '-') . " ?,
                updated_at = NOW()
                WHERE id = ?";

        $stmt = $conn->prepare($sql);
        $stmt->bind_param('ii', $points, $memberId);

        if (!$stmt->execute()) {
            throw new Exception("更新积分失败");
        }

        // 记录积分变动历史
        $sql = "INSERT INTO point_history (
                    member_id, points_change, change_type, 
                    reason, created_by, created_at
                ) VALUES (?, ?, ?, ?, ?, NOW())";

        $pointsChange = $type == 'add' ? $points : -$points;
        $stmt = $conn->prepare($sql);
        $stmt->bind_param(
            'iissi',
            $memberId,
            $pointsChange,
            $type,
            $reason,
            $_SESSION['user_id']
        );

        if (!$stmt->execute()) {
            throw new Exception("记录积分历史失败");
        }

        $conn->commit();
        $_SESSION['success_message'] = '积分调整成功';
        header("Location: index.php?page=member_points");
        exit;
    } catch (Exception $e) {
        $conn->rollback();
        $error = '操作失败: ' . $e->getMessage();
    }
}

// 获取所有会员信息
$sql = "SELECT * FROM members";
$stmt = $conn->prepare($sql);
$stmt->execute();
$result = $stmt->get_result();
$members = $result->fetch_all(MYSQLI_ASSOC);

// 获取积分历史记录
$sql = "SELECT ph.*, u.name as operator_name 
        FROM point_history ph
        LEFT JOIN users u ON ph.created_by = u.id
        WHERE ph.member_id = ?
        ORDER BY ph.created_at DESC";

$pointHistoryStmt = $conn->prepare($sql);
        // 获取会员等级名称
        function getLevelName($level)
        {
            $levels = [
                'regular' => '普通会员',
                'silver' => '白银会员',
                'gold' => '黄金会员',
                'platinum' => '铂金会员'
            ];
            return $levels[$level] ?? $level;
        }
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>会员积分管理</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <a href="member_list.php">会员列表</a> /
            <span>积分管理</span>
        </nav>
    </div>

    <?php if (isset($error)): ?>
        <div class="alert alert-error">
            <?php echo $error; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($_SESSION['success_message'])): ?>
        <div class="alert alert-success">
            <?php
            echo $_SESSION['success_message'];
            unset($_SESSION['success_message']);
            ?>
        </div>
    <?php endif; ?>

    <div class="content-body">
        <?php foreach ($members as $member): ?>
            <div class="member-info">
                <h3>会员信息</h3>
                <div class="info-grid">
                    <div class="info-item">
                        <label>姓名：</label>
                        <span><?php echo htmlspecialchars($member['name']); ?></span>
                    </div>
                    <div class="info-item">
                        <label>手机号：</label>
                        <span><?php echo htmlspecialchars($member['phone']); ?></span>
                    </div>
                    <div class="info-item">
                        <label>会员等级：</label>
                        <span class="badge badge-<?php echo $member['level']; ?>">
                            <?php echo getLevelName($member['level']); ?>
                        </span>
                    </div>
                    <div class="info-item">
                        <label>当前积分：</label>
                        <span class="points"><?php echo number_format($member['points']); ?></span>
                    </div>
                </div>
            </div>

            <div class="points-adjustment">
                <h3>积分调整</h3>
                <form method="post" action="" class="form-container">
                    <input type="hidden" name="member_id" value="<?php echo $member['id']; ?>">
                    <div class="form-row">
                        <div class="form-group col-md-3">
                            <label for="type<?php echo $member['id']; ?>">调整类型 <span class="required">*</span></label>
                            <select id="type<?php echo $member['id']; ?>" name="type" required>
                                <option value="add">增加</option>
                                <option value="deduct">扣减</option>
                            </select>
                        </div>
                        <div class="form-group col-md-3">
                            <label for="points<?php echo $member['id']; ?>">积分数量 <span class="required">*</span></label>
                            <input type="number" id="points<?php echo $member['id']; ?>" name="points" required min="1">
                        </div>
                        <div class="form-group col-md-6">
                            <label for="reason<?php echo $member['id']; ?>">调整原因 <span class="required">*</span></label>
                            <input type="text" id="reason<?php echo $member['id']; ?>" name="reason" required>
                        </div>
                    </div>
                    <div class="form-actions">
                        <button type="submit" name="adjust_points" class="btn btn-primary">确认调整</button>
                    </div>
                </form>

                <div class="points-history">
                    <h3>积分历史</h3>
                    <div class="table-responsive">
                        <table class="table">
                            <thead>
                                <tr>
                                    <th>时间</th>
                                    <th>变动</th>
                                    <th>类型</th>
                                    <th>原因</th>
                                    <th>操作人</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php
                                $pointHistoryStmt->bind_param('i', $member['id']);
                                $pointHistoryStmt->execute();
                                $pointHistoryResult = $pointHistoryStmt->get_result();
                                $pointHistory = $pointHistoryResult->fetch_all(MYSQLI_ASSOC);

                                if (!empty($pointHistory)) {
                                    foreach ($pointHistory as $record) {
                                ?>
                                        <tr>
                                            <td><?php echo date('Y-m-d H:i:s', strtotime($record['created_at'])); ?></td>
                                            <td class="<?php echo $record['points_change'] >= 0 ? 'text-success' : 'text-danger'; ?>">
                                                <?php echo $record['points_change'] >= 0 ? '+' : ''; ?>
                                                <?php echo number_format($record['points_change']); ?>
                                            </td>
                                            <td>
                                                <?php echo $record['change_type'] == 'add' ? '增加' : '扣减'; ?>
                                            </td>
                                            <td><?php echo htmlspecialchars($record['reason']); ?></td>
                                            <td><?php echo htmlspecialchars($record['operator_name']); ?></td>
                                        </tr>
                                    <?php
                                    }
                                } else {
                                    ?>
                                    <tr>
                                        <td colspan="5" class="text-center">暂无积分记录</td>
                                    </tr>
                                <?php
                                }
                                ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </div>
</div>

<style>
    .content-wrapper {
        padding: 20px;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .member-info {
        background: white;
        padding: 20px;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
    }

    .info-grid {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
        gap: 20px;
        margin-top: 15px;
    }

    .info-item label {
        font-weight: bold;
        margin-right: 10px;
        color: #666;
    }

    .points {
        font-size: 1.2em;
        font-weight: bold;
        color: #28a745;
    }

    .points-adjustment {
        background: white;
        padding: 20px;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
    }

    .points-history {
        background: white;
        padding: 20px;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .form-container {
        margin-top: 15px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .form-group {
        padding: 0 10px;
        margin-bottom: 15px;
    }

    .col-md-3 {
        flex: 0 0 25%;
        max-width: 25%;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
    }

    .form-actions {
        margin-top: 20px;
    }

    .table {
        width: 100%;
        margin-top: 15px;
        border-collapse: collapse;
    }

    .table th,
    .table td {
        padding: 12px;
        border-bottom: 1px solid #dee2e6;
    }

    .table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .text-success {
        color: #28a745;
    }

    .text-danger {
        color: #dc3545;
    }

    .text-center {
        text-align: center;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-error {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }

    .badge {
        padding: 5px 10px;
        border-radius: 4px;
        font-weight: normal;
    }

    .required {
        color: red;
    }

    input[type="number"],
    input[type="text"],
    select {
        width: 100%;
        padding: 8px;
        border: 1px solid #ddd;
        border-radius: 4px;
        box-sizing: border-box;
    }

    .btn {
        padding: 8px 16px;
        border-radius: 4px;
        border: none;
        cursor: pointer;
    }

    .btn-primary {
        background-color: #007bff;
        color: white;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 积分数量验证
        document.querySelectorAll('input[type="number"]').forEach(function(pointsInput) {
            pointsInput.addEventListener('input', function() {
                if (this.value < 1) {
                    this.setCustomValidity('积分数量必须大于0');
                } else {
                    this.setCustomValidity('');
                }
            });
        });
    });
</script>