<?php
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

$memberId = isset($_GET['id']) ? (int)$_GET['id'] : 0;

// 获取会员信息
$sql = "SELECT * FROM members WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param('i', $memberId);
$stmt->execute();
$result = $stmt->get_result();
$member = $result->fetch_assoc();

if (!$member) {
    die('会员不存在');
}

// 获取预订历史
$sql = "SELECT b.*, 
        GROUP_CONCAT(DISTINCT r.room_number) as room_numbers,
        COUNT(DISTINCT br.room_id) as room_count
        FROM bookings b
        LEFT JOIN booking_rooms br ON b.id = br.booking_id
        LEFT JOIN rooms r ON br.room_id = r.id
        WHERE b.member_id = ?
        GROUP BY b.id
        ORDER BY b.created_at DESC
        LIMIT 10";

$stmt = $conn->prepare($sql);
$stmt->bind_param('i', $memberId);
$stmt->execute();
$result = $stmt->get_result();
$bookings = [];
while ($row = $result->fetch_assoc()) {
    $bookings[] = $row;
}

// 获取积分历史
$sql = "SELECT ph.*, u.name as operator_name 
        FROM point_history ph
        LEFT JOIN users u ON ph.created_by = u.id
        WHERE ph.member_id = ?
        ORDER BY ph.created_at DESC
        LIMIT 10";

$stmt = $conn->prepare($sql);
$stmt->bind_param('i', $memberId);
$stmt->execute();
$result = $stmt->get_result();
$pointHistory = [];
while ($row = $result->fetch_assoc()) {
    $pointHistory[] = $row;
}

// 获取旅游服务预订历史
$sql = "SELECT tb.*, ts.name as service_name, ts.category
        FROM tourism_bookings tb
        LEFT JOIN tourism_services ts ON tb.service_id = ts.id
        WHERE tb.member_id = ?
        ORDER BY tb.created_at DESC
        LIMIT 10";

$stmt = $conn->prepare($sql);
$stmt->bind_param('i', $memberId);
$stmt->execute();
$result = $stmt->get_result();
$tourismBookings = [];
while ($row = $result->fetch_assoc()) {
    $tourismBookings[] = $row;
}

// 获取会员等级名称
function getLevelName($level)
{
    $levels = [
        'regular' => '普通会员',
        'silver' => '白银会员',
        'gold' => '黄金会员',
        'platinum' => '铂金会员'
    ];
    return $levels[$level] ?? $level;
}

// 获取预订状态名称
function getBookingStatusName($status)
{
    $statuses = [
        'pending' => '待确认',
        'confirmed' => '已确认',
        'checked_in' => '已入住',
        'checked_out' => '已退房',
        'cancelled' => '已取消',
        'no_show' => '未到'
    ];
    return $statuses[$status] ?? $status;
}

// 获取旅游服务类型名称
function getServiceCategoryName($category)
{
    $categories = [
        'ticket' => '门票',
        'transport' => '交通',
        'guide' => '导游',
        'activity' => '活动',
        'other' => '其他'
    ];
    return $categories[$category] ?? $category;
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>会员详情</h2>
        <nav class="breadcrumb">
            <a href="member_list.php">会员列表</a> /
            <span>会员详情</span>
        </nav>
    </div>

    <div class="content-body">
        <div class="member-profile">
            <div class="profile-header">
                <div class="basic-info">
                    <h3><?php echo htmlspecialchars($member['name']); ?></h3>
                    <span class="badge badge-<?php echo $member['level']; ?>">
                        <?php echo getLevelName($member['level']); ?>
                    </span>
                    <span class="badge badge-<?php echo $member['status'] == 'active' ? 'success' : 'danger'; ?>">
                        <?php echo $member['status'] == 'active' ? '活跃' : '停用'; ?>
                    </span>
                </div>
                <div class="action-buttons">
                    <a href="index.php?page=member_edit" class="btn btn-primary <?php echo $page == 'member_edit' ? 'active' : ''; ?>">编辑资料</a>

                    <a href="index.php?page=member_points&id=<?php echo $member['id']; ?>" class="btn btn-info <?php echo $page == 'member_points' ? 'active' : ''; ?>">积分管理</a>

                    
                </div>
            </div>

            <div class="profile-grid">
                <div class="profile-section">
                    <h4>基本信息</h4>
                    <div class="info-grid">
                        <div class="info-item">
                            <label>手机号：</label>
                            <span><?php echo htmlspecialchars($member['phone']); ?></span>
                        </div>
                        <div class="info-item">
                            <label>邮箱：</label>
                            <span><?php echo htmlspecialchars($member['email'] ?: '未设置'); ?></span>
                        </div>
                        <div class="info-item">
                            <label>性别：</label>
                            <span><?php echo $member['gender'] == 'male' ? '男' : ($member['gender'] == 'female' ? '女' : '其他'); ?></span>
                        </div>
                        <div class="info-item">
                            <label>生日：</label>
                            <span><?php echo $member['birthday'] ? date('Y-m-d', strtotime($member['birthday'])) : '未设置'; ?></span>
                        </div>
                        <div class="info-item">
                            <label>证件类型：</label>
                            <span><?php echo $member['id_type'] == 'id_card' ? '身份证' : ($member['id_type'] == 'passport' ? '护照' : ($member['id_type'] == 'driving_license' ? '驾驶证' : '其他')); ?></span>
                        </div>
                        <div class="info-item">
                            <label>证件号码：</label>
                            <span><?php echo htmlspecialchars($member['id_number']); ?></span>
                        </div>
                        <div class="info-item">
                            <label>地址：</label>
                            <span><?php echo htmlspecialchars($member['address'] ?: '未设置'); ?></span>
                        </div>
                        <div class="info-item">
                            <label>注册日期：</label>
                            <span><?php echo date('Y-m-d', strtotime($member['registration_date'])); ?></span>
                        </div>
                    </div>
                </div>

                <div class="profile-section">
                    <h4>会员数据</h4>
                    <div class="stats-grid">
                        <div class="stat-item">
                            <div class="stat-label">当前积分</div>
                            <div class="stat-value"><?php echo number_format($member['points']); ?></div>
                        </div>
                        <div class="stat-item">
                            <div class="stat-label">累计消费</div>
                            <div class="stat-value">¥<?php echo number_format($member['total_spent'], 2); ?></div>
                        </div>
                        <div class="stat-item">
                            <div class="stat-label">入住次数</div>
                            <div class="stat-value"><?php echo number_format($member['total_stays']); ?></div>
                        </div>
                        <div class="stat-item">
                            <div class="stat-label">最近入住</div>
                            <div class="stat-value"><?php echo $member['last_stay_date'] ? date('Y-m-d', strtotime($member['last_stay_date'])) : '无'; ?></div>
                        </div>
                    </div>
                </div>

                <div class="profile-section">
                    <h4>预订历史</h4>
                    <div class="table-responsive">
                        <table class="table">
                            <thead>
                                <tr>
                                    <th>预订号</th>
                                    <th>入住日期</th>
                                    <th>退房日期</th>
                                    <th>房间</th>
                                    <th>金额</th>
                                    <th>状态</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($bookings as $booking): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($booking['booking_number']); ?></td>
                                        <td><?php echo date('Y-m-d', strtotime($booking['check_in_date'])); ?></td>
                                        <td><?php echo date('Y-m-d', strtotime($booking['check_out_date'])); ?></td>
                                        <td>
                                            <?php echo $booking['room_numbers'] ? htmlspecialchars($booking['room_numbers']) : '未分配'; ?>
                                            (<?php echo $booking['room_count']; ?>间)
                                        </td>
                                        <td>¥<?php echo number_format($booking['total_amount'], 2); ?></td>
                                        <td>
                                            <span class="badge badge-<?php echo $booking['status']; ?>">
                                                <?php echo getBookingStatusName($booking['status']); ?>
                                            </span>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                                <?php if (empty($bookings)): ?>
                                    <tr>
                                        <td colspan="6" class="text-center">暂无预订记录</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>

                <div class="profile-section">
                    <h4>积分历史</h4>
                    <div class="table-responsive">
                        <table class="table">
                            <thead>
                                <tr>
                                    <th>时间</th>
                                    <th>变动</th>
                                    <th>类型</th>
                                    <th>原因</th>
                                    <th>操作人</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($pointHistory as $record): ?>
                                    <tr>
                                        <td><?php echo date('Y-m-d H:i:s', strtotime($record['created_at'])); ?></td>
                                        <td class="<?php echo $record['points_change'] >= 0 ? 'text-success' : 'text-danger'; ?>">
                                            <?php echo $record['points_change'] >= 0 ? '+' : ''; ?>
                                            <?php echo number_format($record['points_change']); ?>
                                        </td>
                                        <td>
                                            <?php echo $record['change_type'] == 'add' ? '增加' : '扣减'; ?>
                                        </td>
                                        <td><?php echo htmlspecialchars($record['reason']); ?></td>
                                        <td><?php echo htmlspecialchars($record['operator_name']); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                                <?php if (empty($pointHistory)): ?>
                                    <tr>
                                        <td colspan="5" class="text-center">暂无积分记录</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>

                <div class="profile-section">
                    <h4>旅游服务预订</h4>
                    <div class="table-responsive">
                        <table class="table">
                            <thead>
                                <tr>
                                    <th>服务名称</th>
                                    <th>类型</th>
                                    <th>预订日期</th>
                                    <th>数量</th>
                                    <th>金额</th>
                                    <th>状态</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($tourismBookings as $booking): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($booking['service_name']); ?></td>
                                        <td><?php echo getServiceCategoryName($booking['category']); ?></td>
                                        <td><?php echo date('Y-m-d', strtotime($booking['service_date'])); ?></td>
                                        <td><?php echo $booking['quantity']; ?></td>
                                        <td>¥<?php echo number_format($booking['total_price'], 2); ?></td>
                                        <td>
                                            <span class="badge badge-<?php echo $booking['status']; ?>">
                                                <?php echo $booking['status'] == 'pending' ? '待确认' : ($booking['status'] == 'confirmed' ? '已确认' : ($booking['status'] == 'completed' ? '已完成' : '已取消')); ?>
                                            </span>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                                <?php if (empty($tourismBookings)): ?>
                                    <tr>
                                        <td colspan="6" class="text-center">暂无旅游服务预订记录</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .content-wrapper {
        padding: 20px;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .member-profile {
        background: white;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
    }

    .profile-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 30px;
        padding-bottom: 20px;
        border-bottom: 1px solid #eee;
    }

    .basic-info h3 {
        margin: 0 0 10px 0;
    }

    .badge {
        padding: 5px 10px;
        border-radius: 4px;
        font-weight: normal;
        margin-right: 10px;
    }

    .profile-grid {
        display: grid;
        gap: 20px;
    }

    .profile-section {
        background: white;
        border: 1px solid #eee;
        border-radius: 8px;
        padding: 20px;
    }

    .profile-section h4 {
        margin: 0 0 20px 0;
        padding-bottom: 10px;
        border-bottom: 1px solid #eee;
    }

    .info-grid {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(200px, 1fr));
        gap: 15px;
    }

    .info-item label {
        font-weight: bold;
        color: #666;
        margin-right: 10px;
    }

    .stats-grid {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(150px, 1fr));
        gap: 20px;
    }

    .stat-item {
        text-align: center;
        padding: 15px;
        background: #f8f9fa;
        border-radius: 8px;
    }

    .stat-label {
        color: #666;
        margin-bottom: 5px;
    }

    .stat-value {
        font-size: 1.5em;
        font-weight: bold;
        color: #333;
    }

    .table {
        width: 100%;
        margin-top: 15px;
        border-collapse: collapse;
    }

    .table th,
    .table td {
        padding: 12px;
        border-bottom: 1px solid #dee2e6;
    }

    .table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .text-success {
        color: #28a745;
    }

    .text-danger {
        color: #dc3545;
    }

    .text-center {
        text-align: center;
    }

    .btn {
        padding: 8px 16px;
        border-radius: 4px;
        border: none;
        cursor: pointer;
        margin-left: 10px;
        text-decoration: none;
    }

    .btn-primary {
        background-color: #007bff;
        color: white;
    }

    .btn-info {
        background-color: #17a2b8;
        color: white;
    }

    .badge-regular {
        background-color: #6c757d;
        color: white;
    }

    .badge-silver {
        background-color: #adb5bd;
        color: white;
    }

    .badge-gold {
        background-color: #ffd700;
        color: black;
    }

    .badge-platinum {
        background-color: #e5e4e2;
        color: black;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }

    .badge-pending {
        background-color: #ffc107;
        color: black;
    }

    .badge-confirmed {
        background-color: #17a2b8;
        color: white;
    }

    .badge-checked_in {
        background-color: #28a745;
        color: white;
    }

    .badge-checked_out {
        background-color: #6c757d;
        color: white;
    }

    .badge-cancelled {
        background-color: #dc3545;
        color: white;
    }

    .badge-no_show {
        background-color: #343a40;
        color: white;
    }
</style>