<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 处理添加清洁任务请求
if (isset($_POST['add_task'])) {
    $room_id = $_POST['room_id'];
    $scheduled_date = $_POST['scheduled_date'];
    $scheduled_time = $_POST['scheduled_time'];
    $assigned_to = $_POST['assigned_to'];
    $priority = $_POST['priority'];
    $notes = $_POST['notes'];

    $sql = "INSERT INTO cleaning_tasks (room_id, scheduled_date, scheduled_time, assigned_to, priority, notes) 
            VALUES (?, ?, ?, ?, ?, ?)";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("isssss", $room_id, $scheduled_date, $scheduled_time, $assigned_to, $priority, $notes);

    if ($stmt->execute()) {
        $success_message = "清洁任务添加成功";
    } else {
        $error_message = "清洁任务添加失败: " . $stmt->error;
    }
}

// 处理更新任务状态请求
if (isset($_POST['update_status'])) {
    $task_id = $_POST['task_id'];
    $status = $_POST['status'];
    $completion_notes = $_POST['completion_notes'] ?? '';

    $sql = "UPDATE cleaning_tasks SET status = ?";
    $params = array($status);
    $types = "s";

    if ($status == 'completed') {
        $sql .= ", end_time = CURRENT_TIMESTAMP, notes = CONCAT(IFNULL(notes,''), '\n完成备注：', ?)";
        $params[] = $completion_notes;
        $types .= "s";
    } elseif ($status == 'in_progress') {
        $sql .= ", start_time = CURRENT_TIMESTAMP";
    }

    $sql .= " WHERE id = ?";
    $params[] = $task_id;
    $types .= "i";

    $stmt = $conn->prepare($sql);
    $stmt->bind_param($types, ...$params);

    if ($stmt->execute()) {
        $success_message = "任务状态更新成功";
    } else {
        $error_message = "任务状态更新失败: " . $stmt->error;
    }
}

// 获取房间列表
$rooms = array();
$sql = "SELECT id, room_number FROM rooms ORDER BY room_number";
if ($result = mysqli_query($conn, $sql)) {
    while ($row = mysqli_fetch_assoc($result)) {
        $rooms[] = $row;
    }
} else {
    $error_message = "获取房间列表失败: " . mysqli_error($conn);
}

// 获取保洁人员列表（修改为获取所有员工，因为可能还没有专门的cleaner角色）
$cleaners = array();
$sql = "SELECT id, name FROM users WHERE status = 'active' ORDER BY name";
if ($result = mysqli_query($conn, $sql)) {
    while ($row = mysqli_fetch_assoc($result)) {
        $cleaners[] = $row;
    }
} else {
    $error_message = "获取保洁人员列表失败: " . mysqli_error($conn);
}

// 获取清洁任务列表
$tasks = array();
$sql = "SELECT ct.*, r.room_number, u.name as cleaner_name 
        FROM cleaning_tasks ct 
        LEFT JOIN rooms r ON ct.room_id = r.id 
        LEFT JOIN users u ON ct.assigned_to = u.id 
        WHERE ct.scheduled_date >= CURDATE() 
        ORDER BY ct.scheduled_date ASC, ct.scheduled_time ASC";
if ($result = mysqli_query($conn, $sql)) {
    while ($row = mysqli_fetch_assoc($result)) {
        $tasks[] = $row;
    }
} else {
    // 如果表不存在，创建表
    $create_table_sql = "CREATE TABLE IF NOT EXISTS cleaning_tasks (
        id INT AUTO_INCREMENT PRIMARY KEY,
        room_id INT NOT NULL,
        scheduled_date DATE NOT NULL,
        scheduled_time TIME,
        assigned_to INT,
        status ENUM('pending', 'in_progress', 'completed', 'verified', 'cancelled') NOT NULL DEFAULT 'pending',
        priority ENUM('normal', 'high', 'urgent') NOT NULL DEFAULT 'normal',
        notes TEXT,
        start_time DATETIME,
        end_time DATETIME,
        verified_by INT,
        verification_time DATETIME,
        created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
        updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        FOREIGN KEY (room_id) REFERENCES rooms(id) ON DELETE CASCADE,
        FOREIGN KEY (assigned_to) REFERENCES users(id) ON DELETE SET NULL,
        FOREIGN KEY (verified_by) REFERENCES users(id) ON DELETE SET NULL
    ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4";

    if (mysqli_query($conn, $create_table_sql)) {
        $success_message = "清洁任务表创建成功";
        // 重新尝试获取任务列表
        $result = mysqli_query($conn, $sql);
        while ($row = mysqli_fetch_assoc($result)) {
            $tasks[] = $row;
        }
    } else {
        $error_message = "创建清洁任务表失败: " . mysqli_error($conn);
    }
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="action-buttons">
        <button class="btn btn-primary" onclick="showAddTaskModal()">添加清洁任务</button>
    </div>

    <div class="task-list">
        <table class="data-table">
            <thead>
                <tr>
                    <th>房间号</th>
                    <th>计划日期</th>
                    <th>计划时间</th>
                    <th>保洁员</th>
                    <th>优先级</th>
                    <th>状态</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($tasks as $task): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($task['room_number']); ?></td>
                        <td><?php echo date('Y-m-d', strtotime($task['scheduled_date'])); ?></td>
                        <td><?php echo $task['scheduled_time'] ? date('H:i', strtotime($task['scheduled_time'])) : '未指定'; ?></td>
                        <td><?php echo htmlspecialchars($task['cleaner_name'] ?? '未分配'); ?></td>
                        <td>
                            <span class="badge badge-<?php
                                                        echo $task['priority'] == 'urgent' ? 'danger' : ($task['priority'] == 'high' ? 'warning' : 'info');
                                                        ?>">
                                <?php
                                echo $task['priority'] == 'urgent' ? '紧急' : ($task['priority'] == 'high' ? '高' : '普通');
                                ?>
                            </span>
                        </td>
                        <td>
                            <span class="badge badge-<?php
                                                        echo $task['status'] == 'completed' ? 'success' : ($task['status'] == 'in_progress' ? 'primary' : ($task['status'] == 'cancelled' ? 'danger' : 'warning'));
                                                        ?>">
                                <?php
                                echo $task['status'] == 'completed' ? '已完成' : ($task['status'] == 'in_progress' ? '进行中' : ($task['status'] == 'cancelled' ? '已取消' : ($task['status'] == 'verified' ? '已验证' : '待处理')));
                                ?>
                            </span>
                        </td>
                        <td>
                            <?php if ($task['status'] == 'pending'): ?>
                                <button class="btn btn-sm btn-primary" onclick="updateTaskStatus(<?php echo $task['id']; ?>, 'in_progress')">开始</button>
                            <?php endif; ?>

                            <?php if ($task['status'] == 'in_progress'): ?>
                                <button class="btn btn-sm btn-success" onclick="showCompletionModal(<?php echo $task['id']; ?>)">完成</button>
                            <?php endif; ?>

                            <?php if ($task['status'] == 'pending'): ?>
                                <button class="btn btn-sm btn-danger" onclick="updateTaskStatus(<?php echo $task['id']; ?>, 'cancelled')">取消</button>
                            <?php endif; ?>

                            <button class="btn btn-sm btn-info" onclick="viewTaskDetails(<?php echo $task['id']; ?>)">详情</button>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<!-- 添加任务模态框 -->
<div class="modal" id="addTaskModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">添加清洁任务</h4>
                <button type="button" class="close" onclick="closeModal('addTaskModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form id="addTaskForm" method="post">
                    <div class="form-group">
                        <label>房间</label>
                        <select class="form-control" name="room_id" required>
                            <option value="">请选择房间</option>
                            <?php foreach ($rooms as $room): ?>
                                <option value="<?php echo $room['id']; ?>">
                                    <?php echo $room['room_number']; ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>计划日期</label>
                        <input type="date" class="form-control" name="scheduled_date" required min="<?php echo date('Y-m-d'); ?>">
                    </div>

                    <div class="form-group">
                        <label>计划时间</label>
                        <input type="time" class="form-control" name="scheduled_time">
                    </div>

                    <div class="form-group">
                        <label>分配保洁员</label>
                        <select class="form-control" name="assigned_to">
                            <option value="">请选择保洁员</option>
                            <?php foreach ($cleaners as $cleaner): ?>
                                <option value="<?php echo $cleaner['id']; ?>">
                                    <?php echo $cleaner['name']; ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>优先级</label>
                        <select class="form-control" name="priority" required>
                            <option value="normal">普通</option>
                            <option value="high">高</option>
                            <option value="urgent">紧急</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>备注</label>
                        <textarea class="form-control" name="notes" rows="3"></textarea>
                    </div>

                    <input type="hidden" name="add_task" value="1">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('addTaskModal')">取消</button>
                <button type="button" class="btn btn-primary" onclick="submitAddTaskForm()">添加</button>
            </div>
        </div>
    </div>
</div>

<!-- 完成任务模态框 -->
<div class="modal" id="completionModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">完成清洁任务</h4>
                <button type="button" class="close" onclick="closeModal('completionModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form id="completionForm" method="post">
                    <div class="form-group">
                        <label>完成备注</label>
                        <textarea class="form-control" name="completion_notes" rows="3"></textarea>
                    </div>
                    <input type="hidden" name="task_id" id="completion_task_id">
                    <input type="hidden" name="status" value="completed">
                    <input type="hidden" name="update_status" value="1">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('completionModal')">取消</button>
                <button type="button" class="btn btn-primary" onclick="submitCompletionForm()">确认完成</button>
            </div>
        </div>
    </div>
</div>

<style>
    .content {
        padding: 20px;
    }

    .action-buttons {
        margin-bottom: 20px;
    }

    .task-list {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .badge {
        padding: 5px 10px;
        border-radius: 4px;
        font-size: 12px;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-primary {
        background-color: #007bff;
        color: white;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #000;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }

    .badge-info {
        background-color: #17a2b8;
        color: white;
    }

    .btn {
        display: inline-block;
        padding: 8px 16px;
        border-radius: 4px;
        text-decoration: none;
        font-size: 14px;
        cursor: pointer;
        border: none;
        transition: background-color 0.3s;
    }

    .btn-sm {
        padding: 4px 8px;
        font-size: 12px;
    }

    .btn-primary {
        background-color: #007bff;
        color: #fff;
    }

    .btn-primary:hover {
        background-color: #0056b3;
    }

    .btn-success {
        background-color: #28a745;
        color: #fff;
    }

    .btn-success:hover {
        background-color: #218838;
    }

    .btn-danger {
        background-color: #dc3545;
        color: #fff;
    }

    .btn-danger:hover {
        background-color: #c82333;
    }

    .btn-info {
        background-color: #17a2b8;
        color: #fff;
    }

    .btn-info:hover {
        background-color: #138496;
    }

    .btn-secondary {
        background-color: #6c757d;
        color: #fff;
    }

    .btn-secondary:hover {
        background-color: #5a6268;
    }

    .modal {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
        z-index: 1000;
    }

    .modal-dialog {
        position: relative;
        width: 500px;
        margin: 50px auto;
    }

    .modal-content {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    }

    .modal-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .modal-title {
        margin: 0;
        font-size: 18px;
    }

    .close {
        font-size: 24px;
        font-weight: bold;
        border: none;
        background: none;
        cursor: pointer;
    }

    .modal-body {
        padding: 15px;
    }

    .modal-footer {
        padding: 15px;
        border-top: 1px solid #e9ecef;
        text-align: right;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: bold;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 8px 12px;
        font-size: 14px;
        line-height: 1.5;
        border: 1px solid #ced4da;
        border-radius: 4px;
        transition: border-color 0.3s;
    }

    .form-control:focus {
        border-color: #80bdff;
        outline: 0;
        box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-danger {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }
</style>

<script>
    function showAddTaskModal() {
        document.getElementById('addTaskModal').style.display = 'block';
    }

    function showCompletionModal(taskId) {
        document.getElementById('completion_task_id').value = taskId;
        document.getElementById('completionModal').style.display = 'block';
    }

    function closeModal(modalId) {
        document.getElementById(modalId).style.display = 'none';
    }

    function submitAddTaskForm() {
        if (validateAddTaskForm()) {
            document.getElementById('addTaskForm').submit();
        }
    }

    function submitCompletionForm() {
        document.getElementById('completionForm').submit();
    }

    function validateAddTaskForm() {
        const form = document.getElementById('addTaskForm');
        if (!form.room_id.value) {
            alert('请选择房间');
            return false;
        }
        if (!form.scheduled_date.value) {
            alert('请选择计划日期');
            return false;
        }
        return true;
    }

    function updateTaskStatus(taskId, status) {
        if (confirm('确定要' + (status == 'cancelled' ? '取消' : '开始') + '该任务吗？')) {
            const form = document.createElement('form');
            form.method = 'POST';

            const taskIdInput = document.createElement('input');
            taskIdInput.type = 'hidden';
            taskIdInput.name = 'task_id';
            taskIdInput.value = taskId;

            const statusInput = document.createElement('input');
            statusInput.type = 'hidden';
            statusInput.name = 'status';
            statusInput.value = status;

            const updateInput = document.createElement('input');
            updateInput.type = 'hidden';
            updateInput.name = 'update_status';
            updateInput.value = '1';

            form.appendChild(taskIdInput);
            form.appendChild(statusInput);
            form.appendChild(updateInput);

            document.body.appendChild(form);
            form.submit();
        }
    }

    function viewTaskDetails(taskId) {
        // TODO: 实现查看任务详情功能
        // 显示保洁员id
        alert('保洁员id: ' + taskId);
    }

    // 点击模态框外部关闭
    window.onclick = function(event) {
        if (event.target.className === 'modal') {
            event.target.style.display = 'none';
        }
    }
</script>