<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 获取今日待处理的清洁任务数量
$today = date('Y-m-d');
$sql = "SELECT COUNT(*) as count FROM cleaning_tasks WHERE scheduled_date = ? AND status IN ('pending', 'in_progress')";
$stmt = $conn->prepare($sql);
$stmt->bind_param("s", $today);
$stmt->execute();
$result = $stmt->get_result();
$pending_cleaning = $result->fetch_assoc()['count'];

// 获取待处理的维修工单数量
$sql = "SELECT COUNT(*) as count FROM maintenance_records WHERE status IN ('reported', 'assigned', 'in_progress')";
$result = mysqli_query($conn, $sql);
$pending_maintenance = mysqli_fetch_assoc($result)['count'];

// 获取本月能耗统计
$first_day = date('Y-m-01');
$last_day = date('Y-m-t');
$sql = "SELECT 
            utility_type,
            SUM(consumption) as total_consumption,
            SUM(cost) as total_cost
        FROM utility_usage 
        WHERE reading_date BETWEEN ? AND ?
        GROUP BY utility_type";
$stmt = $conn->prepare($sql);
$stmt->bind_param("ss", $first_day, $last_day);
$stmt->execute();
$utility_stats = $stmt->get_result();

// 获取需要维护的设备数量
$sql = "SELECT COUNT(*) as count FROM equipments WHERE next_maintenance_date <= CURDATE() AND status = 'operational'";
$result = mysqli_query($conn, $sql);
$maintenance_due = mysqli_fetch_assoc($result)['count'];

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="dashboard-stats">
    <div class="stat-card">
        <div class="stat-card-header">
            <h3>今日待处理清洁任务</h3>
        </div>
        <div class="stat-card-body">
            <div class="stat-number"><?php echo $pending_cleaning; ?></div>
            <div class="stat-label">个任务</div>
        </div>
        <div class="stat-card-footer">
            <a href="index.php?page=cleaning_schedule" class="btn btn-primary">查看详情</a>
        </div>
    </div>

    <div class="stat-card">
        <div class="stat-card-header">
            <h3>待处理维修工单</h3>
        </div>
        <div class="stat-card-body">
            <div class="stat-number"><?php echo $pending_maintenance; ?></div>
            <div class="stat-label">个工单</div>
        </div>
        <div class="stat-card-footer">
            <a href="index.php?page=maintenance" class="btn btn-primary">查看详情</a>
        </div>
    </div>

    <div class="stat-card">
        <div class="stat-card-header">
            <h3>待维护设备</h3>
        </div>
        <div class="stat-card-body">
            <div class="stat-number"><?php echo $maintenance_due; ?></div>
            <div class="stat-label">台设备</div>
        </div>
        <div class="stat-card-footer">
            <a href="index.php?page=maintenance" class="btn btn-primary">查看详情</a>
        </div>
    </div>
</div>

<div class="dashboard-charts">
    <div class="chart-card">
        <div class="chart-card-header">
            <h3>本月能耗统计</h3>
        </div>
        <div class="chart-card-body">
            <table class="data-table">
                <thead>
                    <tr>
                        <th>能耗类型</th>
                        <th>消耗量</th>
                        <th>费用(元)</th>
                    </tr>
                </thead>
                <tbody>
                    <?php while ($row = mysqli_fetch_assoc($utility_stats)): ?>
                        <tr>
                            <td>
                                <?php
                                switch ($row['utility_type']) {
                                    case 'electricity':
                                        echo '电';
                                        $unit = 'kWh';
                                        break;
                                    case 'water':
                                        echo '水';
                                        $unit = '吨';
                                        break;
                                    case 'gas':
                                        echo '气';
                                        $unit = '立方米';
                                        break;
                                    default:
                                        echo '其他';
                                        $unit = '';
                                }
                                ?>
                            </td>
                            <td><?php echo number_format($row['total_consumption'], 2) . ' ' . $unit; ?></td>
                            <td><?php echo number_format($row['total_cost'], 2); ?></td>
                        </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        </div>
        <div class="chart-card-footer">
            <a href="index.php?page=utility" class="btn btn-primary">查看详情</a>
        </div>
    </div>
</div>

<style>
    .dashboard-stats {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
        gap: 20px;
        margin-bottom: 20px;
    }

    .stat-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
    }

    .stat-card-header h3 {
        margin: 0;
        font-size: 16px;
        color: #666;
    }

    .stat-card-body {
        padding: 20px 0;
        text-align: center;
    }

    .stat-number {
        font-size: 36px;
        font-weight: bold;
        color: #333;
    }

    .stat-label {
        font-size: 14px;
        color: #666;
        margin-top: 5px;
    }

    .stat-card-footer {
        text-align: center;
    }

    .dashboard-charts {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(400px, 1fr));
        gap: 20px;
    }

    .chart-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
    }

    .chart-card-header h3 {
        margin: 0;
        font-size: 16px;
        color: #666;
    }

    .chart-card-body {
        padding: 20px 0;
    }

    .chart-card-footer {
        text-align: right;
        padding-top: 10px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        font-weight: bold;
        background-color: #f8f9fa;
    }

    .btn {
        display: inline-block;
        padding: 8px 16px;
        border-radius: 4px;
        text-decoration: none;
        font-size: 14px;
        transition: background-color 0.3s;
    }

    .btn-primary {
        background-color: #007bff;
        color: #fff;
        border: none;
    }

    .btn-primary:hover {
        background-color: #0056b3;
    }
</style>