<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 获取设备列表
$equipment_sql = "SELECT id, name, location FROM equipments WHERE status = 'operational'";
$equipment_result = mysqli_query($conn, $equipment_sql);
$equipments = [];
while ($row = mysqli_fetch_assoc($equipment_result)) {
    $equipments[] = $row;
}

// 获取房间列表
$room_sql = "SELECT id, room_number FROM rooms";
$room_result = mysqli_query($conn, $room_sql);
$rooms = [];
while ($row = mysqli_fetch_assoc($room_result)) {
    $rooms[] = $row;
}

// 处理提交维修申请
if (isset($_POST['submit_maintenance'])) {
    $maintenance_type = $_POST['maintenance_type'];
    $equipment_id = ($maintenance_type === 'equipment' && !empty($_POST['equipment_id'])) ? $_POST['equipment_id'] : null;
    $room_id = ($maintenance_type === 'room' && !empty($_POST['room_id'])) ? $_POST['room_id'] : null;
    $issue_description = $_POST['issue_description'];
    $priority = $_POST['priority'];
    $reported_date = date('Y-m-d H:i:s');

    // 验证设备ID是否存在
    if ($maintenance_type === 'equipment' && $equipment_id) {
        $check_equipment = "SELECT id FROM equipments WHERE id = ? AND status = 'operational'";
        $stmt = $conn->prepare($check_equipment);
        $stmt->bind_param("i", $equipment_id);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result->num_rows === 0) {
            $error_message = "选择的设备不存在或已停用";
            $equipment_id = null;
        }
    }

    // 验证房间ID是否存在
    if ($maintenance_type === 'room' && $room_id) {
        $check_room = "SELECT id FROM rooms WHERE id = ?";
        $stmt = $conn->prepare($check_room);
        $stmt->bind_param("i", $room_id);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result->num_rows === 0) {
            $error_message = "选择的房间不存在";
            $room_id = null;
        }
    }

    // 如果没有错误，继续插入记录
    if (!isset($error_message)) {
        $sql = "INSERT INTO maintenance_records (equipment_id, room_id, issue_description, priority, reported_by, reported_date, status) 
                VALUES (?, ?, ?, ?, ?, ?, 'reported')";
        $stmt = $conn->prepare($sql);
        if ($stmt === false) {
            $error_message = "准备SQL语句失败: " . $conn->error;
        } else {
            $stmt->bind_param("iissis", $equipment_id, $room_id, $issue_description, $priority, $_SESSION['user_id'], $reported_date);

            if ($stmt->execute()) {
                $success_message = "维修申请提交成功";
            } else {
                $error_message = "维修申请提交失败: " . $stmt->error;
            }
        }
    }
}

// 处理更新维修状态
if (isset($_POST['update_status'])) {
    $record_id = $_POST['record_id'];
    $new_status = $_POST['new_status'];
    $assigned_to = isset($_POST['assigned_to']) ? $_POST['assigned_to'] : null;
    $solution = isset($_POST['solution']) ? $_POST['solution'] : '';
    $cost = isset($_POST['cost']) ? $_POST['cost'] : null;
    $completion_date = ($new_status == 'completed') ? date('Y-m-d H:i:s') : null;
    $start_date = ($new_status == 'in_progress') ? date('Y-m-d H:i:s') : null;

    $sql = "UPDATE maintenance_records SET 
            status = ?,
            assigned_to = ?,
            solution = ?,
            cost = ?,
            completion_date = ?,
            start_date = ?
            WHERE id = ?";

    $stmt = $conn->prepare($sql);
    if ($stmt === false) {
        $error_message = "准备SQL语句失败: " . $conn->error;
    } else {
        $stmt->bind_param("sissssi", $new_status, $assigned_to, $solution, $cost, $completion_date, $start_date, $record_id);

        if ($stmt->execute()) {
            $success_message = "维修状态更新成功";
        } else {
            $error_message = "维修状态更新失败: " . $stmt->error;
        }
    }
}

// 获取维修人员列表
$maintenance_staff_sql = "SELECT id, name FROM users WHERE role = 'maintenance' AND status = 'active'";
$maintenance_staff_result = mysqli_query($conn, $maintenance_staff_sql);
$maintenance_staff = [];
while ($row = mysqli_fetch_assoc($maintenance_staff_result)) {
    $maintenance_staff[] = $row;
}

// 获取维修记录列表
$filter_status = isset($_GET['status']) ? $_GET['status'] : '';
$filter_priority = isset($_GET['priority']) ? $_GET['priority'] : '';
$filter_date_from = isset($_GET['date_from']) ? $_GET['date_from'] : date('Y-m-d', strtotime('-30 days'));
$filter_date_to = isset($_GET['date_to']) ? $_GET['date_to'] : date('Y-m-d');

$sql = "SELECT m.*, 
        u1.name as reporter_name,
        u2.name as maintainer_name,
        e.name as equipment_name,
        e.location as equipment_location,
        r.room_number
        FROM maintenance_records m
        LEFT JOIN users u1 ON m.reported_by = u1.id
        LEFT JOIN users u2 ON m.assigned_to = u2.id
        LEFT JOIN equipments e ON m.equipment_id = e.id
        LEFT JOIN rooms r ON m.room_id = r.id
        WHERE DATE(m.reported_date) BETWEEN ? AND ?";

$params = [$filter_date_from, $filter_date_to];
$types = "ss";

if (!empty($filter_status)) {
    $sql .= " AND m.status = ?";
    $params[] = $filter_status;
    $types .= "s";
}

if (!empty($filter_priority)) {
    $sql .= " AND m.priority = ?";
    $params[] = $filter_priority;
    $types .= "s";
}

$sql .= " ORDER BY 
          CASE m.priority 
            WHEN 'urgent' THEN 1 
            WHEN 'high' THEN 2 
            WHEN 'medium' THEN 3 
            WHEN 'low' THEN 4 
          END,
          m.reported_date DESC";

$stmt = $conn->prepare($sql);
if ($stmt === false) {
    $error_message = "准备SQL语句失败: " . $conn->error;
} else {
    $stmt->bind_param($types, ...$params);
    $stmt->execute();
    $result = $stmt->get_result();
    $maintenance_records = [];
    while ($row = $result->fetch_assoc()) {
        $maintenance_records[] = $row;
    }
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="action-buttons">
        <button class="btn btn-primary" onclick="showMaintenanceModal()">提交维修申请</button>
    </div>

    <!-- 筛选器 -->
    <div class="filter-section">
        <form method="get" class="filter-form">
            <div class="form-group">
                <label>开始日期：</label>
                <input type="date" name="date_from" value="<?php echo $filter_date_from; ?>" class="form-control">
            </div>
            <div class="form-group">
                <label>结束日期：</label>
                <input type="date" name="date_to" value="<?php echo $filter_date_to; ?>" class="form-control">
            </div>
            <div class="form-group">
                <label>状态：</label>
                <select name="status" class="form-control">
                    <option value="">全部状态</option>
                    <option value="reported" <?php echo $filter_status == 'reported' ? 'selected' : ''; ?>>已报修</option>
                    <option value="assigned" <?php echo $filter_status == 'assigned' ? 'selected' : ''; ?>>已分配</option>
                    <option value="in_progress" <?php echo $filter_status == 'in_progress' ? 'selected' : ''; ?>>处理中</option>
                    <option value="completed" <?php echo $filter_status == 'completed' ? 'selected' : ''; ?>>已完成</option>
                    <option value="cancelled" <?php echo $filter_status == 'cancelled' ? 'selected' : ''; ?>>已取消</option>
                </select>
            </div>
            <div class="form-group">
                <label>优先级：</label>
                <select name="priority" class="form-control">
                    <option value="">全部优先级</option>
                    <option value="urgent" <?php echo $filter_priority == 'urgent' ? 'selected' : ''; ?>>紧急</option>
                    <option value="high" <?php echo $filter_priority == 'high' ? 'selected' : ''; ?>>高</option>
                    <option value="medium" <?php echo $filter_priority == 'medium' ? 'selected' : ''; ?>>中</option>
                    <option value="low" <?php echo $filter_priority == 'low' ? 'selected' : ''; ?>>低</option>
                </select>
            </div>
            <button type="submit" class="btn btn-primary">筛选</button>
        </form>
    </div>

    <!-- 维修记录列表 -->
    <div class="records-list">
        <table class="data-table">
            <thead>
                <tr>
                    <th>设备/房间</th>
                    <th>位置</th>
                    <th>问题描述</th>
                    <th>优先级</th>
                    <th>状态</th>
                    <th>报修人</th>
                    <th>维修人员</th>
                    <th>报修时间</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($maintenance_records as $record): ?>
                    <tr>
                        <td>
                            <?php
                            if ($record['equipment_name']) {
                                echo htmlspecialchars($record['equipment_name']);
                            } elseif ($record['room_number']) {
                                echo '房间: ' . htmlspecialchars($record['room_number']);
                            }
                            ?>
                        </td>
                        <td>
                            <?php
                            if ($record['equipment_location']) {
                                echo htmlspecialchars($record['equipment_location']);
                            } elseif ($record['room_number']) {
                                echo htmlspecialchars($record['room_number']);
                            }
                            ?>
                        </td>
                        <td><?php echo htmlspecialchars($record['issue_description']); ?></td>
                        <td>
                            <span class="badge badge-<?php
                                                        echo $record['priority'] == 'urgent' ? 'danger' : ($record['priority'] == 'high' ? 'warning' : ($record['priority'] == 'medium' ? 'info' : 'secondary'));
                                                        ?>">
                                <?php
                                echo $record['priority'] == 'urgent' ? '紧急' : ($record['priority'] == 'high' ? '高' : ($record['priority'] == 'medium' ? '中' : '低'));
                                ?>
                            </span>
                        </td>
                        <td>
                            <span class="badge badge-<?php
                                                        echo $record['status'] == 'reported' ? 'warning' : ($record['status'] == 'assigned' ? 'info' : ($record['status'] == 'in_progress' ? 'primary' : ($record['status'] == 'completed' ? 'success' : 'secondary')));
                                                        ?>">
                                <?php
                                echo $record['status'] == 'reported' ? '已报修' : ($record['status'] == 'assigned' ? '已分配' : ($record['status'] == 'in_progress' ? '处理中' : ($record['status'] == 'completed' ? '已完成' : '已取消')));
                                ?>
                            </span>
                        </td>
                        <td><?php echo htmlspecialchars($record['reporter_name']); ?></td>
                        <td><?php echo $record['maintainer_name'] ? htmlspecialchars($record['maintainer_name']) : '未分配'; ?></td>
                        <td><?php echo date('Y-m-d H:i', strtotime($record['reported_date'])); ?></td>
                        <td>
                            <button class="btn btn-sm btn-info" onclick="viewMaintenanceDetails(<?php echo $record['id']; ?>)">详情</button>
                            <?php if ($record['status'] != 'completed' && $record['status'] != 'cancelled'): ?>
                                <button class="btn btn-sm btn-success" onclick="showUpdateStatusModal(<?php echo $record['id']; ?>)">更新状态</button>
                            <?php endif; ?>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<!-- 提交维修申请模态框 -->
<div class="modal" id="maintenanceModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">提交维修申请</h4>
                <button type="button" class="close" onclick="closeModal('maintenanceModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form id="maintenanceForm" method="post">
                    <div class="form-group">
                        <label>维修对象</label>
                        <select class="form-control" name="maintenance_type" onchange="toggleMaintenanceType(this.value)">
                            <option value="equipment">设备</option>
                            <option value="room">房间</option>
                        </select>
                    </div>

                    <div class="form-group" id="equipmentGroup">
                        <label>选择设备</label>
                        <select class="form-control" name="equipment_id">
                            <option value="">请选择设备</option>
                            <?php foreach ($equipments as $equipment): ?>
                                <option value="<?php echo $equipment['id']; ?>">
                                    <?php echo htmlspecialchars($equipment['name']) . ' (' . htmlspecialchars($equipment['location']) . ')'; ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group" id="roomGroup" style="display: none;">
                        <label>选择房间</label>
                        <select class="form-control" name="room_id">
                            <option value="">请选择房间</option>
                            <?php foreach ($rooms as $room): ?>
                                <option value="<?php echo $room['id']; ?>">
                                    <?php echo htmlspecialchars($room['room_number']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>问题描述</label>
                        <textarea class="form-control" name="issue_description" rows="3" required></textarea>
                    </div>

                    <div class="form-group">
                        <label>优先级</label>
                        <select class="form-control" name="priority" required>
                            <option value="low">低</option>
                            <option value="medium" selected>中</option>
                            <option value="high">高</option>
                            <option value="urgent">紧急</option>
                        </select>
                    </div>

                    <input type="hidden" name="submit_maintenance" value="1">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('maintenanceModal')">取消</button>
                <button type="button" class="btn btn-primary" onclick="submitMaintenanceForm()">提交</button>
            </div>
        </div>
    </div>
</div>

<!-- 更新状态模态框 -->
<div class="modal" id="updateStatusModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">更新维修状态</h4>
                <button type="button" class="close" onclick="closeModal('updateStatusModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form id="updateStatusForm" method="post">
                    <div class="form-group">
                        <label>状态</label>
                        <select class="form-control" name="new_status" required onchange="toggleStatusFields(this.value)">
                            <option value="reported">已报修</option>
                            <option value="assigned">已分配</option>
                            <option value="in_progress">处理中</option>
                            <option value="completed">已完成</option>
                            <option value="cancelled">已取消</option>
                        </select>
                    </div>

                    <div class="form-group" id="assignedToGroup">
                        <label>分配维修人员</label>
                        <select class="form-control" name="assigned_to">
                            <option value="">选择维修人员</option>
                            <?php foreach ($maintenance_staff as $staff): ?>
                                <option value="<?php echo $staff['id']; ?>"><?php echo htmlspecialchars($staff['name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group" id="solutionGroup" style="display: none;">
                        <label>解决方案</label>
                        <textarea class="form-control" name="solution" rows="3"></textarea>
                    </div>

                    <div class="form-group" id="costGroup" style="display: none;">
                        <label>维修费用</label>
                        <input type="number" class="form-control" name="cost" step="0.01" min="0">
                    </div>

                    <input type="hidden" name="record_id" id="update_record_id">
                    <input type="hidden" name="update_status" value="1">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('updateStatusModal')">取消</button>
                <button type="button" class="btn btn-primary" onclick="submitUpdateStatusForm()">更新</button>
            </div>
        </div>
    </div>
</div>

<!-- 查看详情模态框 -->
<div class="modal" id="detailsModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">维修详情</h4>
                <button type="button" class="close" onclick="closeModal('detailsModal')">&times;</button>
            </div>
            <div class="modal-body" id="detailsContent">
                <!-- 详情内容将通过JavaScript动态填充 -->
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('detailsModal')">关闭</button>
            </div>
        </div>
    </div>
</div>

<style>
    .content {
        padding: 20px;
    }

    .filter-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        margin: 20px 0;
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        align-items: flex-end;
    }

    .filter-form .form-group {
        flex: 1;
        min-width: 200px;
    }

    .records-list {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        margin-top: 20px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .badge {
        display: inline-block;
        padding: 0.25em 0.6em;
        font-size: 75%;
        font-weight: 700;
        line-height: 1;
        text-align: center;
        white-space: nowrap;
        vertical-align: baseline;
        border-radius: 0.25rem;
    }

    .badge-success {
        color: #fff;
        background-color: #28a745;
    }

    .badge-warning {
        color: #212529;
        background-color: #ffc107;
    }

    .badge-danger {
        color: #fff;
        background-color: #dc3545;
    }

    .badge-info {
        color: #fff;
        background-color: #17a2b8;
    }

    .badge-secondary {
        color: #fff;
        background-color: #6c757d;
    }

    .modal {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
        z-index: 1000;
    }

    .modal-dialog {
        position: relative;
        width: 500px;
        margin: 50px auto;
    }

    .modal-content {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    }

    .modal-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .modal-title {
        margin: 0;
        font-size: 18px;
    }

    .close {
        font-size: 24px;
        font-weight: bold;
        border: none;
        background: none;
        cursor: pointer;
    }

    .modal-body {
        padding: 15px;
    }

    .modal-footer {
        padding: 15px;
        border-top: 1px solid #e9ecef;
        text-align: right;
    }

    .btn {
        display: inline-block;
        padding: 8px 16px;
        border-radius: 4px;
        text-decoration: none;
        font-size: 14px;
        cursor: pointer;
        border: none;
        transition: background-color 0.3s;
    }

    .btn-sm {
        padding: 5px 10px;
        font-size: 12px;
    }

    .btn-primary {
        background-color: #007bff;
        color: #fff;
    }

    .btn-primary:hover {
        background-color: #0056b3;
    }

    .btn-secondary {
        background-color: #6c757d;
        color: #fff;
    }

    .btn-secondary:hover {
        background-color: #5a6268;
    }

    .btn-success {
        background-color: #28a745;
        color: #fff;
    }

    .btn-success:hover {
        background-color: #218838;
    }

    .btn-info {
        background-color: #17a2b8;
        color: #fff;
    }

    .btn-info:hover {
        background-color: #138496;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-danger {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }

    .detail-item {
        margin-bottom: 15px;
    }

    .detail-label {
        font-weight: bold;
        display: block;
        margin-bottom: 5px;
    }

    .detail-value {
        padding-left: 10px;
    }
</style>

<script>
    function showMaintenanceModal() {
        document.getElementById('maintenanceModal').style.display = 'block';
    }

    function closeModal(modalId) {
        document.getElementById(modalId).style.display = 'none';
    }

    function toggleMaintenanceType(type) {
        const equipmentGroup = document.getElementById('equipmentGroup');
        const roomGroup = document.getElementById('roomGroup');

        if (type === 'equipment') {
            equipmentGroup.style.display = 'block';
            roomGroup.style.display = 'none';
            document.getElementsByName('room_id')[0].value = '';
        } else {
            equipmentGroup.style.display = 'none';
            roomGroup.style.display = 'block';
            document.getElementsByName('equipment_id')[0].value = '';
        }
    }

    function submitMaintenanceForm() {
        const form = document.getElementById('maintenanceForm');
        const maintenanceType = form.maintenance_type.value;

        if (maintenanceType === 'equipment' && !form.equipment_id.value) {
            alert('请选择设备');
            return false;
        }

        if (maintenanceType === 'room' && !form.room_id.value) {
            alert('请选择房间');
            return false;
        }

        if (!form.issue_description.value) {
            alert('请输入问题描述');
            return false;
        }

        form.submit();
    }

    function showUpdateStatusModal(recordId) {
        document.getElementById('update_record_id').value = recordId;
        document.getElementById('updateStatusModal').style.display = 'block';
    }

    function toggleStatusFields(status) {
        const assignedToGroup = document.getElementById('assignedToGroup');
        const solutionGroup = document.getElementById('solutionGroup');
        const costGroup = document.getElementById('costGroup');

        if (status === 'assigned' || status === 'in_progress') {
            assignedToGroup.style.display = 'block';
            solutionGroup.style.display = 'none';
            costGroup.style.display = 'none';
        } else if (status === 'completed') {
            assignedToGroup.style.display = 'block';
            solutionGroup.style.display = 'block';
            costGroup.style.display = 'block';
        } else {
            assignedToGroup.style.display = 'none';
            solutionGroup.style.display = 'none';
            costGroup.style.display = 'none';
        }
    }

    function submitUpdateStatusForm() {
        const form = document.getElementById('updateStatusForm');
        const status = form.new_status.value;

        if ((status === 'assigned' || status === 'in_progress') && !form.assigned_to.value) {
            alert('请选择维修人员');
            return false;
        }

        if (status === 'completed') {
            if (!form.assigned_to.value) {
                alert('请选择维修人员');
                return false;
            }
            if (!form.solution.value) {
                alert('请填写解决方案');
                return false;
            }
        }

        form.submit();
    }

    function viewMaintenanceDetails(recordId) {
        // 在实际应用中，这里应该通过AJAX获取详细信息
        // 为了简化，我们假设从页面上已有的数据中获取
        const records = <?php echo json_encode($maintenance_records); ?>;
        const record = records.find(r => r.id == recordId);

        if (!record) {
            alert('未找到记录');
            return;
        }

        let statusText = '';
        switch (record.status) {
            case 'reported':
                statusText = '已报修';
                break;
            case 'assigned':
                statusText = '已分配';
                break;
            case 'in_progress':
                statusText = '处理中';
                break;
            case 'completed':
                statusText = '已完成';
                break;
            case 'cancelled':
                statusText = '已取消';
                break;
        }

        let priorityText = '';
        switch (record.priority) {
            case 'urgent':
                priorityText = '紧急';
                break;
            case 'high':
                priorityText = '高';
                break;
            case 'medium':
                priorityText = '中';
                break;
            case 'low':
                priorityText = '低';
                break;
        }

        let detailsHtml = `
            <div class="detail-item">
                <div class="detail-label">维修对象:</div>
                <div class="detail-value">
                    ${record.equipment_name ? record.equipment_name : ('房间: ' + record.room_number)}
                </div>
            </div>
            <div class="detail-item">
                <div class="detail-label">位置:</div>
                <div class="detail-value">
                    ${record.equipment_location ? record.equipment_location : record.room_number}
                </div>
            </div>
            <div class="detail-item">
                <div class="detail-label">问题描述:</div>
                <div class="detail-value">${record.issue_description}</div>
            </div>
            <div class="detail-item">
                <div class="detail-label">优先级:</div>
                <div class="detail-value">${priorityText}</div>
            </div>
            <div class="detail-item">
                <div class="detail-label">状态:</div>
                <div class="detail-value">${statusText}</div>
            </div>
            <div class="detail-item">
                <div class="detail-label">报修人:</div>
                <div class="detail-value">${record.reporter_name}</div>
            </div>
            <div class="detail-item">
                <div class="detail-label">报修时间:</div>
                <div class="detail-value">${new Date(record.reported_date).toLocaleString()}</div>
            </div>
        `;

        if (record.maintainer_name) {
            detailsHtml += `
                <div class="detail-item">
                    <div class="detail-label">维修人员:</div>
                    <div class="detail-value">${record.maintainer_name}</div>
                </div>
            `;
        }

        if (record.solution) {
            detailsHtml += `
                <div class="detail-item">
                    <div class="detail-label">解决方案:</div>
                    <div class="detail-value">${record.solution}</div>
                </div>
            `;
        }

        if (record.cost) {
            detailsHtml += `
                <div class="detail-item">
                    <div class="detail-label">维修费用:</div>
                    <div class="detail-value">￥${record.cost}</div>
                </div>
            `;
        }

        if (record.start_date) {
            detailsHtml += `
                <div class="detail-item">
                    <div class="detail-label">开始时间:</div>
                    <div class="detail-value">${new Date(record.start_date).toLocaleString()}</div>
                </div>
            `;
        }

        if (record.completion_date) {
            detailsHtml += `
                <div class="detail-item">
                    <div class="detail-label">完成时间:</div>
                    <div class="detail-value">${new Date(record.completion_date).toLocaleString()}</div>
                </div>
            `;
        }

        document.getElementById('detailsContent').innerHTML = detailsHtml;
        document.getElementById('detailsModal').style.display = 'block';
    }

    // 点击模态框外部关闭
    window.onclick = function(event) {
        if (event.target.className === 'modal') {
            event.target.style.display = 'none';
        }
    }
</script>