<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 处理添加能耗记录请求
if (isset($_POST['add_utility'])) {
    $utility_type = $_POST['utility_type'];
    $reading_date = $_POST['reading_date'];
    $meter_reading = $_POST['meter_reading'];
    $cost = $_POST['cost'];
    $notes = $_POST['notes'];

    // 获取上次读数以计算消耗量
    $sql = "SELECT meter_reading FROM utility_usage 
            WHERE utility_type = ? AND reading_date < ? 
            ORDER BY reading_date DESC LIMIT 1";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("ss", $utility_type, $reading_date);
    $stmt->execute();
    $result = $stmt->get_result();
    $last_reading = $result->fetch_assoc();

    // 计算消耗量
    $consumption = $last_reading ? $meter_reading - $last_reading['meter_reading'] : $meter_reading;

    // 插入新记录
    $sql = "INSERT INTO utility_usage (utility_type, reading_date, meter_reading, consumption, cost, notes, created_by) 
            VALUES (?, ?, ?, ?, ?, ?, ?)";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("ssdddsi", $utility_type, $reading_date, $meter_reading, $consumption, $cost, $notes, $_SESSION['user_id']);

    if ($stmt->execute()) {
        $success_message = "能耗记录添加成功";
    } else {
        $error_message = "能耗记录添加失败: " . $stmt->error;
    }
}

// 获取统计时间范围
$start_date = $_GET['start_date'] ?? date('Y-m-01'); // 默认本月第一天
$end_date = $_GET['end_date'] ?? date('Y-m-t'); // 默认本月最后一天

// 获取能耗记录列表
$sql = "SELECT u.*, CONCAT(us.name, ' (ID:', us.id, ')') as recorder_name
        FROM utility_usage u
        LEFT JOIN users us ON u.created_by = us.id
        WHERE reading_date BETWEEN ? AND ?
        ORDER BY reading_date DESC, utility_type";
$stmt = $conn->prepare($sql);
$stmt->bind_param("ss", $start_date, $end_date);
$stmt->execute();
$result = $stmt->get_result();
$utility_records = [];
while ($row = $result->fetch_assoc()) {
    $utility_records[] = $row;
}

// 获取能耗统计数据
$sql = "SELECT 
            utility_type,
            COUNT(*) as record_count,
            SUM(consumption) as total_consumption,
            AVG(consumption) as avg_consumption,
            SUM(cost) as total_cost,
            AVG(cost) as avg_cost
        FROM utility_usage
        WHERE reading_date BETWEEN ? AND ?
        GROUP BY utility_type";
$stmt = $conn->prepare($sql);
$stmt->bind_param("ss", $start_date, $end_date);
$stmt->execute();
$result = $stmt->get_result();
$utility_stats = [];
while ($row = $result->fetch_assoc()) {
    $utility_stats[$row['utility_type']] = $row;
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="action-buttons">
        <button class="btn btn-primary" onclick="showAddUtilityModal()">添加能耗记录</button>
    </div>

    <!-- 统计信息卡片 -->
    <div class="stats-container">
        <?php
        $utility_types = [
            'electricity' => ['name' => '电', 'unit' => 'kWh'],
            'water' => ['name' => '水', 'unit' => '吨'],
            'gas' => ['name' => '气', 'unit' => '立方米']
        ];

        foreach ($utility_types as $type => $info):
            $stats = $utility_stats[$type] ?? null;
        ?>
            <div class="stat-card">
                <div class="stat-card-header">
                    <h3><?php echo $info['name']; ?>能耗统计</h3>
                </div>
                <div class="stat-card-body">
                    <?php if ($stats): ?>
                        <div class="stat-item">
                            <span class="stat-label">总消耗量：</span>
                            <span class="stat-value"><?php echo number_format($stats['total_consumption'], 2) . ' ' . $info['unit']; ?></span>
                        </div>
                        <div class="stat-item">
                            <span class="stat-label">平均消耗量：</span>
                            <span class="stat-value"><?php echo number_format($stats['avg_consumption'], 2) . ' ' . $info['unit']; ?></span>
                        </div>
                        <div class="stat-item">
                            <span class="stat-label">总费用：</span>
                            <span class="stat-value"><?php echo number_format($stats['total_cost'], 2); ?> 元</span>
                        </div>
                        <div class="stat-item">
                            <span class="stat-label">平均费用：</span>
                            <span class="stat-value"><?php echo number_format($stats['avg_cost'], 2); ?> 元</span>
                        </div>
                    <?php else: ?>
                        <div class="no-data">暂无数据</div>
                    <?php endif; ?>
                </div>
            </div>
        <?php endforeach; ?>
    </div>

    <!-- 日期筛选 -->
    <div class="filter-section">
        <form method="get" class="date-filter-form">
            <div class="form-group">
                <label>起始日期：</label>
                <input type="date" name="start_date" value="<?php echo $start_date; ?>" class="form-control">
            </div>
            <div class="form-group">
                <label>结束日期：</label>
                <input type="date" name="end_date" value="<?php echo $end_date; ?>" class="form-control">
            </div>
            <button type="submit" class="btn btn-primary">筛选</button>
        </form>
    </div>

    <!-- 能耗记录列表 -->
    <div class="records-list">
        <table class="data-table">
            <thead>
                <tr>
                    <th>类型</th>
                    <th>读数日期</th>
                    <th>表读数</th>
                    <th>消耗量</th>
                    <th>费用(元)</th>
                    <th>记录人</th>
                    <th>备注</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($utility_records as $record): ?>
                    <tr>
                        <td>
                            <?php
                            switch ($record['utility_type']) {
                                case 'electricity':
                                    echo '电';
                                    $unit = 'kWh';
                                    break;
                                case 'water':
                                    echo '水';
                                    $unit = '吨';
                                    break;
                                case 'gas':
                                    echo '气';
                                    $unit = '立方米';
                                    break;
                                default:
                                    echo '其他';
                                    $unit = '';
                            }
                            ?>
                        </td>
                        <td><?php echo date('Y-m-d', strtotime($record['reading_date'])); ?></td>
                        <td><?php echo number_format($record['meter_reading'], 2) . ' ' . $unit; ?></td>
                        <td><?php echo number_format($record['consumption'], 2) . ' ' . $unit; ?></td>
                        <td><?php echo number_format($record['cost'], 2); ?></td>
                        <td><?php echo htmlspecialchars($record['recorder_name']); ?></td>
                        <td><?php echo htmlspecialchars($record['notes']); ?></td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<!-- 添加能耗记录模态框 -->
<div class="modal" id="addUtilityModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">添加能耗记录</h4>
                <button type="button" class="close" onclick="closeModal('addUtilityModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form id="addUtilityForm" method="post">
                    <div class="form-group">
                        <label>能耗类型</label>
                        <select class="form-control" name="utility_type" required>
                            <option value="">请选择能耗类型</option>
                            <option value="electricity">电</option>
                            <option value="water">水</option>
                            <option value="gas">气</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>读数日期</label>
                        <input type="date" class="form-control" name="reading_date" required max="<?php echo date('Y-m-d'); ?>">
                    </div>

                    <div class="form-group">
                        <label>表读数</label>
                        <input type="number" class="form-control" name="meter_reading" required step="0.01" min="0">
                    </div>

                    <div class="form-group">
                        <label>费用(元)</label>
                        <input type="number" class="form-control" name="cost" required step="0.01" min="0">
                    </div>

                    <div class="form-group">
                        <label>备注</label>
                        <textarea class="form-control" name="notes" rows="3"></textarea>
                    </div>

                    <input type="hidden" name="add_utility" value="1">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('addUtilityModal')">取消</button>
                <button type="button" class="btn btn-primary" onclick="submitAddUtilityForm()">添加</button>
            </div>
        </div>
    </div>
</div>

<style>
    .content {
        padding: 20px;
    }

    .stats-container {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
        gap: 20px;
        margin: 20px 0;
    }

    .stat-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
    }

    .stat-card-header h3 {
        margin: 0;
        font-size: 16px;
        color: #666;
    }

    .stat-card-body {
        padding: 15px 0;
    }

    .stat-item {
        margin: 10px 0;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .stat-label {
        color: #666;
    }

    .stat-value {
        font-weight: bold;
        color: #333;
    }

    .filter-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        margin: 20px 0;
    }

    .date-filter-form {
        display: flex;
        gap: 20px;
        align-items: flex-end;
    }

    .date-filter-form .form-group {
        flex: 1;
    }

    .records-list {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        margin-top: 20px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .no-data {
        text-align: center;
        color: #666;
        padding: 20px;
    }

    .modal {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
        z-index: 1000;
    }

    .modal-dialog {
        position: relative;
        width: 500px;
        margin: 50px auto;
    }

    .modal-content {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    }

    .modal-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .modal-title {
        margin: 0;
        font-size: 18px;
    }

    .close {
        font-size: 24px;
        font-weight: bold;
        border: none;
        background: none;
        cursor: pointer;
    }

    .modal-body {
        padding: 15px;
    }

    .modal-footer {
        padding: 15px;
        border-top: 1px solid #e9ecef;
        text-align: right;
    }

    .btn {
        display: inline-block;
        padding: 8px 16px;
        border-radius: 4px;
        text-decoration: none;
        font-size: 14px;
        cursor: pointer;
        border: none;
        transition: background-color 0.3s;
    }

    .btn-primary {
        background-color: #007bff;
        color: #fff;
    }

    .btn-primary:hover {
        background-color: #0056b3;
    }

    .btn-secondary {
        background-color: #6c757d;
        color: #fff;
    }

    .btn-secondary:hover {
        background-color: #5a6268;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-danger {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }
</style>

<script>
    function showAddUtilityModal() {
        document.getElementById('addUtilityModal').style.display = 'block';
    }

    function closeModal(modalId) {
        document.getElementById(modalId).style.display = 'none';
    }

    function submitAddUtilityForm() {
        if (validateAddUtilityForm()) {
            document.getElementById('addUtilityForm').submit();
        }
    }

    function validateAddUtilityForm() {
        const form = document.getElementById('addUtilityForm');
        if (!form.utility_type.value) {
            alert('请选择能耗类型');
            return false;
        }
        if (!form.reading_date.value) {
            alert('请选择读数日期');
            return false;
        }
        if (!form.meter_reading.value || form.meter_reading.value < 0) {
            alert('请输入有效的表读数');
            return false;
        }
        if (!form.cost.value || form.cost.value < 0) {
            alert('请输入有效的费用');
            return false;
        }
        return true;
    }

    // 点击模态框外部关闭
    window.onclick = function(event) {
        if (event.target.className === 'modal') {
            event.target.style.display = 'none';
        }
    }
</script>