<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
require_once '../../config/config.php';
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 获取今日入住统计
$today = date('Y-m-d');
$check_in_sql = "SELECT COUNT(*) as count FROM bookings WHERE check_in_date = ? AND status = 'checked_in'";
$stmt = $conn->prepare($check_in_sql);
$stmt->bind_param("s", $today);
$stmt->execute();
$today_check_in = $stmt->get_result()->fetch_assoc()['count'];

// 获取今日退房统计
$check_out_sql = "SELECT COUNT(*) as count FROM bookings WHERE check_out_date = ? AND status = 'checked_out'";
$stmt = $conn->prepare($check_out_sql);
$stmt->bind_param("s", $today);
$stmt->execute();
$today_check_out = $stmt->get_result()->fetch_assoc()['count'];

// 获取待处理发票数量
$invoice_sql = "SELECT COUNT(*) as count FROM invoices WHERE status = 'pending'";
$pending_invoices = mysqli_query($conn, $invoice_sql)->fetch_assoc()['count'];

// 获取最近的入住记录
$recent_checkins_sql = "SELECT b.*, r.room_number 
                       FROM bookings b
                       LEFT JOIN booking_rooms br ON b.id = br.booking_id
                       LEFT JOIN rooms r ON br.room_id = r.id
                       WHERE b.status = 'checked_in'
                       ORDER BY b.check_in_date DESC, b.created_at DESC
                       LIMIT 5";
$recent_checkins = mysqli_query($conn, $recent_checkins_sql);

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="dashboard">
    <!-- 统计卡片 -->
    <div class="stats-cards">
        <div class="stat-card">
            <div class="stat-card-header">今日入住</div>
            <div class="stat-card-value"><?php echo $today_check_in; ?></div>
            <div class="stat-card-footer">
                <a href="index.php?page=self_checkin" class="btn btn-sm">查看详情</a>
            </div>
        </div>

        <div class="stat-card">
            <div class="stat-card-header">今日退房</div>
            <div class="stat-card-value"><?php echo $today_check_out; ?></div>
            <div class="stat-card-footer">
                <a href="index.php?page=self_checkin" class="btn btn-sm">查看详情</a>
            </div>
        </div>

        <div class="stat-card">
            <div class="stat-card-header">待处理发票</div>
            <div class="stat-card-value"><?php echo $pending_invoices; ?></div>
            <div class="stat-card-footer">
                <a href="index.php?page=e_invoice" class="btn btn-sm">处理发票</a>
            </div>
        </div>
    </div>

    <!-- 快捷功能 -->
    <div class="quick-actions">
        <h3>快捷功能</h3>
        <div class="action-buttons">
            <a href="index.php?page=self_checkin" class="action-btn">
                <i class="fas fa-key"></i>
                <span>自助入住</span>
            </a>
            <a href="index.php?page=door_lock" class="action-btn">
                <i class="fas fa-lock"></i>
                <span>门锁管理</span>
            </a>
            <a href="index.php?page=face_recognition" class="action-btn">
                <i class="fas fa-user-check"></i>
                <span>人脸识别</span>
            </a>
            <a href="index.php?page=police_upload" class="action-btn">
                <i class="fas fa-upload"></i>
                <span>公安上传</span>
            </a>
            <a href="index.php?page=e_invoice" class="action-btn">
                <i class="fas fa-file-invoice"></i>
                <span>电子发票</span>
            </a>
        </div>
    </div>

    <!-- 最近入住记录 -->
    <div class="recent-records">
        <h3>最近入住记录</h3>
        <div class="table-responsive">
            <table class="data-table">
                <thead>
                    <tr>
                        <th>订单号</th>
                        <th>房间号</th>
                        <th>客人姓名</th>
                        <th>入住时间</th>
                        <th>预计退房</th>
                        <th>状态</th>
                    </tr>
                </thead>
                <tbody>
                    <?php while ($record = mysqli_fetch_assoc($recent_checkins)): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($record['booking_number']); ?></td>
                            <td><?php echo htmlspecialchars($record['room_number']); ?></td>
                            <td><?php echo htmlspecialchars($record['guest_name']); ?></td>
                            <td><?php echo date('Y-m-d H:i', strtotime($record['check_in_date'])); ?></td>
                            <td><?php echo date('Y-m-d', strtotime($record['check_out_date'])); ?></td>
                            <td>
                                <span class="badge badge-success">已入住</span>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<style>
    .dashboard {
        padding: 20px;
    }

    .stats-cards {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
        gap: 20px;
        margin-bottom: 30px;
    }

    .stat-card {
        background: #fff;
        border-radius: 8px;
        padding: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .stat-card-header {
        color: #666;
        font-size: 14px;
        margin-bottom: 10px;
    }

    .stat-card-value {
        font-size: 24px;
        font-weight: bold;
        color: #333;
        margin-bottom: 15px;
    }

    .stat-card-footer {
        text-align: right;
    }

    .quick-actions {
        background: #fff;
        border-radius: 8px;
        padding: 20px;
        margin-bottom: 30px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .quick-actions h3 {
        margin: 0 0 20px 0;
        color: #333;
    }

    .action-buttons {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(150px, 1fr));
        gap: 15px;
    }

    .action-btn {
        display: flex;
        flex-direction: column;
        align-items: center;
        padding: 15px;
        background: #f8f9fa;
        border-radius: 8px;
        text-decoration: none;
        color: #333;
        transition: all 0.3s ease;
    }

    .action-btn:hover {
        background: #e9ecef;
        transform: translateY(-2px);
    }

    .action-btn i {
        font-size: 24px;
        margin-bottom: 8px;
        color: #007bff;
    }

    .recent-records {
        background: #fff;
        border-radius: 8px;
        padding: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .recent-records h3 {
        margin: 0 0 20px 0;
        color: #333;
    }

    .table-responsive {
        overflow-x: auto;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .badge {
        display: inline-block;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 12px;
        font-weight: 500;
    }

    .badge-success {
        background-color: #28a745;
        color: #fff;
    }

    .btn {
        display: inline-block;
        padding: 8px 16px;
        border-radius: 4px;
        text-decoration: none;
        font-size: 14px;
        cursor: pointer;
        background-color: #007bff;
        color: #fff;
        border: none;
        transition: background-color 0.3s;
    }

    .btn:hover {
        background-color: #0056b3;
    }

    .btn-sm {
        padding: 4px 8px;
        font-size: 12px;
    }
</style>