<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
require_once '../../config/config.php';
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 检查rooms表中是否存在所需字段
$check_rooms_fields_sql = "SHOW COLUMNS FROM rooms LIKE 'lock_status'";
$result = mysqli_query($conn, $check_rooms_fields_sql);
if (mysqli_num_rows($result) == 0) {
    // 添加门锁相关字段到rooms表
    $alter_rooms_sql = "ALTER TABLE rooms 
        ADD COLUMN lock_status ENUM('normal', 'warning', 'error') DEFAULT 'normal',
        ADD COLUMN battery_level INT DEFAULT 100,
        ADD COLUMN last_update DATETIME DEFAULT CURRENT_TIMESTAMP";
    if (!mysqli_query($conn, $alter_rooms_sql)) {
        die("添加rooms表字段失败: " . mysqli_error($conn));
    }
}

// 检查booking_rooms表中是否存在door_password字段
$check_booking_rooms_field_sql = "SHOW COLUMNS FROM booking_rooms LIKE 'door_password'";
$result = mysqli_query($conn, $check_booking_rooms_field_sql);
if (mysqli_num_rows($result) == 0) {
    // 添加门锁密码字段到booking_rooms表
    $alter_booking_rooms_sql = "ALTER TABLE booking_rooms 
        ADD COLUMN door_password VARCHAR(6) DEFAULT NULL";
    if (!mysqli_query($conn, $alter_booking_rooms_sql)) {
        die("添加booking_rooms表字段失败: " . mysqli_error($conn));
    }
}

// 获取所有房间的门锁信息
$rooms_sql = "SELECT r.*, rt.name as room_type_name,
                     br.door_password, b.guest_name, b.check_in_date, b.check_out_date,
                     r.lock_status, r.battery_level, r.last_update
              FROM rooms r
              LEFT JOIN room_types rt ON r.room_type_id = rt.id
              LEFT JOIN booking_rooms br ON r.id = br.room_id AND br.status = 'checked_in'
              LEFT JOIN bookings b ON br.booking_id = b.id AND b.status = 'checked_in'
              ORDER BY r.floor, r.room_number";
$rooms_result = mysqli_query($conn, $rooms_sql);

if (!$rooms_result) {
    die("查询失败: " . mysqli_error($conn));
}

// 处理重置门锁密码
if (isset($_POST['reset_password'])) {
    $room_id = $_POST['room_id'];
    $new_password = sprintf("%06d", rand(0, 999999)); // 生成6位数字密码，不足6位补0

    $update_sql = "UPDATE booking_rooms SET door_password = ? 
                   WHERE room_id = ? AND status = 'checked_in'";
    $stmt = $conn->prepare($update_sql);
    $stmt->bind_param("si", $new_password, $room_id);

    if ($stmt->execute()) {
        // 更新房间的最后更新时间
        $update_room_sql = "UPDATE rooms SET last_update = CURRENT_TIMESTAMP WHERE id = ?";
        $stmt = $conn->prepare($update_room_sql);
        $stmt->bind_param("i", $room_id);
        $stmt->execute();

        $success_message = "门锁密码重置成功！新密码：" . $new_password;
    } else {
        $error_message = "门锁密码重置失败：" . $stmt->error;
    }
}

// 处理更新门锁状态
if (isset($_POST['update_lock_status'])) {
    $room_id = $_POST['room_id'];
    $lock_status = $_POST['lock_status'];

    $update_sql = "UPDATE rooms SET 
                   lock_status = ?,
                   last_update = CURRENT_TIMESTAMP
                   WHERE id = ?";
    $stmt = $conn->prepare($update_sql);
    $stmt->bind_param("si", $lock_status, $room_id);

    if ($stmt->execute()) {
        $success_message = "门锁状态更新成功！";
    } else {
        $error_message = "门锁状态更新失败：" . $stmt->error;
    }
}

// 处理批量操作
if (isset($_POST['batch_operation'])) {
    $floor = $_POST['floor'];
    $operation = $_POST['operation'];
    $where_clause = $floor ? "WHERE r.floor = ?" : "";

    switch ($operation) {
        case 'reset':
            $update_sql = "UPDATE booking_rooms br 
                          INNER JOIN rooms r ON br.room_id = r.id 
                          SET br.door_password = LPAD(FLOOR(RAND() * 1000000), 6, '0')
                          $where_clause";
            break;

        case 'check':
            $update_sql = "UPDATE rooms r
                          SET last_update = CURRENT_TIMESTAMP 
                          $where_clause";
            break;

        case 'update':
            $update_sql = "UPDATE rooms r
                          SET lock_status = 'normal', 
                              battery_level = 100,
                              last_update = CURRENT_TIMESTAMP 
                          $where_clause";
            break;
    }

    if ($floor) {
        $stmt = $conn->prepare($update_sql);
        $stmt->bind_param("s", $floor);
    } else {
        $stmt = $conn->prepare($update_sql);
    }

    if ($stmt->execute()) {
        $success_message = "批量操作执行成功！";
    } else {
        $error_message = "批量操作执行失败：" . $stmt->error;
    }
}

// 获取所有楼层列表
$floors_sql = "SELECT DISTINCT floor FROM rooms ORDER BY floor";
$floors_result = mysqli_query($conn, $floors_sql);
$floors = [];
while ($row = mysqli_fetch_assoc($floors_result)) {
    $floors[] = $row['floor'];
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="action-buttons">
        <button class="btn btn-primary" onclick="showLockSettingsModal()">门锁系统设置</button>
        <button class="btn btn-info" onclick="showBatchOperationModal()">批量操作</button>
    </div>

    <!-- 楼层分组显示房间门锁状态 -->
    <div class="floor-groups">
        <?php
        $current_floor = '';
        while ($room = mysqli_fetch_assoc($rooms_result)):
            if ($current_floor != $room['floor']):
                if ($current_floor != '') echo '</div></div>';
                $current_floor = $room['floor'];
        ?>
                <div class="floor-section">
                    <h3><?php echo htmlspecialchars($room['floor']); ?>层</h3>
                    <div class="room-grid">
                    <?php endif; ?>
                    <div class="room-card">
                        <div class="room-card-header">
                            <h4><?php echo htmlspecialchars($room['room_number']); ?></h4>
                            <span class="badge badge-<?php
                                                        echo $room['status'] == 'occupied' ? 'warning' : ($room['status'] == 'maintenance' ? 'danger' : 'success');
                                                        ?>">
                                <?php
                                echo $room['status'] == 'occupied' ? '已入住' : ($room['status'] == 'maintenance' ? '维修中' : '空闲');
                                ?>
                            </span>
                        </div>
                        <div class="room-card-body">
                            <p>房型：<?php echo htmlspecialchars($room['room_type_name']); ?></p>
                            <?php if ($room['guest_name']): ?>
                                <p>入住客人：<?php echo htmlspecialchars($room['guest_name']); ?></p>
                                <p>入住时间：<?php echo date('Y-m-d', strtotime($room['check_in_date'])); ?></p>
                                <p>退房时间：<?php echo date('Y-m-d', strtotime($room['check_out_date'])); ?></p>
                                <?php if ($room['door_password']): ?>
                                    <p>门锁密码：<?php echo $room['door_password']; ?></p>
                                <?php endif; ?>
                            <?php endif; ?>
                            <p>门锁状态：
                                <span class="badge badge-<?php
                                                            echo $room['lock_status'] == 'normal' ? 'success' : ($room['lock_status'] == 'warning' ? 'warning' : 'danger');
                                                            ?>">
                                    <?php
                                    echo $room['lock_status'] == 'normal' ? '正常' : ($room['lock_status'] == 'warning' ? '电量不足' : '异常');
                                    ?>
                                </span>
                            </p>
                        </div>
                        <div class="room-card-footer">
                            <?php if ($room['status'] == 'occupied'): ?>
                                <button class="btn btn-sm btn-warning"
                                    onclick="resetPassword(<?php echo $room['id']; ?>)">
                                    重置密码
                                </button>
                            <?php endif; ?>
                            <button class="btn btn-sm btn-info"
                                onclick="showLockDetailModal(<?php
                                                                echo htmlspecialchars(json_encode([
                                                                    'id' => $room['id'],
                                                                    'room_number' => $room['room_number'],
                                                                    'lock_status' => $room['lock_status'],
                                                                    'battery_level' => $room['battery_level'] ?? 100,
                                                                    'last_update' => $room['last_update'] ?? date('Y-m-d H:i:s')
                                                                ]));
                                                                ?>)">
                                门锁详情
                            </button>
                        </div>
                    </div>
                <?php endwhile; ?>
                <?php if ($current_floor != '') echo '</div></div>'; ?>
                    </div>
                </div>

                <!-- 门锁详情模态框 -->
                <div class="modal" id="lockDetailModal">
                    <div class="modal-dialog">
                        <div class="modal-content">
                            <div class="modal-header">
                                <h4 class="modal-title">门锁详情</h4>
                                <button type="button" class="close" onclick="closeModal('lockDetailModal')">&times;</button>
                            </div>
                            <div class="modal-body">
                                <div class="lock-info">
                                    <p><strong>房间号：</strong><span id="detail-room-number"></span></p>
                                    <p><strong>门锁状态：</strong><span id="detail-lock-status"></span></p>
                                    <p><strong>电池电量：</strong>
                                    <div class="progress">
                                        <div id="detail-battery-level" class="progress-bar" role="progressbar"></div>
                                    </div>
                                    </p>
                                    <p><strong>最后更新：</strong><span id="detail-last-update"></span></p>
                                </div>
                                <form id="updateLockForm" method="post">
                                    <div class="form-group">
                                        <label>更新门锁状态</label>
                                        <select class="form-control" name="lock_status">
                                            <option value="normal">正常</option>
                                            <option value="warning">电量不足</option>
                                            <option value="error">异常</option>
                                        </select>
                                    </div>
                                    <input type="hidden" name="room_id" id="detail-room-id">
                                    <input type="hidden" name="update_lock_status" value="1">
                                </form>
                            </div>
                            <div class="modal-footer">
                                <button type="button" class="btn btn-secondary" onclick="closeModal('lockDetailModal')">关闭</button>
                                <button type="button" class="btn btn-primary" onclick="submitUpdateLockForm()">更新状态</button>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- 门锁系统设置模态框 -->
                <div class="modal" id="lockSettingsModal">
                    <div class="modal-dialog">
                        <div class="modal-content">
                            <div class="modal-header">
                                <h4 class="modal-title">门锁系统设置</h4>
                                <button type="button" class="close" onclick="closeModal('lockSettingsModal')">&times;</button>
                            </div>
                            <div class="modal-body">
                                <form id="lockSettingsForm">
                                    <div class="form-group">
                                        <label>密码有效期</label>
                                        <select class="form-control">
                                            <option value="24">24小时</option>
                                            <option value="48">48小时</option>
                                            <option value="72">72小时</option>
                                        </select>
                                    </div>
                                    <div class="form-group">
                                        <label>密码长度</label>
                                        <select class="form-control">
                                            <option value="6">6位数字</option>
                                            <option value="8">8位数字</option>
                                        </select>
                                    </div>
                                    <div class="form-group">
                                        <label>自动锁定时间</label>
                                        <select class="form-control">
                                            <option value="5">5秒</option>
                                            <option value="10">10秒</option>
                                            <option value="15">15秒</option>
                                        </select>
                                    </div>
                                    <div class="form-group">
                                        <label>电量警告阈值</label>
                                        <select class="form-control">
                                            <option value="20">20%</option>
                                            <option value="15">15%</option>
                                            <option value="10">10%</option>
                                        </select>
                                    </div>
                                </form>
                            </div>
                            <div class="modal-footer">
                                <button type="button" class="btn btn-secondary" onclick="closeModal('lockSettingsModal')">取消</button>
                                <button type="button" class="btn btn-primary" onclick="saveLockSettings()">保存设置</button>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- 批量操作模态框 -->
                <div class="modal" id="batchOperationModal">
                    <div class="modal-dialog">
                        <div class="modal-content">
                            <div class="modal-header">
                                <h4 class="modal-title">批量操作</h4>
                                <button type="button" class="close" onclick="closeModal('batchOperationModal')">&times;</button>
                            </div>
                            <div class="modal-body">
                                <div class="form-group">
                                    <label>选择楼层</label>
                                    <select class="form-control" id="batchFloor">
                                        <option value="">所有楼层</option>
                                        <!-- 动态加载楼层选项 -->
                                    </select>
                                </div>
                                <div class="form-group">
                                    <label>操作类型</label>
                                    <select class="form-control" id="batchOperation">
                                        <option value="reset">重置密码</option>
                                        <option value="check">检查状态</option>
                                        <option value="update">更新固件</option>
                                    </select>
                                </div>
                            </div>
                            <div class="modal-footer">
                                <button type="button" class="btn btn-secondary" onclick="closeModal('batchOperationModal')">取消</button>
                                <button type="button" class="btn btn-primary" onclick="executeBatchOperation()">执行操作</button>
                            </div>
                        </div>
                    </div>
                </div>

                <style>
                    .content {
                        padding: 20px;
                    }

                    .floor-section {
                        background: #fff;
                        border-radius: 8px;
                        padding: 20px;
                        margin-bottom: 20px;
                        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
                    }

                    .floor-section h3 {
                        margin: 0 0 20px 0;
                        color: #333;
                    }

                    .room-grid {
                        display: grid;
                        grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
                        gap: 20px;
                    }

                    .room-card {
                        background: #fff;
                        border: 1px solid #ddd;
                        border-radius: 8px;
                        overflow: hidden;
                    }

                    .room-card-header {
                        padding: 15px;
                        background: #f8f9fa;
                        border-bottom: 1px solid #ddd;
                        display: flex;
                        justify-content: space-between;
                        align-items: center;
                    }

                    .room-card-header h4 {
                        margin: 0;
                        font-size: 16px;
                    }

                    .room-card-body {
                        padding: 15px;
                    }

                    .room-card-body p {
                        margin: 0 0 10px 0;
                    }

                    .room-card-footer {
                        padding: 15px;
                        background: #f8f9fa;
                        border-top: 1px solid #ddd;
                        text-align: right;
                    }

                    .room-card-footer .btn {
                        margin-left: 8px;
                    }

                    .progress {
                        height: 20px;
                        background-color: #e9ecef;
                        border-radius: 4px;
                        margin: 5px 0;
                        overflow: hidden;
                    }

                    .progress-bar {
                        height: 100%;
                        background-color: #28a745;
                        transition: width 0.3s ease;
                    }

                    .lock-info {
                        background: #f8f9fa;
                        padding: 15px;
                        border-radius: 4px;
                        margin-bottom: 15px;
                    }

                    .lock-info p {
                        margin: 5px 0;
                    }

                    .badge {
                        display: inline-block;
                        padding: 4px 8px;
                        border-radius: 4px;
                        font-size: 12px;
                        font-weight: 500;
                    }

                    .badge-success {
                        background-color: #28a745;
                        color: #fff;
                    }

                    .badge-warning {
                        background-color: #ffc107;
                        color: #000;
                    }

                    .badge-danger {
                        background-color: #dc3545;
                        color: #fff;
                    }

                    .btn {
                        display: inline-block;
                        padding: 8px 16px;
                        border-radius: 4px;
                        text-decoration: none;
                        font-size: 14px;
                        cursor: pointer;
                        border: none;
                        transition: background-color 0.3s;
                    }

                    .btn-sm {
                        padding: 4px 8px;
                        font-size: 12px;
                    }

                    .btn-primary {
                        background-color: #007bff;
                        color: #fff;
                    }

                    .btn-primary:hover {
                        background-color: #0056b3;
                    }

                    .btn-secondary {
                        background-color: #6c757d;
                        color: #fff;
                    }

                    .btn-secondary:hover {
                        background-color: #5a6268;
                    }

                    .btn-warning {
                        background-color: #ffc107;
                        color: #000;
                    }

                    .btn-warning:hover {
                        background-color: #e0a800;
                    }

                    .btn-info {
                        background-color: #17a2b8;
                        color: #fff;
                    }

                    .btn-info:hover {
                        background-color: #138496;
                    }

                    .action-buttons {
                        margin-bottom: 20px;
                    }

                    .action-buttons .btn {
                        margin-right: 10px;
                    }

                    .form-group {
                        margin-bottom: 1rem;
                    }

                    .form-control {
                        display: block;
                        width: 100%;
                        padding: 0.375rem 0.75rem;
                        font-size: 1rem;
                        line-height: 1.5;
                        color: #495057;
                        background-color: #fff;
                        border: 1px solid #ced4da;
                        border-radius: 0.25rem;
                        transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
                    }
                </style>

                <script>
                    function resetPassword(roomId) {
                        if (confirm('确认要重置该房间的门锁密码吗？')) {
                            const form = document.createElement('form');
                            form.method = 'post';
                            form.innerHTML = `
                <input type="hidden" name="room_id" value="${roomId}">
                <input type="hidden" name="reset_password" value="1">
            `;
                            document.body.appendChild(form);
                            form.submit();
                        }
                    }

                    function showLockDetailModal(lockData) {
                        document.getElementById('detail-room-number').textContent = lockData.room_number;
                        document.getElementById('detail-lock-status').textContent =
                            lockData.lock_status === 'normal' ? '正常' :
                            (lockData.lock_status === 'warning' ? '电量不足' : '异常');

                        const batteryBar = document.getElementById('detail-battery-level');
                        batteryBar.style.width = lockData.battery_level + '%';
                        batteryBar.textContent = lockData.battery_level + '%';

                        if (lockData.battery_level < 20) {
                            batteryBar.style.backgroundColor = '#dc3545';
                        } else if (lockData.battery_level < 50) {
                            batteryBar.style.backgroundColor = '#ffc107';
                        }

                        document.getElementById('detail-last-update').textContent = lockData.last_update;
                        document.getElementById('detail-room-id').value = lockData.id;
                        document.getElementById('lockDetailModal').style.display = 'block';
                    }

                    function showLockSettingsModal() {
                        document.getElementById('lockSettingsModal').style.display = 'block';
                    }

                    function showBatchOperationModal() {
                        document.getElementById('batchOperationModal').style.display = 'block';
                    }

                    function closeModal(modalId) {
                        document.getElementById(modalId).style.display = 'none';
                    }

                    function submitUpdateLockForm() {
                        if (confirm('确认要更新门锁状态吗？')) {
                            document.getElementById('updateLockForm').submit();
                        }
                    }

                    function saveLockSettings() {
                        alert('设置已保存');
                        closeModal('lockSettingsModal');
                    }

                    function executeBatchOperation() {
                        const floor = document.getElementById('batchFloor').value;
                        const operation = document.getElementById('batchOperation').value;
                        alert(`正在对 ${floor ? floor + '楼' : '所有楼层'} 执行 ${operation} 操作`);
                        closeModal('batchOperationModal');
                    }

                    // 点击模态框外部关闭
                    window.onclick = function(event) {
                        if (event.target.className === 'modal') {
                            event.target.style.display = 'none';
                        }
                    }
                </script>