<?php

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
require_once '../../config/config.php';
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 检查发票表是否存在
$check_table_sql = "SHOW TABLES LIKE 'invoices'";
$result = mysqli_query($conn, $check_table_sql);

if (mysqli_num_rows($result) == 0) {
    // 创建发票表
    $create_table_sql = "CREATE TABLE invoices (
        id INT AUTO_INCREMENT PRIMARY KEY,
        booking_id INT NOT NULL,
        type ENUM('normal', 'special') NOT NULL,
        title VARCHAR(100) NOT NULL,
        tax_number VARCHAR(20),
        email VARCHAR(100) NOT NULL,
        amount DECIMAL(10,2) NOT NULL,
        status ENUM('pending', 'issued') NOT NULL DEFAULT 'pending',
        invoice_number VARCHAR(50) UNIQUE,
        created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        FOREIGN KEY (booking_id) REFERENCES bookings(id)
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4";

    if (!mysqli_query($conn, $create_table_sql)) {
        die("创建发票表失败: " . mysqli_error($conn));
    }
} else {
    // 检查是否需要添加updated_at字段
    $check_column_sql = "SELECT COLUMN_NAME 
                        FROM INFORMATION_SCHEMA.COLUMNS 
                        WHERE TABLE_SCHEMA = '" . DB_NAME . "' 
                        AND TABLE_NAME = 'invoices' 
                        AND COLUMN_NAME = 'updated_at'";
    $result = mysqli_query($conn, $check_column_sql);

    if (mysqli_num_rows($result) == 0) {
        $alter_sql = "ALTER TABLE invoices 
                     ADD COLUMN updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP";
        if (!mysqli_query($conn, $alter_sql)) {
            die("添加updated_at字段失败: " . mysqli_error($conn));
        }
    }
}

// 处理发票申请
if (isset($_POST['apply_invoice'])) {
    $booking_id = $_POST['booking_id'];
    $invoice_type = $_POST['invoice_type'];
    $invoice_title = $_POST['invoice_title'];
    $tax_number = isset($_POST['tax_number']) ? $_POST['tax_number'] : '';
    $email = $_POST['email'];

    // 获取订单金额
    $amount_sql = "SELECT total_amount FROM bookings WHERE id = ?";
    $stmt = $conn->prepare($amount_sql);
    $stmt->bind_param("i", $booking_id);
    $stmt->execute();
    $result = $stmt->get_result();
    $booking = $result->fetch_assoc();

    if ($booking) {
        // 创建发票记录
        $create_sql = "INSERT INTO invoices (booking_id, type, title, tax_number, email, amount, status) 
                      VALUES (?, ?, ?, ?, ?, ?, 'pending')";
        $stmt = $conn->prepare($create_sql);
        $stmt->bind_param("issssd", $booking_id, $invoice_type, $invoice_title, $tax_number, $email, $booking['total_amount']);

        if ($stmt->execute()) {
            // 模拟开具过程
            $invoice_number = date('YmdHis') . rand(1000, 9999);

            // 更新发票状态
            $update_sql = "UPDATE invoices SET 
                          status = 'issued',
                          invoice_number = ?
                          WHERE booking_id = ? AND status = 'pending'";
            $stmt = $conn->prepare($update_sql);
            $stmt->bind_param("si", $invoice_number, $booking_id);

            if ($stmt->execute()) {
                $success_message = "发票申请成功，发票号：" . $invoice_number;
            } else {
                $error_message = "发票状态更新失败：" . $stmt->error;
            }
        } else {
            $error_message = "发票申请失败：" . $stmt->error;
        }
    } else {
        $error_message = "未找到订单信息！";
    }
}

// 获取未开具发票的订单
$pending_sql = "SELECT b.*, r.room_number, rt.name as room_type_name
                FROM bookings b
                LEFT JOIN booking_rooms br ON b.id = br.booking_id
                LEFT JOIN rooms r ON br.room_id = r.id
                LEFT JOIN room_types rt ON r.room_type_id = rt.id
                WHERE b.status = 'checked_out' 
                AND NOT EXISTS (
                    SELECT 1 FROM invoices i 
                    WHERE i.booking_id = b.id AND i.status = 'issued'
                )
                ORDER BY b.check_out_date DESC";
$pending_result = mysqli_query($conn, $pending_sql);
if (!$pending_result) {
    die("查询未开具发票订单失败: " . mysqli_error($conn));
}

// 获取已开具的发票
$issued_sql = "SELECT i.*, b.booking_number, b.guest_name, b.total_amount,
                      r.room_number, rt.name as room_type_name
               FROM invoices i
               LEFT JOIN bookings b ON i.booking_id = b.id
               LEFT JOIN booking_rooms br ON b.id = br.booking_id
               LEFT JOIN rooms r ON br.room_id = r.id
               LEFT JOIN room_types rt ON r.room_type_id = rt.id
               WHERE i.status = 'issued'
               ORDER BY i.updated_at DESC
               LIMIT 50";
$issued_result = mysqli_query($conn, $issued_sql);
if (!$issued_result) {
    die("查询已开具发票失败: " . mysqli_error($conn));
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <!-- 待开发票订单 -->
    <div class="section">
        <h3>待开发票订单</h3>
        <div class="table-responsive">
            <table class="data-table">
                <thead>
                    <tr>
                        <th>订单号</th>
                        <th>房间号</th>
                        <th>房型</th>
                        <th>客人姓名</th>
                        <th>订单金额</th>
                        <th>退房时间</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php while ($booking = mysqli_fetch_assoc($pending_result)): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($booking['booking_number']); ?></td>
                            <td><?php echo htmlspecialchars($booking['room_number']); ?></td>
                            <td><?php echo htmlspecialchars($booking['room_type_name']); ?></td>
                            <td><?php echo htmlspecialchars($booking['guest_name']); ?></td>
                            <td>￥<?php echo number_format($booking['total_amount'], 2); ?></td>
                            <td><?php echo date('Y-m-d H:i', strtotime($booking['check_out_date'])); ?></td>
                            <td>
                                <button class="btn btn-sm btn-primary"
                                    onclick="showInvoiceModal(<?php echo $booking['id']; ?>)">
                                    申请发票
                                </button>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- 已开发票记录 -->
    <div class="section">
        <h3>已开发票记录</h3>
        <div class="table-responsive">
            <table class="data-table">
                <thead>
                    <tr>
                        <th>发票号</th>
                        <th>订单号</th>
                        <th>房间号</th>
                        <th>发票抬头</th>
                        <th>发票类型</th>
                        <th>金额</th>
                        <th>开具时间</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php while ($invoice = mysqli_fetch_assoc($issued_result)): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($invoice['invoice_number']); ?></td>
                            <td><?php echo htmlspecialchars($invoice['booking_number']); ?></td>
                            <td><?php echo htmlspecialchars($invoice['room_number']); ?></td>
                            <td><?php echo htmlspecialchars($invoice['title']); ?></td>
                            <td><?php echo $invoice['type'] === 'special' ? '专票' : '普票'; ?></td>
                            <td>￥<?php echo number_format($invoice['amount'], 2); ?></td>
                            <td><?php echo date('Y-m-d H:i:s', strtotime($invoice['updated_at'])); ?></td>
                            <td>
                                <button class="btn btn-sm btn-info"
                                    onclick="downloadInvoice('<?php echo $invoice['invoice_number']; ?>')">
                                    下载
                                </button>
                                <button class="btn btn-sm btn-secondary"
                                    onclick="resendEmail('<?php echo $invoice['id']; ?>')">
                                    重发邮件
                                </button>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- 申请发票模态框 -->
<div class="modal" id="invoiceModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">申请发票</h4>
                <button type="button" class="close" onclick="closeModal('invoiceModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form id="invoiceForm" method="post">
                    <input type="hidden" name="booking_id" id="booking_id">
                    <input type="hidden" name="apply_invoice" value="1">

                    <div class="form-group">
                        <label>发票类型</label>
                        <select class="form-control" name="invoice_type" required>
                            <option value="normal">增值税普通发票</option>
                            <option value="special">增值税专用发票</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>发票抬头</label>
                        <input type="text" class="form-control" name="invoice_title" required>
                    </div>

                    <div class="form-group">
                        <label>税号</label>
                        <input type="text" class="form-control" name="tax_number"
                            pattern="[0-9A-Z]{15,20}" title="请输入15-20位的税号">
                    </div>

                    <div class="form-group">
                        <label>接收邮箱</label>
                        <input type="email" class="form-control" name="email" required>
                    </div>
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('invoiceModal')">取消</button>
                <button type="button" class="btn btn-primary" onclick="submitInvoiceForm()">提交</button>
            </div>
        </div>
    </div>
</div>

<style>
    .content {
        padding: 20px;
    }

    .section {
        background: #fff;
        border-radius: 8px;
        padding: 20px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .section h3 {
        margin: 0 0 20px 0;
        color: #333;
    }

    .table-responsive {
        overflow-x: auto;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .btn {
        display: inline-block;
        padding: 8px 16px;
        border-radius: 4px;
        text-decoration: none;
        font-size: 14px;
        cursor: pointer;
        border: none;
        transition: background-color 0.3s;
        margin-right: 5px;
    }

    .btn-sm {
        padding: 4px 8px;
        font-size: 12px;
    }

    .btn-primary {
        background-color: #007bff;
        color: #fff;
    }

    .btn-primary:hover {
        background-color: #0056b3;
    }

    .btn-info {
        background-color: #17a2b8;
        color: #fff;
    }

    .btn-info:hover {
        background-color: #138496;
    }

    .btn-secondary {
        background-color: #6c757d;
        color: #fff;
    }

    .btn-secondary:hover {
        background-color: #545b62;
    }

    .alert {
        padding: 12px 20px;
        margin-bottom: 20px;
        border-radius: 4px;
    }

    .alert-success {
        background-color: #d4edda;
        color: #155724;
        border: 1px solid #c3e6cb;
    }

    .alert-danger {
        background-color: #f8d7da;
        color: #721c24;
        border: 1px solid #f5c6cb;
    }

    .modal {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
        z-index: 1000;
    }

    .modal-dialog {
        position: relative;
        width: 500px;
        margin: 50px auto;
    }

    .modal-content {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    }

    .modal-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .modal-title {
        margin: 0;
        font-size: 18px;
    }

    .modal-body {
        padding: 15px;
    }

    .modal-footer {
        padding: 15px;
        border-top: 1px solid #e9ecef;
        text-align: right;
    }

    .form-group {
        margin-bottom: 1rem;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 0.375rem 0.75rem;
        font-size: 1rem;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 0.25rem;
        transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
    }

    .form-control:focus {
        border-color: #80bdff;
        outline: 0;
        box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
    }
</style>

<script>
    function showInvoiceModal(bookingId) {
        document.getElementById('booking_id').value = bookingId;
        document.getElementById('invoiceModal').style.display = 'block';
    }

    function closeModal(modalId) {
        document.getElementById(modalId).style.display = 'none';
    }

    function submitInvoiceForm() {
        if (validateForm()) {
            document.getElementById('invoiceForm').submit();
        }
    }

    function validateForm() {
        const form = document.getElementById('invoiceForm');
        const type = form.invoice_type.value;
        const taxNumber = form.tax_number.value;

        if (type === 'special' && !taxNumber) {
            alert('申请专票时必须填写税号！');
            return false;
        }

        if (taxNumber && !/^[0-9A-Z]{15,20}$/.test(taxNumber)) {
            alert('税号格式不正确！');
            return false;
        }

        return true;
    }

    function downloadInvoice(invoiceNumber) {
        // TODO: 实现发票下载功能
        alert('正在准备下载发票：' + invoiceNumber);
    }

    function resendEmail(invoiceId) {
        // TODO: 实现重发邮件功能
        alert('发票已重新发送至登记的邮箱！');
    }

    // 点击模态框外部关闭
    window.onclick = function(event) {
        if (event.target.className === 'modal') {
            event.target.style.display = 'none';
        }
    }
</script>