<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
require_once '../../config/config.php';
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 处理人脸图片上传
if (isset($_POST['upload_face'])) {
    $booking_id = $_POST['booking_id'];
    $face_image = $_FILES['face_image'];

    // 检查文件类型
    $allowed_types = ['image/jpeg', 'image/png'];
    if (in_array($face_image['type'], $allowed_types)) {
        // 创建上传目录
        $upload_dir = '../../uploads/faces/';
        if (!file_exists($upload_dir)) {
            mkdir($upload_dir, 0777, true);
        }

        // 生成文件名
        $file_name = 'face_' . $booking_id . '_' . date('YmdHis') . '.jpg';
        $file_path = $upload_dir . $file_name;

        if (move_uploaded_file($face_image['tmp_name'], $file_path)) {
            // 更新预订记录
            $update_sql = "UPDATE bookings SET face_image = ? WHERE id = ?";
            $stmt = $conn->prepare($update_sql);
            $stmt->bind_param("si", $file_name, $booking_id);

            if ($stmt->execute()) {
                $success_message = "人脸图片上传成功！";
            } else {
                $error_message = "更新数据库失败：" . $stmt->error;
            }
        } else {
            $error_message = "文件上传失败！";
        }
    } else {
        $error_message = "只支持JPG和PNG格式的图片！";
    }
}

// 处理人脸验证
if (isset($_POST['verify_face'])) {
    $booking_id = $_POST['booking_id'];
    $face_image = $_FILES['face_image'];

    // TODO: 调用人脸识别API进行验证
    // 这里模拟验证过程
    $verification_result = rand(0, 1) ? true : false;

    if ($verification_result) {
        $success_message = "人脸验证通过！";
    } else {
        $error_message = "人脸验证失败，请重试！";
    }
}

// 获取今日预计入住的订单
$today = date('Y-m-d');
$checkin_sql = "SELECT b.*, r.room_number, rt.name as room_type_name
                FROM bookings b
                LEFT JOIN booking_rooms br ON b.id = br.booking_id
                LEFT JOIN rooms r ON br.room_id = r.id
                LEFT JOIN room_types rt ON r.room_type_id = rt.id
                WHERE b.check_in_date = ? AND b.status = 'confirmed'
                ORDER BY b.created_at DESC";
$stmt = $conn->prepare($checkin_sql);
$stmt->bind_param("s", $today);
$stmt->execute();
$checkin_result = $stmt->get_result();

// 获取已入住的客人信息
$checked_in_sql = "SELECT b.*, r.room_number, rt.name as room_type_name
                   FROM bookings b
                   LEFT JOIN booking_rooms br ON b.id = br.booking_id
                   LEFT JOIN rooms r ON br.room_id = r.id
                   LEFT JOIN room_types rt ON r.room_type_id = rt.id
                   WHERE b.status = 'checked_in'
                   ORDER BY b.check_in_date DESC";
$checked_in_result = mysqli_query($conn, $checked_in_sql);

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="action-buttons">
        <button class="btn btn-primary" onclick="openCamera()">打开摄像头</button>
        <button class="btn btn-info" onclick="showUploadModal()">上传人脸照片</button>
    </div>

    <!-- 待入住客人列表 -->
    <div class="section">
        <h3>今日待入住客人</h3>
        <div class="table-responsive">
            <table class="data-table">
                <thead>
                    <tr>
                        <th>订单号</th>
                        <th>房间号</th>
                        <th>房型</th>
                        <th>客人姓名</th>
                        <th>联系电话</th>
                        <th>证件号码</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php while ($booking = mysqli_fetch_assoc($checkin_result)): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($booking['booking_number']); ?></td>
                            <td><?php echo htmlspecialchars($booking['room_number']); ?></td>
                            <td><?php echo htmlspecialchars($booking['room_type_name']); ?></td>
                            <td><?php echo htmlspecialchars($booking['guest_name']); ?></td>
                            <td><?php echo htmlspecialchars($booking['guest_phone']); ?></td>
                            <td><?php echo htmlspecialchars($booking['guest_id_number']); ?></td>
                            <td>
                                <button class="btn btn-sm btn-primary"
                                    onclick="startFaceVerification(<?php echo $booking['id']; ?>)">
                                    人脸识别
                                </button>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- 已入住客人列表 -->
    <div class="section">
        <h3>已入住客人</h3>
        <div class="table-responsive">
            <table class="data-table">
                <thead>
                    <tr>
                        <th>订单号</th>
                        <th>房间号</th>
                        <th>房型</th>
                        <th>客人姓名</th>
                        <th>入住时间</th>
                        <th>退房时间</th>
                        <th>人脸照片</th>
                    </tr>
                </thead>
                <tbody>
                    <?php while ($guest = mysqli_fetch_assoc($checked_in_result)): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($guest['booking_number']); ?></td>
                            <td><?php echo htmlspecialchars($guest['room_number']); ?></td>
                            <td><?php echo htmlspecialchars($guest['room_type_name']); ?></td>
                            <td><?php echo htmlspecialchars($guest['guest_name']); ?></td>
                            <td><?php echo date('Y-m-d H:i', strtotime($guest['check_in_date'])); ?></td>
                            <td><?php echo date('Y-m-d', strtotime($guest['check_out_date'])); ?></td>
                            <td>
                                <?php if ($guest['face_image']): ?>
                                    <img src="../../uploads/faces/<?php echo $guest['face_image']; ?>"
                                        alt="人脸照片" class="face-thumbnail"
                                        onclick="showFaceImage(this.src)">
                                <?php else: ?>
                                    <span class="text-muted">未上传</span>
                                <?php endif; ?>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<!-- 摄像头模态框 -->
<div class="modal" id="cameraModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">人脸识别</h4>
                <button type="button" class="close" onclick="closeModal('cameraModal')">&times;</button>
            </div>
            <div class="modal-body">
                <div id="camera-container">
                    <video id="video" width="100%" autoplay></video>
                    <canvas id="canvas" style="display:none;"></canvas>
                </div>
                <div id="verification-result" class="mt-3"></div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('cameraModal')">关闭</button>
                <button type="button" class="btn btn-primary" onclick="captureImage()">拍照</button>
            </div>
        </div>
    </div>
</div>

<!-- 上传照片模态框 -->
<div class="modal" id="uploadModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">上传人脸照片</h4>
                <button type="button" class="close" onclick="closeModal('uploadModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form id="uploadForm" method="post" enctype="multipart/form-data">
                    <div class="form-group">
                        <label>选择订单</label>
                        <select class="form-control" name="booking_id" required>
                            <?php
                            mysqli_data_seek($checkin_result, 0);
                            while ($booking = mysqli_fetch_assoc($checkin_result)):
                            ?>
                                <option value="<?php echo $booking['id']; ?>">
                                    <?php echo $booking['booking_number'] . ' - ' . $booking['guest_name']; ?>
                                </option>
                            <?php endwhile; ?>
                        </select>
                    </div>
                    <div class="form-group">
                        <label>选择照片</label>
                        <input type="file" class="form-control" name="face_image" accept="image/*" required>
                    </div>
                    <input type="hidden" name="upload_face" value="1">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('uploadModal')">取消</button>
                <button type="button" class="btn btn-primary" onclick="submitUploadForm()">上传</button>
            </div>
        </div>
    </div>
</div>

<!-- 查看照片模态框 -->
<div class="modal" id="imageModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">查看照片</h4>
                <button type="button" class="close" onclick="closeModal('imageModal')">&times;</button>
            </div>
            <div class="modal-body text-center">
                <img id="fullImage" src="" alt="人脸照片" style="max-width: 100%;">
            </div>
        </div>
    </div>
</div>

<style>
    .content {
        padding: 20px;
    }

    .section {
        background: #fff;
        border-radius: 8px;
        padding: 20px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .section h3 {
        margin: 0 0 20px 0;
        color: #333;
    }

    .table-responsive {
        overflow-x: auto;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .face-thumbnail {
        width: 50px;
        height: 50px;
        object-fit: cover;
        border-radius: 4px;
        cursor: pointer;
    }

    .face-thumbnail:hover {
        opacity: 0.8;
    }

    #camera-container {
        position: relative;
        width: 100%;
        max-width: 500px;
        margin: 0 auto;
    }

    #video {
        width: 100%;
        border-radius: 8px;
    }

    #verification-result {
        text-align: center;
        margin-top: 15px;
        padding: 10px;
        border-radius: 4px;
    }

    .verification-success {
        background-color: #d4edda;
        color: #155724;
    }

    .verification-error {
        background-color: #f8d7da;
        color: #721c24;
    }

    .action-buttons {
        margin-bottom: 20px;
    }

    .action-buttons .btn {
        margin-right: 10px;
    }

    .modal {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
        z-index: 1000;
    }

    .modal-dialog {
        position: relative;
        width: 500px;
        margin: 50px auto;
    }

    .modal-content {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    }

    .modal-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .modal-title {
        margin: 0;
        font-size: 18px;
    }

    .modal-body {
        padding: 15px;
    }

    .modal-footer {
        padding: 15px;
        border-top: 1px solid #e9ecef;
        text-align: right;
    }

    .form-group {
        margin-bottom: 1rem;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 0.375rem 0.75rem;
        font-size: 1rem;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 0.25rem;
        transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
    }
</style>

<script>
    let currentBookingId = null;
    let stream = null;

    function openCamera() {
        document.getElementById('cameraModal').style.display = 'block';
        const video = document.getElementById('video');

        navigator.mediaDevices.getUserMedia({
                video: true
            })
            .then(function(mediaStream) {
                stream = mediaStream;
                video.srcObject = mediaStream;
            })
            .catch(function(err) {
                console.log("摄像头访问失败：" + err);
                alert("无法访问摄像头，请检查权限设置。");
            });
    }

    function captureImage() {
        const video = document.getElementById('video');
        const canvas = document.getElementById('canvas');
        const context = canvas.getContext('2d');

        // 设置canvas尺寸与视频一致
        canvas.width = video.videoWidth;
        canvas.height = video.videoHeight;

        // 在canvas上绘制当前视频帧
        context.drawImage(video, 0, 0, canvas.width, canvas.height);

        // 将canvas内容转换为图片
        const imageData = canvas.toDataURL('image/jpeg');

        // TODO: 调用人脸识别API进行验证
        // 这里模拟验证过程
        setTimeout(function() {
            const result = Math.random() > 0.5;
            showVerificationResult(result);
        }, 1000);
    }

    function showVerificationResult(success) {
        const resultDiv = document.getElementById('verification-result');
        if (success) {
            resultDiv.className = 'verification-success';
            resultDiv.textContent = '验证通过！';
        } else {
            resultDiv.className = 'verification-error';
            resultDiv.textContent = '验证失败，请重试！';
        }
    }

    function closeCamera() {
        if (stream) {
            stream.getTracks().forEach(track => track.stop());
        }
    }

    function startFaceVerification(bookingId) {
        currentBookingId = bookingId;
        openCamera();
    }

    function showUploadModal() {
        document.getElementById('uploadModal').style.display = 'block';
    }

    function submitUploadForm() {
        document.getElementById('uploadForm').submit();
    }

    function showFaceImage(src) {
        document.getElementById('fullImage').src = src;
        document.getElementById('imageModal').style.display = 'block';
    }

    function closeModal(modalId) {
        document.getElementById(modalId).style.display = 'none';
        if (modalId === 'cameraModal') {
            closeCamera();
        }
    }

    // 点击模态框外部关闭
    window.onclick = function(event) {
        if (event.target.className === 'modal') {
            event.target.style.display = 'none';
            if (event.target.id === 'cameraModal') {
                closeCamera();
            }
        }
    }
</script>