<?php
// 检查用户是否已登录
// session_start();
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
require_once '../../config/config.php';
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 检查并添加必要的字段
$check_columns_sql = "SELECT COLUMN_NAME 
                     FROM INFORMATION_SCHEMA.COLUMNS 
                     WHERE TABLE_SCHEMA = '" . DB_NAME . "' 
                     AND TABLE_NAME = 'bookings' 
                     AND COLUMN_NAME IN ('police_upload_status', 'police_upload_time')";
$result = mysqli_query($conn, $check_columns_sql);
$existing_columns = [];
while ($row = mysqli_fetch_assoc($result)) {
    $existing_columns[] = $row['COLUMN_NAME'];
}

// 添加缺失的字段
if (!in_array('police_upload_status', $existing_columns)) {
    $add_status_sql = "ALTER TABLE bookings ADD COLUMN police_upload_status ENUM('pending', 'uploaded') DEFAULT NULL";
    if (!mysqli_query($conn, $add_status_sql)) {
        die("添加police_upload_status字段失败: " . mysqli_error($conn));
    }
}

if (!in_array('police_upload_time', $existing_columns)) {
    $add_time_sql = "ALTER TABLE bookings ADD COLUMN police_upload_time DATETIME DEFAULT NULL";
    if (!mysqli_query($conn, $add_time_sql)) {
        die("添加police_upload_time字段失败: " . mysqli_error($conn));
    }
}

// 处理上传请求
if (isset($_POST['upload_to_police'])) {
    $booking_ids = $_POST['booking_ids'];
    $success_count = 0;
    $failed_count = 0;

    foreach ($booking_ids as $booking_id) {
        // 模拟上传结果
        if (rand(0, 1)) {
            $update_sql = "UPDATE bookings SET police_upload_status = 'uploaded', 
                          police_upload_time = CURRENT_TIMESTAMP 
                          WHERE id = ?";
            $stmt = $conn->prepare($update_sql);
            $stmt->bind_param("i", $booking_id);

            if ($stmt->execute()) {
                $success_count++;
            } else {
                $failed_count++;
            }
        } else {
            $failed_count++;
        }
    }

    if ($success_count > 0) {
        $success_message = "成功上传 {$success_count} 条记录到警方系统。";
    }
    if ($failed_count > 0) {
        $error_message = "有 {$failed_count} 条记录上传失败，请重试。";
    }
}

// 获取未上传的入住记录
$pending_sql = "SELECT b.*, r.room_number, rt.name as room_type_name
                FROM bookings b
                LEFT JOIN booking_rooms br ON b.id = br.booking_id
                LEFT JOIN rooms r ON br.room_id = r.id
                LEFT JOIN room_types rt ON r.room_type_id = rt.id
                WHERE b.status = 'checked_in' 
                AND (b.police_upload_status IS NULL OR b.police_upload_status = 'pending')
                ORDER BY b.check_in_date DESC";
$pending_result = mysqli_query($conn, $pending_sql);

// 获取已上传的记录
$uploaded_sql = "SELECT b.*, r.room_number, rt.name as room_type_name
                 FROM bookings b
                 LEFT JOIN booking_rooms br ON b.id = br.booking_id
                 LEFT JOIN rooms r ON br.room_id = r.id
                 LEFT JOIN room_types rt ON r.room_type_id = rt.id
                 WHERE b.police_upload_status = 'uploaded'
                 ORDER BY b.police_upload_time DESC
                 LIMIT 50";
$uploaded_result = mysqli_query($conn, $uploaded_sql);

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <!-- 待上传记录 -->
    <div class="section">
        <div class="section-header">
            <h3>待上传记录</h3>
            <button class="btn btn-primary" onclick="uploadSelected()">上传选中记录</button>
        </div>
        <div class="table-responsive">
            <table class="data-table">
                <thead>
                    <tr>
                        <th>
                            <input type="checkbox" id="selectAll" onchange="toggleSelectAll(this)">
                        </th>
                        <th>订单号</th>
                        <th>房间号</th>
                        <th>房型</th>
                        <th>客人姓名</th>
                        <th>证件类型</th>
                        <th>证件号码</th>
                        <th>入住时间</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php while ($booking = mysqli_fetch_assoc($pending_result)): ?>
                        <tr>
                            <td>
                                <input type="checkbox" class="booking-checkbox"
                                    value="<?php echo $booking['id']; ?>">
                            </td>
                            <td><?php echo htmlspecialchars($booking['booking_number']); ?></td>
                            <td><?php echo htmlspecialchars($booking['room_number']); ?></td>
                            <td><?php echo htmlspecialchars($booking['room_type_name']); ?></td>
                            <td><?php echo htmlspecialchars($booking['guest_name']); ?></td>
                            <td><?php echo htmlspecialchars($booking['guest_id_type']); ?></td>
                            <td><?php echo htmlspecialchars($booking['guest_id_number']); ?></td>
                            <td><?php echo date('Y-m-d H:i', strtotime($booking['check_in_date'])); ?></td>
                            <td>
                                <button class="btn btn-sm btn-info"
                                    onclick="uploadSingle(<?php echo $booking['id']; ?>)">
                                    上传
                                </button>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- 已上传记录 -->
    <div class="section">
        <h3>最近上传记录</h3>
        <div class="table-responsive">
            <table class="data-table">
                <thead>
                    <tr>
                        <th>订单号</th>
                        <th>房间号</th>
                        <th>房型</th>
                        <th>客人姓名</th>
                        <th>证件号码</th>
                        <th>上传时间</th>
                        <th>状态</th>
                    </tr>
                </thead>
                <tbody>
                    <?php while ($record = mysqli_fetch_assoc($uploaded_result)): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($record['booking_number']); ?></td>
                            <td><?php echo htmlspecialchars($record['room_number']); ?></td>
                            <td><?php echo htmlspecialchars($record['room_type_name']); ?></td>
                            <td><?php echo htmlspecialchars($record['guest_name']); ?></td>
                            <td><?php echo htmlspecialchars($record['guest_id_number']); ?></td>
                            <td><?php echo date('Y-m-d H:i:s', strtotime($record['police_upload_time'])); ?></td>
                            <td>
                                <span class="badge badge-success">已上传</span>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<style>
    .content {
        padding: 20px;
    }

    .section {
        background: #fff;
        border-radius: 8px;
        padding: 20px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .section-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 20px;
    }

    .section-header h3 {
        margin: 0;
        color: #333;
    }

    .table-responsive {
        overflow-x: auto;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .badge {
        display: inline-block;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 12px;
        font-weight: 500;
    }

    .badge-success {
        background-color: #28a745;
        color: #fff;
    }

    .btn {
        display: inline-block;
        padding: 8px 16px;
        border-radius: 4px;
        text-decoration: none;
        font-size: 14px;
        cursor: pointer;
        border: none;
        transition: background-color 0.3s;
    }

    .btn-sm {
        padding: 4px 8px;
        font-size: 12px;
    }

    .btn-primary {
        background-color: #007bff;
        color: #fff;
    }

    .btn-primary:hover {
        background-color: #0056b3;
    }

    .btn-info {
        background-color: #17a2b8;
        color: #fff;
    }

    .btn-info:hover {
        background-color: #138496;
    }

    .alert {
        padding: 12px 20px;
        margin-bottom: 20px;
        border-radius: 4px;
    }

    .alert-success {
        background-color: #d4edda;
        color: #155724;
        border: 1px solid #c3e6cb;
    }

    .alert-danger {
        background-color: #f8d7da;
        color: #721c24;
        border: 1px solid #f5c6cb;
    }
</style>

<script>
    function toggleSelectAll(checkbox) {
        const checkboxes = document.getElementsByClassName('booking-checkbox');
        for (let i = 0; i < checkboxes.length; i++) {
            checkboxes[i].checked = checkbox.checked;
        }
    }

    function uploadSelected() {
        const checkboxes = document.getElementsByClassName('booking-checkbox');
        const selectedIds = [];

        for (let i = 0; i < checkboxes.length; i++) {
            if (checkboxes[i].checked) {
                selectedIds.push(checkboxes[i].value);
            }
        }

        if (selectedIds.length === 0) {
            alert('请选择要上传的记录！');
            return;
        }

        if (confirm(`确认要上传选中的 ${selectedIds.length} 条记录吗？`)) {
            const form = document.createElement('form');
            form.method = 'post';
            form.innerHTML = `
            <input type="hidden" name="upload_to_police" value="1">
        `;

            selectedIds.forEach(id => {
                form.innerHTML += `<input type="hidden" name="booking_ids[]" value="${id}">`;
            });

            document.body.appendChild(form);
            form.submit();
        }
    }

    function uploadSingle(bookingId) {
        if (confirm('确认要上传该记录吗？')) {
            const form = document.createElement('form');
            form.method = 'post';
            form.innerHTML = `
            <input type="hidden" name="upload_to_police" value="1">
            <input type="hidden" name="booking_ids[]" value="${bookingId}">
        `;
            document.body.appendChild(form);
            form.submit();
        }
    }
</script>