<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
require_once '../../config/config.php';
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 获取可用房间列表
$available_rooms_sql = "SELECT r.*, rt.name as room_type_name, rt.base_price 
                       FROM rooms r 
                       LEFT JOIN room_types rt ON r.room_type_id = rt.id 
                       WHERE r.status = 'available'";
$available_rooms_result = mysqli_query($conn, $available_rooms_sql);
$available_rooms = [];
while ($row = mysqli_fetch_assoc($available_rooms_result)) {
    $available_rooms[] = $row;
}

// 获取当前入住的房间列表
$occupied_rooms_sql = "SELECT r.*, rt.name as room_type_name, 
                             b.booking_number, b.guest_name, b.check_in_date, b.check_out_date,
                             br.door_password
                      FROM rooms r 
                      LEFT JOIN room_types rt ON r.room_type_id = rt.id
                      LEFT JOIN booking_rooms br ON r.id = br.room_id
                      LEFT JOIN bookings b ON br.booking_id = b.id
                      WHERE r.status = 'occupied' AND b.status = 'checked_in'";
$occupied_rooms_result = mysqli_query($conn, $occupied_rooms_sql);
$occupied_rooms = [];
while ($row = mysqli_fetch_assoc($occupied_rooms_result)) {
    $occupied_rooms[] = $row;
}

// 处理退房请求
if (isset($_POST['submit_checkout'])) {
    $room_id = $_POST['room_id'];
    $booking_id = $_POST['booking_id'];

    // 开启事务
    mysqli_begin_transaction($conn);

    try {
        // 更新订单状态
        $update_booking_sql = "UPDATE bookings SET status = 'checked_out' WHERE id = ?";
        $stmt = $conn->prepare($update_booking_sql);
        $stmt->bind_param("i", $booking_id);
        $stmt->execute();

        // 更新订单房间状态
        $update_booking_room_sql = "UPDATE booking_rooms SET status = 'checked_out' WHERE booking_id = ? AND room_id = ?";
        $stmt = $conn->prepare($update_booking_room_sql);
        $stmt->bind_param("ii", $booking_id, $room_id);
        $stmt->execute();

        // 更新房间状态
        $update_room_sql = "UPDATE rooms SET status = 'available' WHERE id = ?";
        $stmt = $conn->prepare($update_room_sql);
        $stmt->bind_param("i", $room_id);
        $stmt->execute();

        // 提交事务
        mysqli_commit($conn);
        $success_message = "退房成功！";

        // 刷新页面数据
        header("Location: " . $_SERVER['PHP_SELF'] . "?page=self_checkin");
        exit;
    } catch (Exception $e) {
        // 回滚事务
        mysqli_rollback($conn);
        $error_message = "退房失败：" . $e->getMessage();
    }
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="action-buttons">
        <button class="btn btn-primary" onclick="showQRCodeModal()">扫码入住</button>
        <button class="btn btn-success" onclick="location.href='index.php?page=face_recognition'">人脸识别</button>
    </div>

    <!-- 入住房间列表 -->
    <div class="section">
        <h3>当前入住房间</h3>
        <div class="table-responsive">
            <table class="data-table">
                <thead>
                    <tr>
                        <th>房间号</th>
                        <th>房型</th>
                        <th>客人姓名</th>
                        <th>入住时间</th>
                        <th>预计退房</th>
                        <th>门锁密码</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($occupied_rooms as $room): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($room['room_number']); ?></td>
                            <td><?php echo htmlspecialchars($room['room_type_name']); ?></td>
                            <td><?php echo htmlspecialchars($room['guest_name']); ?></td>
                            <td><?php echo date('Y-m-d H:i', strtotime($room['check_in_date'])); ?></td>
                            <td><?php echo date('Y-m-d', strtotime($room['check_out_date'])); ?></td>
                            <td><?php echo $room['door_password']; ?></td>
                            <td>
                                <button class="btn btn-sm btn-warning" onclick="showCheckoutModal(<?php
                                                                                                    echo htmlspecialchars(json_encode([
                                                                                                        'room_id' => $room['id'],
                                                                                                        'room_number' => $room['room_number'],
                                                                                                        'guest_name' => $room['guest_name'],
                                                                                                        'booking_number' => $room['booking_number']
                                                                                                    ]));
                                                                                                    ?>)">办理退房</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- 可用房间列表 -->
    <div class="section">
        <h3>可入住房间</h3>
        <div class="room-grid">
            <?php foreach ($available_rooms as $room): ?>
                <div class="room-card">
                    <div class="room-card-header">
                        <h4><?php echo htmlspecialchars($room['room_number']); ?></h4>
                        <span class="badge badge-success">可入住</span>
                    </div>
                    <div class="room-card-body">
                        <p>房型：<?php echo htmlspecialchars($room['room_type_name']); ?></p>
                        <p>价格：￥<?php echo number_format($room['base_price'] + $room['price_adjustment'], 2); ?>/晚</p>
                        <p>楼层：<?php echo htmlspecialchars($room['floor']); ?></p>
                    </div>
                    <div class="room-card-footer">
                        <button class="btn btn-primary btn-sm" onclick="location.href='index.php?page=check_in&room_id=<?php echo $room['id']; ?>'">
                            入住登记
                        </button>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    </div>
</div>

<!-- 扫码入住模态框 -->
<div class="modal" id="qrcodeModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">扫码入住</h4>
                <button type="button" class="close" onclick="closeModal('qrcodeModal')">&times;</button>
            </div>
            <div class="modal-body text-center">
                <div id="qrcode-container">
                    <img src="../../assets/images/sample-qr.png" alt="扫码入住" style="max-width: 200px;">
                </div>
                <p class="mt-3">请使用手机扫描二维码进行自助入住</p>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('qrcodeModal')">关闭</button>
            </div>
        </div>
    </div>
</div>

<!-- 退房确认模态框 -->
<div class="modal" id="checkoutModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">确认退房</h4>
                <button type="button" class="close" onclick="closeModal('checkoutModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form id="checkoutForm" method="post">
                    <p>确认为以下房间办理退房？</p>
                    <div class="checkout-info">
                        <p><strong>房间号：</strong><span id="checkout-room-number"></span></p>
                        <p><strong>客人姓名：</strong><span id="checkout-guest-name"></span></p>
                        <p><strong>订单号：</strong><span id="checkout-booking-number"></span></p>
                    </div>
                    <input type="hidden" name="room_id" id="checkout-room-id">
                    <input type="hidden" name="booking_id" id="checkout-booking-id">
                    <input type="hidden" name="submit_checkout" value="1">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('checkoutModal')">取消</button>
                <button type="button" class="btn btn-primary" onclick="submitCheckoutForm()">确认退房</button>
            </div>
        </div>
    </div>
</div>

<style>
    .content {
        padding: 20px;
    }

    .section {
        background: #fff;
        border-radius: 8px;
        padding: 20px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .section h3 {
        margin: 0 0 20px 0;
        color: #333;
    }

    .room-grid {
        display: grid;
        grid-template-columns: repeat(auto-fill, minmax(250px, 1fr));
        gap: 20px;
    }

    .room-card {
        background: #fff;
        border: 1px solid #ddd;
        border-radius: 8px;
        overflow: hidden;
    }

    .room-card-header {
        padding: 15px;
        background: #f8f9fa;
        border-bottom: 1px solid #ddd;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .room-card-header h4 {
        margin: 0;
        font-size: 16px;
    }

    .room-card-body {
        padding: 15px;
    }

    .room-card-body p {
        margin: 0 0 10px 0;
    }

    .room-card-footer {
        padding: 15px;
        background: #f8f9fa;
        border-top: 1px solid #ddd;
        text-align: right;
    }

    .table-responsive {
        overflow-x: auto;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .modal {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
        z-index: 1000;
    }

    .modal-dialog {
        position: relative;
        width: 500px;
        margin: 50px auto;
    }

    .modal-content {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    }

    .modal-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .modal-title {
        margin: 0;
        font-size: 18px;
    }

    .modal-body {
        padding: 15px;
    }

    .modal-footer {
        padding: 15px;
        border-top: 1px solid #e9ecef;
        text-align: right;
    }

    .checkout-info {
        background: #f8f9fa;
        padding: 15px;
        border-radius: 4px;
        margin: 10px 0;
    }

    .checkout-info p {
        margin: 5px 0;
    }

    .badge {
        display: inline-block;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 12px;
        font-weight: 500;
    }

    .badge-success {
        background-color: #28a745;
        color: #fff;
    }

    .btn {
        display: inline-block;
        padding: 8px 16px;
        border-radius: 4px;
        text-decoration: none;
        font-size: 14px;
        cursor: pointer;
        border: none;
        transition: background-color 0.3s;
    }

    .btn-primary {
        background-color: #007bff;
        color: #fff;
    }

    .btn-primary:hover {
        background-color: #0056b3;
    }

    .btn-secondary {
        background-color: #6c757d;
        color: #fff;
    }

    .btn-secondary:hover {
        background-color: #5a6268;
    }

    .btn-warning {
        background-color: #ffc107;
        color: #000;
    }

    .btn-warning:hover {
        background-color: #e0a800;
    }

    .btn-sm {
        padding: 4px 8px;
        font-size: 12px;
    }

    .action-buttons {
        margin-bottom: 20px;
    }

    .action-buttons .btn {
        margin-right: 10px;
    }
</style>

<script>
    function showQRCodeModal() {
        document.getElementById('qrcodeModal').style.display = 'block';
    }

    function showCheckoutModal(roomData) {
        document.getElementById('checkout-room-number').textContent = roomData.room_number;
        document.getElementById('checkout-guest-name').textContent = roomData.guest_name;
        document.getElementById('checkout-booking-number').textContent = roomData.booking_number;
        document.getElementById('checkout-room-id').value = roomData.room_id;
        document.getElementById('checkoutModal').style.display = 'block';
    }

    function closeModal(modalId) {
        document.getElementById(modalId).style.display = 'none';
    }

    function submitCheckoutForm() {
        if (confirm('确认要办理退房吗？')) {
            document.getElementById('checkoutForm').submit();
        }
    }

    // 点击模态框外部关闭
    window.onclick = function(event) {
        if (event.target.className === 'modal') {
            event.target.style.display = 'none';
        }
    }
</script>