<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取统计数据
$stats = array();

// 获取房间总数
$sql = "SELECT COUNT(*) as total FROM rooms";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['total_rooms'] = $row['total'];
} else {
    $stats['total_rooms'] = 0;
}

// 获取可用房间数
$sql = "SELECT COUNT(*) as available FROM rooms WHERE status = 'available'";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['available_rooms'] = $row['available'];
} else {
    $stats['available_rooms'] = 0;
}

// 获取已预订房间数
$sql = "SELECT COUNT(*) as booked FROM rooms WHERE status = 'booked'";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['booked_rooms'] = $row['booked'];
} else {
    $stats['booked_rooms'] = 0;
}

// 获取已入住房间数
$sql = "SELECT COUNT(*) as occupied FROM rooms WHERE status = 'occupied'";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['occupied_rooms'] = $row['occupied'];
} else {
    $stats['occupied_rooms'] = 0;
}

// 获取维修中房间数
$sql = "SELECT COUNT(*) as maintenance FROM rooms WHERE status = 'maintenance'";
$result = $conn->query($sql);
if ($result && $result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $stats['maintenance_rooms'] = $row['maintenance'];
} else {
    $stats['maintenance_rooms'] = 0;
}

// 获取房型数据
$sql = "SELECT rt.name, COUNT(r.id) as count 
        FROM room_types rt 
        LEFT JOIN rooms r ON rt.id = r.room_type_id 
        GROUP BY rt.id";
$result = $conn->query($sql);
$roomTypes = array();
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $roomTypes[] = $row;
    }
}

// 获取最近添加的房间
$sql = "SELECT r.room_number, r.floor, rt.name as room_type, r.status 
        FROM rooms r 
        JOIN room_types rt ON r.room_type_id = rt.id 
        ORDER BY r.created_at DESC 
        LIMIT 5";
$result = $conn->query($sql);
$recentRooms = array();
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $recentRooms[] = $row;
    }
}
?>

<div class="dashboard">
    <div class="dashboard-stats">
        <div class="stat-card">
            <div class="stat-value"><?php echo $stats['total_rooms']; ?></div>
            <div class="stat-label">房间总数</div>
        </div>
        <div class="stat-card">
            <div class="stat-value"><?php echo $stats['available_rooms']; ?></div>
            <div class="stat-label">可用房间</div>
        </div>
        <div class="stat-card">
            <div class="stat-value"><?php echo $stats['booked_rooms']; ?></div>
            <div class="stat-label">已预订房间</div>
        </div>
        <div class="stat-card">
            <div class="stat-value"><?php echo $stats['occupied_rooms']; ?></div>
            <div class="stat-label">已入住房间</div>
        </div>
        <div class="stat-card">
            <div class="stat-value"><?php echo $stats['maintenance_rooms']; ?></div>
            <div class="stat-label">维修中房间</div>
        </div>
    </div>

    <div class="dashboard-row">
        <div class="dashboard-card">
            <div class="card-header">
                <h3>房型分布</h3>
            </div>
            <div class="card-body">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>房型名称</th>
                            <th>房间数量</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($roomTypes as $type): ?>
                            <tr>
                                <td><?php echo $type['name']; ?></td>
                                <td><?php echo $type['count']; ?></td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($roomTypes)): ?>
                            <tr>
                                <td colspan="2">暂无数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <div class="dashboard-card">
            <div class="card-header">
                <h3>最近添加的房间</h3>
            </div>
            <div class="card-body">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>房间号</th>
                            <th>楼层</th>
                            <th>房型</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($recentRooms as $room): ?>
                            <tr>
                                <td><?php echo $room['room_number']; ?></td>
                                <td><?php echo $room['floor']; ?></td>
                                <td><?php echo $room['room_type']; ?></td>
                                <td>
                                    <span class="status-badge status-<?php echo $room['status']; ?>">
                                        <?php
                                        switch ($room['status']) {
                                            case 'available':
                                                echo '可用';
                                                break;
                                            case 'booked':
                                                echo '已预订';
                                                break;
                                            case 'occupied':
                                                echo '已入住';
                                                break;
                                            case 'maintenance':
                                                echo '维修中';
                                                break;
                                            default:
                                                echo $room['status'];
                                        }
                                        ?>
                                    </span>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($recentRooms)): ?>
                            <tr>
                                <td colspan="4">暂无数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <div class="dashboard-actions">
        <a href="index.php?page=room_list" class="btn btn-primary">查看所有房间</a>
        <a href="index.php?page=room_calendar" class="btn btn-secondary">查看房态日历</a>
    </div>
</div>

<style>
    .dashboard {
        padding: 15px 0;
    }

    .dashboard-stats {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        margin-bottom: 20px;
    }

    .stat-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        padding: 15px;
        flex: 1;
        min-width: 150px;
        text-align: center;
    }

    .stat-value {
        font-size: 24px;
        font-weight: bold;
        color: #0066cc;
        margin-bottom: 5px;
    }

    .stat-label {
        color: #6c757d;
        font-size: 14px;
    }

    .dashboard-row {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
        margin-bottom: 20px;
    }

    .dashboard-card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        flex: 1;
        min-width: 300px;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
    }

    .card-header h3 {
        margin: 0;
        font-size: 16px;
        color: #0066cc;
    }

    .card-body {
        padding: 15px;
    }

    .dashboard-actions {
        display: flex;
        gap: 10px;
    }

    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
        color: #fff;
    }

    .status-available {
        background-color: #28a745;
    }

    .status-booked {
        background-color: #ffc107;
        color: #212529;
    }

    .status-occupied {
        background-color: #0066cc;
    }

    .status-maintenance {
        background-color: #dc3545;
    }
</style>