<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 处理添加维修记录
if (isset($_POST['action']) && $_POST['action'] == 'add') {
    $roomId = (int)$_POST['room_id'];
    $issueDescription = sanitize($_POST['issue_description']);
    $reportedBy = sanitize($_POST['reported_by']);
    $priority = sanitize($_POST['priority']);
    $status = 'reported'; // 新添加的维修记录状态为"已报修"

    // 验证数据
    $errors = [];

    if ($roomId <= 0) {
        $errors[] = '请选择房间';
    }

    if (empty($issueDescription)) {
        $errors[] = '问题描述不能为空';
    }

    // 检查房间是否存在
    $checkSql = "SELECT id, room_number FROM rooms WHERE id = ?";
    $checkStmt = $conn->prepare($checkSql);
    $checkStmt->bind_param("i", $roomId);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows === 0) {
        $errors[] = '所选房间不存在';
    } else {
        $roomData = $checkResult->fetch_assoc();
        $roomNumber = $roomData['room_number'];
    }

    // 如果没有错误，插入数据
    if (empty($errors)) {
        $sql = "INSERT INTO maintenance_records (room_id, issue_description, reported_by, priority, status, reported_date) 
                VALUES (?, ?, ?, ?, ?, NOW())";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("issss", $roomId, $issueDescription, $reportedBy, $priority, $status);

        if ($stmt->execute()) {
            // 更新房间状态为维修中
            $updateRoomSql = "UPDATE rooms SET status = 'maintenance' WHERE id = ?";
            $updateRoomStmt = $conn->prepare($updateRoomSql);
            $updateRoomStmt->bind_param("i", $roomId);
            $updateRoomStmt->execute();

            // 记录操作日志
            logActivity('add_maintenance', '添加维修记录: 房间 ' . $roomNumber);

            // 设置成功消息
            $successMessage = '维修记录添加成功，房间状态已更新为维修中';
        } else {
            $errors[] = '添加维修记录失败: ' . $conn->error;
        }
    }
}

// 处理更新维修记录状态
if (isset($_GET['action']) && $_GET['action'] == 'update_status' && isset($_GET['id']) && isset($_GET['status'])) {
    $maintenanceId = (int)$_GET['id'];
    $newStatus = sanitize($_GET['status']);

    // 验证状态值
    $validStatuses = ['reported', 'assigned', 'in_progress', 'completed', 'cancelled'];
    if (!in_array($newStatus, $validStatuses)) {
        $errorMessage = '无效的状态值';
    } else {
        // 获取维修记录信息
        $getSql = "SELECT m.*, r.room_number 
                   FROM maintenance_records m 
                   JOIN rooms r ON m.room_id = r.id 
                   WHERE m.id = ?";
        $getStmt = $conn->prepare($getSql);
        $getStmt->bind_param("i", $maintenanceId);
        $getStmt->execute();
        $getResult = $getStmt->get_result();

        if ($getResult->num_rows === 0) {
            $errorMessage = '维修记录不存在';
        } else {
            $maintenance = $getResult->fetch_assoc();
            $roomId = $maintenance['room_id'];
            $roomNumber = $maintenance['room_number'];

            // 更新维修记录状态
            $updateSql = "UPDATE maintenance_records SET status = ?";

            // 如果状态为已完成，添加完成日期
            if ($newStatus == 'completed') {
                $updateSql .= ", completion_date = NOW()";

                // 更新房间状态为可用
                $updateRoomSql = "UPDATE rooms SET status = 'available' WHERE id = ?";
                $updateRoomStmt = $conn->prepare($updateRoomSql);
                $updateRoomStmt->bind_param("i", $roomId);
                $updateRoomStmt->execute();
            }

            $updateSql .= " WHERE id = ?";
            $updateStmt = $conn->prepare($updateSql);
            $updateStmt->bind_param("si", $newStatus, $maintenanceId);

            if ($updateStmt->execute()) {
                // 记录操作日志
                logActivity('update_maintenance', '更新维修记录状态: 房间 ' . $roomNumber . ' - ' . $newStatus);

                // 设置成功消息
                $successMessage = '维修记录状态更新成功';
                if ($newStatus == 'completed') {
                    $successMessage .= '，房间状态已更新为可用';
                }
            } else {
                $errorMessage = '更新维修记录状态失败: ' . $conn->error;
            }
        }
    }
}

// 处理删除维修记录
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $maintenanceId = (int)$_GET['id'];

    // 获取维修记录信息
    $getSql = "SELECT m.*, r.room_number 
               FROM maintenance_records m 
               JOIN rooms r ON m.room_id = r.id 
               WHERE m.id = ?";
    $getStmt = $conn->prepare($getSql);
    $getStmt->bind_param("i", $maintenanceId);
    $getStmt->execute();
    $getResult = $getStmt->get_result();

    if ($getResult->num_rows === 0) {
        $errorMessage = '维修记录不存在';
    } else {
        $maintenance = $getResult->fetch_assoc();
        $roomId = $maintenance['room_id'];
        $roomNumber = $maintenance['room_number'];

        // 删除维修记录
        $deleteSql = "DELETE FROM maintenance_records WHERE id = ?";
        $deleteStmt = $conn->prepare($deleteSql);
        $deleteStmt->bind_param("i", $maintenanceId);

        if ($deleteStmt->execute()) {
            // 检查该房间是否还有其他未完成的维修记录
            $checkSql = "SELECT COUNT(*) as count 
                         FROM maintenance_records 
                         WHERE room_id = ? AND status IN ('reported', 'assigned', 'in_progress')";
            $checkStmt = $conn->prepare($checkSql);
            $checkStmt->bind_param("i", $roomId);
            $checkStmt->execute();
            $checkResult = $checkStmt->get_result();
            $count = $checkResult->fetch_assoc()['count'];

            // 如果没有其他未完成的维修记录，将房间状态更新为可用
            if ($count == 0) {
                $updateRoomSql = "UPDATE rooms SET status = 'available' WHERE id = ?";
                $updateRoomStmt = $conn->prepare($updateRoomSql);
                $updateRoomStmt->bind_param("i", $roomId);
                $updateRoomStmt->execute();
            }

            // 记录操作日志
            logActivity('delete_maintenance', '删除维修记录: 房间 ' . $roomNumber);

            // 设置成功消息
            $successMessage = '维修记录删除成功';
            if ($count == 0) {
                $successMessage .= '，房间状态已更新为可用';
            }
        } else {
            $errorMessage = '删除维修记录失败: ' . $conn->error;
        }
    }
}

// 获取所有房间
$roomSql = "SELECT id, room_number, floor FROM rooms ORDER BY floor, room_number";
$roomResult = $conn->query($roomSql);
$rooms = [];
if ($roomResult && $roomResult->num_rows > 0) {
    while ($row = $roomResult->fetch_assoc()) {
        $rooms[] = $row;
    }
}

// 获取维修记录列表
$sql = "SELECT m.*, r.room_number, r.floor 
        FROM maintenance_records m 
        JOIN rooms r ON m.room_id = r.id 
        ORDER BY 
        CASE 
            WHEN m.status = 'reported' THEN 1
            WHEN m.status = 'assigned' THEN 2
            WHEN m.status = 'in_progress' THEN 3
            WHEN m.status = 'completed' THEN 4
            WHEN m.status = 'cancelled' THEN 5
        END, 
        m.reported_date DESC";
$result = $conn->query($sql);
$maintenanceRecords = [];
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $maintenanceRecords[] = $row;
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>房间维修管理</h2>
    </div>

    <?php if (isset($successMessage)): ?>
        <div class="alert alert-success"><?php echo $successMessage; ?></div>
    <?php endif; ?>

    <?php if (isset($errorMessage)): ?>
        <div class="alert alert-error"><?php echo $errorMessage; ?></div>
    <?php endif; ?>

    <div class="maintenance-container">
        <div class="maintenance-list">
            <div class="card">
                <div class="card-header">
                    <h3>维修记录列表</h3>
                </div>
                <div class="card-body">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>房间号</th>
                                <th>问题描述</th>
                                <th>报修人</th>
                                <th>优先级</th>
                                <th>报修日期</th>
                                <th>状态</th>
                                <th>完成日期</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($maintenanceRecords)): ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无维修记录</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($maintenanceRecords as $record): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($record['room_number']); ?> (<?php echo htmlspecialchars($record['floor']); ?>楼)</td>
                                        <td><?php echo htmlspecialchars($record['issue_description']); ?></td>
                                        <td><?php echo htmlspecialchars($record['reported_by']); ?></td>
                                        <td>
                                            <span class="priority-badge priority-<?php echo $record['priority']; ?>">
                                                <?php
                                                switch ($record['priority']) {
                                                    case 'high':
                                                        echo '高';
                                                        break;
                                                    case 'medium':
                                                        echo '中';
                                                        break;
                                                    case 'low':
                                                        echo '低';
                                                        break;
                                                    default:
                                                        echo $record['priority'];
                                                }
                                                ?>
                                            </span>
                                        </td>
                                        <td><?php echo date('Y-m-d', strtotime($record['reported_date'])); ?></td>
                                        <td>
                                            <span class="status-badge status-<?php echo $record['status']; ?>">
                                                <?php
                                                switch ($record['status']) {
                                                    case 'reported':
                                                        echo '已报修';
                                                        break;
                                                    case 'assigned':
                                                        echo '已分配';
                                                        break;
                                                    case 'in_progress':
                                                        echo '处理中';
                                                        break;
                                                    case 'completed':
                                                        echo '已完成';
                                                        break;
                                                    case 'cancelled':
                                                        echo '已取消';
                                                        break;
                                                    default:
                                                        echo $record['status'];
                                                }
                                                ?>
                                            </span>
                                        </td>
                                        <td><?php echo $record['completion_date'] ? date('Y-m-d', strtotime($record['completion_date'])) : '-'; ?></td>
                                        <td class="actions">
                                            <?php if ($record['status'] != 'completed' && $record['status'] != 'cancelled'): ?>
                                                <div class="dropdown">
                                                    <button class="btn btn-sm btn-secondary dropdown-toggle">更新状态</button>
                                                    <div class="dropdown-menu">
                                                        <?php if ($record['status'] == 'reported'): ?>
                                                            <a href="index.php?page=maintenance&action=update_status&id=<?php echo $record['id']; ?>&status=assigned" class="dropdown-item">已分配</a>
                                                        <?php endif; ?>

                                                        <?php if ($record['status'] == 'reported' || $record['status'] == 'assigned'): ?>
                                                            <a href="index.php?page=maintenance&action=update_status&id=<?php echo $record['id']; ?>&status=in_progress" class="dropdown-item">处理中</a>
                                                        <?php endif; ?>

                                                        <a href="index.php?page=maintenance&action=update_status&id=<?php echo $record['id']; ?>&status=completed" class="dropdown-item">已完成</a>
                                                        <a href="index.php?page=maintenance&action=update_status&id=<?php echo $record['id']; ?>&status=cancelled" class="dropdown-item">已取消</a>
                                                    </div>
                                                </div>
                                            <?php endif; ?>
                                            <a href="index.php?page=maintenance&action=delete&id=<?php echo $record['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此维修记录吗？此操作不可恢复！');">删除</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <div class="maintenance-form">
            <div class="card">
                <div class="card-header">
                    <h3>添加维修记录</h3>
                </div>
                <div class="card-body">
                    <?php if (!empty($errors)): ?>
                        <div class="alert alert-error">
                            <ul>
                                <?php foreach ($errors as $error): ?>
                                    <li><?php echo $error; ?></li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    <?php endif; ?>

                    <form method="post" action="">
                        <input type="hidden" name="action" value="add">

                        <div class="form-group">
                            <label for="room_id">房间 <span class="required">*</span></label>
                            <select id="room_id" name="room_id" required>
                                <option value="">请选择房间</option>
                                <?php foreach ($rooms as $room): ?>
                                    <option value="<?php echo $room['id']; ?>">
                                        <?php echo htmlspecialchars($room['room_number']); ?> (<?php echo htmlspecialchars($room['floor']); ?>楼)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="issue_description">问题描述 <span class="required">*</span></label>
                            <textarea id="issue_description" name="issue_description" rows="3" required></textarea>
                        </div>

                        <div class="form-group">
                            <label for="reported_by">报修人</label>
                            <input type="text" id="reported_by" name="reported_by">
                        </div>

                        <div class="form-group">
                            <label for="priority">优先级</label>
                            <select id="priority" name="priority">
                                <option value="high">高</option>
                                <option value="medium" selected>中</option>
                                <option value="low">低</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">添加</button>
                        </div>
                    </form>
                </div>
            </div>

            <div class="maintenance-info">
                <div class="card">
                    <div class="card-header">
                        <h3>维修状态说明</h3>
                    </div>
                    <div class="card-body">
                        <ul>
                            <li><strong>已报修</strong>：问题已报告，等待分配维修人员</li>
                            <li><strong>已分配</strong>：已分配维修人员，等待处理</li>
                            <li><strong>处理中</strong>：维修人员正在处理问题</li>
                            <li><strong>已完成</strong>：问题已解决，维修完成</li>
                            <li><strong>已取消</strong>：维修请求已取消</li>
                        </ul>
                        <p>注意：添加维修记录后，房间状态会自动更新为"维修中"。维修完成后，房间状态会自动更新为"可用"。</p>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 下拉菜单交互
        const dropdowns = document.querySelectorAll('.dropdown');

        dropdowns.forEach(dropdown => {
            const toggle = dropdown.querySelector('.dropdown-toggle');
            const menu = dropdown.querySelector('.dropdown-menu');

            toggle.addEventListener('click', function(e) {
                e.preventDefault();
                e.stopPropagation();

                // 关闭所有其他下拉菜单
                dropdowns.forEach(d => {
                    if (d !== dropdown) {
                        d.querySelector('.dropdown-menu').classList.remove('show');
                    }
                });

                // 切换当前下拉菜单
                menu.classList.toggle('show');
            });
        });

        // 点击页面其他地方关闭下拉菜单
        document.addEventListener('click', function() {
            dropdowns.forEach(dropdown => {
                const menu = dropdown.querySelector('.dropdown-menu');
                if (menu.classList.contains('show')) {
                    menu.classList.remove('show');
                }
            });
        });
    });
</script>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .maintenance-container {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
    }

    .maintenance-list {
        flex: 2;
        min-width: 300px;
    }

    .maintenance-form {
        flex: 1;
        min-width: 300px;
    }

    .maintenance-info {
        margin-top: 20px;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        overflow: hidden;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        background-color: #f8f9fa;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #0066cc;
    }

    .card-body {
        padding: 15px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: bold;
    }

    .required {
        color: #dc3545;
    }

    .form-actions {
        margin-top: 20px;
    }

    .status-badge,
    .priority-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
        color: #fff;
    }

    .status-reported {
        background-color: #ffc107;
        color: #212529;
    }

    .status-assigned {
        background-color: #17a2b8;
    }

    .status-in_progress {
        background-color: #0066cc;
    }

    .status-completed {
        background-color: #28a745;
    }

    .status-cancelled {
        background-color: #6c757d;
    }

    .priority-high {
        background-color: #dc3545;
    }

    .priority-medium {
        background-color: #ffc107;
        color: #212529;
    }

    .priority-low {
        background-color: #28a745;
    }

    .actions {
        display: flex;
        gap: 5px;
    }

    .btn-sm {
        padding: 4px 8px;
        font-size: 12px;
    }

    .text-center {
        text-align: center;
    }

    .dropdown {
        position: relative;
        display: inline-block;
    }

    .dropdown-toggle {
        cursor: pointer;
    }

    .dropdown-menu {
        display: none;
        position: absolute;
        background-color: #fff;
        min-width: 120px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.2);
        z-index: 1;
        border-radius: 4px;
        padding: 5px 0;
    }

    .dropdown-menu.show {
        display: block;
    }

    .dropdown-item {
        display: block;
        padding: 5px 10px;
        color: #212529;
        text-decoration: none;
        font-size: 14px;
    }

    .dropdown-item:hover {
        background-color: #f8f9fa;
    }

    @media (max-width: 768px) {
        .maintenance-container {
            flex-direction: column;
        }
    }
</style>