<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 处理添加价格策略
if (isset($_POST['action']) && $_POST['action'] == 'add') {
    $name = sanitize($_POST['name']);
    $description = sanitize($_POST['description']);
    $startDate = sanitize($_POST['start_date']);
    $endDate = sanitize($_POST['end_date']);
    $adjustmentType = sanitize($_POST['adjustment_type']);
    $adjustmentValue = (float)$_POST['adjustment_value'];
    $roomTypeId = isset($_POST['room_type_id']) ? (int)$_POST['room_type_id'] : null;
    $status = sanitize($_POST['status']);

    // 验证数据
    $errors = [];

    if (empty($name)) {
        $errors[] = '策略名称不能为空';
    }

    if (empty($startDate) || empty($endDate)) {
        $errors[] = '开始日期和结束日期不能为空';
    } elseif (strtotime($startDate) > strtotime($endDate)) {
        $errors[] = '开始日期不能晚于结束日期';
    }

    if ($adjustmentType != 'percentage' && $adjustmentType != 'fixed') {
        $errors[] = '调整类型无效';
    }

    if ($adjustmentValue <= 0) {
        $errors[] = '调整值必须大于0';
    }

    // 如果没有错误，插入数据
    if (empty($errors)) {
        $sql = "INSERT INTO price_strategies (name, description, start_date, end_date, adjustment_type, adjustment_value, room_type_id, status) 
                VALUES (?, ?, ?, ?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ssssssis", $name, $description, $startDate, $endDate, $adjustmentType, $adjustmentValue, $roomTypeId, $status);

        if ($stmt->execute()) {
            // 记录操作日志
            logActivity('add_price_strategy', '添加价格策略: ' . $name);

            // 设置成功消息
            $successMessage = '价格策略添加成功';
        } else {
            $errors[] = '添加价格策略失败: ' . $conn->error;
        }
    }
}

// 处理编辑价格策略
if (isset($_POST['action']) && $_POST['action'] == 'edit') {
    $strategyId = (int)$_POST['strategy_id'];
    $name = sanitize($_POST['name']);
    $description = sanitize($_POST['description']);
    $startDate = sanitize($_POST['start_date']);
    $endDate = sanitize($_POST['end_date']);
    $adjustmentType = sanitize($_POST['adjustment_type']);
    $adjustmentValue = (float)$_POST['adjustment_value'];
    $roomTypeId = isset($_POST['room_type_id']) ? (int)$_POST['room_type_id'] : null;
    $status = sanitize($_POST['status']);

    // 验证数据
    $errors = [];

    if (empty($name)) {
        $errors[] = '策略名称不能为空';
    }

    if (empty($startDate) || empty($endDate)) {
        $errors[] = '开始日期和结束日期不能为空';
    } elseif (strtotime($startDate) > strtotime($endDate)) {
        $errors[] = '开始日期不能晚于结束日期';
    }

    if ($adjustmentType != 'percentage' && $adjustmentType != 'fixed') {
        $errors[] = '调整类型无效';
    }

    if ($adjustmentValue <= 0) {
        $errors[] = '调整值必须大于0';
    }

    // 如果没有错误，更新数据
    if (empty($errors)) {
        $sql = "UPDATE price_strategies SET 
                name = ?, 
                description = ?, 
                start_date = ?, 
                end_date = ?, 
                adjustment_type = ?, 
                adjustment_value = ?, 
                room_type_id = ?, 
                status = ? 
                WHERE id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("sssssdsii", $name, $description, $startDate, $endDate, $adjustmentType, $adjustmentValue, $roomTypeId, $status, $strategyId);

        if ($stmt->execute()) {
            // 记录操作日志
            logActivity('edit_price_strategy', '编辑价格策略: ' . $name);

            // 设置成功消息
            $successMessage = '价格策略更新成功';
        } else {
            $errors[] = '更新价格策略失败: ' . $conn->error;
        }
    }
}

// 处理删除价格策略
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $strategyId = (int)$_GET['id'];

    // 检查价格策略是否存在
    $checkSql = "SELECT name FROM price_strategies WHERE id = ?";
    $checkStmt = $conn->prepare($checkSql);
    $checkStmt->bind_param("i", $strategyId);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows > 0) {
        $strategyName = $checkResult->fetch_assoc()['name'];

        // 删除价格策略
        $deleteSql = "DELETE FROM price_strategies WHERE id = ?";
        $deleteStmt = $conn->prepare($deleteSql);
        $deleteStmt->bind_param("i", $strategyId);

        if ($deleteStmt->execute()) {
            // 记录操作日志
            logActivity('delete_price_strategy', '删除价格策略: ' . $strategyName);

            // 设置成功消息
            $successMessage = '价格策略删除成功';
        } else {
            $errorMessage = '删除价格策略失败: ' . $conn->error;
        }
    } else {
        $errorMessage = '价格策略不存在';
    }
}

// 获取价格策略列表
$sql = "SELECT ps.*, rt.name as room_type_name 
        FROM price_strategies ps 
        LEFT JOIN room_types rt ON ps.room_type_id = rt.id 
        ORDER BY ps.start_date DESC";
$result = $conn->query($sql);
$strategies = [];
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $strategies[] = $row;
    }
}

// 获取要编辑的价格策略信息
$editStrategy = null;
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $strategyId = (int)$_GET['id'];

    $sql = "SELECT * FROM price_strategies WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $strategyId);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $editStrategy = $result->fetch_assoc();
    }
}

// 获取所有房型
$roomTypesSql = "SELECT id, name FROM room_types WHERE status = 'active' ORDER BY name";
$roomTypesResult = $conn->query($roomTypesSql);
$roomTypes = [];
if ($roomTypesResult && $roomTypesResult->num_rows > 0) {
    while ($row = $roomTypesResult->fetch_assoc()) {
        $roomTypes[] = $row;
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>智能定价</h2>
    </div>

    <?php if (isset($successMessage)): ?>
        <div class="alert alert-success"><?php echo $successMessage; ?></div>
    <?php endif; ?>

    <?php if (isset($errorMessage)): ?>
        <div class="alert alert-error"><?php echo $errorMessage; ?></div>
    <?php endif; ?>

    <div class="pricing-container">
        <div class="pricing-list">
            <div class="card">
                <div class="card-header">
                    <h3>价格策略列表</h3>
                </div>
                <div class="card-body">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>策略名称</th>
                                <th>适用房型</th>
                                <th>调整方式</th>
                                <th>调整值</th>
                                <th>生效日期</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($strategies)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无价格策略数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($strategies as $strategy): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($strategy['name']); ?></td>
                                        <td><?php echo $strategy['room_type_id'] ? htmlspecialchars($strategy['room_type_name']) : '所有房型'; ?></td>
                                        <td>
                                            <?php
                                            echo $strategy['adjustment_type'] == 'percentage' ? '百分比' : '固定金额';
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            if ($strategy['adjustment_type'] == 'percentage') {
                                                echo number_format($strategy['adjustment_value'], 2) . '%';
                                            } else {
                                                echo '¥' . number_format($strategy['adjustment_value'], 2);
                                            }
                                            ?>
                                        </td>
                                        <td>
                                            <?php echo date('Y-m-d', strtotime($strategy['start_date'])); ?> 至
                                            <?php echo date('Y-m-d', strtotime($strategy['end_date'])); ?>
                                        </td>
                                        <td>
                                            <span class="status-badge status-<?php echo $strategy['status']; ?>">
                                                <?php echo $strategy['status'] == 'active' ? '启用' : '禁用'; ?>
                                            </span>
                                        </td>
                                        <td class="actions">
                                            <a href="index.php?page=pricing&action=edit&id=<?php echo $strategy['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                            <a href="index.php?page=pricing&action=delete&id=<?php echo $strategy['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此价格策略吗？此操作不可恢复！');">删除</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>

            <div class="pricing-info">
                <div class="card">
                    <div class="card-header">
                        <h3>价格策略说明</h3>
                    </div>
                    <div class="card-body">
                        <p>价格策略用于在特定时间段内调整房间价格，可以基于百分比或固定金额进行调整。</p>
                        <h4>调整方式说明：</h4>
                        <ul>
                            <li><strong>百分比</strong>：按照房间基础价格的百分比进行调整。例如，设置为 120% 表示在原价基础上上浮 20%，设置为 80% 表示在原价基础上下调 20%。</li>
                            <li><strong>固定金额</strong>：直接在房间基础价格上增加或减少固定金额。正数表示增加，负数表示减少。</li>
                        </ul>
                        <h4>适用范围：</h4>
                        <ul>
                            <li>可以针对特定房型设置价格策略，也可以设置适用于所有房型的全局策略。</li>
                            <li>当多个价格策略同时适用时，系统会按照以下优先级应用：特定房型的策略 > 全局策略。</li>
                            <li>同一优先级的多个策略会叠加计算。</li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>

        <div class="pricing-form">
            <div class="card">
                <div class="card-header">
                    <h3><?php echo $editStrategy ? '编辑价格策略' : '添加价格策略'; ?></h3>
                </div>
                <div class="card-body">
                    <?php if (!empty($errors)): ?>
                        <div class="alert alert-error">
                            <ul>
                                <?php foreach ($errors as $error): ?>
                                    <li><?php echo $error; ?></li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    <?php endif; ?>

                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $editStrategy ? 'edit' : 'add'; ?>">
                        <?php if ($editStrategy): ?>
                            <input type="hidden" name="strategy_id" value="<?php echo $editStrategy['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="name">策略名称 <span class="required">*</span></label>
                            <input type="text" id="name" name="name" value="<?php echo $editStrategy ? htmlspecialchars($editStrategy['name']) : ''; ?>" required>
                            <small>例如：节假日涨价、淡季优惠等</small>
                        </div>

                        <div class="form-group">
                            <label for="description">描述</label>
                            <textarea id="description" name="description" rows="3"><?php echo $editStrategy ? htmlspecialchars($editStrategy['description']) : ''; ?></textarea>
                        </div>

                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="start_date">开始日期 <span class="required">*</span></label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $editStrategy ? $editStrategy['start_date'] : ''; ?>" required>
                            </div>

                            <div class="form-group col-md-6">
                                <label for="end_date">结束日期 <span class="required">*</span></label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $editStrategy ? $editStrategy['end_date'] : ''; ?>" required>
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="adjustment_type">调整方式 <span class="required">*</span></label>
                                <select id="adjustment_type" name="adjustment_type" required>
                                    <option value="percentage" <?php echo ($editStrategy && $editStrategy['adjustment_type'] == 'percentage') ? 'selected' : ''; ?>>百分比</option>
                                    <option value="fixed" <?php echo ($editStrategy && $editStrategy['adjustment_type'] == 'fixed') ? 'selected' : ''; ?>>固定金额</option>
                                </select>
                            </div>

                            <div class="form-group col-md-6">
                                <label for="adjustment_value">调整值 <span class="required">*</span></label>
                                <input type="number" id="adjustment_value" name="adjustment_value" step="0.01" min="0" value="<?php echo $editStrategy ? $editStrategy['adjustment_value'] : ''; ?>" required>
                                <small id="adjustment_hint">百分比模式下，100表示原价，120表示上浮20%，80表示下调20%</small>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="room_type_id">适用房型</label>
                            <select id="room_type_id" name="room_type_id">
                                <option value="">所有房型</option>
                                <?php foreach ($roomTypes as $type): ?>
                                    <option value="<?php echo $type['id']; ?>" <?php echo ($editStrategy && $editStrategy['room_type_id'] == $type['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($type['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="status">状态</label>
                            <select id="status" name="status">
                                <option value="active" <?php echo ($editStrategy && $editStrategy['status'] == 'active') ? 'selected' : ''; ?>>启用</option>
                                <option value="inactive" <?php echo ($editStrategy && $editStrategy['status'] == 'inactive') ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary"><?php echo $editStrategy ? '更新' : '添加'; ?></button>
                            <?php if ($editStrategy): ?>
                                <a href="index.php?page=pricing" class="btn btn-secondary">取消</a>
                            <?php endif; ?>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        const adjustmentTypeSelect = document.getElementById('adjustment_type');
        const adjustmentHint = document.getElementById('adjustment_hint');

        function updateAdjustmentHint() {
            if (adjustmentTypeSelect.value === 'percentage') {
                adjustmentHint.textContent = '百分比模式下，100表示原价，120表示上浮20%，80表示下调20%';
            } else {
                adjustmentHint.textContent = '固定金额模式下，正数表示增加金额，负数表示减少金额';
            }
        }

        adjustmentTypeSelect.addEventListener('change', updateAdjustmentHint);
        updateAdjustmentHint();
    });
</script>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .pricing-container {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
    }

    .pricing-list {
        flex: 2;
        min-width: 300px;
    }

    .pricing-form {
        flex: 1;
        min-width: 300px;
    }

    .pricing-info {
        margin-top: 20px;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        overflow: hidden;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        background-color: #f8f9fa;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #0066cc;
    }

    .card-header h4 {
        margin: 15px 0 5px;
        font-size: 16px;
        color: #495057;
    }

    .card-body {
        padding: 15px;
    }

    .card-body p {
        margin-bottom: 15px;
    }

    .card-body ul {
        padding-left: 20px;
        margin-bottom: 15px;
    }

    .card-body li {
        margin-bottom: 5px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: bold;
    }

    .form-group small {
        display: block;
        color: #6c757d;
        margin-top: 5px;
        font-size: 12px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
    }

    .required {
        color: #dc3545;
    }

    .form-actions {
        margin-top: 20px;
        display: flex;
        gap: 10px;
    }

    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
        color: #fff;
    }

    .status-active {
        background-color: #28a745;
    }

    .status-inactive {
        background-color: #6c757d;
    }

    .actions {
        display: flex;
        gap: 5px;
    }

    .btn-sm {
        padding: 4px 8px;
        font-size: 12px;
    }

    .text-center {
        text-align: center;
    }

    @media (max-width: 768px) {
        .pricing-container {
            flex-direction: column;
        }

        .col-md-6 {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>