<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取所有房型
$roomTypesSql = "SELECT id, name FROM room_types WHERE status = 'active' ORDER BY name";
$roomTypesResult = $conn->query($roomTypesSql);
$roomTypes = [];
if ($roomTypesResult && $roomTypesResult->num_rows > 0) {
    while ($row = $roomTypesResult->fetch_assoc()) {
        $roomTypes[] = $row;
    }
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $roomNumber = sanitize($_POST['room_number']);
    $roomTypeId = (int)$_POST['room_type_id'];
    $floor = sanitize($_POST['floor']);
    $area = (float)$_POST['area'];
    $bedType = sanitize($_POST['bed_type']);
    $hasWindow = isset($_POST['has_window']) ? 1 : 0;
    $hasBathroom = isset($_POST['has_bathroom']) ? 1 : 0;
    $amenities = sanitize($_POST['amenities']);
    $description = sanitize($_POST['description']);
    $priceAdjustment = (float)$_POST['price_adjustment'];
    $status = sanitize($_POST['status']);

    // 验证数据
    $errors = [];

    if (empty($roomNumber)) {
        $errors[] = '房间号不能为空';
    }

    if ($roomTypeId <= 0) {
        $errors[] = '请选择房型';
    }

    if (empty($floor)) {
        $errors[] = '楼层不能为空';
    }

    // 检查房间号是否已存在
    $checkSql = "SELECT id FROM rooms WHERE room_number = ?";
    $checkStmt = $conn->prepare($checkSql);
    $checkStmt->bind_param("s", $roomNumber);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows > 0) {
        $errors[] = '房间号已存在，请使用其他房间号';
    }

    // 如果没有错误，插入数据
    if (empty($errors)) {
        $sql = "INSERT INTO rooms (room_number, room_type_id, floor, area, bed_type, has_window, has_bathroom, amenities, description, price_adjustment, status) 
                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("sisdsiissds", $roomNumber, $roomTypeId, $floor, $area, $bedType, $hasWindow, $hasBathroom, $amenities, $description, $priceAdjustment, $status);

        if ($stmt->execute()) {
            $roomId = $conn->insert_id;

            // 处理图片上传
            if (isset($_FILES['room_images']) && !empty($_FILES['room_images']['name'][0])) {
                $uploadDir = '../../assets/images/uploads/rooms/';

                // 确保目录存在
                if (!file_exists($uploadDir)) {
                    mkdir($uploadDir, 0777, true);
                }

                $allowedTypes = ['image/jpeg', 'image/png', 'image/gif'];
                $maxSize = 5 * 1024 * 1024; // 5MB

                $images = $_FILES['room_images'];
                $imageCount = count($images['name']);

                for ($i = 0; $i < $imageCount; $i++) {
                    if ($images['error'][$i] === UPLOAD_ERR_OK) {
                        $tmpName = $images['tmp_name'][$i];
                        $name = $images['name'][$i];
                        $size = $images['size'][$i];
                        $type = $images['type'][$i];

                        // 验证文件类型和大小
                        if (!in_array($type, $allowedTypes)) {
                            $errors[] = '文件类型不支持: ' . $name;
                            continue;
                        }

                        if ($size > $maxSize) {
                            $errors[] = '文件大小超过限制: ' . $name;
                            continue;
                        }

                        // 生成唯一文件名
                        $extension = pathinfo($name, PATHINFO_EXTENSION);
                        $newName = uniqid('room_') . '.' . $extension;
                        $destination = $uploadDir . $newName;

                        if (move_uploaded_file($tmpName, $destination)) {
                            // 保存图片信息到数据库
                            $isPrimary = ($i === 0) ? 1 : 0; // 第一张图片设为主图
                            $imagePath = 'assets/images/uploads/rooms/' . $newName;

                            $imageSql = "INSERT INTO room_images (room_id, image_path, is_primary) VALUES (?, ?, ?)";
                            $imageStmt = $conn->prepare($imageSql);
                            $imageStmt->bind_param("isi", $roomId, $imagePath, $isPrimary);
                            $imageStmt->execute();
                        } else {
                            $errors[] = '上传文件失败: ' . $name;
                        }
                    } else if ($images['error'][$i] !== UPLOAD_ERR_NO_FILE) {
                        $errors[] = '上传文件错误: ' . $images['error'][$i];
                    }
                }
            }

            // 记录操作日志
            logActivity('add_room', '添加房间: ' . $roomNumber);

            // 设置成功消息并重定向
            $_SESSION['success_message'] = '房间添加成功';
            header('Location: index.php?page=room_list');
            exit;
        } else {
            $errors[] = '添加房间失败: ' . $conn->error;
        }
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>添加房间</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <a href="index.php?page=room_list">房间列表</a> /
            <span>添加房间</span>
        </nav>
    </div>

    <?php if (!empty($errors)): ?>
        <div class="alert alert-error">
            <ul>
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <div class="card">
        <div class="card-body">
            <form method="post" action="" enctype="multipart/form-data" class="form-horizontal">
                <div class="form-section">
                    <h3>基本信息</h3>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="room_number">房间号 <span class="required">*</span></label>
                            <input type="text" id="room_number" name="room_number" value="<?php echo isset($_POST['room_number']) ? htmlspecialchars($_POST['room_number']) : ''; ?>" required>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="room_type_id">房型 <span class="required">*</span></label>
                            <select id="room_type_id" name="room_type_id" required>
                                <option value="">请选择房型</option>
                                <?php foreach ($roomTypes as $type): ?>
                                    <option value="<?php echo $type['id']; ?>" <?php echo (isset($_POST['room_type_id']) && $_POST['room_type_id'] == $type['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($type['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="floor">楼层 <span class="required">*</span></label>
                            <input type="text" id="floor" name="floor" value="<?php echo isset($_POST['floor']) ? htmlspecialchars($_POST['floor']) : ''; ?>" required>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="area">面积(㎡)</label>
                            <input type="number" id="area" name="area" step="0.01" min="0" value="<?php echo isset($_POST['area']) ? htmlspecialchars($_POST['area']) : '0'; ?>">
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="bed_type">床型</label>
                            <input type="text" id="bed_type" name="bed_type" value="<?php echo isset($_POST['bed_type']) ? htmlspecialchars($_POST['bed_type']) : ''; ?>">
                        </div>

                        <div class="form-group col-md-6">
                            <label for="price_adjustment">价格调整</label>
                            <input type="number" id="price_adjustment" name="price_adjustment" step="0.01" value="<?php echo isset($_POST['price_adjustment']) ? htmlspecialchars($_POST['price_adjustment']) : '0'; ?>">
                            <small>正数表示上调，负数表示下调</small>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <div class="checkbox-group">
                                <label>
                                    <input type="checkbox" name="has_window" <?php echo (isset($_POST['has_window'])) ? 'checked' : ''; ?>>
                                    有窗户
                                </label>
                            </div>
                        </div>

                        <div class="form-group col-md-6">
                            <div class="checkbox-group">
                                <label>
                                    <input type="checkbox" name="has_bathroom" <?php echo (isset($_POST['has_bathroom'])) ? 'checked' : ''; ?>>
                                    有独立卫生间
                                </label>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="form-section">
                    <h3>详细信息</h3>

                    <div class="form-group">
                        <label for="amenities">设施与服务</label>
                        <textarea id="amenities" name="amenities" rows="3"><?php echo isset($_POST['amenities']) ? htmlspecialchars($_POST['amenities']) : ''; ?></textarea>
                        <small>例如：空调、电视、冰箱、热水壶等，用逗号分隔</small>
                    </div>

                    <div class="form-group">
                        <label for="description">房间描述</label>
                        <textarea id="description" name="description" rows="5"><?php echo isset($_POST['description']) ? htmlspecialchars($_POST['description']) : ''; ?></textarea>
                    </div>
                </div>

                <div class="form-section">
                    <h3>房间图片</h3>

                    <div class="form-group">
                        <label for="room_images">上传图片</label>
                        <input type="file" id="room_images" name="room_images[]" multiple accept="image/*">
                        <small>可以选择多张图片。支持JPG、PNG、GIF格式，单张图片大小不超过5MB。第一张图片将作为主图。</small>
                    </div>

                    <div id="image-preview" class="image-preview-container"></div>
                </div>

                <div class="form-section">
                    <h3>状态</h3>

                    <div class="form-group">
                        <label for="status">房间状态</label>
                        <select id="status" name="status">
                            <option value="available" <?php echo (!isset($_POST['status']) || $_POST['status'] == 'available') ? 'selected' : ''; ?>>可用</option>
                            <option value="maintenance" <?php echo (isset($_POST['status']) && $_POST['status'] == 'maintenance') ? 'selected' : ''; ?>>维修中</option>
                        </select>
                    </div>
                </div>

                <div class="form-actions">
                    <button type="submit" class="btn btn-primary">保存</button>
                    <a href="index.php?page=room_list" class="btn btn-secondary">取消</a>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 图片预览
        const input = document.getElementById('room_images');
        const preview = document.getElementById('image-preview');

        input.addEventListener('change', function() {
            preview.innerHTML = '';

            if (this.files) {
                for (let i = 0; i < this.files.length; i++) {
                    const file = this.files[i];

                    if (!file.type.match('image.*')) {
                        continue;
                    }

                    const reader = new FileReader();

                    reader.onload = function(e) {
                        const div = document.createElement('div');
                        div.className = 'image-preview';

                        const img = document.createElement('img');
                        img.src = e.target.result;
                        img.title = file.name;

                        div.appendChild(img);
                        preview.appendChild(div);
                    };

                    reader.readAsDataURL(file);
                }
            }
        });
    });
</script>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .page-header h2 {
        margin-bottom: 5px;
    }

    .breadcrumb {
        font-size: 14px;
        color: #6c757d;
    }

    .breadcrumb a {
        color: #0066cc;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
    }

    .card-body {
        padding: 20px;
    }

    .form-section {
        margin-bottom: 30px;
    }

    .form-section h3 {
        font-size: 18px;
        color: #0066cc;
        margin-bottom: 15px;
        padding-bottom: 10px;
        border-bottom: 1px solid #e9ecef;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
    }

    .required {
        color: #dc3545;
    }

    .checkbox-group {
        margin-top: 30px;
    }

    .image-preview-container {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        margin-top: 10px;
    }

    .image-preview {
        width: 150px;
        height: 150px;
        border: 1px solid #ddd;
        border-radius: 4px;
        overflow: hidden;
    }

    .image-preview img {
        width: 100%;
        height: 100%;
        object-fit: cover;
    }

    .form-actions {
        display: flex;
        gap: 10px;
        margin-top: 20px;
    }

    @media (max-width: 768px) {
        .col-md-6 {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>