<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取当前年月
$year = isset($_GET['year']) ? (int)$_GET['year'] : (int)date('Y');
$month = isset($_GET['month']) ? (int)$_GET['month'] : (int)date('m');

// 验证年月
if ($year < 2000 || $year > 2100) {
    $year = (int)date('Y');
}
if ($month < 1 || $month > 12) {
    $month = (int)date('m');
}

// 获取上个月和下个月
$prevMonth = $month - 1;
$prevYear = $year;
if ($prevMonth < 1) {
    $prevMonth = 12;
    $prevYear--;
}

$nextMonth = $month + 1;
$nextYear = $year;
if ($nextMonth > 12) {
    $nextMonth = 1;
    $nextYear++;
}

// 获取当前月的第一天和最后一天
$firstDay = new DateTime("$year-$month-01");
$lastDay = new DateTime($firstDay->format('Y-m-t'));

// 获取当前月的天数
$daysInMonth = (int)$lastDay->format('d');

// 获取当前月第一天是星期几（0表示星期日）
$firstDayOfWeek = (int)$firstDay->format('w');

// 获取房间列表
$roomSql = "SELECT r.id, r.room_number, r.floor, rt.name as room_type 
            FROM rooms r 
            JOIN room_types rt ON r.room_type_id = rt.id 
            ORDER BY r.floor, r.room_number";
$roomResult = $conn->query($roomSql);
$rooms = [];
if ($roomResult && $roomResult->num_rows > 0) {
    while ($row = $roomResult->fetch_assoc()) {
        $rooms[] = $row;
    }
}

// 获取当前月的预订信息
$startDate = $firstDay->format('Y-m-d');
$endDate = $lastDay->format('Y-m-d');

$bookingSql = "SELECT br.room_id, b.check_in_date, b.check_out_date, b.status, b.id as booking_id, b.guest_name 
               FROM booking_rooms br 
               JOIN bookings b ON br.booking_id = b.id 
               WHERE (b.check_in_date <= ? AND b.check_out_date >= ?) 
               AND b.status IN ('confirmed', 'checked_in', 'checked_out')";
$bookingStmt = $conn->prepare($bookingSql);
$bookingStmt->bind_param("ss", $endDate, $startDate);
$bookingStmt->execute();
$bookingResult = $bookingStmt->get_result();

// 创建房间预订数据结构
$roomBookings = [];
foreach ($rooms as $room) {
    $roomBookings[$room['id']] = array_fill(1, $daysInMonth, null);
}

// 填充预订数据
if ($bookingResult && $bookingResult->num_rows > 0) {
    while ($booking = $bookingResult->fetch_assoc()) {
        $roomId = $booking['room_id'];
        $checkInDate = new DateTime($booking['check_in_date']);
        $checkOutDate = new DateTime($booking['check_out_date']);

        // 调整日期范围到当前月
        $startDay = ($checkInDate < $firstDay) ? 1 : (int)$checkInDate->format('j');
        $endDay = ($checkOutDate > $lastDay) ? $daysInMonth : (int)$checkOutDate->format('j');

        // 填充预订信息
        for ($day = $startDay; $day <= $endDay; $day++) {
            $roomBookings[$roomId][$day] = [
                'booking_id' => $booking['booking_id'],
                'guest_name' => $booking['guest_name'],
                'status' => $booking['status'],
                'is_check_in' => ($day == $startDay),
                'is_check_out' => ($day == $endDay && $booking['check_out_date'] == date('Y-m-d', strtotime("$year-$month-$day")))
            ];
        }
    }
}

// 获取房间维修信息
$maintenanceSql = "SELECT room_id, DATE(reported_date) as start_date, 
                   IFNULL(DATE(completion_date), CURDATE()) as end_date 
                   FROM maintenance_records 
                   WHERE (DATE(reported_date) <= ? AND (completion_date IS NULL OR DATE(completion_date) >= ?)) 
                   AND status IN ('reported', 'assigned', 'in_progress')";
$maintenanceStmt = $conn->prepare($maintenanceSql);
$maintenanceStmt->bind_param("ss", $endDate, $startDate);
$maintenanceStmt->execute();
$maintenanceResult = $maintenanceStmt->get_result();

// 填充维修数据
if ($maintenanceResult && $maintenanceResult->num_rows > 0) {
    while ($maintenance = $maintenanceResult->fetch_assoc()) {
        $roomId = $maintenance['room_id'];
        $startDate = new DateTime($maintenance['start_date']);
        $endDate = new DateTime($maintenance['end_date']);

        // 调整日期范围到当前月
        $startDay = ($startDate < $firstDay) ? 1 : (int)$startDate->format('j');
        $endDay = ($endDate > $lastDay) ? $daysInMonth : (int)$endDate->format('j');

        // 填充维修信息
        for ($day = $startDay; $day <= $endDay; $day++) {
            // 只有在没有预订的情况下才标记为维修
            if ($roomBookings[$roomId][$day] === null) {
                $roomBookings[$roomId][$day] = [
                    'status' => 'maintenance'
                ];
            }
        }
    }
}

// 获取当前日期
$today = date('Y-m-d');
$currentYear = (int)date('Y');
$currentMonth = (int)date('m');
$currentDay = (int)date('d');

// 是否是当前月
$isCurrentMonth = ($year == $currentYear && $month == $currentMonth);

// 月份名称
$monthNames = [
    1 => '一月',
    2 => '二月',
    3 => '三月',
    4 => '四月',
    5 => '五月',
    6 => '六月',
    7 => '七月',
    8 => '八月',
    9 => '九月',
    10 => '十月',
    11 => '十一月',
    12 => '十二月'
];

// 星期名称
$weekDays = ['日', '一', '二', '三', '四', '五', '六'];
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>房态日历</h2>
    </div>

    <div class="calendar-controls">
        <div class="month-navigation">
            <a href="index.php?page=room_calendar&year=<?php echo $prevYear; ?>&month=<?php echo $prevMonth; ?>" class="btn btn-secondary">&laquo; 上个月</a>
            <h3><?php echo $year; ?>年 <?php echo $monthNames[$month]; ?></h3>
            <a href="index.php?page=room_calendar&year=<?php echo $nextYear; ?>&month=<?php echo $nextMonth; ?>" class="btn btn-secondary">下个月 &raquo;</a>
        </div>

        <div class="calendar-legend">
            <div class="legend-item">
                <span class="legend-color status-available"></span>
                <span class="legend-label">可用</span>
            </div>
            <div class="legend-item">
                <span class="legend-color status-booked"></span>
                <span class="legend-label">已预订</span>
            </div>
            <div class="legend-item">
                <span class="legend-color status-checked_in"></span>
                <span class="legend-label">已入住</span>
            </div>
            <div class="legend-item">
                <span class="legend-color status-checked_out"></span>
                <span class="legend-label">已退房</span>
            </div>
            <div class="legend-item">
                <span class="legend-color status-maintenance"></span>
                <span class="legend-label">维修中</span>
            </div>
            <div class="legend-item">
                <span class="legend-icon check-in-icon">▶</span>
                <span class="legend-label">入住日</span>
            </div>
            <div class="legend-item">
                <span class="legend-icon check-out-icon">◀</span>
                <span class="legend-label">退房日</span>
            </div>
        </div>
    </div>

    <div class="calendar-container">
        <table class="calendar-table">
            <thead>
                <tr>
                    <th class="room-header">房间</th>
                    <?php for ($day = 1; $day <= $daysInMonth; $day++): ?>
                        <?php
                        $dayOfWeek = ($firstDayOfWeek + $day - 1) % 7;
                        $isWeekend = ($dayOfWeek == 0 || $dayOfWeek == 6);
                        $isToday = ($isCurrentMonth && $day == $currentDay);
                        $cellClass = $isWeekend ? 'weekend' : '';
                        $cellClass .= $isToday ? ' today' : '';
                        ?>
                        <th class="day-header <?php echo $cellClass; ?>">
                            <div class="day-number"><?php echo $day; ?></div>
                            <div class="day-name"><?php echo $weekDays[$dayOfWeek]; ?></div>
                        </th>
                    <?php endfor; ?>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($rooms as $room): ?>
                    <tr>
                        <td class="room-cell">
                            <div class="room-number"><?php echo htmlspecialchars($room['room_number']); ?></div>
                            <div class="room-type"><?php echo htmlspecialchars($room['room_type']); ?></div>
                        </td>
                        <?php for ($day = 1; $day <= $daysInMonth; $day++): ?>
                            <?php
                            $booking = $roomBookings[$room['id']][$day];
                            $cellClass = '';
                            $cellContent = '';
                            $title = '';

                            if ($booking === null) {
                                $cellClass = 'status-available';
                            } else {
                                $cellClass = 'status-' . $booking['status'];

                                if (isset($booking['guest_name'])) {
                                    $title = '客人: ' . htmlspecialchars($booking['guest_name']);

                                    if (isset($booking['is_check_in']) && $booking['is_check_in']) {
                                        $cellContent .= '<span class="check-in-icon">▶</span>';
                                    }

                                    if (isset($booking['is_check_out']) && $booking['is_check_out']) {
                                        $cellContent .= '<span class="check-out-icon">◀</span>';
                                    }
                                }
                            }

                            $dayOfWeek = ($firstDayOfWeek + $day - 1) % 7;
                            $isWeekend = ($dayOfWeek == 0 || $dayOfWeek == 6);
                            $isToday = ($isCurrentMonth && $day == $currentDay);

                            if ($isWeekend) {
                                $cellClass .= ' weekend';
                            }

                            if ($isToday) {
                                $cellClass .= ' today';
                            }
                            ?>
                            <td class="calendar-cell <?php echo $cellClass; ?>" title="<?php echo $title; ?>">
                                <?php echo $cellContent; ?>
                            </td>
                        <?php endfor; ?>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .calendar-controls {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 20px;
        flex-wrap: wrap;
    }

    .month-navigation {
        display: flex;
        align-items: center;
        gap: 15px;
    }

    .month-navigation h3 {
        margin: 0;
        font-size: 18px;
        color: #0066cc;
    }

    .calendar-legend {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
    }

    .legend-item {
        display: flex;
        align-items: center;
        font-size: 12px;
    }

    .legend-color {
        width: 15px;
        height: 15px;
        border-radius: 3px;
        margin-right: 5px;
    }

    .legend-icon {
        width: 15px;
        text-align: center;
        margin-right: 5px;
        font-size: 14px;
    }

    .legend-label {
        color: #6c757d;
    }

    .calendar-container {
        overflow-x: auto;
    }

    .calendar-table {
        width: 100%;
        border-collapse: collapse;
        border: 1px solid #e9ecef;
    }

    .calendar-table th,
    .calendar-table td {
        border: 1px solid #e9ecef;
        padding: 8px;
        text-align: center;
        min-width: 40px;
    }

    .room-header {
        background-color: #f8f9fa;
        position: sticky;
        left: 0;
        z-index: 10;
        min-width: 120px;
    }

    .day-header {
        background-color: #f8f9fa;
    }

    .day-number {
        font-weight: bold;
    }

    .day-name {
        font-size: 12px;
        color: #6c757d;
    }

    .room-cell {
        background-color: #f8f9fa;
        position: sticky;
        left: 0;
        z-index: 5;
        text-align: left;
    }

    .room-number {
        font-weight: bold;
    }

    .room-type {
        font-size: 12px;
        color: #6c757d;
    }

    .calendar-cell {
        height: 40px;
        position: relative;
    }

    .status-available {
        background-color: #ffffff;
    }

    .status-confirmed,
    .status-booked {
        background-color: #ffc107;
    }

    .status-checked_in {
        background-color: #28a745;
    }

    .status-checked_out {
        background-color: #6c757d;
    }

    .status-maintenance {
        background-color: #dc3545;
    }

    .weekend {
        background-color: #f8f9fa;
    }

    .today {
        box-shadow: inset 0 0 0 2px #0066cc;
    }

    .check-in-icon {
        position: absolute;
        left: 2px;
        top: 50%;
        transform: translateY(-50%);
        color: #000;
        font-size: 12px;
    }

    .check-out-icon {
        position: absolute;
        right: 2px;
        top: 50%;
        transform: translateY(-50%);
        color: #000;
        font-size: 12px;
    }

    @media (max-width: 768px) {
        .calendar-controls {
            flex-direction: column;
            align-items: flex-start;
            gap: 15px;
        }

        .month-navigation {
            width: 100%;
            justify-content: space-between;
        }
    }
</style>