<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 检查是否有房间ID
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header('Location: index.php?page=room_list');
    exit;
}

$roomId = (int)$_GET['id'];

// 获取房间信息
$sql = "SELECT r.*, rt.name as room_type_name 
        FROM rooms r 
        JOIN room_types rt ON r.room_type_id = rt.id 
        WHERE r.id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $roomId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    header('Location: index.php?page=room_list');
    exit;
}

$room = $result->fetch_assoc();

// 获取所有房型
$roomTypesSql = "SELECT id, name FROM room_types WHERE status = 'active' ORDER BY name";
$roomTypesResult = $conn->query($roomTypesSql);
$roomTypes = [];
if ($roomTypesResult && $roomTypesResult->num_rows > 0) {
    while ($row = $roomTypesResult->fetch_assoc()) {
        $roomTypes[] = $row;
    }
}

// 获取房间图片
$imagesSql = "SELECT id, image_path, is_primary FROM room_images WHERE room_id = ? ORDER BY is_primary DESC, id ASC";
$imagesStmt = $conn->prepare($imagesSql);
$imagesStmt->bind_param("i", $roomId);
$imagesStmt->execute();
$imagesResult = $imagesStmt->get_result();
$roomImages = [];
if ($imagesResult && $imagesResult->num_rows > 0) {
    while ($row = $imagesResult->fetch_assoc()) {
        $roomImages[] = $row;
    }
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $roomNumber = sanitize($_POST['room_number']);
    $roomTypeId = (int)$_POST['room_type_id'];
    $floor = sanitize($_POST['floor']);
    $area = (float)$_POST['area'];
    $bedType = sanitize($_POST['bed_type']);
    $hasWindow = isset($_POST['has_window']) ? 1 : 0;
    $hasBathroom = isset($_POST['has_bathroom']) ? 1 : 0;
    $amenities = sanitize($_POST['amenities']);
    $description = sanitize($_POST['description']);
    $priceAdjustment = (float)$_POST['price_adjustment'];
    $status = sanitize($_POST['status']);

    // 验证数据
    $errors = [];

    if (empty($roomNumber)) {
        $errors[] = '房间号不能为空';
    }

    if ($roomTypeId <= 0) {
        $errors[] = '请选择房型';
    }

    if (empty($floor)) {
        $errors[] = '楼层不能为空';
    }

    // 检查房间号是否已存在（排除当前房间）
    $checkSql = "SELECT id FROM rooms WHERE room_number = ? AND id != ?";
    $checkStmt = $conn->prepare($checkSql);
    $checkStmt->bind_param("si", $roomNumber, $roomId);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows > 0) {
        $errors[] = '房间号已存在，请使用其他房间号';
    }

    // 如果没有错误，更新数据
    if (empty($errors)) {
        $sql = "UPDATE rooms SET 
                room_number = ?, 
                room_type_id = ?, 
                floor = ?, 
                area = ?, 
                bed_type = ?, 
                has_window = ?, 
                has_bathroom = ?, 
                amenities = ?, 
                description = ?, 
                price_adjustment = ?, 
                status = ? 
                WHERE id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("sisdssisdsi", $roomNumber, $roomTypeId, $floor, $area, $bedType, $hasWindow, $hasBathroom, $amenities, $description, $priceAdjustment, $status, $roomId);

        if ($stmt->execute()) {
            // 处理图片上传
            if (isset($_FILES['room_images']) && !empty($_FILES['room_images']['name'][0])) {
                $uploadDir = '../../assets/images/uploads/rooms/';

                // 确保目录存在
                if (!file_exists($uploadDir)) {
                    mkdir($uploadDir, 0777, true);
                }

                $allowedTypes = ['image/jpeg', 'image/png', 'image/gif'];
                $maxSize = 5 * 1024 * 1024; // 5MB

                $images = $_FILES['room_images'];
                $imageCount = count($images['name']);

                for ($i = 0; $i < $imageCount; $i++) {
                    if ($images['error'][$i] === UPLOAD_ERR_OK) {
                        $tmpName = $images['tmp_name'][$i];
                        $name = $images['name'][$i];
                        $size = $images['size'][$i];
                        $type = $images['type'][$i];

                        // 验证文件类型和大小
                        if (!in_array($type, $allowedTypes)) {
                            $errors[] = '文件类型不支持: ' . $name;
                            continue;
                        }

                        if ($size > $maxSize) {
                            $errors[] = '文件大小超过限制: ' . $name;
                            continue;
                        }

                        // 生成唯一文件名
                        $extension = pathinfo($name, PATHINFO_EXTENSION);
                        $newName = uniqid('room_') . '.' . $extension;
                        $destination = $uploadDir . $newName;

                        if (move_uploaded_file($tmpName, $destination)) {
                            // 保存图片信息到数据库
                            $isPrimary = 0; // 新上传的图片默认不是主图
                            $imagePath = 'assets/images/uploads/rooms/' . $newName;

                            $imageSql = "INSERT INTO room_images (room_id, image_path, is_primary) VALUES (?, ?, ?)";
                            $imageStmt = $conn->prepare($imageSql);
                            $imageStmt->bind_param("isi", $roomId, $imagePath, $isPrimary);
                            $imageStmt->execute();
                        } else {
                            $errors[] = '上传文件失败: ' . $name;
                        }
                    } else if ($images['error'][$i] !== UPLOAD_ERR_NO_FILE) {
                        $errors[] = '上传文件错误: ' . $images['error'][$i];
                    }
                }
            }

            // 处理删除图片
            if (isset($_POST['delete_images']) && is_array($_POST['delete_images'])) {
                foreach ($_POST['delete_images'] as $imageId) {
                    // 获取图片路径
                    $getImageSql = "SELECT image_path FROM room_images WHERE id = ? AND room_id = ?";
                    $getImageStmt = $conn->prepare($getImageSql);
                    $getImageStmt->bind_param("ii", $imageId, $roomId);
                    $getImageStmt->execute();
                    $getImageResult = $getImageStmt->get_result();

                    if ($getImageResult->num_rows > 0) {
                        $imageRow = $getImageResult->fetch_assoc();
                        $imagePath = '../../' . $imageRow['image_path'];

                        // 删除文件
                        if (file_exists($imagePath)) {
                            unlink($imagePath);
                        }

                        // 删除数据库记录
                        $deleteImageSql = "DELETE FROM room_images WHERE id = ?";
                        $deleteImageStmt = $conn->prepare($deleteImageSql);
                        $deleteImageStmt->bind_param("i", $imageId);
                        $deleteImageStmt->execute();
                    }
                }
            }

            // 处理设置主图
            if (isset($_POST['primary_image']) && is_numeric($_POST['primary_image'])) {
                $primaryImageId = (int)$_POST['primary_image'];

                // 先将所有图片设为非主图
                $resetSql = "UPDATE room_images SET is_primary = 0 WHERE room_id = ?";
                $resetStmt = $conn->prepare($resetSql);
                $resetStmt->bind_param("i", $roomId);
                $resetStmt->execute();

                // 设置选中的图片为主图
                $setPrimarySql = "UPDATE room_images SET is_primary = 1 WHERE id = ? AND room_id = ?";
                $setPrimaryStmt = $conn->prepare($setPrimarySql);
                $setPrimaryStmt->bind_param("ii", $primaryImageId, $roomId);
                $setPrimaryStmt->execute();
            }

            // 记录操作日志
            logActivity('edit_room', '编辑房间: ' . $roomNumber);

            // 设置成功消息并重定向
            $_SESSION['success_message'] = '房间更新成功';
            header('Location: index.php?page=room_list');
            exit;
        } else {
            $errors[] = '更新房间失败: ' . $conn->error;
        }
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>编辑房间</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <a href="index.php?page=room_list">房间列表</a> /
            <span>编辑房间</span>
        </nav>
    </div>

    <?php if (!empty($errors)): ?>
        <div class="alert alert-error">
            <ul>
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <div class="card">
        <div class="card-body">
            <form method="post" action="" enctype="multipart/form-data" class="form-horizontal">
                <div class="form-section">
                    <h3>基本信息</h3>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="room_number">房间号 <span class="required">*</span></label>
                            <input type="text" id="room_number" name="room_number" value="<?php echo htmlspecialchars($room['room_number']); ?>" required>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="room_type_id">房型 <span class="required">*</span></label>
                            <select id="room_type_id" name="room_type_id" required>
                                <option value="">请选择房型</option>
                                <?php foreach ($roomTypes as $type): ?>
                                    <option value="<?php echo $type['id']; ?>" <?php echo ($room['room_type_id'] == $type['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($type['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="floor">楼层 <span class="required">*</span></label>
                            <input type="text" id="floor" name="floor" value="<?php echo htmlspecialchars($room['floor']); ?>" required>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="area">面积(㎡)</label>
                            <input type="number" id="area" name="area" step="0.01" min="0" value="<?php echo htmlspecialchars($room['area']); ?>">
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="bed_type">床型</label>
                            <input type="text" id="bed_type" name="bed_type" value="<?php echo htmlspecialchars($room['bed_type']); ?>">
                        </div>

                        <div class="form-group col-md-6">
                            <label for="price_adjustment">价格调整</label>
                            <input type="number" id="price_adjustment" name="price_adjustment" step="0.01" value="<?php echo htmlspecialchars($room['price_adjustment']); ?>">
                            <small>正数表示上调，负数表示下调</small>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <div class="checkbox-group">
                                <label>
                                    <input type="checkbox" name="has_window" <?php echo ($room['has_window']) ? 'checked' : ''; ?>>
                                    有窗户
                                </label>
                            </div>
                        </div>

                        <div class="form-group col-md-6">
                            <div class="checkbox-group">
                                <label>
                                    <input type="checkbox" name="has_bathroom" <?php echo ($room['has_bathroom']) ? 'checked' : ''; ?>>
                                    有独立卫生间
                                </label>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="form-section">
                    <h3>详细信息</h3>

                    <div class="form-group">
                        <label for="amenities">设施与服务</label>
                        <textarea id="amenities" name="amenities" rows="3"><?php echo htmlspecialchars($room['amenities']); ?></textarea>
                        <small>例如：空调、电视、冰箱、热水壶等，用逗号分隔</small>
                    </div>

                    <div class="form-group">
                        <label for="description">房间描述</label>
                        <textarea id="description" name="description" rows="5"><?php echo htmlspecialchars($room['description']); ?></textarea>
                    </div>
                </div>

                <div class="form-section">
                    <h3>房间图片</h3>

                    <?php if (!empty($roomImages)): ?>
                        <div class="current-images">
                            <h4>当前图片</h4>
                            <div class="image-grid">
                                <?php foreach ($roomImages as $image): ?>
                                    <div class="image-item <?php echo $image['is_primary'] ? 'is-primary' : ''; ?>">
                                        <div class="image-preview">
                                            <img src="../../<?php echo htmlspecialchars($image['image_path']); ?>" alt="房间图片">
                                        </div>
                                        <div class="image-actions">
                                            <label>
                                                <input type="radio" name="primary_image" value="<?php echo $image['id']; ?>" <?php echo $image['is_primary'] ? 'checked' : ''; ?>>
                                                设为主图
                                            </label>
                                            <label>
                                                <input type="checkbox" name="delete_images[]" value="<?php echo $image['id']; ?>">
                                                删除
                                            </label>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="form-group">
                        <label for="room_images">上传新图片</label>
                        <input type="file" id="room_images" name="room_images[]" multiple accept="image/*">
                        <small>可以选择多张图片。支持JPG、PNG、GIF格式，单张图片大小不超过5MB。</small>
                    </div>

                    <div id="image-preview" class="image-preview-container"></div>
                </div>

                <div class="form-section">
                    <h3>状态</h3>

                    <div class="form-group">
                        <label for="status">房间状态</label>
                        <select id="status" name="status">
                            <option value="available" <?php echo ($room['status'] == 'available') ? 'selected' : ''; ?>>可用</option>
                            <option value="booked" <?php echo ($room['status'] == 'booked') ? 'selected' : ''; ?>>已预订</option>
                            <option value="occupied" <?php echo ($room['status'] == 'occupied') ? 'selected' : ''; ?>>已入住</option>
                            <option value="maintenance" <?php echo ($room['status'] == 'maintenance') ? 'selected' : ''; ?>>维修中</option>
                        </select>
                    </div>
                </div>

                <div class="form-actions">
                    <button type="submit" class="btn btn-primary">保存</button>
                    <a href="index.php?page=room_list" class="btn btn-secondary">取消</a>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 图片预览
        const input = document.getElementById('room_images');
        const preview = document.getElementById('image-preview');

        input.addEventListener('change', function() {
            preview.innerHTML = '';

            if (this.files) {
                for (let i = 0; i < this.files.length; i++) {
                    const file = this.files[i];

                    if (!file.type.match('image.*')) {
                        continue;
                    }

                    const reader = new FileReader();

                    reader.onload = function(e) {
                        const div = document.createElement('div');
                        div.className = 'image-preview';

                        const img = document.createElement('img');
                        img.src = e.target.result;
                        img.title = file.name;

                        div.appendChild(img);
                        preview.appendChild(div);
                    };

                    reader.readAsDataURL(file);
                }
            }
        });
    });
</script>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .page-header h2 {
        margin-bottom: 5px;
    }

    .breadcrumb {
        font-size: 14px;
        color: #6c757d;
    }

    .breadcrumb a {
        color: #0066cc;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
    }

    .card-body {
        padding: 20px;
    }

    .form-section {
        margin-bottom: 30px;
    }

    .form-section h3 {
        font-size: 18px;
        color: #0066cc;
        margin-bottom: 15px;
        padding-bottom: 10px;
        border-bottom: 1px solid #e9ecef;
    }

    .form-section h4 {
        font-size: 16px;
        color: #495057;
        margin-bottom: 10px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
    }

    .required {
        color: #dc3545;
    }

    .checkbox-group {
        margin-top: 30px;
    }

    .current-images {
        margin-bottom: 20px;
    }

    .image-grid {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        margin-bottom: 20px;
    }

    .image-item {
        width: 200px;
        border: 1px solid #ddd;
        border-radius: 4px;
        overflow: hidden;
        padding-bottom: 10px;
    }

    .image-item.is-primary {
        border-color: #0066cc;
        box-shadow: 0 0 0 2px rgba(0, 102, 204, 0.3);
    }

    .image-preview {
        width: 100%;
        height: 150px;
        overflow: hidden;
        margin-bottom: 10px;
    }

    .image-preview img {
        width: 100%;
        height: 100%;
        object-fit: cover;
    }

    .image-actions {
        padding: 0 10px;
        font-size: 14px;
    }

    .image-actions label {
        display: block;
        margin-bottom: 5px;
    }

    .image-preview-container {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        margin-top: 10px;
    }

    .form-actions {
        display: flex;
        gap: 10px;
        margin-top: 20px;
    }

    @media (max-width: 768px) {
        .col-md-6 {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>