<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 处理删除房间请求
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $roomId = (int)$_GET['id'];

    // 检查房间是否存在
    $checkSql = "SELECT id FROM rooms WHERE id = ?";
    $checkStmt = $conn->prepare($checkSql);
    $checkStmt->bind_param("i", $roomId);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows > 0) {
        // 删除房间
        $deleteSql = "DELETE FROM rooms WHERE id = ?";
        $deleteStmt = $conn->prepare($deleteSql);
        $deleteStmt->bind_param("i", $roomId);

        if ($deleteStmt->execute()) {
            // 记录操作日志
            logActivity('delete_room', '删除房间ID: ' . $roomId);
            $successMessage = '房间删除成功';
        } else {
            $errorMessage = '删除房间失败: ' . $conn->error;
        }
    } else {
        $errorMessage = '房间不存在';
    }
}

// 处理房间状态更新请求
if (isset($_GET['action']) && $_GET['action'] == 'update_status' && isset($_GET['id']) && isset($_GET['status'])) {
    $roomId = (int)$_GET['id'];
    $status = $_GET['status'];

    // 验证状态值
    $validStatuses = ['available', 'booked', 'occupied', 'maintenance'];
    if (in_array($status, $validStatuses)) {
        // 更新房间状态
        $updateSql = "UPDATE rooms SET status = ? WHERE id = ?";
        $updateStmt = $conn->prepare($updateSql);
        $updateStmt->bind_param("si", $status, $roomId);

        if ($updateStmt->execute()) {
            // 记录操作日志
            logActivity('update_room_status', '更新房间ID: ' . $roomId . ' 状态为: ' . $status);
            $successMessage = '房间状态更新成功';
        } else {
            $errorMessage = '更新房间状态失败: ' . $conn->error;
        }
    } else {
        $errorMessage = '无效的房间状态';
    }
}

// 分页设置
$page = isset($_GET['p']) ? (int)$_GET['p'] : 1;
$perPage = 10;
$offset = ($page - 1) * $perPage;

// 搜索条件
$search = isset($_GET['search']) ? $_GET['search'] : '';
$statusFilter = isset($_GET['status_filter']) ? $_GET['status_filter'] : '';
$roomTypeFilter = isset($_GET['room_type_filter']) ? (int)$_GET['room_type_filter'] : 0;

// 构建查询条件
$whereConditions = [];
$params = [];
$paramTypes = '';

if (!empty($search)) {
    $whereConditions[] = "(r.room_number LIKE ? OR r.floor LIKE ?)";
    $searchParam = "%$search%";
    $params[] = $searchParam;
    $params[] = $searchParam;
    $paramTypes .= 'ss';
}

if (!empty($statusFilter)) {
    $whereConditions[] = "r.status = ?";
    $params[] = $statusFilter;
    $paramTypes .= 's';
}

if ($roomTypeFilter > 0) {
    $whereConditions[] = "r.room_type_id = ?";
    $params[] = $roomTypeFilter;
    $paramTypes .= 'i';
}

$whereClause = '';
if (!empty($whereConditions)) {
    $whereClause = "WHERE " . implode(" AND ", $whereConditions);
}

// 获取房间总数
$countSql = "SELECT COUNT(*) as total FROM rooms r $whereClause";
$countStmt = null;

if (!empty($params)) {
    $countStmt = $conn->prepare($countSql);
    $countStmt->bind_param($paramTypes, ...$params);
    $countStmt->execute();
    $countResult = $countStmt->get_result();
} else {
    $countResult = $conn->query($countSql);
}

$totalRooms = 0;
if ($countResult && $countResult->num_rows > 0) {
    $row = $countResult->fetch_assoc();
    $totalRooms = $row['total'];
}

$totalPages = ceil($totalRooms / $perPage);

// 获取房间列表
$sql = "SELECT r.id, r.room_number, r.floor, r.area, r.bed_type, r.status, 
               rt.name as room_type, rt.base_price, r.price_adjustment
        FROM rooms r
        JOIN room_types rt ON r.room_type_id = rt.id
        $whereClause
        ORDER BY r.room_number
        LIMIT ?, ?";

// 添加分页参数
$params[] = $offset;
$params[] = $perPage;
$paramTypes .= 'ii';

$stmt = $conn->prepare($sql);
$stmt->bind_param($paramTypes, ...$params);
$stmt->execute();
$result = $stmt->get_result();

$rooms = [];
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $rooms[] = $row;
    }
}

// 获取所有房型，用于筛选
$roomTypesSql = "SELECT id, name FROM room_types ORDER BY name";
$roomTypesResult = $conn->query($roomTypesSql);
$roomTypes = [];
if ($roomTypesResult && $roomTypesResult->num_rows > 0) {
    while ($row = $roomTypesResult->fetch_assoc()) {
        $roomTypes[] = $row;
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>房间列表</h2>
        <div class="page-actions">
            <a href="index.php?page=room_add" class="btn btn-primary">添加房间</a>
        </div>
    </div>

    <?php if (isset($_SESSION['success_message'])): ?>
        <div class="alert alert-success">
            <?php
            echo $_SESSION['success_message'];
            unset($_SESSION['success_message']);
            ?>
        </div>
    <?php endif; ?>

    <!-- 搜索和筛选 -->
    <div class="filter-container">
        <form method="get" action="" class="filter-form">
            <input type="hidden" name="page" value="room_list">

            <div class="form-group">
                <input type="text" name="search" placeholder="搜索房间号或楼层" value="<?php echo htmlspecialchars($search); ?>">
            </div>

            <div class="form-group">
                <select name="status_filter">
                    <option value="">所有状态</option>
                    <option value="available" <?php echo $statusFilter == 'available' ? 'selected' : ''; ?>>可用</option>
                    <option value="booked" <?php echo $statusFilter == 'booked' ? 'selected' : ''; ?>>已预订</option>
                    <option value="occupied" <?php echo $statusFilter == 'occupied' ? 'selected' : ''; ?>>已入住</option>
                    <option value="maintenance" <?php echo $statusFilter == 'maintenance' ? 'selected' : ''; ?>>维修中</option>
                </select>
            </div>

            <div class="form-group">
                <select name="room_type_filter">
                    <option value="0">所有房型</option>
                    <?php foreach ($roomTypes as $type): ?>
                        <option value="<?php echo $type['id']; ?>" <?php echo $roomTypeFilter == $type['id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($type['name']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <button type="submit" class="btn btn-primary">筛选</button>
            <a href="index.php?page=room_list" class="btn btn-secondary">重置</a>
        </form>
    </div>

    <!-- 房间列表 -->
    <div class="table-responsive">
        <table class="data-table">
            <thead>
                <tr>
                    <th>房间号</th>
                    <th>楼层</th>
                    <th>房型</th>
                    <th>面积(㎡)</th>
                    <th>床型</th>
                    <th>基础价格</th>
                    <th>调整价格</th>
                    <th>实际价格</th>
                    <th>状态</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($rooms)): ?>
                    <tr>
                        <td colspan="10" class="text-center">暂无房间数据</td>
                    </tr>
                <?php else: ?>
                    <?php foreach ($rooms as $room): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($room['room_number']); ?></td>
                            <td><?php echo htmlspecialchars($room['floor']); ?></td>
                            <td><?php echo htmlspecialchars($room['room_type']); ?></td>
                            <td><?php echo htmlspecialchars($room['area']); ?></td>
                            <td><?php echo htmlspecialchars($room['bed_type']); ?></td>
                            <td>¥<?php echo number_format($room['base_price'], 2); ?></td>
                            <td>¥<?php echo number_format($room['price_adjustment'], 2); ?></td>
                            <td>¥<?php echo number_format($room['base_price'] + $room['price_adjustment'], 2); ?></td>
                            <td>
                                <span class="status-badge status-<?php echo $room['status']; ?>">
                                    <?php
                                    switch ($room['status']) {
                                        case 'available':
                                            echo '可用';
                                            break;
                                        case 'booked':
                                            echo '已预订';
                                            break;
                                        case 'occupied':
                                            echo '已入住';
                                            break;
                                        case 'maintenance':
                                            echo '维修中';
                                            break;
                                        default:
                                            echo $room['status'];
                                    }
                                    ?>
                                </span>
                            </td>
                            <td class="actions">
                                <div class="dropdown">
                                    <button class="btn btn-secondary dropdown-toggle">操作</button>
                                    <div class="dropdown-menu">
                                        <a href="index.php?page=room_edit&id=<?php echo $room['id']; ?>" class="dropdown-item">编辑</a>
                                        <a href="index.php?page=room_view&id=<?php echo $room['id']; ?>" class="dropdown-item">查看详情</a>
                                        <div class="dropdown-divider"></div>
                                        <a href="#" class="dropdown-item status-change" data-id="<?php echo $room['id']; ?>" data-status="available">设为可用</a>
                                        <a href="#" class="dropdown-item status-change" data-id="<?php echo $room['id']; ?>" data-status="maintenance">设为维修中</a>
                                        <div class="dropdown-divider"></div>
                                        <a href="#" class="dropdown-item text-danger delete-room" data-id="<?php echo $room['id']; ?>" data-room="<?php echo htmlspecialchars($room['room_number']); ?>">删除</a>
                                    </div>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <!-- 分页 -->
    <?php if ($totalPages > 1): ?>
        <div class="pagination">
            <?php if ($page > 1): ?>
                <a href="index.php?page=room_list&p=1<?php echo !empty($search) ? '&search=' . urlencode($search) : ''; ?><?php echo !empty($statusFilter) ? '&status_filter=' . urlencode($statusFilter) : ''; ?><?php echo $roomTypeFilter > 0 ? '&room_type_filter=' . $roomTypeFilter : ''; ?>" class="pagination-item">首页</a>
                <a href="index.php?page=room_list&p=<?php echo $page - 1; ?><?php echo !empty($search) ? '&search=' . urlencode($search) : ''; ?><?php echo !empty($statusFilter) ? '&status_filter=' . urlencode($statusFilter) : ''; ?><?php echo $roomTypeFilter > 0 ? '&room_type_filter=' . $roomTypeFilter : ''; ?>" class="pagination-item">上一页</a>
            <?php endif; ?>

            <?php
            $startPage = max(1, $page - 2);
            $endPage = min($totalPages, $page + 2);

            for ($i = $startPage; $i <= $endPage; $i++):
            ?>
                <a href="index.php?page=room_list&p=<?php echo $i; ?><?php echo !empty($search) ? '&search=' . urlencode($search) : ''; ?><?php echo !empty($statusFilter) ? '&status_filter=' . urlencode($statusFilter) : ''; ?><?php echo $roomTypeFilter > 0 ? '&room_type_filter=' . $roomTypeFilter : ''; ?>" class="pagination-item <?php echo $i == $page ? 'active' : ''; ?>"><?php echo $i; ?></a>
            <?php endfor; ?>

            <?php if ($page < $totalPages): ?>
                <a href="index.php?page=room_list&p=<?php echo $page + 1; ?><?php echo !empty($search) ? '&search=' . urlencode($search) : ''; ?><?php echo !empty($statusFilter) ? '&status_filter=' . urlencode($statusFilter) : ''; ?><?php echo $roomTypeFilter > 0 ? '&room_type_filter=' . $roomTypeFilter : ''; ?>" class="pagination-item">下一页</a>
                <a href="index.php?page=room_list&p=<?php echo $totalPages; ?><?php echo !empty($search) ? '&search=' . urlencode($search) : ''; ?><?php echo !empty($statusFilter) ? '&status_filter=' . urlencode($statusFilter) : ''; ?><?php echo $roomTypeFilter > 0 ? '&room_type_filter=' . $roomTypeFilter : ''; ?>" class="pagination-item">末页</a>
            <?php endif; ?>
        </div>
    <?php endif; ?>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 状态更改
        const statusLinks = document.querySelectorAll('.status-change');
        statusLinks.forEach(link => {
            link.addEventListener('click', function(e) {
                e.preventDefault();
                const roomId = this.getAttribute('data-id');
                const status = this.getAttribute('data-status');

                if (confirm('确定要将此房间状态更改为' + (status === 'available' ? '可用' : '维修中') + '吗？')) {
                    window.location.href = `index.php?page=room_list&action=update_status&id=${roomId}&status=${status}`;
                }
            });
        });

        // 删除房间
        const deleteLinks = document.querySelectorAll('.delete-room');
        deleteLinks.forEach(link => {
            link.addEventListener('click', function(e) {
                e.preventDefault();
                const roomId = this.getAttribute('data-id');
                const roomNumber = this.getAttribute('data-room');

                if (confirm(`确定要删除房间 ${roomNumber} 吗？此操作不可恢复！`)) {
                    window.location.href = `index.php?page=room_list&action=delete&id=${roomId}`;
                }
            });
        });

        // 下拉菜单
        const dropdowns = document.querySelectorAll('.dropdown');
        dropdowns.forEach(dropdown => {
            const toggle = dropdown.querySelector('.dropdown-toggle');
            const menu = dropdown.querySelector('.dropdown-menu');

            toggle.addEventListener('click', function(e) {
                e.preventDefault();
                menu.classList.toggle('show');
            });

            // 点击外部关闭下拉菜单
            document.addEventListener('click', function(e) {
                if (!dropdown.contains(e.target)) {
                    menu.classList.remove('show');
                }
            });
        });
    });
</script>

<style>
    .filter-container {
        display: flex;
        justify-content: space-between;
        margin-bottom: 20px;
        flex-wrap: wrap;
    }

    .filter-form {
        display: flex;
        gap: 10px;
        flex-wrap: wrap;
    }

    .action-buttons {
        display: flex;
        gap: 10px;
        align-items: flex-start;
    }

    .table-responsive {
        overflow-x: auto;
        margin-bottom: 20px;
    }

    .text-center {
        text-align: center;
    }

    .dropdown {
        position: relative;
        display: inline-block;
    }

    .dropdown-menu {
        display: none;
        position: absolute;
        right: 0;
        background-color: #fff;
        min-width: 160px;
        box-shadow: 0 8px 16px rgba(0, 0, 0, 0.1);
        z-index: 1;
        border-radius: 4px;
        padding: 5px 0;
    }

    .dropdown-menu.show {
        display: block;
    }

    .dropdown-item {
        display: block;
        padding: 8px 15px;
        color: #333;
        text-decoration: none;
    }

    .dropdown-item:hover {
        background-color: #f5f5f5;
        text-decoration: none;
    }

    .dropdown-divider {
        height: 1px;
        background-color: #e9ecef;
        margin: 5px 0;
    }

    .text-danger {
        color: #dc3545;
    }
</style>