<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 检查是否有房间ID
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header('Location: index.php?page=room_list');
    exit;
}

$roomId = (int)$_GET['id'];

// 获取房间信息
$sql = "SELECT r.*, rt.name as room_type_name, rt.base_price 
        FROM rooms r 
        JOIN room_types rt ON r.room_type_id = rt.id 
        WHERE r.id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $roomId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    header('Location: index.php?page=room_list');
    exit;
}

$room = $result->fetch_assoc();

// 获取房间图片
$imagesSql = "SELECT id, image_path, is_primary FROM room_images WHERE room_id = ? ORDER BY is_primary DESC, id ASC";
$imagesStmt = $conn->prepare($imagesSql);
$imagesStmt->bind_param("i", $roomId);
$imagesStmt->execute();
$imagesResult = $imagesStmt->get_result();
$roomImages = [];
if ($imagesResult && $imagesResult->num_rows > 0) {
    while ($row = $imagesResult->fetch_assoc()) {
        $roomImages[] = $row;
    }
}

// 获取当前预订信息（如果有）
$bookingSql = "SELECT b.id, b.booking_number, b.guest_name, b.check_in_date, b.check_out_date, b.status 
               FROM bookings b 
               JOIN booking_rooms br ON b.id = br.booking_id 
               WHERE br.room_id = ? AND (b.status = 'confirmed' OR b.status = 'checked_in') 
               ORDER BY b.check_in_date ASC 
               LIMIT 1";
$bookingStmt = $conn->prepare($bookingSql);
$bookingStmt->bind_param("i", $roomId);
$bookingStmt->execute();
$bookingResult = $bookingStmt->get_result();
$currentBooking = null;
if ($bookingResult && $bookingResult->num_rows > 0) {
    $currentBooking = $bookingResult->fetch_assoc();
}

// 获取未来预订信息
$futureBookingsSql = "SELECT b.id, b.booking_number, b.guest_name, b.check_in_date, b.check_out_date, b.status 
                      FROM bookings b 
                      JOIN booking_rooms br ON b.id = br.booking_id 
                      WHERE br.room_id = ? AND b.status = 'confirmed' AND b.check_in_date > CURDATE() 
                      ORDER BY b.check_in_date ASC 
                      LIMIT 5";
$futureBookingsStmt = $conn->prepare($futureBookingsSql);
$futureBookingsStmt->bind_param("i", $roomId);
$futureBookingsStmt->execute();
$futureBookingsResult = $futureBookingsStmt->get_result();
$futureBookings = [];
if ($futureBookingsResult && $futureBookingsResult->num_rows > 0) {
    while ($row = $futureBookingsResult->fetch_assoc()) {
        $futureBookings[] = $row;
    }
}

// 获取最近的维修记录
$maintenanceSql = "SELECT id, issue_description, reported_date, status, completion_date 
                   FROM maintenance_records 
                   WHERE room_id = ? 
                   ORDER BY reported_date DESC 
                   LIMIT 5";
$maintenanceStmt = $conn->prepare($maintenanceSql);
$maintenanceStmt->bind_param("i", $roomId);
$maintenanceStmt->execute();
$maintenanceResult = $maintenanceStmt->get_result();
$maintenanceRecords = [];
if ($maintenanceResult && $maintenanceResult->num_rows > 0) {
    while ($row = $maintenanceResult->fetch_assoc()) {
        $maintenanceRecords[] = $row;
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>房间详情</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <a href="index.php?page=room_list">房间列表</a> /
            <span>房间详情</span>
        </nav>
    </div>

    <div class="room-header">
        <div class="room-title">
            <h1><?php echo htmlspecialchars($room['room_number']); ?></h1>
            <span class="room-type"><?php echo htmlspecialchars($room['room_type_name']); ?></span>
            <span class="status-badge status-<?php echo $room['status']; ?>">
                <?php
                switch ($room['status']) {
                    case 'available':
                        echo '可用';
                        break;
                    case 'booked':
                        echo '已预订';
                        break;
                    case 'occupied':
                        echo '已入住';
                        break;
                    case 'maintenance':
                        echo '维修中';
                        break;
                    default:
                        echo $room['status'];
                }
                ?>
            </span>
        </div>

        <div class="room-actions">
            <a href="index.php?page=room_edit&id=<?php echo $roomId; ?>" class="btn btn-primary">编辑房间</a>
            <?php if ($room['status'] == 'available'): ?>
                <a href="index.php?page=room_list&action=update_status&id=<?php echo $roomId; ?>&status=maintenance" class="btn btn-warning" onclick="return confirm('确定要将此房间状态更改为维修中吗？');">设为维修中</a>
            <?php elseif ($room['status'] == 'maintenance'): ?>
                <a href="index.php?page=room_list&action=update_status&id=<?php echo $roomId; ?>&status=available" class="btn btn-success" onclick="return confirm('确定要将此房间状态更改为可用吗？');">设为可用</a>
            <?php endif; ?>
        </div>
    </div>

    <div class="room-content">
        <div class="room-gallery">
            <?php if (!empty($roomImages)): ?>
                <div class="gallery-main">
                    <img src="../../<?php echo htmlspecialchars($roomImages[0]['image_path']); ?>" alt="房间主图" id="main-image">
                </div>

                <?php if (count($roomImages) > 1): ?>
                    <div class="gallery-thumbs">
                        <?php foreach ($roomImages as $index => $image): ?>
                            <div class="thumb <?php echo $index === 0 ? 'active' : ''; ?>" data-src="../../<?php echo htmlspecialchars($image['image_path']); ?>">
                                <img src="../../<?php echo htmlspecialchars($image['image_path']); ?>" alt="房间图片">
                            </div>
                        <?php endforeach; ?>
                    </div>
                <?php endif; ?>
            <?php else: ?>
                <div class="no-images">
                    <p>暂无房间图片</p>
                </div>
            <?php endif; ?>
        </div>

        <div class="room-details">
            <div class="card">
                <div class="card-header">
                    <h3>基本信息</h3>
                </div>
                <div class="card-body">
                    <div class="detail-row">
                        <div class="detail-label">房间号</div>
                        <div class="detail-value"><?php echo htmlspecialchars($room['room_number']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">房型</div>
                        <div class="detail-value"><?php echo htmlspecialchars($room['room_type_name']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">楼层</div>
                        <div class="detail-value"><?php echo htmlspecialchars($room['floor']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">面积</div>
                        <div class="detail-value"><?php echo htmlspecialchars($room['area']); ?> ㎡</div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">床型</div>
                        <div class="detail-value"><?php echo htmlspecialchars($room['bed_type']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">窗户</div>
                        <div class="detail-value"><?php echo $room['has_window'] ? '有' : '无'; ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">独立卫生间</div>
                        <div class="detail-value"><?php echo $room['has_bathroom'] ? '有' : '无'; ?></div>
                    </div>
                </div>
            </div>

            <div class="card">
                <div class="card-header">
                    <h3>价格信息</h3>
                </div>
                <div class="card-body">
                    <div class="detail-row">
                        <div class="detail-label">基础价格</div>
                        <div class="detail-value">¥<?php echo number_format($room['base_price'], 2); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">价格调整</div>
                        <div class="detail-value">¥<?php echo number_format($room['price_adjustment'], 2); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">实际价格</div>
                        <div class="detail-value price-highlight">¥<?php echo number_format($room['base_price'] + $room['price_adjustment'], 2); ?></div>
                    </div>
                </div>
            </div>

            <?php if (!empty($room['amenities']) || !empty($room['description'])): ?>
                <div class="card">
                    <div class="card-header">
                        <h3>详细信息</h3>
                    </div>
                    <div class="card-body">
                        <?php if (!empty($room['amenities'])): ?>
                            <div class="detail-section">
                                <h4>设施与服务</h4>
                                <div class="amenities-list">
                                    <?php
                                    $amenitiesArray = explode(',', $room['amenities']);
                                    foreach ($amenitiesArray as $amenity):
                                        $amenity = trim($amenity);
                                        if (!empty($amenity)):
                                    ?>
                                            <span class="amenity-tag"><?php echo htmlspecialchars($amenity); ?></span>
                                    <?php
                                        endif;
                                    endforeach;
                                    ?>
                                </div>
                            </div>
                        <?php endif; ?>

                        <?php if (!empty($room['description'])): ?>
                            <div class="detail-section">
                                <h4>房间描述</h4>
                                <div class="room-description">
                                    <?php echo nl2br(htmlspecialchars($room['description'])); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endif; ?>

            <?php if ($currentBooking): ?>
                <div class="card">
                    <div class="card-header">
                        <h3>当前预订</h3>
                    </div>
                    <div class="card-body">
                        <div class="detail-row">
                            <div class="detail-label">预订号</div>
                            <div class="detail-value"><?php echo htmlspecialchars($currentBooking['booking_number']); ?></div>
                        </div>
                        <div class="detail-row">
                            <div class="detail-label">客人姓名</div>
                            <div class="detail-value"><?php echo htmlspecialchars($currentBooking['guest_name']); ?></div>
                        </div>
                        <div class="detail-row">
                            <div class="detail-label">入住日期</div>
                            <div class="detail-value"><?php echo htmlspecialchars($currentBooking['check_in_date']); ?></div>
                        </div>
                        <div class="detail-row">
                            <div class="detail-label">退房日期</div>
                            <div class="detail-value"><?php echo htmlspecialchars($currentBooking['check_out_date']); ?></div>
                        </div>
                        <div class="detail-row">
                            <div class="detail-label">状态</div>
                            <div class="detail-value">
                                <span class="status-badge status-<?php echo $currentBooking['status']; ?>">
                                    <?php
                                    switch ($currentBooking['status']) {
                                        case 'confirmed':
                                            echo '已确认';
                                            break;
                                        case 'checked_in':
                                            echo '已入住';
                                            break;
                                        default:
                                            echo $currentBooking['status'];
                                    }
                                    ?>
                                </span>
                            </div>
                        </div>
                        <div class="detail-actions">
                            <a href="../booking_management/index.php?page=booking_view&id=<?php echo $currentBooking['id']; ?>" class="btn btn-secondary">查看预订详情</a>
                        </div>
                    </div>
                </div>
            <?php endif; ?>

            <?php if (!empty($futureBookings)): ?>
                <div class="card">
                    <div class="card-header">
                        <h3>未来预订</h3>
                    </div>
                    <div class="card-body">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>预订号</th>
                                    <th>客人姓名</th>
                                    <th>入住日期</th>
                                    <th>退房日期</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($futureBookings as $booking): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($booking['booking_number']); ?></td>
                                        <td><?php echo htmlspecialchars($booking['guest_name']); ?></td>
                                        <td><?php echo htmlspecialchars($booking['check_in_date']); ?></td>
                                        <td><?php echo htmlspecialchars($booking['check_out_date']); ?></td>
                                        <td>
                                            <a href="../booking_management/index.php?page=booking_view&id=<?php echo $booking['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            <?php endif; ?>

            <?php if (!empty($maintenanceRecords)): ?>
                <div class="card">
                    <div class="card-header">
                        <h3>维修记录</h3>
                    </div>
                    <div class="card-body">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>问题描述</th>
                                    <th>报修日期</th>
                                    <th>状态</th>
                                    <th>完成日期</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($maintenanceRecords as $record): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($record['issue_description']); ?></td>
                                        <td><?php echo date('Y-m-d', strtotime($record['reported_date'])); ?></td>
                                        <td>
                                            <span class="status-badge status-<?php echo $record['status']; ?>">
                                                <?php
                                                switch ($record['status']) {
                                                    case 'reported':
                                                        echo '已报修';
                                                        break;
                                                    case 'assigned':
                                                        echo '已分配';
                                                        break;
                                                    case 'in_progress':
                                                        echo '处理中';
                                                        break;
                                                    case 'completed':
                                                        echo '已完成';
                                                        break;
                                                    case 'cancelled':
                                                        echo '已取消';
                                                        break;
                                                    default:
                                                        echo $record['status'];
                                                }
                                                ?>
                                            </span>
                                        </td>
                                        <td><?php echo $record['completion_date'] ? date('Y-m-d', strtotime($record['completion_date'])) : '-'; ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 图片切换
        const thumbs = document.querySelectorAll('.thumb');
        const mainImage = document.getElementById('main-image');

        thumbs.forEach(thumb => {
            thumb.addEventListener('click', function() {
                // 更新主图
                mainImage.src = this.getAttribute('data-src');

                // 更新选中状态
                thumbs.forEach(t => t.classList.remove('active'));
                this.classList.add('active');
            });
        });
    });
</script>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .page-header h2 {
        margin-bottom: 5px;
    }

    .breadcrumb {
        font-size: 14px;
        color: #6c757d;
    }

    .breadcrumb a {
        color: #0066cc;
    }

    .room-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 20px;
    }

    .room-title h1 {
        font-size: 24px;
        margin: 0 0 5px 0;
    }

    .room-type {
        font-size: 16px;
        color: #6c757d;
        margin-right: 10px;
    }

    .room-actions {
        display: flex;
        gap: 10px;
    }

    .room-content {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
    }

    .room-gallery {
        flex: 1;
        min-width: 300px;
    }

    .gallery-main {
        width: 100%;
        height: 400px;
        overflow: hidden;
        border-radius: 8px;
        margin-bottom: 10px;
    }

    .gallery-main img {
        width: 100%;
        height: 100%;
        object-fit: cover;
    }

    .gallery-thumbs {
        display: flex;
        gap: 10px;
        overflow-x: auto;
        padding-bottom: 10px;
    }

    .thumb {
        width: 80px;
        height: 60px;
        border-radius: 4px;
        overflow: hidden;
        cursor: pointer;
        border: 2px solid transparent;
    }

    .thumb.active {
        border-color: #0066cc;
    }

    .thumb img {
        width: 100%;
        height: 100%;
        object-fit: cover;
    }

    .no-images {
        width: 100%;
        height: 400px;
        display: flex;
        align-items: center;
        justify-content: center;
        background-color: #f8f9fa;
        border-radius: 8px;
        color: #6c757d;
    }

    .room-details {
        flex: 1;
        min-width: 300px;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        overflow: hidden;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        background-color: #f8f9fa;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #0066cc;
    }

    .card-body {
        padding: 15px;
    }

    .detail-row {
        display: flex;
        margin-bottom: 10px;
    }

    .detail-label {
        width: 120px;
        font-weight: bold;
        color: #495057;
    }

    .detail-value {
        flex: 1;
    }

    .price-highlight {
        font-weight: bold;
        color: #dc3545;
    }

    .detail-section {
        margin-bottom: 20px;
    }

    .detail-section h4 {
        font-size: 16px;
        color: #495057;
        margin-bottom: 10px;
    }

    .amenities-list {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
    }

    .amenity-tag {
        display: inline-block;
        padding: 5px 10px;
        background-color: #e9ecef;
        border-radius: 4px;
        font-size: 14px;
    }

    .room-description {
        line-height: 1.6;
    }

    .detail-actions {
        margin-top: 15px;
    }

    .btn-sm {
        padding: 4px 8px;
        font-size: 12px;
    }

    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
        color: #fff;
    }

    .status-available {
        background-color: #28a745;
    }

    .status-booked {
        background-color: #ffc107;
        color: #212529;
    }

    .status-occupied {
        background-color: #0066cc;
    }

    .status-maintenance {
        background-color: #dc3545;
    }

    .status-confirmed {
        background-color: #17a2b8;
    }

    .status-checked_in {
        background-color: #28a745;
    }

    .status-reported {
        background-color: #ffc107;
        color: #212529;
    }

    .status-assigned {
        background-color: #17a2b8;
    }

    .status-in_progress {
        background-color: #0066cc;
    }

    .status-completed {
        background-color: #28a745;
    }

    .status-cancelled {
        background-color: #6c757d;
    }

    .btn-warning {
        background-color: #ffc107;
        color: #212529;
    }

    .btn-warning:hover {
        background-color: #e0a800;
    }

    @media (max-width: 768px) {
        .room-header {
            flex-direction: column;
            align-items: flex-start;
        }

        .room-actions {
            margin-top: 10px;
        }

        .gallery-main {
            height: 300px;
        }
    }
</style>