<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 检查是否存在清洁用品分类
$result = $conn->query("SELECT id FROM inventory_categories WHERE name = '清洁用品'");
$cleaning_category_id = 0;

if ($result->num_rows == 0) {
    // 创建清洁用品分类
    $conn->query("INSERT INTO inventory_categories (name, description) VALUES ('清洁用品', '洗涤剂、卫生纸、垃圾袋等清洁相关物品')");
    $cleaning_category_id = $conn->insert_id;
} else {
    $row = $result->fetch_assoc();
    $cleaning_category_id = $row['id'];
}

// 处理添加物品请求
if (isset($_POST['add_item'])) {
    $name = $_POST['name'];
    $description = $_POST['description'];
    $unit = $_POST['unit'];
    $current_quantity = $_POST['current_quantity'];
    $minimum_quantity = $_POST['minimum_quantity'];
    $cost_per_unit = $_POST['cost_per_unit'];

    $stmt = $conn->prepare("INSERT INTO inventory_items (category_id, name, description, unit, current_quantity, minimum_quantity, cost_per_unit) VALUES (?, ?, ?, ?, ?, ?, ?)");
    $stmt->bind_param("isssidd", $cleaning_category_id, $name, $description, $unit, $current_quantity, $minimum_quantity, $cost_per_unit);

    if ($stmt->execute()) {
        $item_id = $conn->insert_id;

        // 记录库存交易
        $transaction_type = 'purchase';
        $quantity = $current_quantity;
        $unit_price = $cost_per_unit;
        $total_price = $quantity * $unit_price;
        $transaction_date = date('Y-m-d H:i:s');
        $notes = '初始库存';
        $user_id = $_SESSION['user_id'];

        $stmt = $conn->prepare("INSERT INTO inventory_transactions (item_id, transaction_type, quantity, unit_price, total_price, transaction_date, notes, created_by) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
        $stmt->bind_param("isiiddsi", $item_id, $transaction_type, $quantity, $unit_price, $total_price, $transaction_date, $notes, $user_id);
        $stmt->execute();

        $success_message = "物品添加成功";
    } else {
        $error_message = "物品添加失败: " . $stmt->error;
    }
}

// 处理库存操作请求
if (isset($_POST['inventory_operation'])) {
    $item_id = $_POST['item_id'];
    $transaction_type = $_POST['transaction_type'];
    $quantity = $_POST['quantity'];
    $unit_price = $_POST['unit_price'];
    $total_price = $quantity * $unit_price;
    $transaction_date = $_POST['transaction_date'];
    $notes = $_POST['notes'];
    $user_id = $_SESSION['user_id'];

    // 开始事务
    $conn->begin_transaction();

    try {
        // 插入交易记录
        $stmt = $conn->prepare("INSERT INTO inventory_transactions (item_id, transaction_type, quantity, unit_price, total_price, transaction_date, notes, created_by) VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
        $stmt->bind_param("isiiddsi", $item_id, $transaction_type, $quantity, $unit_price, $total_price, $transaction_date, $notes, $user_id);
        $stmt->execute();

        // 更新物品库存
        if ($transaction_type == 'purchase' || $transaction_type == 'adjustment') {
            $stmt = $conn->prepare("UPDATE inventory_items SET current_quantity = current_quantity + ? WHERE id = ?");
            $stmt->bind_param("ii", $quantity, $item_id);
        } else if ($transaction_type == 'consumption' || $transaction_type == 'return') {
            $stmt = $conn->prepare("UPDATE inventory_items SET current_quantity = current_quantity - ? WHERE id = ?");
            $stmt->bind_param("ii", $quantity, $item_id);
        }
        $stmt->execute();

        // 提交事务
        $conn->commit();
        $success_message = "库存操作成功";
    } catch (Exception $e) {
        // 回滚事务
        $conn->rollback();
        $error_message = "库存操作失败: " . $e->getMessage();
    }
}

// 获取清洁用品列表
$items = [];
$sql = "SELECT ii.*, ic.name AS category_name
        FROM inventory_items ii
        JOIN inventory_categories ic ON ii.category_id = ic.id
        WHERE ii.category_id = ?
        ORDER BY ii.name";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $cleaning_category_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result) {
    while ($row = $result->fetch_assoc()) {
        $items[] = $row;
    }
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content-wrapper">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="tabs">
        <div class="tab-header">
            <div class="tab-btn active" data-tab="item-list">物品列表</div>
            <div class="tab-btn" data-tab="add-item">添加物品</div>
            <div class="tab-btn" data-tab="inventory-operation">库存操作</div>
        </div>

        <div class="tab-content">
            <!-- 物品列表 -->
            <div class="tab-pane active" id="item-list">
                <div class="card">
                    <div class="card-header">
                        <h3>清洁用品库存列表</h3>
                        <div class="card-tools">
                            <div class="search-box">
                                <input type="text" id="searchInput" class="form-control" placeholder="搜索物品...">
                            </div>
                        </div>
                    </div>
                    <div class="card-body">
                        <?php if (empty($items)): ?>
                            <div class="alert alert-info">暂无清洁用品库存数据</div>
                        <?php else: ?>
                            <table class="data-table" id="inventoryTable">
                                <thead>
                                    <tr>
                                        <th>物品名称</th>
                                        <th>描述</th>
                                        <th>单位</th>
                                        <th>当前库存</th>
                                        <th>最低库存</th>
                                        <th>单价</th>
                                        <th>总价值</th>
                                        <th>状态</th>
                                        <th>操作</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($items as $item): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($item['name']); ?></td>
                                            <td><?php echo htmlspecialchars($item['description']); ?></td>
                                            <td><?php echo htmlspecialchars($item['unit']); ?></td>
                                            <td><?php echo $item['current_quantity']; ?></td>
                                            <td><?php echo $item['minimum_quantity']; ?></td>
                                            <td>¥<?php echo number_format($item['cost_per_unit'], 2); ?></td>
                                            <td>¥<?php echo number_format($item['current_quantity'] * $item['cost_per_unit'], 2); ?></td>
                                            <td>
                                                <?php if ($item['current_quantity'] == 0): ?>
                                                    <span class="badge badge-danger">缺货</span>
                                                <?php elseif ($item['current_quantity'] <= $item['minimum_quantity']): ?>
                                                    <span class="badge badge-warning">库存不足</span>
                                                <?php else: ?>
                                                    <span class="badge badge-success">库存充足</span>
                                                <?php endif; ?>
                                            </td>
                                            <td>
                                                <button class="btn btn-sm btn-primary operation-btn"
                                                    data-id="<?php echo $item['id']; ?>"
                                                    data-name="<?php echo htmlspecialchars($item['name']); ?>"
                                                    data-unit="<?php echo htmlspecialchars($item['unit']); ?>"
                                                    data-cost="<?php echo $item['cost_per_unit']; ?>">
                                                    库存操作
                                                </button>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

            <!-- 添加物品 -->
            <div class="tab-pane" id="add-item">
                <div class="card">
                    <div class="card-header">
                        <h3>添加清洁用品</h3>
                    </div>
                    <div class="card-body">
                        <form method="post" action="index.php?page=cleaning_inventory">
                            <div class="form-group">
                                <label>物品名称</label>
                                <input type="text" class="form-control" name="name" required>
                            </div>

                            <div class="form-group">
                                <label>描述</label>
                                <textarea class="form-control" name="description" rows="3"></textarea>
                            </div>

                            <div class="form-group">
                                <label>单位</label>
                                <select class="form-control" name="unit" required>
                                    <option value="个">个</option>
                                    <option value="包">包</option>
                                    <option value="盒">盒</option>
                                    <option value="瓶">瓶</option>
                                    <option value="箱">箱</option>
                                    <option value="袋">袋</option>
                                    <option value="卷">卷</option>
                                    <option value="kg">千克</option>
                                    <option value="g">克</option>
                                    <option value="L">升</option>
                                    <option value="ml">毫升</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label>初始库存数量</label>
                                <input type="number" class="form-control" name="current_quantity" min="0" value="0" required>
                            </div>

                            <div class="form-group">
                                <label>最低库存数量</label>
                                <input type="number" class="form-control" name="minimum_quantity" min="0" value="5" required>
                                <small class="form-text text-muted">当库存低于此数量时将触发库存预警</small>
                            </div>

                            <div class="form-group">
                                <label>单价 (元)</label>
                                <input type="number" class="form-control" name="cost_per_unit" min="0" step="0.01" required>
                            </div>

                            <button type="submit" name="add_item" class="btn btn-primary">添加物品</button>
                        </form>
                    </div>
                </div>
            </div>

            <!-- 库存操作 -->
            <div class="tab-pane" id="inventory-operation">
                <div class="card">
                    <div class="card-header">
                        <h3>库存操作</h3>
                    </div>
                    <div class="card-body">
                        <form method="post" action="index.php?page=cleaning_inventory">
                            <div class="form-group">
                                <label>选择物品</label>
                                <select class="form-control" name="item_id" id="item-select" required>
                                    <option value="">请选择物品</option>
                                    <?php foreach ($items as $item): ?>
                                        <option value="<?php echo $item['id']; ?>"
                                            data-unit="<?php echo htmlspecialchars($item['unit']); ?>"
                                            data-cost="<?php echo $item['cost_per_unit']; ?>">
                                            <?php echo htmlspecialchars($item['name']); ?>
                                            (当前库存: <?php echo $item['current_quantity']; ?> <?php echo htmlspecialchars($item['unit']); ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="form-group">
                                <label>操作类型</label>
                                <select class="form-control" name="transaction_type" id="transaction-type" required>
                                    <option value="purchase">采购入库</option>
                                    <option value="consumption">消耗出库</option>
                                    <option value="adjustment">库存调整</option>
                                    <option value="return">退货</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label>数量</label>
                                <div class="input-group">
                                    <input type="number" class="form-control" name="quantity" id="quantity" min="1" value="1" required>
                                    <div class="input-group-append">
                                        <span class="input-group-text" id="unit-display">个</span>
                                    </div>
                                </div>
                            </div>

                            <div class="form-group" id="price-group">
                                <label>单价 (元)</label>
                                <input type="number" class="form-control" name="unit_price" id="unit-price" min="0" step="0.01" required>
                            </div>

                            <div class="form-group">
                                <label>总价 (元)</label>
                                <input type="text" class="form-control" id="total-price" readonly>
                            </div>

                            <div class="form-group">
                                <label>交易日期</label>
                                <input type="datetime-local" class="form-control" name="transaction_date" required>
                            </div>

                            <div class="form-group">
                                <label>备注</label>
                                <textarea class="form-control" name="notes" rows="3"></textarea>
                            </div>

                            <input type="hidden" name="inventory_operation" value="1">
                            <button type="submit" class="btn btn-primary">提交</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .tabs {
        margin-bottom: 20px;
    }

    .tab-header {
        display: flex;
        border-bottom: 1px solid #dee2e6;
        margin-bottom: 20px;
    }

    .tab-btn {
        padding: 10px 20px;
        cursor: pointer;
        border: 1px solid transparent;
        border-radius: 4px 4px 0 0;
        margin-bottom: -1px;
    }

    .tab-btn.active {
        border-color: #dee2e6 #dee2e6 #fff;
        background-color: #fff;
        color: #0066cc;
        font-weight: bold;
    }

    .tab-pane {
        display: none;
    }

    .tab-pane.active {
        display: block;
    }

    .card {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        overflow: hidden;
    }

    .card-header {
        padding: 15px;
        background-color: #f8f9fa;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .card-tools {
        display: flex;
        align-items: center;
    }

    .search-box {
        width: 250px;
    }

    .card-body {
        padding: 15px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: bold;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 8px 12px;
        font-size: 14px;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 4px;
        transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
    }

    .form-text {
        display: block;
        margin-top: 5px;
        font-size: 12px;
        color: #6c757d;
    }

    .input-group {
        display: flex;
    }

    .input-group-append {
        margin-left: -1px;
    }

    .input-group-text {
        display: flex;
        align-items: center;
        padding: 8px 12px;
        font-size: 14px;
        font-weight: 400;
        line-height: 1.5;
        color: #495057;
        text-align: center;
        white-space: nowrap;
        background-color: #e9ecef;
        border: 1px solid #ced4da;
        border-radius: 0 4px 4px 0;
    }

    .btn {
        display: inline-block;
        font-weight: 400;
        text-align: center;
        white-space: nowrap;
        vertical-align: middle;
        user-select: none;
        border: 1px solid transparent;
        padding: 0.375rem 0.75rem;
        font-size: 1rem;
        line-height: 1.5;
        border-radius: 0.25rem;
        transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        text-decoration: none;
        cursor: pointer;
    }

    .btn-sm {
        padding: 0.25rem 0.5rem;
        font-size: 0.875rem;
        line-height: 1.5;
        border-radius: 0.2rem;
    }

    .btn-primary {
        color: #fff;
        background-color: #007bff;
        border-color: #007bff;
    }

    .btn-primary:hover {
        color: #fff;
        background-color: #0069d9;
        border-color: #0062cc;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .badge {
        padding: 5px 10px;
        border-radius: 4px;
        font-size: 12px;
        font-weight: normal;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #212529;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-danger {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }

    .alert-info {
        color: #0c5460;
        background-color: #d1ecf1;
        border-color: #bee5eb;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 标签页切换
        const tabBtns = document.querySelectorAll('.tab-btn');
        const tabPanes = document.querySelectorAll('.tab-pane');

        tabBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const tabId = this.getAttribute('data-tab');

                // 移除所有活动状态
                tabBtns.forEach(b => b.classList.remove('active'));
                tabPanes.forEach(p => p.classList.remove('active'));

                // 设置当前标签为活动状态
                this.classList.add('active');
                document.getElementById(tabId).classList.add('active');
            });
        });

        // 设置当前日期时间为默认交易时间
        const now = new Date();
        const year = now.getFullYear();
        const month = String(now.getMonth() + 1).padStart(2, '0');
        const day = String(now.getDate()).padStart(2, '0');
        const hours = String(now.getHours()).padStart(2, '0');
        const minutes = String(now.getMinutes()).padStart(2, '0');

        document.querySelector('input[name="transaction_date"]').value = `${year}-${month}-${day}T${hours}:${minutes}`;

        // 物品选择变化
        const itemSelect = document.getElementById('item-select');
        const unitDisplay = document.getElementById('unit-display');
        const unitPrice = document.getElementById('unit-price');

        if (itemSelect) {
            itemSelect.addEventListener('change', function() {
                if (this.value) {
                    const option = this.options[this.selectedIndex];
                    const unit = option.getAttribute('data-unit');
                    const cost = option.getAttribute('data-cost');

                    unitDisplay.textContent = unit;
                    unitPrice.value = cost;
                    calculateTotal();
                }
            });
        }

        // 交易类型变化
        const transactionType = document.getElementById('transaction-type');
        const priceGroup = document.getElementById('price-group');

        if (transactionType) {
            transactionType.addEventListener('change', function() {
                if (this.value === 'consumption' || this.value === 'adjustment') {
                    priceGroup.style.display = 'none';
                    unitPrice.value = 0;
                } else {
                    priceGroup.style.display = 'block';
                    if (itemSelect.value) {
                        const option = itemSelect.options[itemSelect.selectedIndex];
                        unitPrice.value = option.getAttribute('data-cost');
                    }
                }
                calculateTotal();
            });
        }

        // 数量或单价变化时计算总价
        const quantity = document.getElementById('quantity');
        const totalPrice = document.getElementById('total-price');

        function calculateTotal() {
            const qty = parseFloat(quantity.value) || 0;
            const price = parseFloat(unitPrice.value) || 0;
            totalPrice.value = '¥' + (qty * price).toFixed(2);
        }

        if (quantity) {
            quantity.addEventListener('input', calculateTotal);
        }

        if (unitPrice) {
            unitPrice.addEventListener('input', calculateTotal);
        }

        // 库存操作按钮点击
        const operationBtns = document.querySelectorAll('.operation-btn');

        operationBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const itemId = this.getAttribute('data-id');
                const itemName = this.getAttribute('data-name');
                const itemUnit = this.getAttribute('data-unit');
                const itemCost = this.getAttribute('data-cost');

                // 切换到库存操作标签页
                tabBtns.forEach(b => b.classList.remove('active'));
                tabPanes.forEach(p => p.classList.remove('active'));

                document.querySelector('.tab-btn[data-tab="inventory-operation"]').classList.add('active');
                document.getElementById('inventory-operation').classList.add('active');

                // 设置选中的物品
                const options = itemSelect.options;
                for (let i = 0; i < options.length; i++) {
                    if (options[i].value === itemId) {
                        itemSelect.selectedIndex = i;
                        break;
                    }
                }

                // 更新单位和单价
                unitDisplay.textContent = itemUnit;
                unitPrice.value = itemCost;
                calculateTotal();
            });
        });

        // 搜索功能
        const searchInput = document.getElementById('searchInput');
        const inventoryTable = document.getElementById('inventoryTable');

        if (searchInput && inventoryTable) {
            searchInput.addEventListener('keyup', function() {
                const searchText = this.value.toLowerCase();
                const rows = inventoryTable.getElementsByTagName('tbody')[0].getElementsByTagName('tr');

                for (let i = 0; i < rows.length; i++) {
                    const nameCell = rows[i].getElementsByTagName('td')[0];
                    const descCell = rows[i].getElementsByTagName('td')[1];

                    if (nameCell && descCell) {
                        const nameText = nameCell.textContent || nameCell.innerText;
                        const descText = descCell.textContent || descCell.innerText;

                        if (nameText.toLowerCase().indexOf(searchText) > -1 ||
                            descText.toLowerCase().indexOf(searchText) > -1) {
                            rows[i].style.display = '';
                        } else {
                            rows[i].style.display = 'none';
                        }
                    }
                }
            });
        }

        // 初始计算总价
        calculateTotal();
    });
</script>