<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 获取库存分类统计
$categories = [];
$sql = "SELECT ic.id, ic.name, COUNT(ii.id) AS item_count, 
        SUM(ii.current_quantity) AS total_quantity,
        SUM(ii.current_quantity * ii.cost_per_unit) AS total_value
        FROM inventory_categories ic
        LEFT JOIN inventory_items ii ON ic.id = ii.category_id
        GROUP BY ic.id
        ORDER BY ic.name";
$result = mysqli_query($conn, $sql);

if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        $categories[] = $row;
    }
}

// 获取库存预警物品
$low_stock_items = [];
$sql = "SELECT ii.*, ic.name AS category_name
        FROM inventory_items ii
        JOIN inventory_categories ic ON ii.category_id = ic.id
        WHERE ii.current_quantity <= ii.minimum_quantity
        ORDER BY (ii.current_quantity / ii.minimum_quantity) ASC
        LIMIT 5";
$result = mysqli_query($conn, $sql);

if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        $low_stock_items[] = $row;
    }
}

// 获取最近的库存交易记录
$recent_transactions = [];
$sql = "SELECT it.*, ii.name AS item_name, u.username AS user_name
        FROM inventory_transactions it
        JOIN inventory_items ii ON it.item_id = ii.id
        LEFT JOIN users u ON it.created_by = u.id
        ORDER BY it.transaction_date DESC
        LIMIT 10";
$result = mysqli_query($conn, $sql);

if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        $recent_transactions[] = $row;
    }
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="dashboard-container">
    <div class="dashboard-row">
        <div class="dashboard-card">
            <div class="card-header">
                <h3>库存分类统计</h3>
            </div>
            <div class="card-body">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>分类名称</th>
                            <th>物品数量</th>
                            <th>总库存量</th>
                            <th>总价值</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($categories)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无库存分类数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($categories as $category): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($category['name']); ?></td>
                                    <td><?php echo $category['item_count']; ?></td>
                                    <td><?php echo $category['total_quantity'] ?? 0; ?></td>
                                    <td>¥<?php echo number_format($category['total_value'] ?? 0, 2); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <div class="dashboard-card">
            <div class="card-header">
                <h3>库存预警</h3>
            </div>
            <div class="card-body">
                <?php if (empty($low_stock_items)): ?>
                    <div class="alert alert-success">所有物品库存充足</div>
                <?php else: ?>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>物品名称</th>
                                <th>分类</th>
                                <th>当前库存</th>
                                <th>最低库存</th>
                                <th>状态</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($low_stock_items as $item): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($item['name']); ?></td>
                                    <td><?php echo htmlspecialchars($item['category_name']); ?></td>
                                    <td><?php echo $item['current_quantity']; ?> <?php echo $item['unit']; ?></td>
                                    <td><?php echo $item['minimum_quantity']; ?> <?php echo $item['unit']; ?></td>
                                    <td>
                                        <?php if ($item['current_quantity'] == 0): ?>
                                            <span class="badge badge-danger">缺货</span>
                                        <?php else: ?>
                                            <span class="badge badge-warning">库存不足</span>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                    <div class="text-right mt-2">
                        <a href="index.php?page=inventory_alert" class="btn btn-sm btn-primary">查看全部</a>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <div class="dashboard-row">
        <div class="dashboard-card full-width">
            <div class="card-header">
                <h3>最近库存交易记录</h3>
            </div>
            <div class="card-body">
                <?php if (empty($recent_transactions)): ?>
                    <div class="alert alert-info">暂无库存交易记录</div>
                <?php else: ?>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>物品名称</th>
                                <th>交易类型</th>
                                <th>数量</th>
                                <th>单价</th>
                                <th>总价</th>
                                <th>交易日期</th>
                                <th>操作人</th>
                                <th>备注</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($recent_transactions as $transaction): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($transaction['item_name']); ?></td>
                                    <td>
                                        <?php
                                        $typeLabels = [
                                            'purchase' => '<span class="badge badge-success">采购入库</span>',
                                            'consumption' => '<span class="badge badge-info">消耗出库</span>',
                                            'adjustment' => '<span class="badge badge-warning">库存调整</span>',
                                            'return' => '<span class="badge badge-danger">退货</span>'
                                        ];
                                        echo $typeLabels[$transaction['transaction_type']] ?? $transaction['transaction_type'];
                                        ?>
                                    </td>
                                    <td><?php echo $transaction['quantity']; ?></td>
                                    <td>¥<?php echo number_format($transaction['unit_price'], 2); ?></td>
                                    <td>¥<?php echo number_format($transaction['total_price'], 2); ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($transaction['transaction_date'])); ?></td>
                                    <td><?php echo htmlspecialchars($transaction['user_name'] ?? '未知'); ?></td>
                                    <td><?php echo htmlspecialchars($transaction['notes'] ?? ''); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>

<style>
    .dashboard-container {
        display: flex;
        flex-direction: column;
        gap: 20px;
    }

    .dashboard-row {
        display: flex;
        gap: 20px;
    }

    .dashboard-card {
        flex: 1;
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        overflow: hidden;
    }

    .dashboard-card.full-width {
        width: 100%;
    }

    .card-header {
        padding: 15px;
        background-color: #f8f9fa;
        border-bottom: 1px solid #e9ecef;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .card-body {
        padding: 15px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .badge {
        padding: 5px 10px;
        border-radius: 4px;
        font-size: 12px;
        font-weight: normal;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #212529;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }

    .badge-info {
        background-color: #17a2b8;
        color: white;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-info {
        color: #0c5460;
        background-color: #d1ecf1;
        border-color: #bee5eb;
    }

    .text-center {
        text-align: center;
    }

    .text-right {
        text-align: right;
    }

    .mt-2 {
        margin-top: 10px;
    }

    .btn {
        display: inline-block;
        font-weight: 400;
        text-align: center;
        white-space: nowrap;
        vertical-align: middle;
        user-select: none;
        border: 1px solid transparent;
        padding: 0.375rem 0.75rem;
        font-size: 1rem;
        line-height: 1.5;
        border-radius: 0.25rem;
        transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        text-decoration: none;
        cursor: pointer;
    }

    .btn-sm {
        padding: 0.25rem 0.5rem;
        font-size: 0.875rem;
        line-height: 1.5;
        border-radius: 0.2rem;
    }

    .btn-primary {
        color: #fff;
        background-color: #007bff;
        border-color: #007bff;
    }

    .btn-primary:hover {
        color: #fff;
        background-color: #0069d9;
        border-color: #0062cc;
    }
</style>