<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 获取库存预警物品
$low_stock_items = [];
$sql = "SELECT ii.*, ic.name AS category_name
        FROM inventory_items ii
        JOIN inventory_categories ic ON ii.category_id = ic.id
        WHERE ii.current_quantity <= ii.minimum_quantity
        ORDER BY (ii.current_quantity / ii.minimum_quantity) ASC, ic.name, ii.name";
$result = mysqli_query($conn, $sql);

if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        $low_stock_items[] = $row;
    }
}

// 获取库存分类
$categories = [];
$sql = "SELECT * FROM inventory_categories ORDER BY name";
$result = mysqli_query($conn, $sql);

if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        $categories[$row['id']] = $row['name'];
    }
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content-wrapper">
    <div class="card">
        <div class="card-header">
            <h3>库存预警列表</h3>
            <div class="card-tools">
                <div class="filter-box">
                    <select id="categoryFilter" class="form-control">
                        <option value="all">所有分类</option>
                        <?php foreach ($categories as $id => $name): ?>
                            <option value="<?php echo $id; ?>"><?php echo htmlspecialchars($name); ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="search-box">
                    <input type="text" id="searchInput" class="form-control" placeholder="搜索物品...">
                </div>
            </div>
        </div>
        <div class="card-body">
            <?php if (empty($low_stock_items)): ?>
                <div class="alert alert-success">
                    <i class="fa fa-check-circle"></i> 所有物品库存充足，无需补货。
                </div>
            <?php else: ?>
                <div class="alert alert-warning">
                    <i class="fa fa-exclamation-triangle"></i> 发现 <?php echo count($low_stock_items); ?> 个物品库存不足，请及时补货。
                </div>
                <table class="data-table" id="alertTable">
                    <thead>
                        <tr>
                            <th>物品名称</th>
                            <th>分类</th>
                            <th>当前库存</th>
                            <th>最低库存</th>
                            <th>单位</th>
                            <th>单价</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($low_stock_items as $item): ?>
                            <tr data-category="<?php echo $item['category_id']; ?>">
                                <td><?php echo htmlspecialchars($item['name']); ?></td>
                                <td><?php echo htmlspecialchars($item['category_name']); ?></td>
                                <td><?php echo $item['current_quantity']; ?></td>
                                <td><?php echo $item['minimum_quantity']; ?></td>
                                <td><?php echo htmlspecialchars($item['unit']); ?></td>
                                <td>¥<?php echo number_format($item['cost_per_unit'], 2); ?></td>
                                <td>
                                    <?php if ($item['current_quantity'] == 0): ?>
                                        <span class="badge badge-danger">缺货</span>
                                    <?php else: ?>
                                        <span class="badge badge-warning">库存不足</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <a href="index.php?page=<?php
                                                            if ($item['category_name'] == '客房用品') {
                                                                echo 'room_inventory';
                                                            } elseif ($item['category_name'] == '餐饮库存') {
                                                                echo 'food_inventory';
                                                            } elseif ($item['category_name'] == '清洁用品') {
                                                                echo 'cleaning_inventory';
                                                            } else {
                                                                echo 'room_inventory';
                                                            }
                                                            ?>" class="btn btn-sm btn-primary">
                                        前往补货
                                    </a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php endif; ?>
        </div>
    </div>

    <div class="card mt-4">
        <div class="card-header">
            <h3>库存预警设置</h3>
        </div>
        <div class="card-body">
            <div class="alert alert-info">
                <i class="fa fa-info-circle"></i> 库存预警系统会自动监控所有物品的库存量，当库存低于最低库存量时，系统会在此页面显示预警信息。
            </div>
            <div class="tips">
                <h4>库存管理建议</h4>
                <ul>
                    <li>定期检查库存预警列表，及时补充库存不足的物品</li>
                    <li>根据物品的使用频率和重要性，合理设置最低库存量</li>
                    <li>对于重要物品，建议保持较高的安全库存</li>
                    <li>对于易腐物品，建议保持较低的库存量，避免浪费</li>
                    <li>可以根据季节和入住率的变化，动态调整最低库存量</li>
                </ul>
            </div>
        </div>
    </div>
</div>

<style>
    .card {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        overflow: hidden;
    }

    .card-header {
        padding: 15px;
        background-color: #f8f9fa;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .card-tools {
        display: flex;
        align-items: center;
        gap: 10px;
    }

    .search-box {
        width: 250px;
    }

    .filter-box {
        width: 150px;
    }

    .card-body {
        padding: 15px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .badge {
        padding: 5px 10px;
        border-radius: 4px;
        font-size: 12px;
        font-weight: normal;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-warning {
        background-color: #ffc107;
        color: #212529;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-warning {
        color: #856404;
        background-color: #fff3cd;
        border-color: #ffeeba;
    }

    .alert-info {
        color: #0c5460;
        background-color: #d1ecf1;
        border-color: #bee5eb;
    }

    .btn {
        display: inline-block;
        font-weight: 400;
        text-align: center;
        white-space: nowrap;
        vertical-align: middle;
        user-select: none;
        border: 1px solid transparent;
        padding: 0.375rem 0.75rem;
        font-size: 1rem;
        line-height: 1.5;
        border-radius: 0.25rem;
        transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        text-decoration: none;
        cursor: pointer;
    }

    .btn-sm {
        padding: 0.25rem 0.5rem;
        font-size: 0.875rem;
        line-height: 1.5;
        border-radius: 0.2rem;
    }

    .btn-primary {
        color: #fff;
        background-color: #007bff;
        border-color: #007bff;
    }

    .btn-primary:hover {
        color: #fff;
        background-color: #0069d9;
        border-color: #0062cc;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 8px 12px;
        font-size: 14px;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 4px;
        transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
    }

    .mt-4 {
        margin-top: 1.5rem;
    }

    .tips {
        margin-top: 20px;
    }

    .tips h4 {
        margin-bottom: 10px;
        font-size: 16px;
        color: #333;
    }

    .tips ul {
        padding-left: 20px;
    }

    .tips li {
        margin-bottom: 8px;
        color: #555;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 搜索功能
        const searchInput = document.getElementById('searchInput');
        const alertTable = document.getElementById('alertTable');

        if (searchInput && alertTable) {
            searchInput.addEventListener('keyup', function() {
                const searchText = this.value.toLowerCase();
                filterTable(searchText, null);
            });
        }

        // 分类筛选
        const categoryFilter = document.getElementById('categoryFilter');

        if (categoryFilter && alertTable) {
            categoryFilter.addEventListener('change', function() {
                const categoryId = this.value;
                const searchText = searchInput ? searchInput.value.toLowerCase() : '';
                filterTable(searchText, categoryId);
            });
        }

        // 表格筛选函数
        function filterTable(searchText, categoryId) {
            if (!alertTable) return;

            const rows = alertTable.getElementsByTagName('tbody')[0].getElementsByTagName('tr');

            for (let i = 0; i < rows.length; i++) {
                const nameCell = rows[i].getElementsByTagName('td')[0];
                const categoryCell = rows[i].getElementsByTagName('td')[1];
                const rowCategoryId = rows[i].getAttribute('data-category');

                let showRow = true;

                // 搜索文本筛选
                if (searchText && nameCell && categoryCell) {
                    const nameText = nameCell.textContent || nameCell.innerText;
                    const categoryText = categoryCell.textContent || categoryCell.innerText;

                    if (nameText.toLowerCase().indexOf(searchText) === -1 &&
                        categoryText.toLowerCase().indexOf(searchText) === -1) {
                        showRow = false;
                    }
                }

                // 分类筛选
                if (categoryId && categoryId !== 'all' && rowCategoryId !== categoryId) {
                    showRow = false;
                }

                rows[i].style.display = showRow ? '' : 'none';
            }
        }
    });
</script>