<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 处理添加供应商请求
if (isset($_POST['add_supplier'])) {
    $name = $_POST['name'];
    $contact_person = $_POST['contact_person'];
    $phone = $_POST['phone'];
    $email = $_POST['email'];
    $address = $_POST['address'];
    $product_categories = $_POST['product_categories'];
    $notes = $_POST['notes'];

    $stmt = $conn->prepare("INSERT INTO suppliers (name, contact_person, phone, email, address, product_categories, notes) VALUES (?, ?, ?, ?, ?, ?, ?)");
    $stmt->bind_param("sssssss", $name, $contact_person, $phone, $email, $address, $product_categories, $notes);

    if ($stmt->execute()) {
        $success_message = "供应商添加成功";
    } else {
        $error_message = "供应商添加失败: " . $stmt->error;
    }
}

// 处理更新供应商状态请求
if (isset($_POST['update_status'])) {
    $supplier_id = $_POST['supplier_id'];
    $status = $_POST['status'];

    $stmt = $conn->prepare("UPDATE suppliers SET status = ? WHERE id = ?");
    $stmt->bind_param("si", $status, $supplier_id);

    if ($stmt->execute()) {
        $success_message = "供应商状态更新成功";
    } else {
        $error_message = "供应商状态更新失败: " . $stmt->error;
    }
}

// 处理编辑供应商请求
if (isset($_POST['edit_supplier'])) {
    $supplier_id = $_POST['supplier_id'];
    $name = $_POST['name'];
    $contact_person = $_POST['contact_person'];
    $phone = $_POST['phone'];
    $email = $_POST['email'];
    $address = $_POST['address'];
    $product_categories = $_POST['product_categories'];
    $notes = $_POST['notes'];

    $stmt = $conn->prepare("UPDATE suppliers SET name = ?, contact_person = ?, phone = ?, email = ?, address = ?, product_categories = ?, notes = ? WHERE id = ?");
    $stmt->bind_param("sssssssi", $name, $contact_person, $phone, $email, $address, $product_categories, $notes, $supplier_id);

    if ($stmt->execute()) {
        $success_message = "供应商信息更新成功";
    } else {
        $error_message = "供应商信息更新失败: " . $stmt->error;
    }
}

// 获取供应商交易记录
if (isset($_GET['get_transactions']) && isset($_GET['supplier_id'])) {
    $supplier_id = $_GET['supplier_id'];
    $transactions = [];

    $sql = "SELECT it.*, ii.name AS item_name, ii.unit, u.username AS operator_name
            FROM inventory_transactions it
            JOIN inventory_items ii ON it.item_id = ii.id
            LEFT JOIN users u ON it.created_by = u.id
            WHERE ii.supplier_id = ?
            ORDER BY it.transaction_date DESC
            LIMIT 50";

    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $supplier_id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result) {
        while ($row = $result->fetch_assoc()) {
            $transactions[] = $row;
        }
    }

    header('Content-Type: application/json');
    echo json_encode($transactions);
    exit;
}

// 获取供应商列表
$suppliers = [];
$sql = "SELECT * FROM suppliers ORDER BY name";
$result = mysqli_query($conn, $sql);

if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {
        $suppliers[] = $row;
    }
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content-wrapper">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="tabs">
        <div class="tab-header">
            <div class="tab-btn active" data-tab="supplier-list">供应商列表</div>
            <div class="tab-btn" data-tab="add-supplier">添加供应商</div>
        </div>

        <div class="tab-content">
            <!-- 供应商列表 -->
            <div class="tab-pane active" id="supplier-list">
                <div class="card">
                    <div class="card-header">
                        <h3>供应商管理</h3>
                        <div class="card-tools">
                            <div class="search-box">
                                <input type="text" id="searchInput" class="form-control" placeholder="搜索供应商...">
                            </div>
                        </div>
                    </div>
                    <div class="card-body">
                        <?php if (empty($suppliers)): ?>
                            <div class="alert alert-info">暂无供应商数据</div>
                        <?php else: ?>
                            <table class="data-table" id="supplierTable">
                                <thead>
                                    <tr>
                                        <th>供应商名称</th>
                                        <th>联系人</th>
                                        <th>联系电话</th>
                                        <th>电子邮箱</th>
                                        <th>供应产品类别</th>
                                        <th>状态</th>
                                        <th>操作</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($suppliers as $supplier): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($supplier['name']); ?></td>
                                            <td><?php echo htmlspecialchars($supplier['contact_person']); ?></td>
                                            <td><?php echo htmlspecialchars($supplier['phone']); ?></td>
                                            <td><?php echo htmlspecialchars($supplier['email']); ?></td>
                                            <td><?php echo htmlspecialchars($supplier['product_categories']); ?></td>
                                            <td>
                                                <span class="badge badge-<?php echo $supplier['status'] == 'active' ? 'success' : 'danger'; ?>">
                                                    <?php echo $supplier['status'] == 'active' ? '正常' : '停用'; ?>
                                                </span>
                                            </td>
                                            <td>
                                                <button class="btn btn-sm btn-info view-btn" data-id="<?php echo $supplier['id']; ?>">查看</button>
                                                <button class="btn btn-sm btn-primary edit-btn" data-id="<?php echo $supplier['id']; ?>">编辑</button>
                                                <button class="btn btn-sm <?php echo $supplier['status'] == 'active' ? 'btn-danger' : 'btn-success'; ?> status-btn"
                                                    data-id="<?php echo $supplier['id']; ?>"
                                                    data-status="<?php echo $supplier['status']; ?>">
                                                    <?php echo $supplier['status'] == 'active' ? '停用' : '启用'; ?>
                                                </button>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

            <!-- 添加供应商 -->
            <div class="tab-pane" id="add-supplier">
                <div class="card">
                    <div class="card-header">
                        <h3>添加供应商</h3>
                    </div>
                    <div class="card-body">
                        <form method="post" action="index.php?page=supplier">
                            <div class="form-group">
                                <label>供应商名称</label>
                                <input type="text" class="form-control" name="name" required>
                            </div>

                            <div class="form-group">
                                <label>联系人</label>
                                <input type="text" class="form-control" name="contact_person" required>
                            </div>

                            <div class="form-group">
                                <label>联系电话</label>
                                <input type="tel" class="form-control" name="phone" required>
                            </div>

                            <div class="form-group">
                                <label>电子邮箱</label>
                                <input type="email" class="form-control" name="email">
                            </div>

                            <div class="form-group">
                                <label>地址</label>
                                <textarea class="form-control" name="address" rows="3"></textarea>
                            </div>

                            <div class="form-group">
                                <label>供应产品类别</label>
                                <textarea class="form-control" name="product_categories" rows="3" required></textarea>
                                <small class="form-text text-muted">请输入供应商提供的产品类别，多个类别用逗号分隔</small>
                            </div>

                            <div class="form-group">
                                <label>备注</label>
                                <textarea class="form-control" name="notes" rows="3"></textarea>
                            </div>

                            <button type="submit" name="add_supplier" class="btn btn-primary">添加供应商</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- 供应商详情模态框 -->
<div class="modal" id="supplierDetailModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">供应商详情</h4>
                <button type="button" class="close" data-dismiss="modal">&times;</button>
            </div>
            <div class="modal-body">
                <div class="supplier-info">
                    <div class="info-group">
                        <label>供应商名称:</label>
                        <span id="detail-name"></span>
                    </div>
                    <div class="info-group">
                        <label>联系人:</label>
                        <span id="detail-contact"></span>
                    </div>
                    <div class="info-group">
                        <label>联系电话:</label>
                        <span id="detail-phone"></span>
                    </div>
                    <div class="info-group">
                        <label>电子邮箱:</label>
                        <span id="detail-email"></span>
                    </div>
                    <div class="info-group">
                        <label>地址:</label>
                        <span id="detail-address"></span>
                    </div>
                    <div class="info-group">
                        <label>供应产品类别:</label>
                        <span id="detail-categories"></span>
                    </div>
                    <div class="info-group">
                        <label>状态:</label>
                        <span id="detail-status"></span>
                    </div>
                    <div class="info-group">
                        <label>备注:</label>
                        <span id="detail-notes"></span>
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">关闭</button>
            </div>
        </div>
    </div>
</div>

<!-- 供应商编辑模态框 -->
<div class="modal" id="supplierEditModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">编辑供应商</h4>
                <button type="button" class="close" data-dismiss="modal">&times;</button>
            </div>
            <div class="modal-body">
                <form id="editSupplierForm" method="post" action="index.php?page=supplier">
                    <input type="hidden" name="supplier_id" id="edit-id">
                    <div class="form-group">
                        <label>供应商名称</label>
                        <input type="text" class="form-control" name="name" id="edit-name" required>
                    </div>

                    <div class="form-group">
                        <label>联系人</label>
                        <input type="text" class="form-control" name="contact_person" id="edit-contact" required>
                    </div>

                    <div class="form-group">
                        <label>联系电话</label>
                        <input type="tel" class="form-control" name="phone" id="edit-phone" required>
                    </div>

                    <div class="form-group">
                        <label>电子邮箱</label>
                        <input type="email" class="form-control" name="email" id="edit-email">
                    </div>

                    <div class="form-group">
                        <label>地址</label>
                        <textarea class="form-control" name="address" id="edit-address" rows="3"></textarea>
                    </div>

                    <div class="form-group">
                        <label>供应产品类别</label>
                        <textarea class="form-control" name="product_categories" id="edit-categories" rows="3" required></textarea>
                        <small class="form-text text-muted">请输入供应商提供的产品类别，多个类别用逗号分隔</small>
                    </div>

                    <div class="form-group">
                        <label>备注</label>
                        <textarea class="form-control" name="notes" id="edit-notes" rows="3"></textarea>
                    </div>

                    <input type="hidden" name="edit_supplier" value="1">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">取消</button>
                <button type="button" class="btn btn-primary" id="saveEditBtn">保存</button>
            </div>
        </div>
    </div>
</div>

<!-- 交易记录模态框 -->
<div class="modal" id="transactionModal">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">交易记录</h4>
                <button type="button" class="close" data-dismiss="modal">&times;</button>
            </div>
            <div class="modal-body">
                <div class="transaction-info">
                    <h5 id="transaction-supplier-name"></h5>
                    <div class="table-responsive">
                        <table class="data-table" id="transactionTable">
                            <thead>
                                <tr>
                                    <th>交易日期</th>
                                    <th>物品名称</th>
                                    <th>交易类型</th>
                                    <th>数量</th>
                                    <th>单价</th>
                                    <th>总价</th>
                                    <th>操作人</th>
                                    <th>备注</th>
                                </tr>
                            </thead>
                            <tbody>
                            </tbody>
                        </table>
                    </div>
                    <div id="no-transactions" class="alert alert-info" style="display: none;">
                        暂无交易记录
                    </div>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">关闭</button>
            </div>
        </div>
    </div>
</div>

<style>
    .tabs {
        margin-bottom: 20px;
    }

    .tab-header {
        display: flex;
        border-bottom: 1px solid #dee2e6;
        margin-bottom: 20px;
    }

    .tab-btn {
        padding: 10px 20px;
        cursor: pointer;
        border: 1px solid transparent;
        border-radius: 4px 4px 0 0;
        margin-bottom: -1px;
    }

    .tab-btn.active {
        border-color: #dee2e6 #dee2e6 #fff;
        background-color: #fff;
        color: #0066cc;
        font-weight: bold;
    }

    .tab-pane {
        display: none;
    }

    .tab-pane.active {
        display: block;
    }

    .card {
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        overflow: hidden;
    }

    .card-header {
        padding: 15px;
        background-color: #f8f9fa;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .card-tools {
        display: flex;
        align-items: center;
    }

    .search-box {
        width: 250px;
    }

    .card-body {
        padding: 15px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: bold;
    }

    .form-control {
        display: block;
        width: 100%;
        padding: 8px 12px;
        font-size: 14px;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        border: 1px solid #ced4da;
        border-radius: 4px;
        transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
    }

    .form-text {
        display: block;
        margin-top: 5px;
        font-size: 12px;
        color: #6c757d;
    }

    .btn {
        display: inline-block;
        font-weight: 400;
        text-align: center;
        white-space: nowrap;
        vertical-align: middle;
        user-select: none;
        border: 1px solid transparent;
        padding: 0.375rem 0.75rem;
        font-size: 1rem;
        line-height: 1.5;
        border-radius: 0.25rem;
        transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        text-decoration: none;
        cursor: pointer;
        margin-right: 5px;
    }

    .btn-sm {
        padding: 0.25rem 0.5rem;
        font-size: 0.875rem;
        line-height: 1.5;
        border-radius: 0.2rem;
    }

    .btn-primary {
        color: #fff;
        background-color: #007bff;
        border-color: #007bff;
    }

    .btn-primary:hover {
        color: #fff;
        background-color: #0069d9;
        border-color: #0062cc;
    }

    .btn-info {
        color: #fff;
        background-color: #17a2b8;
        border-color: #17a2b8;
    }

    .btn-info:hover {
        color: #fff;
        background-color: #138496;
        border-color: #117a8b;
    }

    .btn-danger {
        color: #fff;
        background-color: #dc3545;
        border-color: #dc3545;
    }

    .btn-danger:hover {
        color: #fff;
        background-color: #c82333;
        border-color: #bd2130;
    }

    .btn-success {
        color: #fff;
        background-color: #28a745;
        border-color: #28a745;
    }

    .btn-success:hover {
        color: #fff;
        background-color: #218838;
        border-color: #1e7e34;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .badge {
        padding: 5px 10px;
        border-radius: 4px;
        font-size: 12px;
        font-weight: normal;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-danger {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }

    .alert-info {
        color: #0c5460;
        background-color: #d1ecf1;
        border-color: #bee5eb;
    }

    .modal {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
        z-index: 1000;
    }

    .modal-dialog {
        position: relative;
        width: 500px;
        margin: 50px auto;
        background-color: #fff;
        border-radius: 5px;
        box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    }

    .modal-content {
        position: relative;
        background-color: #fff;
        border-radius: 5px;
        outline: none;
    }

    .modal-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .modal-title {
        margin: 0;
        font-size: 18px;
        color: #333;
    }

    .close {
        padding: 0;
        background-color: transparent;
        border: 0;
        font-size: 24px;
        font-weight: bold;
        line-height: 1;
        color: #000;
        text-shadow: 0 1px 0 #fff;
        opacity: .5;
        cursor: pointer;
    }

    .close:hover {
        opacity: .75;
    }

    .modal-body {
        padding: 15px;
        max-height: calc(100vh - 210px);
        overflow-y: auto;
    }

    .modal-footer {
        padding: 15px;
        border-top: 1px solid #e9ecef;
        text-align: right;
    }

    .supplier-info {
        margin-bottom: 20px;
    }

    .info-group {
        margin-bottom: 10px;
    }

    .info-group label {
        font-weight: bold;
        margin-right: 10px;
        min-width: 120px;
        display: inline-block;
    }

    .btn-secondary {
        color: #fff;
        background-color: #6c757d;
        border-color: #6c757d;
    }

    .btn-secondary:hover {
        color: #fff;
        background-color: #5a6268;
        border-color: #545b62;
    }

    .modal-lg {
        width: 800px;
    }

    .table-responsive {
        overflow-x: auto;
        -webkit-overflow-scrolling: touch;
    }

    .transaction-info h5 {
        margin-bottom: 20px;
        color: #333;
        font-size: 16px;
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 标签页切换
        const tabBtns = document.querySelectorAll('.tab-btn');
        const tabPanes = document.querySelectorAll('.tab-pane');

        tabBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const tabId = this.getAttribute('data-tab');

                // 移除所有活动状态
                tabBtns.forEach(b => b.classList.remove('active'));
                tabPanes.forEach(p => p.classList.remove('active'));

                // 设置当前标签为活动状态
                this.classList.add('active');
                document.getElementById(tabId).classList.add('active');
            });
        });

        // 搜索功能
        const searchInput = document.getElementById('searchInput');
        const supplierTable = document.getElementById('supplierTable');

        if (searchInput && supplierTable) {
            searchInput.addEventListener('keyup', function() {
                const searchText = this.value.toLowerCase();
                const rows = supplierTable.getElementsByTagName('tbody')[0].getElementsByTagName('tr');

                for (let i = 0; i < rows.length; i++) {
                    const nameCell = rows[i].getElementsByTagName('td')[0];
                    const contactCell = rows[i].getElementsByTagName('td')[1];
                    const phoneCell = rows[i].getElementsByTagName('td')[2];
                    const emailCell = rows[i].getElementsByTagName('td')[3];
                    const categoryCell = rows[i].getElementsByTagName('td')[4];

                    if (nameCell && contactCell && phoneCell && emailCell && categoryCell) {
                        const text = nameCell.textContent + ' ' +
                            contactCell.textContent + ' ' +
                            phoneCell.textContent + ' ' +
                            emailCell.textContent + ' ' +
                            categoryCell.textContent;

                        if (text.toLowerCase().indexOf(searchText) > -1) {
                            rows[i].style.display = '';
                        } else {
                            rows[i].style.display = 'none';
                        }
                    }
                }
            });
        }

        // 状态切换按钮
        const statusBtns = document.querySelectorAll('.status-btn');

        statusBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const supplierId = this.getAttribute('data-id');
                const currentStatus = this.getAttribute('data-status');
                const newStatus = currentStatus === 'active' ? 'inactive' : 'active';

                if (confirm('确定要' + (currentStatus === 'active' ? '停用' : '启用') + '该供应商吗？')) {
                    const form = document.createElement('form');
                    form.method = 'POST';
                    form.action = 'index.php?page=supplier';

                    const idInput = document.createElement('input');
                    idInput.type = 'hidden';
                    idInput.name = 'supplier_id';
                    idInput.value = supplierId;

                    const statusInput = document.createElement('input');
                    statusInput.type = 'hidden';
                    statusInput.name = 'status';
                    statusInput.value = newStatus;

                    const submitInput = document.createElement('input');
                    submitInput.type = 'hidden';
                    submitInput.name = 'update_status';
                    submitInput.value = '1';

                    form.appendChild(idInput);
                    form.appendChild(statusInput);
                    form.appendChild(submitInput);

                    document.body.appendChild(form);
                    form.submit();
                }
            });
        });

        // 查看按钮点击事件
        const viewBtns = document.querySelectorAll('.view-btn');
        const modal = document.getElementById('supplierDetailModal');
        const closeBtn = modal.querySelector('.close');
        const closeModalBtn = modal.querySelector('.btn-secondary');

        viewBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const tr = this.closest('tr');
                const cells = tr.getElementsByTagName('td');

                // 填充模态框数据
                document.getElementById('detail-name').textContent = cells[0].textContent;
                document.getElementById('detail-contact').textContent = cells[1].textContent;
                document.getElementById('detail-phone').textContent = cells[2].textContent;
                document.getElementById('detail-email').textContent = cells[3].textContent;
                document.getElementById('detail-categories').textContent = cells[4].textContent;
                document.getElementById('detail-status').textContent = cells[5].textContent;

                // 显示模态框
                modal.style.display = 'block';
            });
        });

        // 关闭模态框
        function closeModal() {
            modal.style.display = 'none';
        }

        closeBtn.addEventListener('click', closeModal);
        closeModalBtn.addEventListener('click', closeModal);

        // 点击模态框外部关闭
        window.addEventListener('click', function(event) {
            if (event.target == modal) {
                closeModal();
            }
        });

        // 编辑按钮点击事件
        const editBtns = document.querySelectorAll('.edit-btn');
        const editModal = document.getElementById('supplierEditModal');
        const editCloseBtn = editModal.querySelector('.close');
        const editCancelBtn = editModal.querySelector('.btn-secondary');
        const saveEditBtn = document.getElementById('saveEditBtn');

        editBtns.forEach(btn => {
            btn.addEventListener('click', function() {
                const supplierId = this.getAttribute('data-id');
                const tr = this.closest('tr');
                const cells = tr.getElementsByTagName('td');

                // 填充编辑表单数据
                document.getElementById('edit-id').value = supplierId;
                document.getElementById('edit-name').value = cells[0].textContent;
                document.getElementById('edit-contact').value = cells[1].textContent;
                document.getElementById('edit-phone').value = cells[2].textContent;
                document.getElementById('edit-email').value = cells[3].textContent;
                document.getElementById('edit-categories').value = cells[4].textContent;

                // 显示编辑模态框
                editModal.style.display = 'block';
            });
        });

        // 保存编辑
        saveEditBtn.addEventListener('click', function() {
            if (validateEditForm()) {
                document.getElementById('editSupplierForm').submit();
            }
        });

        // 验证编辑表单
        function validateEditForm() {
            const name = document.getElementById('edit-name').value.trim();
            const contact = document.getElementById('edit-contact').value.trim();
            const phone = document.getElementById('edit-phone').value.trim();
            const email = document.getElementById('edit-email').value.trim();
            const categories = document.getElementById('edit-categories').value.trim();

            if (!name) {
                alert('请输入供应商名称');
                return false;
            }
            if (!contact) {
                alert('请输入联系人');
                return false;
            }
            if (!phone) {
                alert('请输入联系电话');
                return false;
            }
            if (email && !isValidEmail(email)) {
                alert('请输入有效的电子邮箱');
                return false;
            }
            if (!categories) {
                alert('请输入供应产品类别');
                return false;
            }

            return true;
        }

        // 验证邮箱格式
        function isValidEmail(email) {
            const re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
            return re.test(email.toLowerCase());
        }

        // 关闭编辑模态框
        function closeEditModal() {
            editModal.style.display = 'none';
        }

        editCloseBtn.addEventListener('click', closeEditModal);
        editCancelBtn.addEventListener('click', closeEditModal);

        // 点击编辑模态框外部关闭
        window.addEventListener('click', function(event) {
            if (event.target == editModal) {
                closeEditModal();
            }
        });

        // 查看交易记录按钮点击事件
        const transactionModal = document.getElementById('transactionModal');
        const transactionCloseBtn = transactionModal.querySelector('.close');
        const transactionCancelBtn = transactionModal.querySelector('.btn-secondary');
        const transactionTable = document.getElementById('transactionTable').getElementsByTagName('tbody')[0];
        const noTransactions = document.getElementById('no-transactions');

        document.querySelectorAll('.view-btn').forEach(btn => {
            btn.addEventListener('click', function() {
                const supplierId = this.getAttribute('data-id');
                const supplierName = this.closest('tr').getElementsByTagName('td')[0].textContent;

                // 设置供应商名称
                document.getElementById('transaction-supplier-name').textContent = supplierName + ' - 交易记录';

                // 清空表格
                transactionTable.innerHTML = '';

                // 获取交易记录
                fetch(`index.php?page=supplier&get_transactions=1&supplier_id=${supplierId}`)
                    .then(response => response.json())
                    .then(data => {
                        if (data.length > 0) {
                            noTransactions.style.display = 'none';
                            data.forEach(transaction => {
                                const row = document.createElement('tr');
                                row.innerHTML = `
                                    <td>${formatDate(transaction.transaction_date)}</td>
                                    <td>${transaction.item_name}</td>
                                    <td>${getTransactionTypeText(transaction.transaction_type)}</td>
                                    <td>${transaction.quantity} ${transaction.unit}</td>
                                    <td>¥${parseFloat(transaction.unit_price).toFixed(2)}</td>
                                    <td>¥${parseFloat(transaction.total_price).toFixed(2)}</td>
                                    <td>${transaction.operator_name || '未知'}</td>
                                    <td>${transaction.notes || ''}</td>
                                `;
                                transactionTable.appendChild(row);
                            });
                        } else {
                            noTransactions.style.display = 'block';
                        }
                    })
                    .catch(error => {
                        console.error('获取交易记录失败:', error);
                        noTransactions.style.display = 'block';
                        noTransactions.textContent = '获取交易记录失败';
                    });

                // 显示模态框
                transactionModal.style.display = 'block';
            });
        });

        // 格式化日期
        function formatDate(dateString) {
            const date = new Date(dateString);
            const year = date.getFullYear();
            const month = String(date.getMonth() + 1).padStart(2, '0');
            const day = String(date.getDate()).padStart(2, '0');
            const hours = String(date.getHours()).padStart(2, '0');
            const minutes = String(date.getMinutes()).padStart(2, '0');
            return `${year}-${month}-${day} ${hours}:${minutes}`;
        }

        // 获取交易类型文本
        function getTransactionTypeText(type) {
            const types = {
                'purchase': '采购入库',
                'consumption': '消耗出库',
                'adjustment': '库存调整',
                'return': '退货'
            };
            return types[type] || type;
        }

        // 关闭交易记录模态框
        function closeTransactionModal() {
            transactionModal.style.display = 'none';
        }

        transactionCloseBtn.addEventListener('click', closeTransactionModal);
        transactionCancelBtn.addEventListener('click', closeTransactionModal);

        // 点击交易记录模态框外部关闭
        window.addEventListener('click', function(event) {
            if (event.target == transactionModal) {
                closeTransactionModal();
            }
        });
    });
</script>