<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 检查用户是否有管理员权限
if ($_SESSION['user_role'] != 'admin') {
    header('Location: ../../home.php');
    exit;
}

require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 获取系统统计信息
$stats = [
    'users' => 0,
    'logs' => 0,
    'last_backup' => '未备份',
    'disk_usage' => '0 MB'
];

// 获取管理员数量
$result = $conn->query("SELECT COUNT(*) as count FROM users WHERE role = 'admin'");
if ($result && $row = $result->fetch_assoc()) {
    $stats['users'] = $row['count'];
}

// 获取日志数量
$result = $conn->query("SELECT COUNT(*) as count FROM system_logs");
if ($result && $row = $result->fetch_assoc()) {
    $stats['logs'] = $row['count'];
}

// 获取最后备份时间
$result = $conn->query("SELECT backup_time FROM system_backups WHERE status = 'completed' ORDER BY backup_time DESC LIMIT 1");
if ($result && $row = $result->fetch_assoc()) {
    $stats['last_backup'] = date('Y-m-d H:i:s', strtotime($row['backup_time']));
}

// 获取磁盘使用情况
$backup_dir = '../../backups';
$stats['disk_usage'] = '0 MB';
if (file_exists($backup_dir)) {
    $size = 0;
    foreach (new RecursiveIteratorIterator(new RecursiveDirectoryIterator($backup_dir, FilesystemIterator::SKIP_DOTS)) as $file) {
        $size += $file->getSize();
    }
    $stats['disk_usage'] = formatBytes($size);
}

// 获取最近日志
$recent_logs = [];
$result = $conn->query("SELECT * FROM system_logs ORDER BY created_at DESC LIMIT 5");
if ($result) {
    while ($row = $result->fetch_assoc()) {
        $recent_logs[] = $row;
    }
}

// 获取在线管理员
$online_admins = [];
$query = "SELECT id, username, last_login, last_activity FROM users WHERE role = 'admin' OR role = 'super_admin' ORDER BY last_activity DESC LIMIT 10";
$result = $conn->query($query);
if ($result) {
    while ($row = $result->fetch_assoc()) {
        // 标记当前登录的管理员
        if ($row['id'] == $_SESSION['user_id']) {
            $row['is_current'] = true;
        } else {
            $row['is_current'] = false;
        }

        // 判断是否在线（30分钟内有活动）
        $row['is_online'] = false;
        if (!empty($row['last_activity'])) {
            $last_activity = strtotime($row['last_activity']);
            $row['is_online'] = (time() - $last_activity) < 1800; // 30分钟 = 1800秒
        }

        $online_admins[] = $row;
    }
}

// 当前用户名 - 添加安全检查
$current_username = isset($_SESSION['username']) ? $_SESSION['username'] : '管理员';
?>

<div class="content">
    <!-- 统计卡片 -->
    <div class="stats-container">
        <div class="stat-card">
            <div class="stat-card-icon">
                <i class="fas fa-users"></i>
            </div>
            <div class="stat-card-info">
                <h3>管理员数量</h3>
                <p><?php echo $stats['users']; ?></p>
            </div>
        </div>
        <div class="stat-card">
            <div class="stat-card-icon">
                <i class="fas fa-list"></i>
            </div>
            <div class="stat-card-info">
                <h3>系统日志</h3>
                <p><?php echo $stats['logs']; ?></p>
            </div>
        </div>
        <div class="stat-card">
            <div class="stat-card-icon">
                <i class="fas fa-database"></i>
            </div>
            <div class="stat-card-info">
                <h3>最后备份</h3>
                <p><?php echo $stats['last_backup']; ?></p>
            </div>
        </div>
        <div class="stat-card">
            <div class="stat-card-icon">
                <i class="fas fa-hdd"></i>
            </div>
            <div class="stat-card-info">
                <h3>备份存储占用</h3>
                <p><?php echo $stats['disk_usage']; ?></p>
            </div>
        </div>
    </div>

    <div class="row">
        <!-- 最近日志 -->
        <div class="col-md-6">
            <div class="card">
                <div class="card-header">
                    <h3>最近系统日志</h3>
                </div>
                <div class="card-body">
                    <?php if (count($recent_logs) > 0): ?>
                        <ul class="log-list">
                            <?php foreach ($recent_logs as $log): ?>
                                <li>
                                    <div class="log-info">
                                        <div class="log-time"><?php echo date('Y-m-d H:i', strtotime($log['created_at'])); ?></div>
                                        <div class="log-user"><?php echo htmlspecialchars($log['username'] ?? '系统'); ?></div>
                                    </div>
                                    <div class="log-action"><?php echo htmlspecialchars($log['action']); ?></div>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                        <a href="?page=log_management" class="btn btn-outline-primary btn-sm mt-3">查看全部日志</a>
                    <?php else: ?>
                        <div class="alert alert-info">暂无日志记录</div>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <!-- 在线用户和快捷链接 -->
        <div class="col-md-6">
            <!-- 在线管理员 -->
            <div class="card mb-4">
                <div class="card-header">
                    <h3>管理员状态</h3>
                </div>
                <div class="card-body">
                    <?php if (count($online_admins) > 0): ?>
                        <ul class="user-list">
                            <?php foreach ($online_admins as $admin): ?>
                                <li class="<?php echo $admin['is_current'] ? 'current-user' : ''; ?>">
                                    <div class="user-avatar">
                                        <i class="fas fa-user-circle"></i>
                                    </div>
                                    <div class="user-info">
                                        <div class="user-name">
                                            <?php echo htmlspecialchars($admin['username']); ?>
                                            <?php if ($admin['is_current']): ?>
                                                <span class="current-user-label">(当前)</span>
                                            <?php endif; ?>
                                        </div>
                                        <div class="user-status">
                                            <?php if ($admin['is_online']): ?>
                                                <span class="badge badge-success">在线</span>
                                            <?php else: ?>
                                                <span class="badge badge-secondary">离线</span>
                                            <?php endif; ?>
                                            <small>
                                                <?php echo $admin['last_login'] ? '最后登录: ' . date('Y-m-d H:i', strtotime($admin['last_login'])) : '从未登录'; ?>
                                            </small>
                                        </div>
                                    </div>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    <?php else: ?>
                        <div class="alert alert-info">暂无在线管理员</div>
                    <?php endif; ?>
                </div>
            </div>

            <!-- 快捷链接 -->
            <div class="card">
                <div class="card-header">
                    <h3>快捷操作</h3>
                </div>
                <div class="card-body">
                    <div class="quick-links">
                        <a href="?page=user_management" class="quick-link">
                            <i class="fas fa-user-cog"></i>
                            <span>管理员设置</span>
                        </a>
                        <a href="?page=backup" class="quick-link">
                            <i class="fas fa-save"></i>
                            <span>备份系统</span>
                        </a>
                        <a href="?page=log_management" class="quick-link">
                            <i class="fas fa-clipboard-list"></i>
                            <span>日志管理</span>
                        </a>
                        <a href="../../home.php" class="quick-link">
                            <i class="fas fa-home"></i>
                            <span>返回首页</span>
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .stats-container {
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(240px, 1fr));
        gap: 20px;
        margin-bottom: 30px;
    }

    .stat-card {
        display: flex;
        align-items: center;
        background-color: #fff;
        border-radius: 8px;
        padding: 20px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
    }

    .stat-card-icon {
        width: 50px;
        height: 50px;
        border-radius: 50%;
        background-color: #007bff;
        display: flex;
        align-items: center;
        justify-content: center;
        margin-right: 16px;
    }

    .stat-card-icon i {
        font-size: 24px;
        color: #fff;
    }

    .stat-card-info h3 {
        font-size: 16px;
        margin: 0 0 5px;
        color: #666;
    }

    .stat-card-info p {
        font-size: 20px;
        font-weight: bold;
        margin: 0;
        color: #333;
    }

    .log-list,
    .user-list {
        list-style: none;
        padding: 0;
        margin: 0;
    }

    .log-list li {
        padding: 10px 0;
        border-bottom: 1px solid #eee;
    }

    .log-info {
        display: flex;
        align-items: center;
        margin-bottom: 5px;
    }

    .log-time {
        font-size: 12px;
        color: #666;
        margin-right: 10px;
    }

    .log-user {
        font-size: 12px;
        font-weight: bold;
        color: #007bff;
    }

    .log-action {
        font-size: 14px;
        color: #333;
    }

    .user-list li {
        display: flex;
        align-items: center;
        padding: 10px 0;
        border-bottom: 1px solid #eee;
    }

    .user-list li.current-user {
        background-color: #f8f9fa;
        border-left: 3px solid #007bff;
        padding-left: 10px;
    }

    .current-user-label {
        font-size: 11px;
        color: #007bff;
        font-weight: normal;
        margin-left: 5px;
    }

    .user-avatar {
        width: 40px;
        height: 40px;
        margin-right: 12px;
        color: #007bff;
        font-size: 32px;
    }

    .user-name {
        font-size: 14px;
        font-weight: bold;
        margin-bottom: 2px;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
        padding: 3px 6px;
        border-radius: 3px;
        font-size: 11px;
    }

    .badge-secondary {
        background-color: #6c757d;
        color: white;
        padding: 3px 6px;
        border-radius: 3px;
        font-size: 11px;
    }

    .user-status small {
        display: block;
        font-size: 11px;
        color: #6c757d;
        margin-top: 3px;
    }

    .quick-links {
        display: grid;
        grid-template-columns: repeat(2, 1fr);
        gap: 15px;
    }

    .quick-link {
        display: flex;
        flex-direction: column;
        align-items: center;
        justify-content: center;
        background-color: #f8f9fa;
        border-radius: 6px;
        padding: 15px;
        text-decoration: none;
        color: #333;
        transition: background-color 0.2s;
    }

    .quick-link:hover {
        background-color: #e9ecef;
        text-decoration: none;
    }

    .quick-link i {
        font-size: 24px;
        margin-bottom: 8px;
        color: #007bff;
    }

    .quick-link span {
        font-size: 14px;
    }
</style>

<?php
// 格式化文件大小
function formatBytes($bytes, $precision = 2)
{
    $units = array('B', 'KB', 'MB', 'GB', 'TB');
    $bytes = max($bytes, 0);
    $pow = floor(($bytes ? log($bytes) : 0) / log(1024));
    $pow = min($pow, count($units) - 1);
    return round($bytes / pow(1024, $pow), $precision) . ' ' . $units[$pow];
}
