<?php
session_start();
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 检查用户是否有管理员权限
if ($_SESSION['user_role'] != 'admin') {
    header('Location: ../../home.php');
    exit;
}

// 获取当前页面
$page = isset($_GET['page']) ? $_GET['page'] : 'dashboard';

// 页面标题
$pageTitle = '系统管理';
$subTitle = '';

// 获取子页面内容
$contentFile = '';
switch ($page) {
    case 'user_management':
        $contentFile = 'user_management.php';
        $subTitle = '管理员管理';
        break;
    case 'log_management':
        $contentFile = 'log_management.php';
        $subTitle = '日志管理';
        break;
    case 'backup':
        $contentFile = 'backup.php';
        $subTitle = '系统备份与恢复';
        break;
    default:
        $contentFile = 'dashboard.php';
        $subTitle = '概览';
}

// 检查文件是否存在
if (!file_exists($contentFile)) {
    $contentFile = 'dashboard.php';
    $subTitle = '概览';
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $subTitle; ?> - <?php echo $pageTitle; ?> - <?php echo SITE_NAME; ?></title>
    <link rel="stylesheet" href="../../assets/css/style.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/css/bootstrap.min.css">
    <script src="https://cdn.jsdelivr.net/npm/jquery@3.6.4/dist/jquery.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/js/bootstrap.bundle.min.js"></script>
</head>

<body>
    <header class="main-header">
        <div class="user-info">
            <span class="user-name"><?php echo isset($_SESSION['username']) ? $_SESSION['username'] : '管理员'; ?></span>
            <span class="user-role"><?php echo $_SESSION['user_role']; ?></span>
        </div>

        <div class="site-title">
            <h1><?php echo SITE_NAME; ?></h1>
            <p><?php echo SITE_SUBTITLE; ?></p>
        </div>

        <div class="header-actions">
            <a href="../../logout.php" class="btn btn-logout">退出登录</a>
        </div>
    </header>

    <div class="module-layout">
        <aside class="module-sidebar">
            <div class="module-sidebar-header">
                <h2><?php echo $pageTitle; ?></h2>
            </div>

            <nav class="module-nav">
                <a href="../../home.php" class="module-nav-item">返回首页</a>
                <a href="index.php" class="module-nav-item <?php echo $page == 'dashboard' ? 'active' : ''; ?>">概览</a>
                <a href="index.php?page=user_management" class="module-nav-item <?php echo $page == 'user_management' ? 'active' : ''; ?>">管理员管理</a>
                <a href="index.php?page=log_management" class="module-nav-item <?php echo $page == 'log_management' ? 'active' : ''; ?>">日志管理</a>
                <a href="index.php?page=backup" class="module-nav-item <?php echo $page == 'backup' ? 'active' : ''; ?>">系统备份与恢复</a>
            </nav>
        </aside>

        <main class="module-content">
            <div class="module-content-header">
                <h2><?php echo $subTitle; ?></h2>
            </div>
            <?php
            // 包含子页面内容
            include $contentFile;
            ?>
        </main>
    </div>
</body>

</html>