<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 检查用户是否有管理员权限
if ($_SESSION['user_role'] != 'admin') {
    header('Location: ../../home.php');
    exit;
}

require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 确保日志表存在
$sql = "CREATE TABLE IF NOT EXISTS system_logs (
    id INT AUTO_INCREMENT PRIMARY KEY,
    user_id INT,
    username VARCHAR(50),
    action TEXT NOT NULL,
    ip_address VARCHAR(45),
    user_agent TEXT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE SET NULL
)";
$conn->query($sql);

// 处理日志清理
if (isset($_POST['clear_logs']) && isset($_POST['days'])) {
    $days = intval($_POST['days']);
    try {
        $query = "DELETE FROM system_logs WHERE created_at < DATE_SUB(NOW(), INTERVAL ? DAY)";
        $stmt = $conn->prepare($query);

        if (!$stmt) {
            throw new Exception("数据库查询准备失败：" . $conn->error);
        }

        $stmt->bind_param("i", $days);
        $stmt->execute();
        $affected = $stmt->affected_rows;
        $stmt->close();

        $success_message = "成功清理 {$affected} 条日志记录！";

        // 记录清理操作到日志
        if (function_exists('logSystemAction')) {
            logSystemAction($_SESSION['user_id'], "清理了{$days}天前的系统日志");
        } else {
            // 如果函数不存在，使用直接插入方式记录
            $action = "清理了{$days}天前的系统日志";
            $ip = $_SERVER['REMOTE_ADDR'] ?? '';
            $username = isset($_SESSION['username']) ? $_SESSION['username'] : '';

            $insertLog = $conn->prepare("INSERT INTO system_logs (user_id, username, action, ip_address) VALUES (?, ?, ?, ?)");
            if ($insertLog) {
                $insertLog->bind_param("isss", $_SESSION['user_id'], $username, $action, $ip);
                $insertLog->execute();
                $insertLog->close();
            }
        }
    } catch (Exception $e) {
        $error_message = "清理失败：" . $e->getMessage();
    }
}

// 处理日志导出
if (isset($_POST['export_logs'])) {
    $filename = "system_logs_" . date('Y-m-d_His') . ".csv";
    header('Content-Type: text/csv');
    header('Content-Disposition: attachment; filename="' . $filename . '"');

    $output = fopen('php://output', 'w');

    // 写入CSV头部
    fputcsv($output, ['ID', '用户', '操作', 'IP地址', '时间']);

    // 获取并写入数据
    $result = $conn->query("SELECT id, username, action, ip_address, created_at FROM system_logs ORDER BY created_at DESC");
    while ($row = $result->fetch_assoc()) {
        fputcsv($output, [
            $row['id'],
            $row['username'],
            $row['action'],
            $row['ip_address'],
            $row['created_at']
        ]);
    }

    fclose($output);
    exit;
}

// 获取日志列表
$page = isset($_GET['page_num']) ? intval($_GET['page_num']) : 1;
$per_page = 50;
$offset = ($page - 1) * $per_page;

// 获取总记录数
$total_result = $conn->query("SELECT COUNT(*) as count FROM system_logs");
$total_records = $total_result->fetch_assoc()['count'];
$total_pages = ceil($total_records / $per_page);

// 获取当前页的日志
$logs = [];
$result = $conn->query("SELECT * FROM system_logs ORDER BY created_at DESC LIMIT {$offset}, {$per_page}");
while ($row = $result->fetch_assoc()) {
    $logs[] = $row;
}
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success"><?php echo $success_message; ?></div>
    <?php endif; ?>
    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger"><?php echo $error_message; ?></div>
    <?php endif; ?>

    <!-- 操作按钮 -->
    <div class="action-buttons mb-4">
        <button class="btn btn-primary" onclick="showClearLogsModal()">清理日志</button>
        <form method="post" style="display: inline;">
            <button type="submit" name="export_logs" class="btn btn-success">导出日志</button>
        </form>
    </div>

    <!-- 日志列表 -->
    <div class="card">
        <div class="card-header">
            <h3>系统日志</h3>
            <div class="card-tools">
                共 <?php echo $total_records; ?> 条记录
            </div>
        </div>
        <div class="card-body">
            <?php if (count($logs) > 0): ?>
                <div class="table-responsive">
                    <table class="table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>时间</th>
                                <th>用户</th>
                                <th>操作</th>
                                <th>IP地址</th>
                                <th>User Agent</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($logs as $log): ?>
                                <tr>
                                    <td><?php echo $log['id']; ?></td>
                                    <td><?php echo date('Y-m-d H:i:s', strtotime($log['created_at'])); ?></td>
                                    <td><?php echo htmlspecialchars($log['username'] ?? '系统'); ?></td>
                                    <td><?php echo htmlspecialchars($log['action']); ?></td>
                                    <td><?php echo htmlspecialchars($log['ip_address'] ?? ''); ?></td>
                                    <td class="text-truncate" style="max-width: 200px;" title="<?php echo htmlspecialchars($log['user_agent'] ?? ''); ?>">
                                        <?php echo htmlspecialchars($log['user_agent'] ?? ''); ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 分页 -->
                <?php if ($total_pages > 1): ?>
                    <div class="pagination-container">
                        <ul class="pagination">
                            <?php if ($page > 1): ?>
                                <li class="page-item">
                                    <a class="page-link" href="?page=log_management&page_num=<?php echo ($page - 1); ?>">上一页</a>
                                </li>
                            <?php endif; ?>

                            <?php
                            $start_page = max(1, $page - 2);
                            $end_page = min($total_pages, $page + 2);

                            if ($start_page > 1) {
                                echo '<li class="page-item"><a class="page-link" href="?page=log_management&page_num=1">1</a></li>';
                                if ($start_page > 2) {
                                    echo '<li class="page-item disabled"><span class="page-link">...</span></li>';
                                }
                            }

                            for ($i = $start_page; $i <= $end_page; $i++) {
                                echo '<li class="page-item ' . ($i == $page ? 'active' : '') . '">';
                                echo '<a class="page-link" href="?page=log_management&page_num=' . $i . '">' . $i . '</a>';
                                echo '</li>';
                            }

                            if ($end_page < $total_pages) {
                                if ($end_page < $total_pages - 1) {
                                    echo '<li class="page-item disabled"><span class="page-link">...</span></li>';
                                }
                                echo '<li class="page-item"><a class="page-link" href="?page=log_management&page_num=' . $total_pages . '">' . $total_pages . '</a></li>';
                            }
                            ?>

                            <?php if ($page < $total_pages): ?>
                                <li class="page-item">
                                    <a class="page-link" href="?page=log_management&page_num=<?php echo ($page + 1); ?>">下一页</a>
                                </li>
                            <?php endif; ?>
                        </ul>
                    </div>
                <?php endif; ?>
            <?php else: ?>
                <div class="alert alert-info">暂无日志记录</div>
            <?php endif; ?>
        </div>
    </div>
</div>

<!-- 清理日志模态框 -->
<div class="modal fade" id="clearLogsModal" tabindex="-1" role="dialog" style="display: none;">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">清理日志</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <form method="post">
                <div class="modal-body">
                    <div class="form-group">
                        <label for="days">清理多少天前的日志？</label>
                        <select class="form-control" id="days" name="days" required>
                            <option value="30">30天</option>
                            <option value="60">60天</option>
                            <option value="90">90天</option>
                            <option value="180">180天</option>
                            <option value="365">365天</option>
                        </select>
                    </div>
                    <div class="alert alert-warning">
                        <i class="fas fa-exclamation-triangle"></i>
                        警告：此操作不可恢复，请谨慎操作！
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">取消</button>
                    <button type="submit" name="clear_logs" class="btn btn-danger">确认清理</button>
                </div>
            </form>
        </div>
    </div>
</div>

<style>
    .action-buttons {
        margin-bottom: 20px;
    }

    .action-buttons .btn {
        margin-right: 10px;
    }

    .pagination-container {
        display: flex;
        justify-content: center;
        margin-top: 20px;
    }

    .pagination {
        display: flex;
        list-style: none;
        padding: 0;
        margin: 0;
    }

    .page-item {
        margin: 0 2px;
    }

    .page-link {
        display: block;
        padding: 8px 12px;
        color: #007bff;
        background-color: #fff;
        border: 1px solid #dee2e6;
        border-radius: 4px;
        text-decoration: none;
    }

    .page-item.active .page-link {
        color: #fff;
        background-color: #007bff;
        border-color: #007bff;
    }

    .page-item.disabled .page-link {
        color: #6c757d;
        pointer-events: none;
        background-color: #fff;
        border-color: #dee2e6;
    }

    .text-truncate {
        overflow: hidden;
        text-overflow: ellipsis;
        white-space: nowrap;
    }

    @media (max-width: 768px) {
        .table-responsive {
            margin-bottom: 15px;
            overflow-y: hidden;
            -ms-overflow-style: -ms-autohiding-scrollbar;
            border: 1px solid #dee2e6;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 确保jQuery和Bootstrap已加载
        if (typeof jQuery !== 'undefined' && typeof jQuery.fn.modal !== 'undefined') {
            console.log('jQuery和Bootstrap已正确加载');
            // 初始化并隐藏模态框
            jQuery('#clearLogsModal').modal('hide');
        } else {
            console.error('jQuery或Bootstrap未正确加载，模态框可能无法正常工作');
        }
    });

    function showClearLogsModal() {
        console.log('正在尝试显示清理日志模态框');
        if (typeof jQuery !== 'undefined' && typeof jQuery.fn.modal !== 'undefined') {
            jQuery('#clearLogsModal').modal('show');
        } else {
            alert('无法显示模态框：jQuery或Bootstrap未正确加载');
        }
    }
</script>