<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查是否有门票类别
$result = $conn->query("SELECT COUNT(*) as count FROM tourism_services WHERE category = 'ticket' AND status = 'active'");
$ticketCount = $result->fetch_assoc()['count'];

// 修改查询前添加确保数据表存在的代码
$sql = "SHOW TABLES LIKE 'tourism_services'";
$tableExistsResult = $conn->query($sql);
if ($tableExistsResult->num_rows == 0) {
    // 如果表不存在，创建表
    $conn->query("CREATE TABLE IF NOT EXISTS tourism_services (
        id INT AUTO_INCREMENT PRIMARY KEY,
        name VARCHAR(100) NOT NULL,
        category ENUM(
            'ticket',
            'transport',
            'guide',
            'activity',
            'other'
        ) NOT NULL,
        description TEXT,
        price DECIMAL(10, 2) NOT NULL,
        commission_rate DECIMAL(5, 2) DEFAULT 0.00,
        provider VARCHAR(100),
        contact_info TEXT,
        status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
        created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
        updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
    ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;");
}

$sql = "SHOW TABLES LIKE 'tourism_bookings'";
$tableExistsResult = $conn->query($sql);
if ($tableExistsResult->num_rows == 0) {
    // 如果表不存在，创建表
    $conn->query("CREATE TABLE IF NOT EXISTS tourism_bookings (
        id INT AUTO_INCREMENT PRIMARY KEY,
        service_id INT NOT NULL,
        booking_id INT,
        member_id INT,
        guest_name VARCHAR(100) NOT NULL,
        guest_phone VARCHAR(20) NOT NULL,
        service_date DATE NOT NULL,
        service_time TIME,
        quantity INT NOT NULL DEFAULT 1,
        total_price DECIMAL(12, 2) NOT NULL,
        payment_status ENUM('unpaid', 'paid', 'refunded') NOT NULL DEFAULT 'unpaid',
        status ENUM('pending', 'confirmed', 'completed', 'cancelled') NOT NULL DEFAULT 'pending',
        notes TEXT,
        created_by INT,
        created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
        updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        FOREIGN KEY (service_id) REFERENCES tourism_services(id) ON DELETE RESTRICT
    ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;");
}

// 处理门票添加/编辑
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['save_ticket'])) {
    $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
    $name = $_POST['name'];
    $description = $_POST['description'];
    $price = $_POST['price'];
    $commission_rate = $_POST['commission_rate'];
    $provider = $_POST['provider'];
    $contact_info = $_POST['contact_info'];
    $status = $_POST['status'];

    try {
        if ($id > 0) {
            // 更新门票
            $stmt = $conn->prepare("UPDATE tourism_services SET 
                name = ?, description = ?, price = ?, commission_rate = ?, 
                provider = ?, contact_info = ?, status = ? 
                WHERE id = ? AND category = 'ticket'");
            $stmt->bind_param("ssddsssi", $name, $description, $price, $commission_rate, $provider, $contact_info, $status, $id);
            $stmt->execute();
            $success_message = "景区门票信息更新成功！";
        } else {
            // 添加新门票
            $stmt = $conn->prepare("INSERT INTO tourism_services 
                (name, category, description, price, commission_rate, provider, contact_info, status) 
                VALUES (?, 'ticket', ?, ?, ?, ?, ?, ?)");
            $stmt->bind_param("ssddsss", $name, $description, $price, $commission_rate, $provider, $contact_info, $status);
            $stmt->execute();
            $success_message = "景区门票添加成功！";
        }
    } catch (Exception $e) {
        $error_message = "操作失败：" . $e->getMessage();
    }
}

// 处理门票删除
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $id = intval($_GET['id']);

    // 检查门票是否有预订记录
    $stmt = $conn->prepare("SELECT COUNT(*) FROM tourism_bookings WHERE service_id = ?");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $stmt->bind_result($bookingCount);
    $stmt->fetch();
    $stmt->close();

    if ($bookingCount > 0) {
        $error_message = "无法删除！该门票已有 {$bookingCount} 条预订记录。";
    } else {
        try {
            $stmt = $conn->prepare("DELETE FROM tourism_services WHERE id = ? AND category = 'ticket'");
            $stmt->bind_param("i", $id);
            $stmt->execute();
            $success_message = "景区门票删除成功！";
        } catch (Exception $e) {
            $error_message = "删除失败：" . $e->getMessage();
        }
    }
}

// 处理门票预订
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['book_ticket'])) {
    $service_id = intval($_POST['service_id']);
    $guest_name = $_POST['guest_name'];
    $guest_phone = $_POST['guest_phone'];
    $service_date = $_POST['service_date'];
    $quantity = intval($_POST['quantity']);
    $member_id = !empty($_POST['member_id']) ? intval($_POST['member_id']) : null;
    $booking_id = !empty($_POST['booking_id']) ? intval($_POST['booking_id']) : null;
    $notes = $_POST['notes'];

    // 获取门票价格
    $stmt = $conn->prepare("SELECT price FROM tourism_services WHERE id = ?");
    $stmt->bind_param("i", $service_id);
    $stmt->execute();
    $stmt->bind_result($ticketPrice);
    $stmt->fetch();
    $stmt->close();

    $total_price = $ticketPrice * $quantity;

    try {
        $stmt = $conn->prepare("INSERT INTO tourism_bookings 
            (service_id, booking_id, member_id, guest_name, guest_phone, service_date, 
            quantity, total_price, payment_status, status, notes, created_by) 
            VALUES (?, ?, ?, ?, ?, ?, ?, ?, 'unpaid', 'pending', ?, ?)");
        $stmt->bind_param(
            "iiisssdsi",
            $service_id,
            $booking_id,
            $member_id,
            $guest_name,
            $guest_phone,
            $service_date,
            $quantity,
            $total_price,
            $notes,
            $_SESSION['user_id']
        );
        $stmt->execute();
        $success_message = "门票预订成功！";
    } catch (Exception $e) {
        $error_message = "预订失败：" . $e->getMessage();
    }
}

// 处理订单状态更新
if (isset($_GET['action']) && $_GET['action'] == 'update_status' && isset($_GET['id']) && isset($_GET['status'])) {
    $id = intval($_GET['id']);
    $status = $_GET['status'];
    $validStatuses = ['pending', 'confirmed', 'completed', 'cancelled'];

    if (in_array($status, $validStatuses)) {
        try {
            $stmt = $conn->prepare("UPDATE tourism_bookings SET status = ? WHERE id = ?");
            $stmt->bind_param("si", $status, $id);
            $stmt->execute();
            $success_message = "订单状态更新成功！";
        } catch (Exception $e) {
            $error_message = "状态更新失败：" . $e->getMessage();
        }
    } else {
        $error_message = "无效的状态值！";
    }
}

// 处理支付状态更新
if (isset($_GET['action']) && $_GET['action'] == 'update_payment' && isset($_GET['id']) && isset($_GET['status'])) {
    $id = intval($_GET['id']);
    $status = $_GET['status'];
    $validStatuses = ['unpaid', 'paid', 'refunded'];

    if (in_array($status, $validStatuses)) {
        try {
            $stmt = $conn->prepare("UPDATE tourism_bookings SET payment_status = ? WHERE id = ?");
            $stmt->bind_param("si", $status, $id);
            $stmt->execute();
            $success_message = "支付状态更新成功！";
        } catch (Exception $e) {
            $error_message = "状态更新失败：" . $e->getMessage();
        }
    } else {
        $error_message = "无效的状态值！";
    }
}

// 获取要编辑的门票
$editing = false;
$ticket = [
    'name' => '',
    'description' => '',
    'price' => '',
    'commission_rate' => '0.00',
    'provider' => '',
    'contact_info' => '',
    'status' => 'active'
];

if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $id = intval($_GET['id']);
    $stmt = $conn->prepare("SELECT * FROM tourism_services WHERE id = ? AND category = 'ticket'");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $editing = true;
        $ticket = $result->fetch_assoc();
    }
}

// 获取所有景区门票
$stmt = $conn->prepare("SELECT * FROM tourism_services WHERE category = 'ticket' ORDER BY name");
$stmt->execute();
$result = $stmt->get_result();
$tickets = [];
while ($row = $result->fetch_assoc()) {
    $tickets[] = $row;
}

// 获取最近的门票预订
$query = "SELECT tb.*, ts.name as service_name 
          FROM tourism_bookings tb
          JOIN tourism_services ts ON tb.service_id = ts.id
          WHERE ts.category = 'ticket'
          ORDER BY tb.created_at DESC LIMIT 10";
$result = $conn->query($query);
$bookings = [];
while ($row = $result->fetch_assoc()) {
    $bookings[] = $row;
}

// 获取会员列表（用于预订）
$query = "SELECT id, name, phone FROM members WHERE status = 'active' ORDER BY name";
$result = $conn->query($query);
$members = [];
while ($row = $result->fetch_assoc()) {
    $members[] = $row;
}

// 获取住宿预订列表（用于关联）
$roomBookings = [];
$query = "SELECT id, guest_name, checkin_date, checkout_date FROM bookings 
          WHERE status IN ('confirmed', 'checked_in') 
          ORDER BY checkin_date DESC LIMIT 20";
$result = $conn->query($query);

// 检查查询是否成功
if ($result && $result !== false) {
    while ($row = $result->fetch_assoc()) {
        $roomBookings[] = $row;
    }
}
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success"><?php echo $success_message; ?></div>
    <?php endif; ?>
    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger"><?php echo $error_message; ?></div>
    <?php endif; ?>

    <!-- 操作按钮 -->
    <div class="action-buttons mb-4">
        <button class="btn btn-primary" onclick="showTicketList()">门票列表</button>
        <button class="btn btn-success" onclick="showAddTicket()">添加门票</button>
        <button class="btn btn-info" onclick="showBookingList()">预订记录</button>
        <button class="btn btn-warning" onclick="showBookTicket()">预订门票</button>
    </div>

    <!-- 门票列表 -->
    <div class="card mb-4 tab-pane" id="ticket-list">
        <div class="card-header">
            <h3>景区门票列表</h3>
        </div>
        <div class="card-body">
            <?php if (count($tickets) > 0): ?>
                <div class="table-responsive">
                    <table class="table table-striped">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>名称</th>
                                <th>价格</th>
                                <th>佣金率</th>
                                <th>提供方</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($tickets as $item): ?>
                                <tr>
                                    <td><?php echo $item['id']; ?></td>
                                    <td><?php echo htmlspecialchars($item['name']); ?></td>
                                    <td>¥<?php echo number_format($item['price'], 2); ?></td>
                                    <td><?php echo $item['commission_rate']; ?>%</td>
                                    <td><?php echo htmlspecialchars($item['provider']); ?></td>
                                    <td>
                                        <span class="status-badge <?php echo $item['status']; ?>">
                                            <?php echo $item['status'] == 'active' ? '启用' : '停用'; ?>
                                        </span>
                                    </td>
                                    <td>
                                        <div class="btn-group">
                                            <a href="index.php?page=ticket&action=edit&id=<?php echo $item['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                            <a href="index.php?page=ticket&action=delete&id=<?php echo $item['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此门票吗？')">删除</a>
                                        </div>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php else: ?>
                <div class="alert alert-info">暂无景区门票信息，请添加</div>
            <?php endif; ?>
        </div>
    </div>

    <!-- 添加/编辑门票 -->
    <div class="card mb-4 tab-pane" id="add-ticket" style="display: none;">
        <div class="card-header">
            <h3><?php echo $editing ? '编辑门票' : '添加新门票'; ?></h3>
        </div>
        <div class="card-body">
            <form method="post" action="index.php?page=ticket">
                <?php if ($editing): ?>
                    <input type="hidden" name="id" value="<?php echo $ticket['id']; ?>">
                <?php endif; ?>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="name">门票名称</label>
                        <input type="text" class="form-control" id="name" name="name" value="<?php echo htmlspecialchars($ticket['name']); ?>" required>
                    </div>
                    <div class="form-group col-md-6">
                        <label for="price">价格</label>
                        <div class="input-group">
                            <div class="input-group-prepend">
                                <span class="input-group-text">¥</span>
                            </div>
                            <input type="number" class="form-control" id="price" name="price" step="0.01" value="<?php echo $ticket['price']; ?>" required>
                        </div>
                    </div>
                </div>

                <div class="form-group">
                    <label for="description">描述</label>
                    <textarea class="form-control" id="description" name="description" rows="3"><?php echo htmlspecialchars($ticket['description']); ?></textarea>
                </div>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="commission_rate">佣金率</label>
                        <div class="input-group">
                            <input type="number" class="form-control" id="commission_rate" name="commission_rate" step="0.01" min="0" max="100" value="<?php echo $ticket['commission_rate']; ?>">
                            <div class="input-group-append">
                                <span class="input-group-text">%</span>
                            </div>
                        </div>
                    </div>
                    <div class="form-group col-md-6">
                        <label for="status">状态</label>
                        <select class="form-control" id="status" name="status">
                            <option value="active" <?php echo $ticket['status'] == 'active' ? 'selected' : ''; ?>>启用</option>
                            <option value="inactive" <?php echo $ticket['status'] == 'inactive' ? 'selected' : ''; ?>>停用</option>
                        </select>
                    </div>
                </div>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="provider">提供方</label>
                        <input type="text" class="form-control" id="provider" name="provider" value="<?php echo htmlspecialchars($ticket['provider']); ?>">
                    </div>
                    <div class="form-group col-md-6">
                        <label for="contact_info">联系信息</label>
                        <input type="text" class="form-control" id="contact_info" name="contact_info" value="<?php echo htmlspecialchars($ticket['contact_info']); ?>">
                    </div>
                </div>

                <button type="submit" name="save_ticket" class="btn btn-primary"><?php echo $editing ? '更新' : '添加'; ?></button>
                <a href="index.php?page=ticket" class="btn btn-secondary">取消</a>
            </form>
        </div>
    </div>

    <!-- 预订记录 -->
    <div class="card mb-4 tab-pane" id="booking-list" style="display: none;">
        <div class="card-header">
            <h3>门票预订记录</h3>
        </div>
        <div class="card-body">
            <?php if (count($bookings) > 0): ?>
                <div class="table-responsive">
                    <table class="table table-striped">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>客人</th>
                                <th>门票</th>
                                <th>日期</th>
                                <th>数量</th>
                                <th>总价</th>
                                <th>支付状态</th>
                                <th>订单状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($bookings as $booking): ?>
                                <tr>
                                    <td><?php echo $booking['id']; ?></td>
                                    <td>
                                        <?php echo htmlspecialchars($booking['guest_name']); ?><br>
                                        <small><?php echo htmlspecialchars($booking['guest_phone']); ?></small>
                                    </td>
                                    <td><?php echo htmlspecialchars($booking['service_name']); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($booking['service_date'])); ?></td>
                                    <td><?php echo $booking['quantity']; ?></td>
                                    <td>¥<?php echo number_format($booking['total_price'], 2); ?></td>
                                    <td>
                                        <span class="status-badge <?php echo $booking['payment_status']; ?>">
                                            <?php echo getPaymentStatusName($booking['payment_status']); ?>
                                        </span>
                                    </td>
                                    <td>
                                        <span class="status-badge <?php echo $booking['status']; ?>">
                                            <?php echo getBookingStatusName($booking['status']); ?>
                                        </span>
                                    </td>
                                    <td>
                                        <div class="dropdown">
                                            <button class="btn btn-sm btn-secondary dropdown-toggle" type="button" id="dropdownMenuButton" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                                操作
                                            </button>
                                            <div class="dropdown-menu" aria-labelledby="dropdownMenuButton">
                                                <h6 class="dropdown-header">订单状态</h6>
                                                <a class="dropdown-item" href="index.php?page=ticket&action=update_status&id=<?php echo $booking['id']; ?>&status=confirmed">确认订单</a>
                                                <a class="dropdown-item" href="index.php?page=ticket&action=update_status&id=<?php echo $booking['id']; ?>&status=completed">完成订单</a>
                                                <a class="dropdown-item" href="index.php?page=ticket&action=update_status&id=<?php echo $booking['id']; ?>&status=cancelled">取消订单</a>
                                                <div class="dropdown-divider"></div>
                                                <h6 class="dropdown-header">支付状态</h6>
                                                <a class="dropdown-item" href="index.php?page=ticket&action=update_payment&id=<?php echo $booking['id']; ?>&status=paid">标记为已支付</a>
                                                <a class="dropdown-item" href="index.php?page=ticket&action=update_payment&id=<?php echo $booking['id']; ?>&status=refunded">标记为已退款</a>
                                            </div>
                                        </div>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php else: ?>
                <div class="alert alert-info">暂无门票预订记录</div>
            <?php endif; ?>
        </div>
    </div>

    <!-- 预订门票 -->
    <div class="card mb-4 tab-pane" id="book-ticket" style="display: none;">
        <div class="card-header">
            <h3>预订门票</h3>
        </div>
        <div class="card-body">
            <?php if ($ticketCount > 0): ?>
                <form method="post" action="index.php?page=ticket">
                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="service_id">选择门票</label>
                            <select class="form-control" id="service_id" name="service_id" required>
                                <option value="">-- 请选择门票 --</option>
                                <?php foreach ($tickets as $t): ?>
                                    <?php if ($t['status'] == 'active'): ?>
                                        <option value="<?php echo $t['id']; ?>" data-price="<?php echo $t['price']; ?>">
                                            <?php echo htmlspecialchars($t['name']); ?> (¥<?php echo number_format($t['price'], 2); ?>)
                                        </option>
                                    <?php endif; ?>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="form-group col-md-6">
                            <label for="service_date">参观日期</label>
                            <input type="date" class="form-control" id="service_date" name="service_date" required min="<?php echo date('Y-m-d'); ?>">
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="guest_name">客人姓名</label>
                            <input type="text" class="form-control" id="guest_name" name="guest_name" required>
                        </div>
                        <div class="form-group col-md-6">
                            <label for="guest_phone">联系电话</label>
                            <input type="text" class="form-control" id="guest_phone" name="guest_phone" required>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-4">
                            <label for="quantity">数量</label>
                            <input type="number" class="form-control" id="quantity" name="quantity" min="1" value="1" required>
                        </div>
                        <div class="form-group col-md-4">
                            <label for="total_price">总价</label>
                            <div class="input-group">
                                <div class="input-group-prepend">
                                    <span class="input-group-text">¥</span>
                                </div>
                                <input type="text" class="form-control" id="total_price" readonly>
                            </div>
                        </div>
                        <div class="form-group col-md-4">
                            <label for="member_id">关联会员 (可选)</label>
                            <select class="form-control" id="member_id" name="member_id">
                                <option value="">-- 无关联会员 --</option>
                                <?php foreach ($members as $member): ?>
                                    <option value="<?php echo $member['id']; ?>">
                                        <?php echo htmlspecialchars($member['name']); ?> (<?php echo $member['phone']; ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>

                    <div class="form-group">
                        <label for="booking_id">关联住宿预订 (可选)</label>
                        <select class="form-control" id="booking_id" name="booking_id">
                            <option value="">-- 无关联住宿预订 --</option>
                            <?php foreach ($roomBookings as $rb): ?>
                                <option value="<?php echo $rb['id']; ?>">
                                    #<?php echo $rb['id']; ?> - <?php echo htmlspecialchars($rb['guest_name']); ?>
                                    (<?php echo date('Y-m-d', strtotime($rb['checkin_date'])); ?> 至
                                    <?php echo date('Y-m-d', strtotime($rb['checkout_date'])); ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="notes">备注</label>
                        <textarea class="form-control" id="notes" name="notes" rows="2"></textarea>
                    </div>

                    <button type="submit" name="book_ticket" class="btn btn-primary">预订门票</button>
                </form>
            <?php else: ?>
                <div class="alert alert-warning">
                    <p>暂无可用的门票信息。请先添加门票信息再进行预订。</p>
                    <button class="btn btn-primary mt-2" onclick="showAddTicket()">添加门票</button>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<script>
    $(document).ready(function() {
        // 初始化按钮点击事件
        $('.action-buttons .btn').on('click', function() {
            var action = $(this).attr('onclick');
            if (action) {
                // 提取函数名并直接调用
                var functionName = action.replace(/^(\w+)\(.*\)$/, '$1');
                if (typeof window[functionName] === 'function') {
                    window[functionName]();
                }
            }
            return false; // 阻止默认行为
        });

        // 根据URL参数显示相应的标签页
        <?php if (isset($_GET['action']) && $_GET['action'] == 'edit'): ?>
            showAddTicket();
        <?php else: ?>
            showTicketList();
        <?php endif; ?>

        // 计算总价
        $('#service_id, #quantity').change(function() {
            calculateTotal();
        });

        // 客人姓名从会员或预订中获取
        $('#member_id').change(function() {
            var selectedOption = $(this).find('option:selected');
            if (selectedOption.val() !== '') {
                var memberInfo = selectedOption.text().split(' (');
                $('#guest_name').val(memberInfo[0]);
                var phone = memberInfo[1].replace(')', '');
                $('#guest_phone').val(phone);
            }
        });

        $('#booking_id').change(function() {
            var selectedOption = $(this).find('option:selected');
            if (selectedOption.val() !== '') {
                var guestName = selectedOption.text().split(' - ')[1].split(' (')[0];
                $('#guest_name').val(guestName.trim());
            }
        });
    });

    function calculateTotal() {
        var price = $('#service_id option:selected').data('price') || 0;
        var quantity = $('#quantity').val() || 1;
        var total = price * quantity;
        $('#total_price').val(total.toFixed(2));
    }

    function showTicketList() {
        $('.tab-pane').hide();
        $('#ticket-list').show();
        $('.action-buttons button').removeClass('active');
        $('.action-buttons button:eq(0)').addClass('active');
    }

    function showAddTicket() {
        $('.tab-pane').hide();
        $('#add-ticket').show();
        $('.action-buttons button').removeClass('active');
        $('.action-buttons button:eq(1)').addClass('active');
    }

    function showBookingList() {
        $('.tab-pane').hide();
        $('#booking-list').show();
        $('.action-buttons button').removeClass('active');
        $('.action-buttons button:eq(2)').addClass('active');
    }

    function showBookTicket() {
        $('.tab-pane').hide();
        $('#book-ticket').show();
        $('.action-buttons button').removeClass('active');
        $('.action-buttons button:eq(3)').addClass('active');
        calculateTotal();
    }
</script>

<style>
    .action-buttons {
        display: flex;
        gap: 10px;
        margin-bottom: 20px;
    }

    .action-buttons button {
        flex: 1;
    }

    .action-buttons button.active {
        box-shadow: 0 0 0 3px rgba(0, 123, 255, 0.25);
    }

    .status-badge {
        display: inline-block;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 0.8rem;
    }

    .status-badge.active {
        background-color: #d4edda;
        color: #155724;
    }

    .status-badge.inactive {
        background-color: #f8d7da;
        color: #721c24;
    }

    .status-badge.pending {
        background-color: #fff3cd;
        color: #856404;
    }

    .status-badge.confirmed {
        background-color: #d1ecf1;
        color: #0c5460;
    }

    .status-badge.completed {
        background-color: #d4edda;
        color: #155724;
    }

    .status-badge.cancelled {
        background-color: #f8d7da;
        color: #721c24;
    }

    .status-badge.unpaid {
        background-color: #f8d7da;
        color: #721c24;
    }

    .status-badge.paid {
        background-color: #d4edda;
        color: #155724;
    }

    .status-badge.refunded {
        background-color: #f8d7da;
        color: #856404;
    }
</style>

<?php
function getBookingStatusName($status)
{
    $statuses = [
        'pending' => '待确认',
        'confirmed' => '已确认',
        'completed' => '已完成',
        'cancelled' => '已取消'
    ];
    return isset($statuses[$status]) ? $statuses[$status] : $status;
}

function getPaymentStatusName($status)
{
    $statuses = [
        'unpaid' => '未支付',
        'paid' => '已支付',
        'refunded' => '已退款'
    ];
    return isset($statuses[$status]) ? $statuses[$status] : $status;
}
?>